@@ -17,9 +17,6 @@ in=<file>       Primary input, or read 1 input.
 in2=<file>      Read 2 input if reads are in two files.
 out=<file>      Primary output, or read 1 output.
 out2=<file>     Read 2 output if reads are in two files.
-overwrite=f     (ow) Set to false to force the program to abort rather than
-                overwrite an existing file.
-showspeed=t     (ss) Set to 'f' to suppress display of processing speed.
 ziplevel=2      (zl) Set to 1 (lowest) through 9 (max) to change compression
                 level; lower compression is faster.
 
