@@ -3,14 +3,14 @@
 usage(){
 echo "
 Written by Brian Bushnell
-Last modified August 9, 2018
+Last modified September 9, 2019
 
 Description:  Looks at accessions to see how to compress them.
 
 Usage:  analyzeaccession.sh *accession2taxid.gz out=<output file>
 
 Parameters:
-lines=-1        If positive, stop after this many lines.
+perfile=t       Use multiple threads per file and multiple files at a time.
 
 Java Parameters:
 -Xmx            This will set Java's memory usage, overriding autodetection.
