@@ -3,7 +3,7 @@
 usage(){
 echo "
 Written by Brian Bushnell
-Last modified November 9, 2023
+Last modified November 18, 2024
 
 Description:  Compares reads to the kmers in a reference dataset, optionally 
 allowing an edit distance. Splits the reads into two outputs - those that 
@@ -24,6 +24,10 @@ ref=<file,file>     Comma-delimited list of reference files.
                     In addition to filenames, you may also use the keywords:
                     adapters, artifacts, phix, lambda, pjet, mtst, kapa
 literal=<seq,seq>   Comma-delimited list of literal reference sequences.
+                    Polymers are also allowed with the 'poly' prefix;
+                    for example, 'literal=ATGGT,polyGC' will add both ATGGT
+                    and GCGCGCGCGCGCGCGCGCGCGCGCGCGCGCGCGCGC - 32+ of them,
+                    enough replicates to ensure that all kmers are present.
 touppercase=f       (tuc) Change all bases upper-case.
 interleaved=auto    (int) t/f overrides interleaved autodetection.
                     Must be set mainually when streaming fastq input.
@@ -208,6 +212,9 @@ qtrim=f             Trim read ends to remove bases with quality below trimq.
 trimq=6             Regions with average quality BELOW this will be trimmed,
                     if qtrim is set to something other than f.  Can be a 
                     floating-point number like 7.3.
+quantize            Bin quality scores to reduce file size.  quantize=2 will
+                    eliminate all odd quality scores, while quantize=0,10,37
+                    will only allow qualty scores of 0, 10, or 37.
 trimclip=f          Trim soft-clipped bases from sam files.
 minlength=10        (ml) Reads shorter than this after trimming will be 
                     discarded.  Pairs will be discarded if both are shorter.
@@ -313,6 +320,23 @@ khist=<file>        Kmer frequency histogram; plots number of kmers versus
                     kmer depth.  This is approximate.
 khistout=<file>     Kmer frequency histogram for output reads.
 
+Side Channel:
+sideout=<file>      Output for aligned reads.
+sideref=phix        Reference for side-channel alignment; must be a single
+                    sequence and virtually repeat-free at selected k.
+sidek1=17           Kmer length for seeding alignment to reference.
+sidek2=13           Kmer length for seeding alignment of unaligned reads
+                    with an aligned mate.
+sideminid1=0.66     Minimum identity to accept individual alignments.
+sideminid2=0.58     Minimum identity for aligning reads with aligned mates.
+sidemm1=1           Middle mask length for sidek1.
+sidemm2=1           Middle mask length for sidek2.
+Note:  The side channel is a special additional output that allows alignment
+to a secondary reference while also doing trimming.  Alignment does not affect
+whether reads go to the normal outputs (out, outm).  The main purpose is to
+simplify pipelines that need trimmed, aligned phiX reads for recalibration.
+
+
 Java Parameters:
 
 -Xmx                This will set Java's memory usage, overriding autodetection.
