@@ -13,7 +13,7 @@ match the reference.
 Usage:  bloomfilter.sh in=<input file> out=<nonmatches> outm=<matches> ref=<reference>
 
 Example:
-bloomfilter.sh in=reads.fq outm=nonhuman.fq outm=human.fq k=31 minhits=3 ref=human.fa
+bloomfilter.sh in=reads.fq outm=nonhuman.fq out=human.fq k=31 minhits=3 ref=human.fa
 
 Error correction and depth filtering can be done simultaneously.
 
