@@ -3,7 +3,7 @@
 usage(){
 echo "
 Written by Brian Bushnell
-Last modified January 15, 2025
+Last modified January 10, 2025
 
 Description:  Sorts sequences to put similar reads near each other.
 Can be used for increased compression or error correction.
@@ -93,10 +93,6 @@ dedupe=f            Remove duplicate reads.  For pairs, both must match.
 markduplicates=f    Don't remove; just append ' duplicate' to the name.
 allduplicates=f     Mark or remove all copies of duplicates, instead of
                     keeping the highest-quality copy.
-umi=f               Set to true to require matching UMIs in read headers
-                    to consider reads as duplicates.  These are parsed from
-		    standard Illumina header format.
-umisubs=0           Maximum mismatches in UMIs to be considered matching.
 addcount=f          Append the number of copies to the read name.
                     Mutually exclusive with markduplicates or allduplicates.
 entryfilter=f       This assists in removing exact duplicates, which saves
@@ -108,6 +104,10 @@ subrate=0.0         (dsr) If set, the number of substitutions allowed will be
 allowns=t           No-called bases will not be considered substitutions.
 scanlimit=5         (scan) Continue for this many reads after encountering a
                     nonduplicate.  Improves detection of inexact duplicates.
+umi=f               If reads have UMIs in the headers, require them to match
+                    to consider the reads duplicates.
+umisubs=0           Consider UMIs as matching if they have up to this many
+                    mismatches.
 containment=f       Allow containments (where one sequence is shorter).
 affix=f             For containments, require one sequence to be an affix
                     (prefix or suffix) of the other.
