@@ -623,7 +623,7 @@ public final class BBIndexAcc extends AbstractIndex {
 		 * bestScores[4]	maxQuickScore
 		 * bestScores[5]	perfectsFound
 		 */
-		final int[] bestScores=new int[6];
+		final int[] bestScores=KillSwitch.allocInt1D(6);
 		
 		//This prevents filtering by qscore when a low-quality read only uses a few keys.
 		//In that case, extending is more important.
@@ -2611,7 +2611,7 @@ public final class BBIndexAcc extends AbstractIndex {
 	private final int[] startArray=new int[256];
 	private final int[] stopArray=new int[256];
 	private final Quad[] tripleStorage=makeQuadStorage(256);
-	private final int[] greedyReturn=new int[2];
+	private final int[] greedyReturn=KillSwitch.allocInt1D(2);
 	private final int[][] shrinkReturn2=new int[3][];
 	private final int[][] shrinkReturn3=new int[5][];
 	private final int[][] prescanReturn=new int[2][];
