@@ -527,7 +527,7 @@ public final ArrayList<SiteScore> find(byte[] basesP, byte[] basesM, byte[] qual
 		 * bestScores[4]	maxQuickScore
 		 * bestScores[5]	perfectsFound
 		 */
-		final int[] bestScores=new int[6];
+		final int[] bestScores=KillSwitch.allocInt1D(6);
 		
 		//This prevents filtering by qscore when a low-quality read only uses a few keys.
 		//In that case, extending is more important.
@@ -2416,7 +2416,7 @@ public final ArrayList<SiteScore> find(byte[] basesP, byte[] basesM, byte[] qual
 	private final int[] startArray=new int[HEAP_LENGTH];
 	private final int[] stopArray=new int[HEAP_LENGTH];
 	private final Quad[] tripleStorage=makeQuadStorage(HEAP_LENGTH);
-	private final int[] greedyReturn=new int[2];
+	private final int[] greedyReturn=KillSwitch.allocInt1D(2);
 	private final int[][] shrinkReturn2=new int[3][];
 	private final int[][] shrinkReturn3=new int[5][];
 	private final int[][] prescanReturn=new int[2][];
