@@ -9,7 +9,6 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.LinkedHashMap;
 import java.util.LinkedHashSet;
-import java.util.Locale;
 
 import dna.Data;
 import fileIO.FileFormat;
@@ -1222,10 +1221,10 @@ public class BBSplitter {
 		for(SetCount sc : list){
 			if(!nzo || sc.mappedReads>0 || sc.ambiguousReads>0 || sc.assignedReads>0){
 				sb.append(sc.name).append('\t');
-				sb.append(String.format(Locale.ROOT, "%.5f\t", sc.mappedReads*divR));
-				sb.append(String.format(Locale.ROOT, "%.6f\t", sc.mappedBases*divB));
-				sb.append(String.format(Locale.ROOT, "%.5f\t", sc.ambiguousReads*divR));
-				sb.append(String.format(Locale.ROOT, "%.6f\t", sc.ambiguousBases*divB));
+				sb.append(Tools.format("%.5f\t", sc.mappedReads*divR));
+				sb.append(Tools.format("%.6f\t", sc.mappedBases*divB));
+				sb.append(Tools.format("%.5f\t", sc.ambiguousReads*divR));
+				sb.append(Tools.format("%.6f\t", sc.ambiguousBases*divB));
 				sb.append(sc.mappedReads).append('\t');
 				sb.append(sc.ambiguousReads).append('\t');
 				sb.append(sc.assignedReads).append('\t');
