@@ -5,9 +5,9 @@ import java.util.ArrayList;
 
 import dna.Data;
 import fileIO.TextFile;
+import shared.Parse;
 import shared.PreParser;
 import shared.Shared;
-import shared.Tools;
 import stream.Read;
 
 /**
@@ -118,7 +118,7 @@ public class BBWrap {
 				add(b, bsList);
 				args[i]=null;
 			}else if(a.equals("append") || a.equals("app")){
-				append=Tools.parseBoolean(b);
+				append=Parse.parseBoolean(b);
 			}
 		}
 		
