@@ -1,10 +1,10 @@
 package align2;
 
 import java.io.File;
-import java.util.Locale;
 
 import fileIO.ReadWrite;
 import shared.Parse;
+import shared.Tools;
 
 public class PrintTime {
 	
@@ -25,9 +25,9 @@ public class PrintTime {
 				long old=Long.parseLong(s);
 				long elapsed=millis-old;
 				if(args.length<2 || Parse.parseBoolean(args[1])){
-					System.out.println("Elapsed:\t"+String.format(Locale.ROOT, "%.2f", elapsed/1000d));
+					System.out.println("Elapsed:\t"+Tools.format("%.2f", elapsed/1000d));
 					if(true){
-						System.err.println("Elapsed:\t"+String.format(Locale.ROOT, "%.2f", elapsed/1000d));
+						System.err.println("Elapsed:\t"+Tools.format("%.2f", elapsed/1000d));
 					}
 				}
 			}
