@@ -1,7 +1,6 @@
 package align2;
 
 import java.util.Arrays;
-import java.util.Locale;
 import java.util.Random;
 
 import dna.AminoAcid;
@@ -91,7 +90,7 @@ public class QualityTools {
 		
 		time=System.nanoTime()-time;
 		float seconds=(float)(time/1000000000d);
-		System.out.println("Bench Time: "+String.format(Locale.ROOT, "%.3f",seconds)+" s");
+		System.out.println("Bench Time: "+Tools.format("%.3f",seconds)+" s");
 	}
 	
 	public static void bench2(int length, int rounds){
@@ -111,7 +110,7 @@ public class QualityTools {
 		
 		time=System.nanoTime()-time;
 		float seconds=(float)(time/1000000000d);
-		System.out.println("Bench2 Time: "+String.format(Locale.ROOT, "%.3f",seconds)+" s");
+		System.out.println("Bench2 Time: "+Tools.format("%.3f",seconds)+" s");
 	}
 	
 	public static int[] makeKeyScores(byte[] qual, byte[] bases, int keylen, int range, int baseScore, int[] out, boolean useModulo){
@@ -485,11 +484,6 @@ public class QualityTools {
 	/*-------------------- Constants --------------------*/
 
 	/*-------------------- Initializers --------------------*/
-	
-	private static final double phredToProbError(int phred){
-		if(phred<1){return 1;}
-		return Math.pow(10, 0-.1*phred);
-	}
 
 	public static float[] phredToProbError(float[] trimq){
 		if(trimq==null){return null;}
