@@ -1048,7 +1048,7 @@ public final class RandomReads3 {
 			int max=slens.length;
 			scafProbs[chrom]=new double[max];
 			for(int snum=0; snum<max; snum++){
-				double d=exponential(randy, 2.5);
+				double d=sortOfExponential(randy, 2.5);
 				scafProbs[chrom][snum]=d;
 				sum+=d;
 //				outstream.println("d="+d+", sum="+sum);
@@ -1072,8 +1072,10 @@ public final class RandomReads3 {
 		}
 	}
 	
-	public static double exponential(Random rand, double width){
-		double d=rand.nextDouble();
+	public static double sortOfExponential(Random rand, double width){
+		//I changed to mid of 3 to reduce the amount of extreme values
+		//Extreme values left some things totally uncovered which was annoying
+		double d=Tools.mid(rand.nextDouble(), rand.nextDouble(), rand.nextDouble());
 		d=d*width-width+1;
 		double exp=Math.pow(10, d)/10;
 		return exp;
@@ -1101,6 +1103,7 @@ public final class RandomReads3 {
 		}else{
 			start=loc+randy.nextInt(scaflen-readlen);
 		}
+//		assert(false) : start+", "+readlen;
 		return new int[] {chrom, start, readlen};
 	}
 	
