@@ -23,13 +23,16 @@ public class MicroAligner3 implements MicroAligner {
 	/*----------------        Initialization        ----------------*/
 	/*--------------------------------------------------------------*/
 	
-	public MicroAligner3(MicroIndex3 index_, float minIdentity_) {
+	public MicroAligner3(MicroIndex3 index_, float minIdentity_, boolean shared_) {
 		index=index_;
 		minIdentity=minIdentity_;
 		maxSubFraction=1-minIdentity;
 		k=index.k;
 		k2=k-1;
 		middleMask=index.middleMask;
+		shared=shared_;
+		myBuffer=(shared ? null : new ByteBuilder());
+		mySSA=(shared ? null : new SingleStateAlignerFlat2());
 	}
 	
 	/*--------------------------------------------------------------*/
@@ -79,7 +82,7 @@ public class MicroAligner3 implements MicroAligner {
 		}
 		assert(!r.mapped());
 		
-		SingleStateAlignerFlat2 ssa=GeneCaller.getSSA();
+		SingleStateAlignerFlat2 ssa=getSSA();
 		a=Tools.max(0, a-pad);
 		b=Tools.min(ref.length-1, b+pad);
 		int[] max=ssa.fillUnlimited(r.bases, ref, a, b, 0);
@@ -112,7 +115,7 @@ public class MicroAligner3 implements MicroAligner {
 	/** Returns identity (approx, in the case of Ns) */
 	public float quickAlign(Read read, byte[] ref, int a, float minid) {
 		byte[] bases=read.bases;
-		ByteBuilder buffer=buffer();
+		ByteBuilder buffer=getBuffer();
 		buffer.clear();
 		int subs=0, ns=0;
 		for(int i=0, j=a; i<bases.length; i++, j++) {
@@ -148,6 +151,16 @@ public class MicroAligner3 implements MicroAligner {
 	/*----------------           Getters            ----------------*/
 	/*--------------------------------------------------------------*/
 	
+	private final SingleStateAlignerFlat2 getSSA() {
+		if(!shared) {return mySSA;}
+		return GeneCaller.getSSA();
+	}
+	
+	private final ByteBuilder getBuffer() {
+		if(!shared) {return myBuffer;}
+		return buffer();
+	}
+	
 	private static final ByteBuilder buffer() {
 		ByteBuilder buffer=bufferHolder.get();
 		if(buffer==null) {
@@ -169,6 +182,9 @@ public class MicroAligner3 implements MicroAligner {
 	final int k2;
 	final long middleMask;
 	final MicroIndex3 index;
+	final SingleStateAlignerFlat2 mySSA;
+	final ByteBuilder myBuffer;
+	final boolean shared;
 	
 	/*--------------------------------------------------------------*/
 	/*----------------            Statics           ----------------*/
