@@ -1,8 +1,6 @@
 package aligner;
 
 import java.util.ArrayList;
-import java.util.concurrent.atomic.AtomicLong;
-
 import dna.Data;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
@@ -46,8 +44,8 @@ public class SideChannel3 {
 		final Read r=MicroIndex3.loadRef(ref, samOut);
 		index1=new MicroIndex3(k1, midMaskLen1, r);
 		index2=(k2<1 ? null : new MicroIndex3(k2, midMaskLen2, r));
-		mapper1=new MicroAligner3(index1, minIdentity1);
-		mapper2=(k2<1 ? null : new MicroAligner3(index2, minIdentity2));
+		mapper1=new MicroAligner3(index1, minIdentity1, true);
+		mapper2=(k2<1 ? null : new MicroAligner3(index2, minIdentity2, true));
 
 		if(samOut) {ReadStreamByteWriter.USE_ATTACHED_SAMLINE=true;}
 		final int buff=(!ordered ? 12 : Tools.max(32, 2*Shared.threads()));
@@ -257,13 +255,13 @@ public class SideChannel3 {
 		return ret;
 	}
 	
-	private static float fixID(float id) {
+	static float fixID(float id) {
 		if(id>1) {id=id/100;}
 		assert(id<=1);
 		return id;
 	}
 	
-	private static String fixRefPath(String refPath) {
+	static String fixRefPath(String refPath) {
 		if(refPath==null || Tools.isReadableFile(refPath)) {return refPath;}
 		if("phix".equalsIgnoreCase(refPath)){return Data.findPath("?phix2.fa.gz");}
 		return refPath;
