@@ -2,6 +2,7 @@ package assemble;
 
 import java.util.ArrayList;
 
+import shared.KillSwitch;
 import stream.ConcurrentReadInputStream;
 import structures.ByteBuilder;
 import structures.LongList;
@@ -25,8 +26,8 @@ abstract class AbstractBuildThread extends Thread {
 	final int mode;
 	int minCountSeedCurrent;
 
-	final int[] leftCounts=new int[4];
-	final int[] rightCounts=new int[4];
+	final int[] leftCounts=KillSwitch.allocInt1D(4);
+	final int[] rightCounts=KillSwitch.allocInt1D(4);
 	final ByteBuilder builderT=new ByteBuilder();
 //	final Contig tempContig=new Contig(null);
 	
