@@ -636,9 +636,13 @@ public class BubblePopper {
 				}
 			}
 		}
-		if(verbose){System.err.println("Mid nodes concur.");}
-		assert(leftDest<0 || leftDest==center.id);
+		if(leftDest>=0 && leftDest!=center.id){return false;}//workaround for actual assertion failure
+		assert(leftDest<0 || leftDest==center.id) : 
+			leftDest+", "+center.id; //TODO: This triggered once nondeterministially; determine why
+		if(rightDest>=0 && rightDest!=center.id){return false;}//workaround for potential assertion failure
 		assert(rightDest<0 || rightDest==dest.id);
+		
+		if(verbose){System.err.println("Mid nodes concur.");}
 		return leftDest>=0 && rightDest>=0;
 	}
 	
