@@ -171,7 +171,7 @@ public class Shaver1 extends Shaver {
 			final long x=rightMaxPos;
 			final long x2=AminoAcid.numberToComplement[rightMaxPos];
 			kmer=((kmer<<2)|(long)x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			
 			//Now consider the next kmer
 			key=toValue(kmer, rkmer);
@@ -304,7 +304,7 @@ public class Shaver1 extends Shaver {
 			final long x=rightMaxPos;
 			final long x2=AminoAcid.numberToComplement[rightMaxPos];
 			kmer=((kmer<<2)|(long)x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			
 			//Now consider the next kmer
 			key=toValue(kmer, rkmer);
