@@ -756,7 +756,7 @@ public abstract class Tadpole extends ShaveObject{
 		
 		{
 			String outContigs=out1.isEmpty() ? null : out1.get(0);
-			if(showStats && outContigs!=null && processingMode==contigMode && FileFormat.isFasta(ReadWrite.rawExtension(outContigs)) && !FileFormat.isStdio(outContigs)){
+			if(showStats && outContigs!=null && processingMode==contigMode && FileFormat.isFastaExt(ReadWrite.rawExtension(outContigs)) && !FileFormat.isStdio(outContigs)){
 				outstream.println();
 				jgi.AssemblyStats2.main(new String[] {"in="+outContigs, "printextended"});
 			}
