@@ -740,7 +740,7 @@ public class Tadpole1 extends Tadpole {
 				long x=rightMaxPos;
 				long x2=3-x;
 				kmer=((kmer<<2)|x)&mask;
-				rkmer=(rkmer>>>2)|(x2<<shift2);
+				rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			}
 			lastLength=length;
 			lastTarget=owner;
@@ -857,7 +857,7 @@ public class Tadpole1 extends Tadpole {
 			
 			//Now consider the next kmer
 			kmer=((kmer<<2)|(long)x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			
 			assert(tables.getCount(kmer, rkmer)==rightMax);
 			count=rightMax;
@@ -912,7 +912,7 @@ public class Tadpole1 extends Tadpole {
 				final long x=AminoAcid.baseToNumber[b];
 				final long x2=AminoAcid.baseToComplementNumber[b];
 				kmer=((kmer<<2)|x)&mask;
-				rkmer=(rkmer>>>2)|(x2<<shift2);
+				rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 				if(x<0){
 					len=0;
 					kmer=rkmer=0;
@@ -1001,7 +1001,7 @@ public class Tadpole1 extends Tadpole {
 			
 			//Now consider the next kmer
 			kmer=((kmer<<2)|(long)x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			
 			key=toValue(kmer, rkmer);
 			table=tables.getTableForKey(key);
@@ -1104,7 +1104,7 @@ public class Tadpole1 extends Tadpole {
 				final long x=AminoAcid.baseToNumber[b];
 				final long x2=AminoAcid.baseToComplementNumber[b];
 				kmer=((kmer<<2)|x)&mask;
-				rkmer=(rkmer>>>2)|(x2<<shift2);
+				rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 				if(x<0){
 					len=0;
 					kmer=rkmer=0;
@@ -1188,7 +1188,7 @@ public class Tadpole1 extends Tadpole {
 			
 			//Now consider the next kmer
 			kmer=((kmer<<2)|(long)x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			
 			key=toValue(kmer, rkmer);
 			table=tables.getTableForKey(key);
@@ -1282,7 +1282,7 @@ public class Tadpole1 extends Tadpole {
 				final long x=AminoAcid.baseToNumber[b];
 				final long x2=AminoAcid.baseToComplementNumber[b];
 				kmer=((kmer<<2)|x)&mask;
-				rkmer=(rkmer>>>2)|(x2<<shift2);
+				rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 				if(x<0){
 					len=0;
 					kmer=rkmer=0;
@@ -1307,7 +1307,7 @@ public class Tadpole1 extends Tadpole {
 				final long x=AminoAcid.baseToNumber[b];
 				final long x2=AminoAcid.baseToComplementNumber[b];
 				kmer=((kmer<<2)|x)&mask;
-				rkmer=(rkmer>>>2)|(x2<<shift2);
+				rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 				if(x<0){
 					len=0;
 					kmer=rkmer=0;
@@ -1365,7 +1365,7 @@ public class Tadpole1 extends Tadpole {
 				final long x=AminoAcid.baseToNumber[b];
 				final long x2=AminoAcid.baseToComplementNumber[b];
 				kmer=((kmer<<2)|x)&mask;
-				rkmer=(rkmer>>>2)|(x2<<shift2);
+				rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 				if(x<0){
 					len=0;
 					kmer=rkmer=0;
@@ -1787,7 +1787,7 @@ public class Tadpole1 extends Tadpole {
 
 				//Now consider the next kmer
 				kmer=((kmer<<2)|(long)x)&mask;
-				rkmer=(rkmer>>>2)|(x2<<shift2);
+				rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 				len++;
 
 				if(verbose){
