@@ -1,7 +1,6 @@
 package barcode;
 
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
@@ -418,6 +417,38 @@ public class Barcode implements Comparable<Barcode> {
 		return 0;//No delimiter or multiple delimiters
 	}
 	
+	public static int countPolymers(String code) {
+		int delimiter=code.length();
+		for(int i=0; i<code.length(); i++) {
+			if(!Tools.isLetter(code.charAt(i))){delimiter=i; break;}
+		}
+		
+		int polymers=0;
+		{
+			int same=0, len=0;
+			char last=0;
+			for(int i=0; i<delimiter; i++) {
+				char c=code.charAt(i);
+				same+=(c==last ? 1 : 0);
+				len++;
+				last=c;
+			}
+			polymers+=(len>1 && same>=len-1) ? 1 : 0;
+		}
+		{
+			int same=0, len=0;
+			char last=0;
+			for(int i=delimiter+1; i<code.length(); i++) {
+				char c=code.charAt(i);
+				same+=(c==last ? 1 : 0);
+				len++;
+				last=c;
+			}
+			polymers+=(len>1 && same>=len-1) ? 1 : 0;
+		}
+		return polymers; //0, 1, or 2.
+	}
+	
 	/*--------------------------------------------------------------*/
 	/*----------------            Fields            ----------------*/
 	/*--------------------------------------------------------------*/
