@@ -639,9 +639,9 @@ public class BarcodeStats {
 		if(polymerArray[2]>0) {sb.append("\n--polyG\t"+polymerArray[2]);}
 		if(polymerArray[3]>0) {sb.append("\n--polyT\t"+polymerArray[3]);}
 		if(barcodesPerRead>1 && !expectedCodeList.isEmpty()){
-			sb.append("\n-badPair\t"+pad(validArray[2])+"\t("+validArrayU[2]+" unique)"+"\t"+String.format("(%.4f)%%",badPairFraction));
-			sb.append("\n-singleMatch\t"+pad(validArray[1])+"\t("+validArrayU[1]+" unique)"+"\t"+String.format("(%.4f)%%",(float)(validArray[1]/(1.0*totalCodes))));
-			sb.append("\n-neitherMatch\t"+pad(validArray[0])+"\t("+validArrayU[0]+" unique)"+"\t"+String.format("(%.4f)%%",(float)(validArray[0]/(1.0*totalCodes))));
+			sb.append("\n-badPair\t"+pad(validArray[2])+"\t("+validArrayU[2]+" unique)"+"\t"+String.format("(%.4f)",badPairFraction));
+			sb.append("\n-singleMatch\t"+pad(validArray[1])+"\t("+validArrayU[1]+" unique)"+"\t"+String.format("(%.4f)",(float)(validArray[1]/(1.0*totalCodes))));
+			sb.append("\n-neitherMatch\t"+pad(validArray[0])+"\t("+validArrayU[0]+" unique)"+"\t"+String.format("(%.4f)",(float)(validArray[0]/(1.0*totalCodes))));
 		}
 		if(!expectedCodeList.isEmpty() && barcodesPerRead<2) {
 //			sb.append("\n-hDist 1,2,3+\t"+hdistSum(1,1)+", "+hdistSum(2,2)+", "+hdistSum(3,999));
