@@ -3,7 +3,6 @@ package barcode;
 import java.io.File;
 import java.io.PrintStream;
 import java.util.ArrayList;
-import java.util.Locale;
 
 import fileIO.ByteFile;
 import fileIO.ByteFile1;
@@ -84,7 +83,7 @@ public class CorrelateBarcodes {
 				mqhist=b;
 			}else if(a.equals("mmq")){//minimum min quality cutoff
 				minBarcodeMinQuality=Integer.parseInt(b);
-			}else if(parser.in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+			}else if(parser.in1==null && i==0 && Tools.looksLikeInputStream(arg)){
 				parser.in1=arg;
 			}else{
 				outstream.println("Unknown parameter "+args[i]);
@@ -310,7 +309,7 @@ public class CorrelateBarcodes {
 				long sum1=shared.Vector.sum(array1), sum2=shared.Vector.sum(array2);
 				double avg1=Tools.averageHistogram(array1), avg2=Tools.averageHistogram(array2);
 				double dev1=Tools.standardDeviationHistogram(array1), dev2=Tools.standardDeviationHistogram(array2);
-				tsw.print(String.format(Locale.ROOT, "%d\t%.1f\t%.1f\t%d\t%d\t%.1f\t%.1f\t%d\n", i, avg1, dev1, sum1, i, avg2, dev2, sum2));
+				tsw.print(Tools.format("%d\t%.1f\t%.1f\t%d\t%d\t%.1f\t%.1f\t%d\n", i, avg1, dev1, sum1, i, avg2, dev2, sum2));
 			}
 			tsw.poisonAndWait();
 			errorState|=tsw.errorState;
@@ -325,7 +324,7 @@ public class CorrelateBarcodes {
 			long y=0;
 			for(int i=0; i<aqhistArray.length; i++){
 				long x=aqhistArray[i];
-				tsw.print(String.format(Locale.ROOT, "%d\t%d\t%.5f\n", i, x, x*mult));
+				tsw.print(Tools.format("%d\t%d\t%.5f\n", i, x, x*mult));
 				y+=x;
 				if(y==sum){break;}
 			}
@@ -342,7 +341,7 @@ public class CorrelateBarcodes {
 			long y=0;
 			for(int i=0; i<mqhistArray.length; i++){
 				long x=mqhistArray[i];
-				tsw.print(String.format(Locale.ROOT, "%d\t%d\t%.5f\n", i, x, x*mult));
+				tsw.print(Tools.format("%d\t%d\t%.5f\n", i, x, x*mult));
 				y+=x;
 				if(y==sum){break;}
 			}
@@ -362,8 +361,8 @@ public class CorrelateBarcodes {
 		
 		if(minBarcodeAverageQuality>0){
 			outstream.println();
-			outstream.println("Reads Discarded:    "+readsTossed+" \t"+String.format(Locale.ROOT, "%.3f%%",readsTossed*100.0/readsProcessed));
-			outstream.println("Reads Discarded:    "+basesTossed+" \t"+String.format(Locale.ROOT, "%.3f%%",basesTossed*100.0/basesProcessed));
+			outstream.println("Reads Discarded:    "+readsTossed+" \t"+Tools.format("%.3f%%",readsTossed*100.0/readsProcessed));
+			outstream.println("Reads Discarded:    "+basesTossed+" \t"+Tools.format("%.3f%%",basesTossed*100.0/basesProcessed));
 		}
 		
 		if(errorState){
@@ -424,7 +423,7 @@ public class CorrelateBarcodes {
 	private PrintStream outstream=System.err;
 	public static boolean verbose=false;
 	public boolean errorState=false;
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	private boolean append=false;
 	
 }
