@@ -102,7 +102,7 @@ public class CountBarcodes {
 				}
 			}else if(a.equals("counts") || a.equals("outc")){
 				outCounts=b;
-			}else if(parser.in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+			}else if(parser.in1==null && i==0 && Tools.looksLikeInputStream(arg)){
 				parser.in1=arg;
 			}else if(parser.out1==null && i==1 && !arg.contains("=")){
 				parser.out1=arg;
@@ -417,7 +417,7 @@ public class CountBarcodes {
 	private PrintStream outstream=System.err;
 	public static boolean verbose=false;
 	public boolean errorState=false;
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	private boolean append=false;
 	
 }
