@@ -174,30 +174,38 @@ public class CountBarcodes2 {
 				minCount0=Long.parseLong(b);
 			}else if(a.equals("mincountpercent") || a.equals("mincountpercentile")){
 				minCountPercentile=Float.parseFloat(b);
-			}else if(a.equals("transitions") || a.equals("errors") || a.equals("substitutions")){
-				transitionsOut=b;
-			}else if(a.equals("matrixout") || a.equals("countmatrix") || a.equals("outmatrix")){
-				matrixOut=b;
 			}else if(a.equals("pcrmatrix") || a.equals("usematrix") || a.equals("matrix")){
 				useMatrix=Parse.parseBoolean(b);
-			}else if(a.equals("probsout") || a.equals("outprobs")){
-				probsOut=b;
 			}else if(a.equals("client") || a.equals("server") || a.equals("useserver")){
 				useServer=Parse.parseBoolean(b);
+			}
+			
+			else if(a.equals("probsout") || a.equals("outprobs")){
+				probsOut=b;
+			}else if(a.equals("accuracyout") || a.equals("outaccuracy")){
+				accuracyOut=b;
 			}else if(a.equals("mapout") || a.equals("outmap")){
 				mapOut=b;
 			}else if(a.equals("barcodesout") || a.equals("outbarcodes")){
 				barcodesOut=b;
 			}else if(a.equals("contamout") || a.equals("outcontam")){
 				contamOut=b;
-			}else if(a.equals("quantifysource")){
+			}else if(a.equals("transitions") || a.equals("errors") || a.equals("substitutions")){
+				transitionsOut=b;
+			}else if(a.equals("matrixout") || a.equals("countmatrix") || a.equals("outmatrix")){
+				matrixOut=b;
+			}else if(a.equalsIgnoreCase("printStats")) {
+				printStats=Parse.parseBoolean(b);
+			}else if(a.equalsIgnoreCase("excludeUnknownInAccuracy")) {
+				excludeUnknownInAccuracy=Parse.parseBoolean(b);
+			}
+			
+			else if(a.equals("quantifysource")){
 				quantifySource=Parse.parseBoolean(b);
 			}else if(a.equals("quantifysink")){
 				quantifySource=!Parse.parseBoolean(b);
 			}else if(a.equals("quantset")){
 				quantSetFile=b;
-			}else if(a.equalsIgnoreCase("printStats")) {
-				printStats=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equals("parse_flag_goes_here")){
@@ -340,7 +348,8 @@ public class CountBarcodes2 {
 			ReadWrite.writeString(bb, transitionsOut);
 		}
 		
-		if(matrixOut!=null || probsOut!=null || mapOut!=null || barcodesOut!=null || useMatrix) {
+		if(matrixOut!=null || probsOut!=null || accuracyOut!=null || 
+				mapOut!=null || barcodesOut!=null || useMatrix) {
 			assert(!bs.expectedCodeList.isEmpty()) : 
 				"For matrix output expected barcodes are required.";
 			Timer t2=new Timer();
@@ -403,6 +412,11 @@ public class CountBarcodes2 {
 						ReadWrite.writeString(bb, probsOut);
 					}
 					
+					if(accuracyOut!=null) {
+						ByteBuilder bb=pcrMatrix.toAccuracy(null, excludeUnknownInAccuracy);
+						ReadWrite.writeString(bb, accuracyOut);
+					}
+					
 //					pcrMatrix=null;
 				}
 			}
@@ -830,12 +844,14 @@ public class CountBarcodes2 {
 	private String transitionsOut=null;
 	private String matrixOut=null;
 	private String probsOut=null;
+	private String accuracyOut=null;
 	private String mapOut=null;
 	private String barcodesOut=null;
 	private String contamOut=null;
 	private String quantSetFile=null;
 	private boolean quantifySource=false;
-
+	private boolean excludeUnknownInAccuracy=true;
+	
 	private boolean useServer=false;
 	private boolean setUseServer=false;
 	
