@@ -601,6 +601,10 @@ public abstract class PCRMatrix {
 		return toBytes(counts, bb);
 	}
 	
+	public ByteBuilder toAccuracy(ByteBuilder bb, boolean excludeUnknown) {
+		return toAccuracy(counts, bb, excludeUnknown);
+	}
+	
 	public boolean byTile() {return false;}
 	public abstract ByteBuilder toBytesProb(ByteBuilder bb);
 	
@@ -641,6 +645,53 @@ public abstract class PCRMatrix {
 		return bb;
 	}
 	
+	public static final ByteBuilder toAccuracy(long[][][] counts, ByteBuilder bb, boolean excludeUnknown) {
+		if(bb==null) {bb=new ByteBuilder();}
+
+		bb.append("#pos\tA_call\tC_call\tG_call\tT_call\tA_ref\tC_ref\tG_ref\tT_ref\n");
+		for(int pos=0; pos<counts.length; pos++) {
+			long[] refCount=new long[5];
+			long[] callCount=new long[5];
+			long[] unknown=new long[5];
+			long[] callCorrect=new long[5];
+			long[] refCorrect=new long[5];
+			long sum=0;
+			for(int xc=0; xc<5; xc++) {
+				for(int xr=0; xr<5; xr++) {
+					final long count=counts[pos][xc][xr];
+					refCount[xr]+=count;
+					callCount[xc]+=count;
+					sum+=count;
+					if(xc==xr) {
+						refCorrect[xr]+=count;
+						callCorrect[xc]+=count;
+					}
+					if(xr==4) {unknown[xc]=count;}
+				}
+			}
+			if(sum>refCount[4]) {
+				bb.append(pos);
+				for(int i=0; i<4; i++) {
+					long count=callCount[i], correct=callCorrect[i];
+					if(excludeUnknown) {count-=unknown[i];}
+					double accuracy=(count<1 ? 1 : correct/(double)count);
+					bb.tab().append(accuracy, 4);
+//					assert(false) : "\ncount="+count+", correct="+correct
+//						+", cc4="+callCount[4]+", acc="+accuracy
+//						+"\ncounts="+Arrays.toString(callCount)
+//						+"\ncorrects="+Arrays.toString(callCorrect);
+				}
+				for(int i=0; i<4; i++) {
+					long count=refCount[i], correct=refCorrect[i];
+					double accuracy=(count<1 ? 1 : correct/(double)count);
+					bb.tab().append(accuracy, 4);
+				}
+				bb.nl();
+			}
+		}
+		return bb;
+	}
+	
 	private static String poly(char c, int len) {
 		ByteBuilder bb=new ByteBuilder(len);
 		for(int i=0; i<len; i++) {bb.append(c);}
