@@ -36,6 +36,8 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 		
 		else if(a.equalsIgnoreCase("perfectoracle")){
 			PERFECT_ORACLE=Parse.parseBoolean(b);
+		}else if(a.equalsIgnoreCase("banbadmerges")){
+			BAN_BAD_MERGES=Parse.parseBoolean(b);
 		}
 		
 		else if(a.equalsIgnoreCase("basePasses")){
@@ -45,9 +47,31 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 		}else if(a.equalsIgnoreCase("residueRange")){
 			residueRange=Integer.parseInt(b);
 		}
+		
+		else if(a.equalsIgnoreCase("prepass") || a.equalsIgnoreCase("passAA")){
+			runPassAA=Parse.parseBoolean(b);
+		}else if(a.equalsIgnoreCase("runPassA") || a.equalsIgnoreCase("passA")){
+			runPassA=Parse.parseBoolean(b);
+		}else if(a.equalsIgnoreCase("runPassB") || a.equalsIgnoreCase("passB")){
+			runPassB=Parse.parseBoolean(b);
+		}else if(a.equalsIgnoreCase("runPassC") || a.equalsIgnoreCase("passC")){
+			runPassC=Parse.parseBoolean(b);
+		}else if(a.equalsIgnoreCase("runPassD") || a.equalsIgnoreCase("passD")){
+			runPassD=Parse.parseBoolean(b);
+		}else if(a.equalsIgnoreCase("runPassE") || a.equalsIgnoreCase("passE")){
+			runPassE=Parse.parseBoolean(b);
+		}else if(a.equalsIgnoreCase("runPassF") || a.equalsIgnoreCase("passF")){
+			runPassF=Parse.parseBoolean(b);
+		}else if(a.equalsIgnoreCase("runPassG") || a.equalsIgnoreCase("passG")){
+			runPassG=Parse.parseBoolean(b);
+		}
 
-		else if(a.equalsIgnoreCase("maxDif1") || a.equalsIgnoreCase("maxKmerDif1")){
+		else if(a.equalsIgnoreCase("maxTrimerDif1") || a.equalsIgnoreCase("max3merDif1")){
+			maxTrimerDif1=Float.parseFloat(b);
+		}else if(a.equalsIgnoreCase("maxDif1") || a.equalsIgnoreCase("maxKmerDif1")){
 			maxKmerDif1=Float.parseFloat(b);
+		}else if(a.equalsIgnoreCase("maxPentamerDif1") || a.equalsIgnoreCase("max5merDif1")){
+			max5merDif1=Float.parseFloat(b);
 		}else if(a.equalsIgnoreCase("maxRatio1") || a.equalsIgnoreCase("maxDepthRatio1")){
 			maxDepthRatio1=Float.parseFloat(b);
 		}else if(a.equalsIgnoreCase("maxGCDif1")){
@@ -56,14 +80,27 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 			maxCovariance1=Float.parseFloat(b);
 		}
 		
-		else if(a.equalsIgnoreCase("maxDif2") || a.equalsIgnoreCase("maxKmerDif2")){
+		else if(a.equalsIgnoreCase("maxTrimerDif2") || a.equalsIgnoreCase("maxTrimerDif") || 
+				a.equalsIgnoreCase("max3merDif")){
+			maxTrimerDif2=Float.parseFloat(b);
+		}else if(a.equalsIgnoreCase("maxKmerDif2") || a.equalsIgnoreCase("maxKmerDif")  || 
+				a.equalsIgnoreCase("max4merDif")){
 			maxKmerDif2=Float.parseFloat(b);
-		}else if(a.equalsIgnoreCase("maxRatio2") || a.equalsIgnoreCase("maxDepthRatio2")){
+		}else if(a.equalsIgnoreCase("maxPentamerDif2") || a.equalsIgnoreCase("maxPentamerDif") || 
+				a.equalsIgnoreCase("max5merDif")){
+			max5merDif2=Float.parseFloat(b);
+		}else if(a.equalsIgnoreCase("maxDepthRatio2") || a.equalsIgnoreCase("maxDepthRatio")){
 			maxDepthRatio2=Float.parseFloat(b);
-		}else if(a.equalsIgnoreCase("maxGCDif2")){
+		}else if(a.equalsIgnoreCase("maxGCDif2") || a.equalsIgnoreCase("maxGCDif")){
 			maxGCDif2=Float.parseFloat(b);
-		}else if(a.equalsIgnoreCase("maxCovariance2")){
+		}else if(a.equalsIgnoreCase("maxCovariance2") || a.equalsIgnoreCase("maxCovariance")){
 			maxCovariance2=Float.parseFloat(b);
+		}else if(a.equalsIgnoreCase("minkmerprob") || a.equalsIgnoreCase("minkmerprob2")){
+			minKmerProb2=Float.parseFloat(b);
+		}
+		
+		else if(a.equalsIgnoreCase("minSimilarity")){
+			minSimilarity=Float.parseFloat(b);
 		}
 		
 		else if(a.equalsIgnoreCase("depthBoost")){
@@ -85,10 +122,18 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 //			minSizeToAdd=Parse.parseIntKMG(b);
 		}else if(a.equalsIgnoreCase("minSizeResidue") || a.equalsIgnoreCase("minResidue")){
 			minSizeResidue=Parse.parseIntKMG(b);
+		}else if(a.equalsIgnoreCase("minNetSize")){
+			minNetSize=Parse.parseIntKMG(b);
+		}else if(a.equalsIgnoreCase("midNetSize")){
+			midNetSize=Parse.parseIntKMG(b);
+		}else if(a.equalsIgnoreCase("largeNetSize")){
+			largeNetSize=Parse.parseIntKMG(b);
 		}
 		
 		else if(a.equalsIgnoreCase("residueStringency")){
 			residueStringency=Float.parseFloat(b);
+		}else if(a.equalsIgnoreCase("purifyStringency")){
+			purifyStringency=Float.parseFloat(b);
 		}else if(a.equalsIgnoreCase("smallthresh")){
 			smallThresh=Parse.parseIntKMG(b);
 		}else if(a.equalsIgnoreCase("smallmult")){
@@ -113,6 +158,16 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 			minEdgeWeight=Integer.parseInt(b);
 		}else if(a.equalsIgnoreCase("minEdgeRatio")){
 			minEdgeRatio=Float.parseFloat(b);
+		}else if(a.equalsIgnoreCase("reciprocalEdges")){
+			reciprocalEdges=Boolean.parseBoolean(b);
+		}
+		
+		else if(a.equalsIgnoreCase("fuseLowerLimit")){
+			fuseLowerLimit=Parse.parseIntKMG(b);
+		}else if(a.equalsIgnoreCase("fuseUpperLimit")){
+			fuseUpperLimit=Parse.parseIntKMG(b);
+		}else if(a.equalsIgnoreCase("fuseStringency")){
+			fuseStringency=Float.parseFloat(b);
 		}
 		
 		else if(a.equalsIgnoreCase("lowDepthEdgeRatio")){
@@ -121,6 +176,35 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 			highDepthEdgeRatio=Float.parseFloat(b);
 		}else if(a.equalsIgnoreCase("goodEdgeMult")){
 			goodEdgeMult=Float.parseFloat(b);
+		}else if(a.equalsIgnoreCase("transEdgeMult") || a.equalsIgnoreCase("goodTransEdgeMult") || 
+				a.equalsIgnoreCase("goodTransitiveEdgeMult")){
+			goodTransEdgeMult=Float.parseFloat(b);
+		}
+		
+		else if(a.equals("netcutoff") || a.equals("cutoff")) {
+			netCutoff_small=netCutoff_mid=netCutoff_large=Float.parseFloat(b);
+		}else if(a.equals("cutoffsmall") || a.equals("smallcutoff")) {
+			netCutoff_small=Float.parseFloat(b);
+		}else if(a.equals("cutoffmid") || a.equals("midcutoff")) {
+			netCutoff_mid=Float.parseFloat(b);
+		}else if(a.equals("cutofflarge") || a.equals("largecutoff")) {
+			netCutoff_large=Float.parseFloat(b);
+		}else if(a.equals("netcutoffupper") || a.equals("cutoffupper") || a.equals("cutoff2")) {
+			netCutoffUpper=Float.parseFloat(b);
+		}else if(a.equals("netcutofflower") || a.equals("cutofflower")) {
+			netCutoffLower=Float.parseFloat(b);
+		}else if(a.equalsIgnoreCase("netMultUpper")) {
+			netMultUpper=Float.parseFloat(b);
+		}else if(a.equalsIgnoreCase("netMultLower")) {
+			netMultLower=Float.parseFloat(b);
+		}else if(a.equalsIgnoreCase("cutoffMultA")){
+			cutoffMultA=Float.parseFloat(b);
+		}else if(a.equalsIgnoreCase("cutoffMultB")){
+			cutoffMultB=Float.parseFloat(b);
+		}else if(a.equalsIgnoreCase("cutoffMultC")){
+			cutoffMultC=Float.parseFloat(b);
+		}else if(a.equalsIgnoreCase("cutoffMultD")){
+			cutoffMultD=Float.parseFloat(b);
 		}
 		
 //		else if(a.equalsIgnoreCase("mtcompare") || a.equalsIgnoreCase("comparemt")){
@@ -147,7 +231,7 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 		//This phase can be much slower than edge-following, presumably when clusters get big.
 		if(merges>0) {merges=mergeWithDest(contigs, input);}
 		
-		if(merges>0) {phaseTimer.stop("Merged "+merges+"/"+input.size()+" bins: \t");}
+		if(merges>0 && loud) {phaseTimer.stop("Merged "+merges+"/"+input.size()+" bins: \t");}
 		return merges;
 	}
 	
@@ -167,12 +251,14 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 				if(b.cluster()!=null) {b=b.cluster();}
 				if(!b.isEmpty() && !a.sameCluster(b)) {
 					if(a.labelTaxid>=0 && b.labelTaxid>=0) {
+						long minSize=Tools.min(a.size(), b.size());
+						addMerge(minSize, a.labelTaxid==b.labelTaxid);
 						if(a.labelTaxid==b.labelTaxid) {
 							goodMergesFollow++;
-							goodMergeSizeFollow+=(Tools.min(a.size(), b.size()));
+							goodMergeSizeFollow+=minSize;
 						}else {
 							badMergesFollow++;
-							badMergeSizeFollow+=(Tools.min(a.size(), b.size()));
+							badMergeSizeFollow+=minSize;
 						}
 					}
 					assert(b.isValid());
@@ -210,17 +296,22 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 		return clustered;
 	}
 	
-	public static final ArrayList<Bin> toBinList(ArrayList<? extends Bin> list){
+	public static final ArrayList<Bin> toBinList(ArrayList<? extends Bin> list, int minSize){
 		ArrayList<Bin> bins=new ArrayList<Bin>();
 		IntHashSet clusterSet=new IntHashSet(255);
 		for(Bin a : list) {
 			Cluster c=a.cluster();
+			long size=(c==null ? a.size() : c.size());
+			if(size<minSize) {continue;}
+			
 			if(c==null) {//Contig
 				bins.add(a);
 			}else if(!clusterSet.contains(c.id())){
 				bins.add(c);
 				clusterSet.add(c.id());
 			}
+//			Bin b=bins.get(bins.size()-1);
+//			assert(b.size()>=minSize);//123
 		}
 		return bins;
 	}
@@ -320,7 +411,8 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 		
 		float[] ret=new float[1];
 		float maxProduct=maxKmerDif1*maxDepthRatio1*Binner.productMult;
-		Oracle oracle=new Oracle(maxGCDif1, maxDepthRatio1, maxKmerDif1, maxProduct, maxCovariance1, 0);
+		Oracle oracle=new Oracle(maxGCDif1, maxDepthRatio1, maxTrimerDif1, maxKmerDif1, max5merDif1, maxProduct, 
+				maxCovariance1, minKmerProb2, 0);
 		for(Bin a : input) {
 			int initialContigs=a.numContigs();
 //			Cluster c=map.addOrMerge(a, minSizeToCompare*8, minSizeToMerge*4, minSizeToCompare,	
@@ -335,18 +427,21 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 				if(c.numContigs()==1) {
 					clustersCreated++;
 				}else if(c.labelTaxid>0 && a.labelTaxid>0) {
+					long minSize=Tools.min(a.size(), c.size());
+					addMerge(minSize, a.labelTaxid==c.labelTaxid);
 					goodMergesCreate+=(c.labelTaxid==a.labelTaxid) ? 1 : 0;
 					badMergesCreate+=(c.labelTaxid==a.labelTaxid) ? 0 : 1;
 					if(a.labelTaxid!=c.labelTaxid) {
-						badMergeSizeCreate+=Tools.min(a.size(), c.size());
+						badMergeSizeCreate+=minSize;
 					}else {
-						goodMergeSizeCreate+=(Tools.min(a.size(), c.size()));
+						goodMergeSizeCreate+=minSize;
 					}
 				}
 			}
 		}
 		fastComparisons.addAndGet(oracle.fastComparisons);
 		slowComparisons.addAndGet(oracle.slowComparisons);
+		netComparisons.addAndGet(oracle.netComparisons);
 		phaseTimer.stopAndPrint();
 		outstream.println("Made "+map.map.size()+" lists containing "+clustersCreated+
 				" clusters and "+contigsAdded+" contigs from "+contigList.size()+" elements.");
@@ -357,7 +452,9 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 			int taxlevel, boolean allowNoTaxID, boolean allowHalfTaxID, int range, int minSize) {
 //		System.err.println("Merging clusters pass.");
 		
+		float maxTrimerDif=maxTrimerDif2*stringency;
 		float maxKmerDif=maxKmerDif2*stringency;
+		float max5merDif=max5merDif2*stringency;
 		float maxDepthRatio=1+((maxDepthRatio2-1)*stringency);
 		float maxGCDif=maxGCDif2*stringency;
 		float maxProduct=maxKmerDif*maxDepthRatio*Binner.productMult;
@@ -377,7 +474,8 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 		
 		int merged=0;
 		
-		Oracle oracle=new Oracle(maxGCDif, maxDepthRatio, maxKmerDif, maxProduct, maxCovariance, 0);
+		Oracle oracle=new Oracle(maxGCDif, maxDepthRatio, maxTrimerDif, maxKmerDif, max5merDif, 
+				maxProduct, maxCovariance, minKmerProb2, 0);
 		launchThreads(clusters, map, null, REFINE_MODE, range, minSize, oracle.clone());
 		for(Cluster c : clusters) {
 			synchronized(c) {
@@ -403,12 +501,14 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 							assert(a.id()!=dest && a.id()!=b.id()) : a.id+", "+dest+", "+b.id+", "+(a.id()==dest)+", "+(b.id()==dest)+", "+(a.id()!=b.id());
 
 							if(a.labelTaxid>0 && b.labelTaxid>0) {
+								long smaller=Tools.min(a.size(), b.size());
+								addMerge(smaller, a.labelTaxid==b.labelTaxid);
 								goodMergesRefine+=(a.labelTaxid==b.labelTaxid) ? 1 : 0;
 								badMergesRefine+=(a.labelTaxid==b.labelTaxid) ? 0 : 1;
 								if(a.labelTaxid!=b.labelTaxid) {
-									badMergeSizeRefine+=Tools.min(a.size(), b.size());
+									badMergeSizeRefine+=smaller;
 								}else {
-									goodMergeSizeRefine+=(Tools.min(a.size(), b.size()));
+									goodMergeSizeRefine+=smaller;
 								}
 							}
 							b.add(a);
@@ -433,7 +533,9 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 	public int purify(BinMap map, float stringency, int range, int minSizePurify, int minSizeCompare) {
 //		System.err.println("Merging clusters pass.");
 		
+		float maxTrimerDif=maxTrimerDif2*stringency;
 		float maxKmerDif=maxKmerDif2*stringency;
+		float max5merDif=max5merDif2*stringency;
 		float maxDepthRatio=1+((maxDepthRatio2-1)*stringency);
 		float maxGCDif=maxGCDif2*stringency;
 		float maxProduct=maxKmerDif*maxDepthRatio*Binner.productMult;
@@ -459,7 +561,8 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 		
 		int removed=0;
 
-		Oracle oracle=new Oracle(maxGCDif, maxDepthRatio, maxKmerDif, maxProduct, maxCovariance, 0);
+		Oracle oracle=new Oracle(maxGCDif, maxDepthRatio, maxTrimerDif, maxKmerDif, max5merDif, 
+				maxProduct, maxCovariance, minKmerProb2*0.8f, 0);
 		oracle.useEdges=false;
 		launchThreads(clusters, map, null, PURIFY_MODE, range, minSizeCompare, oracle.clone());
 		for(Cluster clust : clusters) {
@@ -469,7 +572,7 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 		}
 		if(removed>0) {
 			map.clear(true);
-			ArrayList<Bin> bins=toBinList(map.contigList);
+			ArrayList<Bin> bins=toBinList(map.contigList, 0);
 			Collections.sort(bins);
 			Key key=new Key();
 			for(Bin b : bins) {
@@ -501,7 +604,7 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 				}
 			}
 			assert(clust.contigSet.contains(clust.id));
-			clust.fillNormDepth();
+			if(clust.numDepths()>1) {clust.fillNormDepth();}
 		}
 		return removed;
 	}
@@ -513,7 +616,9 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 		Timer t=new Timer(outstream, true);
 		if(map.residual.isEmpty()) {return 0;}
 		
+		float maxTrimerDif=maxTrimerDif2*stringency;
 		float maxKmerDif=maxKmerDif2*stringency;
+		float max5merDif=max5merDif2*stringency;
 		float maxDepthRatio=1+((maxDepthRatio2-1)*stringency);
 		float maxGCDif=maxGCDif2*stringency;
 		float maxProduct=maxKmerDif*maxDepthRatio*Binner.productMult;
@@ -523,11 +628,12 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 //				+", maxProduct="+maxProduct+", allowNoTaxID="+allowNoTaxID+", allowHalfTaxID="+allowHalfTaxID
 //				+", range="+range);
 		int merged=0;
-		map.residual=toBinList(map.residual);
+		map.residual=toBinList(map.residual, 0);
 //		assert(map.isValid());
 		
-		int minSize=Tools.max(minSizeToMerge, minBasesPerCluster/5);
-		Oracle oracle=new Oracle(maxGCDif, maxDepthRatio, maxKmerDif, maxProduct, maxCovariance, 0);
+		int minSize=Tools.max(minSizeToMerge, minClusterSize/5);
+		Oracle oracle=new Oracle(maxGCDif, maxDepthRatio, maxTrimerDif, maxKmerDif, max5merDif, 
+				maxProduct, maxCovariance, minKmerProb2, 0);
 		launchThreads(map.residual, map, null, RESIDUE_MODE, range, minSize, oracle);
 		for(Bin c : map.residual) {
 			synchronized(c) {
@@ -544,12 +650,14 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 				assert(a!=b) : "\n"+a.id()+"\n"+b.id()+"\n"+a.dest+"\n"+
 						a.getClass()+"\n"+b.getClass()+"\n"+b.contigSet.contains(a.id());
 				if(a.labelTaxid>0 && b.labelTaxid>0) {
+					long smaller=Tools.min(a.size(), b.size());
+					addMerge(smaller, a.labelTaxid==b.labelTaxid);
 					goodMergesResidue+=(a.labelTaxid==b.labelTaxid) ? 1 : 0;
 					badMergesResidue+=(a.labelTaxid==b.labelTaxid) ? 0 : 1;
 					if(a.labelTaxid!=b.labelTaxid) {
-						badMergeSizeResidue+=Tools.min(a.size(), b.size());
+						badMergeSizeResidue+=smaller;
 					}else {
-						goodMergeSizeResidue+=(Tools.min(a.size(), b.size()));
+						goodMergeSizeResidue+=smaller;
 					}
 				}
 				b.add(a);//Note at this point b could be a residue that becomes bigger than residue size
@@ -587,41 +695,60 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 		
 		int removedThisPhase=0;
 		int removedTotal=0;
+//		net0small.cutoff+=0.02;
+//		net0mid.cutoff+=0.02;
+//		net0large.cutoff+=0.02;
 		if(sketchContigs || sketchClusters) {
-			removedThisPhase=refinePhase(map, "aa", 2.5f, TaxTree.SPECIES, false, false, baseRange, 8);
+			removedThisPhase=refinePhase(map, "aa", 2.5f, TaxTree.SPECIES, false, false, baseRange, minSizeToMerge, 8);
 			removedTotal+=removedThisPhase;
 
-			removedThisPhase=refinePhase(map, "bb", 1.5f, TaxTree.SPECIES, true, false, baseRange, 8);
+			removedThisPhase=refinePhase(map, "bb", 1.5f, TaxTree.SPECIES, true, false, baseRange, minSizeToMerge, 8);
 			removedTotal+=removedThisPhase;
 
-			removedThisPhase=refinePhase(map, "cc", 1.0f, TaxTree.GENUS, true, true, baseRange, 8);
+			removedThisPhase=refinePhase(map, "cc", 1.0f, TaxTree.GENUS, true, true, baseRange, minSizeToMerge, 8);
 			removedTotal+=removedThisPhase;
 		}else {
-			removedThisPhase=refinePhase(map, "a", 0.75f, -1, true, true, baseRange, basePasses+1);
+			if(runPassAA) {
+				removedThisPhase=refinePhase(map, "aa", 0.8f, -1, true, true, baseRange+1, Tools.max(4*minSizeToMerge, 20000), basePasses+1);
+				removedTotal+=removedThisPhase;
+			}
+			if(runPassA) {
+				removedThisPhase=refinePhase(map, "a", 0.8f, -1, true, true, baseRange, minSizeToMerge, basePasses+1);
+				removedTotal+=removedThisPhase;
+			}
+			if(runPassB) {
+				removedThisPhase=refinePhase(map, "b", 0.85f, -1, true, true, baseRange+2, minSizeToMerge, basePasses+2);
+				removedTotal+=removedThisPhase;
+			}
+		}
+//		net0small.cutoff-=0.02;
+//		net0mid.cutoff-=0.02;
+//		net0large.cutoff-=0.02;
+		if(runPassD) {
+			removedThisPhase=refinePhase(map, "d", 0.9f, -1, true, true, baseRange, minSizeToMerge, basePasses+0);
 			removedTotal+=removedThisPhase;
-			removedThisPhase=refinePhase(map, "b", 0.8f, -1, true, true, baseRange+2, basePasses+2);
+		}
+		if(runPassE) {
+			removedThisPhase=refinePhase(map, "e", 1.0f, -1, true, true, baseRange+2, minSizeToMerge, basePasses+3);
 			removedTotal+=removedThisPhase;
 		}
-
-		removedThisPhase=refinePhase(map, "d", 0.9f, -1, true, true, baseRange, basePasses+0);
-		removedTotal+=removedThisPhase;
-		removedThisPhase=refinePhase(map, "e", 1.0f, -1, true, true, baseRange+2, basePasses+3);
-		removedTotal+=removedThisPhase;
 		
 		phaseTimer.stop("Refinement merged "+removedTotal+" clusters. ");
 		return removedTotal;
 	}
 	
 	int refinePhase(BinMap map, String phase,
-			float stringency, int taxLevel, boolean noTax, boolean halfTax, int range, int passes) {
+			float stringency, int taxLevel, boolean noTax, boolean halfTax, int range, int initialMinSize, int passes) {
 		Timer t=new Timer(outstream, true);
 		int removedThisPhase=0;
 		for(int pass=1; pass<=passes; pass++) {
 			int initial=map.countClusters();
-			int removed=refineBinMapPass(map, stringency, taxLevel, noTax, halfTax, range, minSizeToMerge*pass);
+			int removed=refineBinMapPass(map, stringency, taxLevel, noTax, halfTax, range, initialMinSize*pass);
 			removedThisPhase+=removed;
+			if(loud) {
 			System.err.print("Refinement Pass "+pass+phase+": Merged "+removed+"/"+initial+" clusters. ");
 			t.stopAndStart("\t");
+			}
 			if(removed<2) {break;}
 		}
 		if(sketchClusters && removedThisPhase>0) {sketcher.sketch(map.toList(false), false);}
@@ -671,80 +798,201 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 		return out;
 	}
 	
+	public long fuse(ArrayList<Contig> contigs, ArrayList<? extends Bin> input, float stringency){
+		if(loud) {outstream.print("Initiating Fusion:  \t");}
+		phaseTimer.start();
+		
+//		for(int i=1; i<input.size(); i++) {
+//			assert(input.get(i).size()<=input.get(i-1).size());
+//			assert(input.get(i).size()>=fuseLowerLimit);
+//		}
+//		assert(false) : fuseLowerLimit;
+		
+		float maxTrimerDif=maxTrimerDif2*stringency;
+		float maxKmerDif=maxKmerDif2*stringency;
+		float max5merDif=max5merDif2*stringency;
+		float maxDepthRatio=1+((maxDepthRatio2-1)*stringency);
+		float maxGCDif=maxGCDif2*stringency;
+		float maxProduct=maxKmerDif*maxDepthRatio*Binner.productMult;
+		float maxCovariance=maxCovariance2*stringency;
+		Oracle oracle=new Oracle(maxGCDif, maxDepthRatio, maxTrimerDif, maxKmerDif, max5merDif, 
+				maxProduct, maxCovariance, minKmerProb2, 0);
+		
+//		System.err.println("maxKmerDif="+maxKmerDif+", maxDepthRatio="+maxDepthRatio+
+//				", maxGCDif="+maxGCDif+", maxProduct="+maxProduct+
+//				", maxCovariance="+maxCovariance+", minKmerProb2="+minKmerProb2);
+//		System.err.println("List size: "+input.size());
+		
+		long merges=0;
+		merges=launchThreads(input, null, contigs, FUSE_MODE, 0, 0, oracle.clone());
+//		phaseTimer.stopAndPrint();
+//		phaseTimer.start();
+		
+		//This phase can be slow.
+		if(merges>0) {merges=mergeWithDest(contigs, input);}
+		
+		if(merges>0 && loud) {phaseTimer.stop("Merged "+merges+"/"+input.size()+" bins: \t");}
+		return merges;
+	}
+	
 	/*--------------------------------------------------------------*/
 	
 	void setSamples(int samples, float mult) {
 		
-		if(samples<2) {//Single mode
-			maxKmerDif2=0.005f;
-			maxDepthRatio2=1.25f;
-			maxGCDif2=0.03f;
-			smallThresh=10000;
-			smallMult=2.2f;
+		if(samples<2) {//Single mode //maxkmerdif=0.0060 maxgcdif=0.045
+			maxKmerDif2=0.0048f;
+//			maxKmerDif2=0.008f;
+			maxDepthRatio2=1.38f;
+			maxGCDif2=0.032f;
+			minKmerProb2=0.82f;
+			max5merDif2=0.007f;
+			
+			fuseStringency=1.6f;
 		}else if(samples<3){//Two mode
-			maxKmerDif2=0.0075f;
-			maxDepthRatio2=1.25f;
-			maxGCDif2=0.03f;
-			smallThresh=10000;
-			smallMult=2.2f;
-			maxCovariance2=0.003f;
+			maxKmerDif2=0.0065f;
+			maxDepthRatio2=1.32f;
+			maxGCDif2=0.032f;
+			maxCovariance2=0.0035f;
+			minKmerProb2=0.80f;
+			max5merDif2=0.008f;
+			
+			netCutoffUpper=0.85f;
+			netCutoff_small=netCutoff_mid=netCutoff_large=0.8f;
+			fuseStringency=1.6f;
 		}else if(samples<4){//Three mode
-			maxKmerDif2=0.0115f;
-			maxDepthRatio2=1.3f;
+//			maxKmerDif2=0.0115f;
+			maxKmerDif2=0.0075f;
+			maxDepthRatio2=1.40f;
 			maxGCDif2=0.04f;
-			smallThresh=10000;
-			smallMult=2.2f;
-			maxCovariance2=0.002f;
+			maxCovariance2=0.0045f;
+			minKmerProb2=0.75f;
+			max5merDif2=0.009f;
+			
+			netCutoffUpper=0.85f;
+			netCutoff_small=netCutoff_mid=netCutoff_large=0.8f;
+			fuseStringency=1.6f;
 		}else if(samples<5){//Four mode
-			maxKmerDif2=0.02f;
+//			maxKmerDif2=0.02f;
+			maxKmerDif2=0.0085f;
 			maxDepthRatio2=1.4f;
 			maxGCDif2=0.05f;
-			maxCovariance2=0.002f;
-		}else if(samples<7){//5-6
-			maxKmerDif2=0.020f;
+			maxCovariance2=0.0045f;
+			minKmerProb2=0.7f;
+			max5merDif2=0.010f;
+			
+			netCutoffUpper=0.85f;
+			netCutoff_small=netCutoff_mid=netCutoff_large=0.8f;
+			fuseStringency=1.6f;
+			purifyStringency=3.0f;
+		}else if(samples<6){//5
+//			maxKmerDif2=0.020f;
+			maxKmerDif2=0.0095f;
 			maxDepthRatio2=1.45f;
-			maxGCDif2=0.055f;
-			maxCovariance2=0.0022f;
-		}else if(samples<9){//7-8
-			maxKmerDif2=0.020f;
+			maxGCDif2=0.05f;
+			maxCovariance2=0.0035f;
+			minKmerProb2=0.7f;
+			max5merDif2=0.0011f;
+			
+			netCutoffUpper=0.85f;
+			netCutoff_small=netCutoff_mid=netCutoff_large=0.8f;
+			fuseStringency=1.6f;
+			purifyStringency=2.5f;
+		}else if(samples<7){//6
+			maxKmerDif2=0.0105f;
 			maxDepthRatio2=1.45f;
-			maxGCDif2=0.055f;
-			maxCovariance2=0.0025f;
-		}else {//9+
-			maxKmerDif2=0.020f;
+			maxGCDif2=0.05f;
+			maxCovariance2=0.0035f;
+			minKmerProb2=0.7f;
+			max5merDif2=0.012f;
+			
+			netCutoffUpper=0.85f;
+			netCutoff_small=netCutoff_mid=netCutoff_large=0.8f;
+			fuseStringency=1.6f;
+			purifyStringency=2.5f;
+		}else{//7+
+			maxKmerDif2=0.0115f;
 			maxDepthRatio2=1.45f;
-			maxGCDif2=0.055f;
-			maxCovariance2=0.0030f;
+			maxGCDif2=0.05f;
+			maxCovariance2=0.0035f;
+			minKmerProb2=0.7f;
+			max5merDif2=0.015f;
+			
+			netCutoffUpper=0.85f;
+			netCutoff_small=netCutoff_mid=netCutoff_large=0.8f;
+			fuseStringency=1.6f;
+			purifyStringency=2.5f;
 		}
 		
 		if(mult!=1) {
 			float lowMult=((mult-1)*0.5f)+1;
 			float highMult=((mult-1)*2f)+1;
-			maxKmerDif2*=mult;
+			maxKmerDif2*=lowMult;
 			maxDepthRatio2=1+(maxDepthRatio2-1)*mult;
 			maxGCDif2*=mult;
 			maxCovariance2*=(mult);
+			purifyStringency*=mult;
+			fuseStringency=1+(fuseStringency-1)*mult;
+			smallMult=1+(smallMult-1)*mult;
+			
+//			float netAdjust=-((16*mult)-16)/400f;
+//			netCutoff_small+=netAdjust;
+//			netCutoff_mid+=netAdjust;
+//			netCutoff_large+=netAdjust;
+//			float netAdjust2=(1-mult)*0.08f;
+//			netCutoffUpper+=netAdjust2;
+			
+			if(mult>1) {
+				minKmerProb2=1-mult*mult*mult*mult*(1-minKmerProb2);
+			}else {
+				minKmerProb2=1-mult*(1-minKmerProb2);
+			}
 			if(mult>1) {
 				hugeMult=1/(1+(1/hugeMult-1)/highMult);
 			}else {
 				hugeMult=1/(1+(1/hugeMult-1)/lowMult);
 			}
+			if(samples==1) {
+//				if(mult==1.4f) {
+//					maxKmerDif2=0.0078f;
+//					minKmerProb2=0.99f;
+//				}else if(mult==1.3f) {
+//					maxKmerDif2=0.0068f;
+//					minKmerProb2=0.99f;
+//				}else if(mult==1.2f) {
+//					maxKmerDif2=0.0062f;
+//					minKmerProb2=0.99f;
+//				}else if(mult==1.1f) {
+//					maxKmerDif2=0.0055f;
+//					minKmerProb2=0.99f;
+//				}
+				if(mult==1.5f) {
+					minKmerProb2=0.7f;
+				}else if(mult==1.375f) {
+					minKmerProb2=0.75f;
+				}else if(mult==1.25f) {
+					minKmerProb2=0.80f;
+				}else if(mult==1.125f) {
+					minKmerProb2=0.81f;
+				}
+			}
 		}
 	}
 	
 	void printThresholds(){
-		System.err.println("maxKmerDif2 =    "+maxKmerDif2);
-		System.err.println("maxKmerDif2 =    "+maxKmerDif2);
-		System.err.println("maxDepthRatio2 = "+maxDepthRatio2);
-		System.err.println("maxDepthRatio2 = "+maxDepthRatio2);
-		System.err.println("maxGCDif2 =      "+maxGCDif2);
-		System.err.println("maxGCDif2 =      "+maxGCDif2);
-		System.err.println("maxCovariance1 = "+maxCovariance1);
-		System.err.println("maxCovariance2 = "+maxCovariance2);
-		System.err.println("smallThresh =    "+smallThresh);
-		System.err.println("smallMult =      "+smallMult);
-		System.err.println("bigThresh =      "+bigThresh);
-		System.err.println("bigMult =        "+bigMult);
+//		netCutoffUpper=0.7f;
+		System.err.println("maxKmerDif:       "+maxKmerDif2);
+		System.err.println("minKmerProb:      "+minKmerProb2);
+		System.err.println("maxDepthRatio:    "+maxDepthRatio2);
+		System.err.println("maxGCDif:         "+maxGCDif2);
+		System.err.println("maxCovariance:    "+maxCovariance2);
+		System.err.println("netCutoff:        "+netCutoff_large);
+		System.err.println("netCutoffUpper:   "+netCutoffUpper);
+		System.err.println("fuseStringency:   "+fuseStringency);
+		System.err.println("purifyStringency: "+purifyStringency);
+		System.err.println("smallThresh:      "+smallThresh);
+		System.err.println("smallMult:        "+smallMult);
+		System.err.println("bigThresh:        "+bigThresh);
+		System.err.println("bigMult:          "+bigMult);
 	}
 	
 	/*--------------------------------------------------------------*/
@@ -757,8 +1005,8 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 		//Do anything necessary prior to processing
 		
 		//Determine how many threads may be used
-		final int threads=Tools.mid(1, list.size()/64, Shared.threads());
-		
+		int threads=Tools.mid(1, list.size()/64, Shared.threads());
+//		if(mode==FUSE_MODE) {threads=1;}//123
 		threadMerges=0;
 		
 		//Fill a list with LoadThreads
@@ -782,6 +1030,7 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 		synchronized(t){
 			fastComparisons.addAndGet(t.oracle.fastComparisons);
 			slowComparisons.addAndGet(t.oracle.slowComparisons);
+			netComparisons.addAndGet(t.oracle.netComparisons);
 			threadMerges+=t.mergesT;
 			errorState|=(!t.success);
 		}
@@ -819,6 +1068,8 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 					purify();
 				}else if(mode==FOLLOW_MODE) {
 					follow();
+				}else if(mode==FUSE_MODE) {
+					fuse();
 				}else {
 					throw new RuntimeException("Bad mode: "+mode);
 				}
@@ -829,6 +1080,7 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 		private int follow() {
 			for(int i=tid; i<input.size(); i+=threads) {
 				Bin a=input.get(i);
+				assert(a.dest<0);
 				if(a.pairMap!=null) {
 					int dest=followEdges(a, contigs, oracle);
 					if(dest>=0) {
@@ -840,6 +1092,53 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 			return mergesT;
 		}
 		
+		private int fuse() {
+			for(int i=tid; i<input.size(); i+=threads) {
+				Bin a=input.get(i);
+				if(a.size()<fuseLowerLimit) {
+					assert(false);
+					break;
+				}
+				if(a.size()>fuseUpperLimit) {continue;}
+				fuseSeeks++;
+				Bin b=findBestFuseTarget(a);
+				mergesT+=(b==null ? 0 : 1);
+				fuseTargets+=(b==null ? 0 : 1);
+			}
+//			System.err.println("fuseSeeks="+fuseSeeks);
+//			System.err.println("fuseCompares="+fuseCompares);
+//			System.err.println("fuseTargets="+fuseTargets);
+			return mergesT;
+		}
+		
+		private Bin findBestFuseTarget(Bin a) {
+			oracle.best=null;
+			oracle.topScore=-1;
+			for(Bin b : input) {
+				if(b.size()<fuseLowerLimit) {
+					assert(false) : a.size()+", "+b.size();
+					break;
+				}
+				if(b.size()<a.size()) {break;}
+				if(b==a) {continue;}
+				fuseCompares++;
+				float f=oracle.similarity(a, b, 1);
+//				if(f<=0) {
+//					verbose=true;
+//					oracle.similarity(a, b, 1);
+//					assert(false);
+//				}
+				if(f>oracle.topScore) {
+					assert(f>0) : f;//Actually, could be -1; or clear should set to -1
+					oracle.best=b;
+					oracle.topScore=f;
+				}
+			}
+//			System.err.print('.');
+			if(oracle.best!=null) {a.dest=oracle.best.id();}
+			return oracle.best;
+		}
+		
 		private int purify() {
 			for(int i=tid; i<input.size(); i+=threads) {
 				Bin a=input.get(i);
@@ -860,17 +1159,26 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 				synchronized(a) {
 					a.dest=-1;
 					a.score=oracle.similarity(clust, a, 1);
+					if(a.score<0) {
+						a.dest=a.id();
+						changes++;
+//						synchronized(Binner.class) {
+//							oracle.verbose2=true;
+//							oracle.similarity(clust, a, 1);
+//							assert(false);
+//						}
+					}
 				}
 			}
 			Collections.sort(contigs, ScoreComparator.comparator);
 			for(Contig a : contigs) {
 				if(a.id()!=clust.id()) {
 					Cluster b=map.findBestCluster(a, minSize, key, range, oracle);
-					if(b!=null && b!=clust && oracle.score>=a.score) {
+					if(b!=null && b!=clust && oracle.score>=1.125f*a.score) {
 						synchronized(a) {
+							if(a.dest<0) {changes++;}
 							a.dest=b.id();
 						}
-						changes++;
 //						System.err.print(".");
 					}else {
 						break;
@@ -938,6 +1246,11 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 		final int tid;
 		final int threads;
 		final int mode;
+
+		
+		long fuseCompares=0;
+		long fuseSeeks=0;
+		long fuseTargets=0;
 		
 //		final float maxKmerDif;
 //		final float maxDepthRatio;
@@ -958,7 +1271,7 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 	
 	static float sizeAdjustMult(long size) {
 		float f=sizeAdjustMult2(size);
-		if(size<tinyThresh && size>minSizeToCompare) {
+		if(size<tinyThresh){// && size>minSizeToCompare) {
 			f*=tinyMult;//This is to correct the exemption from residueStringency
 		}
 		return f;
@@ -979,6 +1292,12 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 		return 1f;
 	}
 	
+	void addMerge(long size, boolean good) {
+		int idx=(int)(Tools.log2(size));
+		if(good) {goodMergeSize[idx]++;}
+		else {badMergeSize[idx]++;}
+	}
+	
 	/*--------------------------------------------------------------*/
 	/*----------------            Fields            ----------------*/
 	/*--------------------------------------------------------------*/
@@ -992,6 +1311,14 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 	int basePasses=1;
 	int residueRange=3;
 	boolean errorState=false;
+	boolean runPassAA=false;
+	boolean runPassA=true;
+	boolean runPassB=false;
+	boolean runPassC=true;
+	boolean runPassD=true;
+	boolean runPassE=true;
+	boolean runPassF=false;
+	boolean runPassG=true;
 
 	long goodMergesFollow=0;
 	long badMergesFollow=0;
@@ -1009,6 +1336,9 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 	long badMergesResidue=0;
 	long goodMergeSizeResidue=0;
 	long badMergeSizeResidue=0;
+
+	long[] goodMergeSize=new long[40];
+	long[] badMergeSize=new long[40];
 	
 	BinMap binMap;
 	
@@ -1022,57 +1352,87 @@ public class Binner extends BinObject implements Accumulator<Binner.CompareThrea
 	/*--------------------------------------------------------------*/
 	/*----------------            Static Fields          ----------------*/
 	/*--------------------------------------------------------------*/
-	
+
 	static boolean PERFECT_ORACLE=false;
+	static boolean BAN_BAD_MERGES=false;
 	
 	static final int REFINE_MODE=0;
 	static final int RESIDUE_MODE=1;
 	static final int PURIFY_MODE=2;
 	static final int FOLLOW_MODE=3;
+	static final int FUSE_MODE=4;
+	
+	static int fuseLowerLimit=5000;
+	static int fuseUpperLimit=1000000;
+	static float fuseStringency=1.56f;
+	static float purifyStringency=3f;
 	
 	static float residueStringency=0.6f;
-	static float productMult=0.70f;
+	static float productMult=0.68f;
+	static float minSimilarity=0.0f;
 	
 	static int maxEdges=3;
 	static int minEdgeWeight=2;
+	static boolean reciprocalEdges=true;
 	static float minEdgeRatio=0.4f;
 
 	static float lowDepthEdgeRatio=0.2f;
 	static float highDepthEdgeRatio=2f;
 	static float goodEdgeMult=1.4f;
+	static float goodTransEdgeMult=1.3f;
 
 	static int hugeThresh=1200000;
-	static float hugeMult=0.2f;//0.65f;
+	static float hugeMult=0.4f;
 	static int bigThresh=100000;
-	static float bigMult=0.8f;
-	static int smallThresh=10000; //10000 better for 1 depth
-	static float smallMult=2.2f; //2.2f is better for 1 depth
-	static int tinyThresh=3000; //10000 better for 1 depth
+	static float bigMult=0.75f;
+	static int smallThresh=8000;
+	static float smallMult=2.44f;
+	static int tinyThresh=1000;
 	static float tinyMult=0.72f;
 	
 //	static int minSizeToCluster=0;
 //	static int minSizeToRefine=500;
 	/** Size of the bigger one */
-	static int minSizeToCompare=2000;
+	static int minSizeToCompare=3000;//2000
 	/** Size of the smaller one being compared */
-	static int minSizeToMerge=1500;
+	static int minSizeToMerge=3000;//1500
 //	static int minSizeToAdd=4000;//Should always be the same as minSizeToCompare...
 	static int minSizeResidue=200;
+	static int minNetSize=200;
+	static int midNetSize=3000;
+	static int largeNetSize=15000;
+	static float netCutoffUpper=0.65f;
+	static float netCutoffLower=0.547f;
+	static float netCutoff_small=0.56f;
+	static float netCutoff_mid=0.56f;
+	static float netCutoff_large=0.56f;
+	static float netMultUpper=1.4f;
+	static float netMultLower=0.5f;
+	static float cutoffMultA=2.7f;
+	static float cutoffMultB=1.7f;
+	static float cutoffMultC=1.6f;
+	static float cutoffMultD=1.2f;
 	
 	//Optimal selection when forming clusters
-	static float maxKmerDif1=0.002f;//0.004f;
-	static float maxDepthRatio1=1.05f;//1.1f;
-	static float maxGCDif1=0.01f;//0.02f;
-	static float maxCovariance1=0.0001f;
+	static float maxTrimerDif1=0.1f;
+	static float maxKmerDif1=0.002f;
+	static float max5merDif1=0.1f;
+	static float maxDepthRatio1=1.05f;
+	static float maxGCDif1=0.01f;
+	static float maxCovariance1=0.00005f;
 	
 	//When merging clusters
-	static float maxKmerDif2=0.005f; //.005 for k=4; .012 for k=5
-	static float maxDepthRatio2=1.25f;
+	static float maxTrimerDif2=0.1f;
+	static float maxKmerDif2=0.005f; //.005 for k=4; .012 for k=5; .008 for Euclid
+	static float max5merDif2=0.007f;
+	static float maxDepthRatio2=1.36f;
 	static float maxGCDif2=0.03f; //0.02f for 1 depth, 0.05 for 4 depths
 	static float maxCovariance2=0.002f;
+	static float minKmerProb2=0.9f;
 	
 	private int threadMerges=0;
 	public AtomicLong fastComparisons=new AtomicLong(0);
 	public AtomicLong slowComparisons=new AtomicLong(0);
+	public AtomicLong netComparisons=new AtomicLong(0);
 	
 }
