@@ -1,14 +1,12 @@
 package bin;
 
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.Iterator;
 
 import shared.Tools;
 import sketch.Sketch;
 import sketch.SketchMakerMini;
 import stream.Read;
-import structures.FloatList;
 import structures.IntHashMap;
 import structures.IntHashSet;
 import tracker.EntropyTracker;
@@ -36,8 +34,20 @@ public class Cluster extends Bin {
 	
 	@Override
 	public final int id() {return id;}
+
+	public boolean pure(float fraction) {return nonDominantSize<=size*fraction;}
 	
-	public boolean pure() {return pure;}
+	public float minContigDepth() {
+		float d=contigs.size()==0 ? 0 : contigs.get(0).depth();
+		for(Contig c : contigs) {d=Math.min(c.depth(), d);}
+		return d;
+	}
+	
+	public float maxContigDepth() {
+		float d=0;
+		for(Contig c : contigs) {d=Math.max(c.depth(), d);}
+		return d;
+	}
 	
 	@Override
 	@Deprecated
@@ -86,22 +96,31 @@ public class Cluster extends Bin {
 			entropy=c.entropy;
 //			acRatio=c.acRatio;
 		}else {
-			if(labelTaxid<1 || (c.labelTaxid!=labelTaxid && c.size()>=0.05f*size())) {pure=false;}
+			if(labelTaxid<1 || (c.labelTaxid!=labelTaxid && c.size()>=0.05f*size())) {nonDominantSize+=c.size();}
 //			assert(isValid());
 			entropy=(entropy*size()+c.entropy*c.size())*invSize2;
 //			acRatio=(acRatio*size()+c.acRatio*c.size())*invSize2;
 		}
 		contigs.add(c);
 		contigSet.add(c.id());
-		kmers+=c.kmers;
-		invKmers=1f/kmers;
-		if(counts==null) {counts=c.counts.clone();}
-		else {Tools.add(counts, c.counts);}
+		numTetramers+=c.numTetramers;
+		numPentamers+=c.numPentamers;
+//		invKmers=1f/numTetramers;
+		if(tetramers==null) {tetramers=c.tetramers.clone();}
+		else {Tools.add(tetramers, c.tetramers);}
 		if(c.dimers!=null) {
 			if(dimers==null) {dimers=c.dimers.clone();}
 			else {Tools.add(dimers, c.dimers);}
 			strandedness=EntropyTracker.strandedness(dimers, 2);
 		}
+		if(c.trimers!=null) {
+			if(trimers==null) {trimers=c.trimers.clone();}
+			else {Tools.add(trimers, c.trimers);}
+		}
+		if(c.pentamers!=null) {
+			if(pentamers==null) {pentamers=c.pentamers.clone();}
+			else {Tools.add(pentamers, c.pentamers);}
+		}
 		
 		if(c.pairMap!=null) {
 			if(pairMap==null) {pairMap=new IntHashMap(5);}
@@ -160,7 +179,7 @@ public class Cluster extends Bin {
 			assert(false) : id()+", "+contigSet;
 			return false;
 		}
-		if(counts==null) {
+		if(tetramers==null) {
 			assert(false) : id()+", "+contigSet;
 			return false;
 		}
@@ -195,10 +214,13 @@ public class Cluster extends Bin {
 		contigSet.clear();
 		pairMap=null;
 		
-		kmers=0;
-		invKmers=0;
-		counts=null;
+		numTetramers=0;
+		numPentamers=0;
+//		invKmers=0;
 		dimers=null;
+		trimers=null;
+		tetramers=null;
+		pentamers=null;
 		gcSum=0;
 		sketchedSize=0;
 		clearDepth();
@@ -206,7 +228,7 @@ public class Cluster extends Bin {
 		dest=0;
 		taxid=genusTaxid=labelTaxid=0;
 		topHit=secondHit=null;
-		pure=true;
+		nonDominantSize=0;
 	}
 	
 	@Override
@@ -222,6 +244,6 @@ public class Cluster extends Bin {
 	public ArrayList<Contig> contigs=new ArrayList<Contig>(8);
 	public IntHashSet contigSet=new IntHashSet(5);
 	private int timestamp=-1;
-	private boolean pure=true;
+	long nonDominantSize=0;
 	
 }
