@@ -63,8 +63,14 @@ public class Contig extends Bin {
 	
 	@Override
 	public boolean isValid() {
-		if(numDepths()<1) {return false;}
-		if(counts==null) {return false;}
+		if(numDepths()<1) {
+			assert(false) : numDepths()+", "+name+"\n"+this;
+			return false;
+		}
+		if(tetramers==null) {
+			assert(false) : name;
+			return false;
+		}
 //		assert(gcSum>0) : gcSum+", "+new String(bases);
 		if(cluster!=null) {
 			if(!cluster.contigSet.contains(id())) {
@@ -82,43 +88,19 @@ public class Contig extends Bin {
 	}
 	
 	public void loadCounts() {
-		assert(kmers==0);
-		counts=new int[canonicalKmers];
-//		int[] dimers=new int[16];
-		kmers=countKmers(bases, counts);
-		invKmers=1f/Tools.max(1, kmers);
+		assert(numTetramers==0);
+		tetramers=new int[canonicalKmers[4]];
+		numTetramers=countKmers(bases, tetramers, 4);
+//		invKmers=1f/Tools.max(1, numTetramers);
 		for(byte b : bases) {
 			int x=AminoAcid.baseToNumber[b];
 			gcSum+=(x==1 || x==2) ? 1 : 0;
 		}
-		
-		//AC=0b0001=0d1, GT=0b1011=0d11
-		//CA=0b0100=4, TG=0b1101=0d13
-		//AG=0b0010=2, CT=0b0111=0d7
-		//AA=0000=0, 1111=15, 0101=5, 1010=10
-		//AT=0011=3, 1100=12, 0110=6, 1001=9
-//		int ac=dimers[1]+dimers[11];
-//		int ca=dimers[4]+dimers[13];
-//		int ag=dimers[2]+dimers[7];
-//		int aa=dimers[0]+dimers[15];
-//		int at=dimers[3]+dimers[12];
-//		int gg=dimers[5]+dimers[10];
-//		int cg=dimers[6]+dimers[9];
-//		acRatio=ac/(Tools.max(ac+ca, 1f));
-//		float agRatio=ac/(Tools.max(ac+ag, 1f));
-//		float aaRatio=aa/(Tools.max(aa+at, 1f));
-//		float ggRatio=gg/(Tools.max(gg+cg, 1f));
-//		float aaggRatio=(aa+gg)/(Tools.max(gg+cg+aa+at, 1f));
-//		
-//		acRatio=0.4f*(aaRatio/ggRatio);
-		
-//		System.err.println(String.format("(gc=%.4f,ac=%.4f,ag=%.4f,aa=%.4f,gg=%.4f)", 
-//				gc(), acRatio, agRatio, aaRatio, ggRatio));
-		
-//		System.err.println(String.format("%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f", 
-//				gc(), acRatio, agRatio, aaRatio, ggRatio, aaggRatio));
-		//This assertion can fail; I saw an all A/T contig
-//		assert(gcSum>0) : gcSum+", "+kmers+", "+new String(bases);
+
+		if(countPentamers && size()>=minPentamerSizeCount) {
+			pentamers=new int[canonicalKmers[5]];
+			numPentamers=countKmers(bases, pentamers, 5);
+		}
 	}
 	
 	/** In fasta format */
@@ -157,7 +139,8 @@ public class Contig extends Bin {
 		}
 		ArrayList<KeyValue> list=KeyValue.toList(pairMap);
 		if(list!=null) {
-			for(KeyValue ip : list) {
+			for(int i=0; i<list.size() && i<DataLoader.MAX_EDGES_TO_PRINT; i++) {
+				KeyValue ip=list.get(i);
 				bb.tab().append(ip.key).tab().append(ip.value);
 			}
 		}
