@@ -10,6 +10,7 @@ import java.util.concurrent.locks.ReentrantReadWriteLock;
 import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.LineParser1;
 import shared.LineParser4;
 import shared.Parse;
 import shared.Parser;
@@ -164,6 +165,8 @@ public class ContigRenamer implements Accumulator<ContigRenamer.ProcessThread> {
 				addDepth=Parse.parseBoolean(b);
 			}else if(a.equals("tid") || a.equalsIgnoreCase("taxid")){
 				addTid=Parse.parseBoolean(b);
+			}else if(a.equals("cami")){
+				cami=b;
 			}else if(a.equals("clearfilters")){
 				if(Parse.parseBoolean(b)){
 					samFilter.clear();
@@ -257,23 +260,14 @@ public class ContigRenamer implements Accumulator<ContigRenamer.ProcessThread> {
 		//Reset counters
 		readsProcessed=readsOut=0;
 		basesProcessed=basesOut=0;
-		for(int i=0; i<in.size(); i++) {
-			FileFormat ffin=FileFormat.testInput(in.get(i), FileFormat.SAM, extin, true, true);
-
-			//Create a read input stream
-			SamStreamer ss=makeStreamer(ffin);
-
-			if(scafMap.isEmpty()) {scafMap=makeScafMap();}
-
-			//Process the reads in separate threads
-			spawnThreads(ss);
-			
-			for(Scaf scaf : scafMap.values()) {
-				scaf.process();
-				scaf.map.clear();
-			}
-		}
 		
+		if(in.size()>0) {
+			processSam();
+		}else if(cami!=null) {
+			processCami();
+		}else {
+			assert(false) : "No input.";
+		}
 		processReference();
 		
 		if(verbose){outstream.println("Finished; closing streams.");}
@@ -295,6 +289,46 @@ public class ContigRenamer implements Accumulator<ContigRenamer.ProcessThread> {
 		}
 	}
 	
+	private void processSam() {
+
+		for(int i=0; i<in.size(); i++) {
+			FileFormat ffin=FileFormat.testInput(in.get(i), FileFormat.SAM, extin, true, true);
+
+			//Create a read input stream
+			SamStreamer ss=makeStreamer(ffin);
+
+			if(scafMap.isEmpty()) {scafMap=makeScafMap();}
+
+			//Process the reads in separate threads
+			spawnThreads(ss);
+			
+			for(Scaf scaf : scafMap.values()) {
+				scaf.process();
+				scaf.map.clear();
+			}
+		}
+	}
+	
+	private void processCami() {
+		LineParser1 lp=new LineParser1('\t');
+		ArrayList<byte[]> lines=ByteFile.toLines(cami);
+		scafMap=new HashMap<String, Scaf>();
+		addDepth=false;
+		addTid=true;
+		for(byte[] line : lines) {
+			if(!Tools.startsWith(line, '@')){
+				lp.set(line);
+				String name=lp.parseString(0);
+				int taxID=lp.parseInt(2);
+				Scaf scaf=new Scaf(name, 1);
+				Scaf old=scafMap.putIfAbsent(name, scaf);
+				assert(old==null) : "Name conflict for scaffold "+name;
+				scaf.tidList.add(taxID);
+				scaf.covList.add(1);
+			}
+		}
+	}
+	
 	private ConcurrentReadInputStream makeRefCris(){
 		ConcurrentReadInputStream cris=ConcurrentReadInputStream.getReadInputStream(maxReads, true, ffref, null);
 		cris.start(); //Start the stream
@@ -397,6 +431,8 @@ public class ContigRenamer implements Accumulator<ContigRenamer.ProcessThread> {
 				r.id=(rename(r.id, r.length(), r.numericID));
 				readsOut++;
 				basesOut+=r.length();
+				readsProcessed++;
+				basesProcessed+=r.length();
 			}
 			if(ros!=null) {ros.add(ln.list, ln.id);}
 			cris.returnList(ln);
@@ -597,6 +633,8 @@ public class ContigRenamer implements Accumulator<ContigRenamer.ProcessThread> {
 	/** Contig input file path */
 	private String ref=null;
 
+	private String cami=null;
+	
 	/** Primary output file path */
 	private String out=null;
 	
