@@ -10,9 +10,12 @@ import java.util.HashMap;
 import java.util.Map.Entry;
 import bloom.BloomFilter;
 import bloom.KmerCountAbstract;
+import dna.Data;
 import fileIO.ByteFile;
 import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
+import fileIO.ReadWrite;
+import ml.CellNet;
 import ml.CellNetParser;
 import shared.LineParser1;
 import shared.LineParser2;
@@ -54,12 +57,31 @@ public class DataLoader extends BinObject {
 			}
 		}else if(a.equals("maxdepths") || a.equals("maxdepthcount") || a.equals("samples")){
 			MAX_DEPTH_COUNT=Parse.parseIntKMG(b);
+		}else if(a.equals("maxedgestoprint")){
+			MAX_EDGES_TO_PRINT=Parse.parseIntKMG(b);
 		}else if(a.equals("maxreads")){
 			maxReads=Parse.parseKMG(b);
 		}else if(a.equals("mincontig") || a.equals("minsizetoload")){
 			minContigToLoad=Parse.parseIntKMG(b);
 		}else if(a.equals("mapq") || a.equals("minmapq")){
 			minMapq=Integer.parseInt(b);
+		}else if(a.equals("maxsubs")){
+			maxSubs=Integer.parseInt(b);
+		}else if(a.equalsIgnoreCase("tipLimit")){
+			tipLimit=Integer.parseInt(b);
+		}else if(a.equals("minid")){
+			minID=Float.parseFloat(b);
+			if(minID>1) {minID/=100;}
+			assert(minID>=0 && minID<=1) : minID;
+		}else if(a.equals("minmateid")){
+			minMateID=Float.parseFloat(b);
+			if(minMateID>1) {minMateID/=100;}
+			assert(minMateID>=0 && minMateID<=1) : minMateID;
+		}else if(a.equals("minentropy")){
+			minEntropy=Float.parseFloat(b);
+			assert(minEntropy>=0 && minEntropy<=1);
+		}else if(a.equals("minalignedbases")){
+			minAlignedBases=Integer.parseInt(b);
 		}
 		
 		else if(a.equals("bloomk") || a.equals("kbloom")){
@@ -78,15 +100,40 @@ public class DataLoader extends BinObject {
 			makePairGraph=Parse.parseBoolean(b);
 		}
 		
-		else if(a.equals("network") || a.equals("netfile")){
-			netFile=b;
-		}else if(a.equals("netcutoff") || a.equals("cutoff")) {
-			netCutoff=Float.parseFloat(b);
+		else if(a.equalsIgnoreCase("streamContigs")){
+			streamContigs=Parse.parseBoolean(b);
 		}
 		
-		else if(a.equals("k")) {
-			int k=Integer.parseInt(b);
-			setK(k);
+		else if(a.equals("network") || a.equals("netfile") || a.equals("net") || a.equals("nn")){
+			if(b==null || b.equalsIgnoreCase("f") || b.equalsIgnoreCase("false")) {b=null;}
+			else if(b.equalsIgnoreCase("t") || b.equalsIgnoreCase("true")) {b="auto";}
+			netFileSmall=netFileMid=netFileLarge=b;
+		}else if(a.equals("netsmall") || a.equals("smallnet") || a.equals("nnsmall") || a.equals("smallnn")){
+			if(b==null || b.equalsIgnoreCase("f") || b.equalsIgnoreCase("false")) {b=null;}
+			else if(b.equalsIgnoreCase("t") || b.equalsIgnoreCase("true")) {b="auto";}
+			netFileSmall=b;
+		}else if(a.equals("netmid") || a.equals("midnet") || a.equals("nnmid") || a.equals("midnn")){
+			if(b==null || b.equalsIgnoreCase("f") || b.equalsIgnoreCase("false")) {b=null;}
+			else if(b.equalsIgnoreCase("t") || b.equalsIgnoreCase("true")) {b="auto";}
+			netFileMid=b;
+		}else if(a.equals("netlarge") || a.equals("largenet") || a.equals("nnlarge") || a.equals("largenn")){
+			if(b==null || b.equalsIgnoreCase("f") || b.equalsIgnoreCase("false")) {b=null;}
+			else if(b.equalsIgnoreCase("t") || b.equalsIgnoreCase("true")) {b="auto";}
+			netFileLarge=b;
+		}
+		
+		else if(a.equals("samserial") || a.equals("loadsamserial")){
+			loadSamSerial=Parse.parseBoolean(b);
+		}else if(a.equals("samparallel") || a.equals("loadsamparallel")){
+			loadSamSerial=!Parse.parseBoolean(b);
+		}else if(a.equals("pentamers")){
+			countPentamers=Parse.parseBoolean(b);
+		}else if(a.equals("minpentamersize")){
+			minPentamerSizeCount=minPentamerSizeCompare=Parse.parseIntKMG(b);
+		}else if(a.equals("minpentamersizecount")){
+			minPentamerSizeCount=Parse.parseIntKMG(b);
+		}else if(a.equals("minpentamersizecompare")){
+			minPentamerSizeCompare=Parse.parseIntKMG(b);
 		}
 		
 		else if(a.equals("ref") || a.equals("contigs") || a.equals("scaffolds") || a.equals("in")){
@@ -100,21 +147,27 @@ public class DataLoader extends BinObject {
 		}else if(a.equals("cov") || a.equals("covin")){
 			covIn=b;
 		}else if(new File(arg).isFile()) {
-			FileFormat ff=FileFormat.testInput(arg, FileFormat.SAM, null, false, false);
-			if(ff.samOrBam() || ff.fastq()) {
-				System.err.println("Adding reads file "+ff.simpleName());
-				readFiles.add(arg);
-			}else if(ff.fasta()) {
-				System.err.println("Adding ref file "+ff.simpleName());
-				ref=arg;
+			if(looksLikeCovFile(arg)) {
+				System.err.println("Adding cov file "+ReadWrite.stripPath(arg));
+				covIn=arg;
 			}else {
-				System.err.println("Adding covstats file "+ff.simpleName());
-				covstats.add(arg);
+				FileFormat ff=FileFormat.testInput(arg, FileFormat.SAM, null, false, false);
+				if(ff.samOrBam() || ff.fastq()) {
+					System.err.println("Adding reads file "+ff.simpleName());
+					readFiles.add(arg);
+				}else if(ff.fasta()) {
+					System.err.println("Adding ref file "+ff.simpleName());
+					ref=arg;
+				}else if(ff.bbnet()){
+					System.err.println("Adding network file "+ff.simpleName());
+					netFileSmall=netFileMid=netFileLarge=arg;
+				}else if(b.contains("stats") && ff.text()){
+					System.err.println("Adding covstats file "+ff.simpleName());
+					covstats.add(arg);
+				}else {
+					return false;
+				}
 			}
-		}else if(a.equals("samserial") || a.equals("loadsamserial")){
-			loadSamSerial=Parse.parseBoolean(b);
-		}else if(a.equals("samparallel") || a.equals("loadsamparallel")){
-			loadSamSerial=!Parse.parseBoolean(b);
 		}
 		
 		else {return false;}
@@ -122,6 +175,15 @@ public class DataLoader extends BinObject {
 		return true;
 	}
 	
+	static boolean looksLikeCovFile(String s) {
+		if(s==null) {return false;}
+		String ext=ReadWrite.rawExtension(s);
+		if("txt".equals(ext) || "tsv".equals(ext) || "cov".equals(ext)) {
+			return s.contains("cov");
+		}
+		return false;
+	}
+	
 	/*--------------------------------------------------------------*/
 	/*----------------          Validation          ----------------*/
 	/*--------------------------------------------------------------*/
@@ -143,62 +205,39 @@ public class DataLoader extends BinObject {
 	/*--------------------------------------------------------------*/
 	/*----------------            Wrapper           ----------------*/
 	/*--------------------------------------------------------------*/
-	
-	ArrayList<Contig> loadData() {
-		//Turn off read validation in the input threads to increase speed
-		final boolean vic=Read.VALIDATE_IN_CONSTRUCTOR;
-		Read.VALIDATE_IN_CONSTRUCTOR=Shared.threads()<4;
-		
-		final boolean parseTax=true;
-		final boolean parseCov=(covIn==null && readFiles.isEmpty() && covstats.isEmpty());
 
-		final ArrayList<Contig> contigs=loadContigs(ref, minContigToLoad);
-		
-		if(parseCov) {
-			depthCalculated=true;
-		}else {
-			calculateDepth(contigs);
-		}
-		assert(depthCalculated);
-		
-		long removedEdges=0;
-		phaseTimer.start();
-		for(Contig c : contigs) {
-			removedEdges+=fixEdges(c, contigs.size());
-		}
-		if(removedEdges>0) {
-			phaseTimer.stop("Removed "+removedEdges+" edges: \t");
-		}
-		
-		outstream.print("Calculating kmer frequency spectra: \t");
-		phaseTimer.start();
-		
-		SpectraCounter sc=new SpectraCounter(outstream, parseTax, parseCov);
-		sc.makeSpectra(contigs);
-		sizeMap=sc.sizeMap;
-		phaseTimer.stopAndPrint();
-		
+	ArrayList<Contig> loadData() {
+		ArrayList<Contig> contigs=loadContigs(ref);
+
+		//		sizeMap=sc.sizeMap;
+//		phaseTimer.stopAndPrint();
+
 		if(validation && makePairGraph) {
 			validateEdges(contigs);
 		}
-		
+
 		if(sketchContigs) {
 			System.err.println("Sketching contigs. ");
 			sketcher.sketch(contigs, true);
 		}
-		
+
 		//Reset read validation
-		Read.VALIDATE_IN_CONSTRUCTOR=vic;
+		Read.VALIDATE_IN_CONSTRUCTOR=true;//should be adjusted for many threads
 		numDepths=(contigs.isEmpty()) ? 0 : contigs.get(0).numDepths();
 		assert(numDepths>0) : "At least one depth is required.";
+
+		net0small=loadNetwork(netFileSmall, "all", Binner.netCutoff_small, numDepths);
+		net0mid=loadNetwork(netFileMid, "all", Binner.netCutoff_mid, numDepths);
+		net0large=loadNetwork(netFileLarge, "all", Binner.netCutoff_large, numDepths);
 		
-		if(netFile!=null) {
-			loadNetwork(netFile, netCutoff, numDepths);
+		if(net0small==null && net0mid==null && net0large==null) {
+			Binner.cutoffMultA=Binner.cutoffMultB=Binner.cutoffMultC=Binner.cutoffMultD=1;
 		}
-		
+
+		allContigs=contigs;
 		return contigs;
 	}
-	
+
 	int fixEdges(final Contig c, final int numContigs) {
 		if(c.pairMap==null) {return 0;}
 		int removed=0, seen=0;
@@ -212,22 +251,101 @@ public class DataLoader extends BinObject {
 		if(removed>=seen) {c.pairMap=null;}
 		return removed;
 	}
+
+	public ArrayList<Contig> loadContigs(String fname){
+		
+		final boolean vic=Read.VALIDATE_IN_CONSTRUCTOR;
+		Read.VALIDATE_IN_CONSTRUCTOR=Shared.threads()<4;
+
+		final boolean parseCov=(covIn==null && readFiles.isEmpty() && covstats.isEmpty());
+		final ArrayList<Contig> contigs=loadAndProcessContigs(fname, parseCov);
+
+		if(parseCov) {
+			depthCalculated=true;
+		}else {
+			calculateDepth(contigs);
+		}
+		if(streamContigs && contigs.get(0).numDepths()>1) {//Normally handled by SpectraCounter
+			for(Contig c : contigs) {
+				synchronized(c) {
+					float[] f=c.normDepth();
+					assert(f!=null);
+					assert(f.length==c.numDepths()) : f.length+", "+c.numDepths();
+				}
+			}
+		}
+		assert(depthCalculated);
+		assert(isValid(contigs, false)) : parseCov;
+
+		long removedEdges=0;
+		phaseTimer.start();
+		for(Contig c : contigs) {
+			removedEdges+=fixEdges(c, contigs.size());
+		}
+		if(removedEdges>0) {
+			phaseTimer.stop("Removed "+removedEdges+" edges: \t");
+		}
+		
+		Read.VALIDATE_IN_CONSTRUCTOR=vic;
+		
+		return contigs;//not necessarily optimal
+	}
+	
+	public ArrayList<Contig> loadAndProcessContigs(String fname, boolean parseCov) {
+		return streamContigs ? loadAndProcessContigsMT(fname, parseCov) : 
+			loadAndProcessContigsST(fname, parseCov);
+	}
+	
+	public ArrayList<Contig> loadAndProcessContigsMT(String fname, boolean parseCov) {
+		final ArrayList<Contig> contigs=new ArrayList<Contig>();
+		boolean parseTID=validation;
+		sizeMap=new IntLongHashMap(1023);
+
+		FileFormat ff=FileFormat.testInput(fname, FileFormat.FASTA, null, true, true);
+		ConcurrentReadInputStream cris=ConcurrentReadInputStream.getReadInputStream(maxReads, true, ff, null);
+		cris.start(); //Start the stream
+		if(verbose){outstream.println("Started cris");}
+		outstream.print("Loading contigs:\t");
+		phaseTimer.start();
+		SpectraCounter sc=new SpectraCounter(outstream, parseCov, parseTID, sizeMap);
+		sc.makeSpectra(contigs, cris, minContigToLoad);
+		errorState|=sc.errorState;
+		contigsLoaded+=sc.contigsLoaded;
+		basesLoaded+=sc.basesLoaded;
+		contigsRetained+=sc.contigsRetained;
+		basesRetained+=sc.basesRetained;
+		phaseTimer.stopAndPrint();
+		Collections.sort(contigs);
+		for(int i=0; i<contigs.size(); i++) {contigs.get(i).setID(i);}
+		errorState|=ReadWrite.closeStream(cris);
+
+		return contigs;
+	}
+	
+	public ArrayList<Contig> loadAndProcessContigsST(String fname, boolean parseCov) {
+		final ArrayList<Contig> contigs=loadContigsST(ref, minContigToLoad);
+		boolean parseTID=false;
+		outstream.print("Calculating kmer frequency spectra: \t");
+		SpectraCounter sc=new SpectraCounter(outstream, parseCov, parseTID, sizeMap);
+		sc.makeSpectra(contigs, null, minContigToLoad);
+		phaseTimer.stopAndPrint();
+		return contigs;
+	}
 	
 	/*--------------------------------------------------------------*/
 	/*----------------         Data Loading         ----------------*/
 	/*--------------------------------------------------------------*/
 	
-	void loadNetwork(String fname, float cutoff, int samples) {
-		if(fname==null) {
-			net0=null;
-			return;
-		}
-		
+	CellNet loadNetwork(String fname, String size, float cutoff, int samples) {
+		if(fname==null) {return null;}
+		String d=(samples<2 ? "1" : "N");
 		if(fname.equals("auto")) {
-			assert(false) : "TODO";
+			//E.G. "?quickbin1D_small.bbnet" or "?quickbinND_small.bbnet"
+			fname=Data.findPath("?quickbin"+d+"D_"+size+".bbnet", false);
 		}
-		net0=CellNetParser.load(fname);
+		CellNet net0=CellNetParser.load(fname);
 		if(cutoff!=-9999) {net0.cutoff=cutoff;}
+		return net0;
 	}
 	
 	void calculateDepth(ArrayList<Contig> contigs) {
@@ -243,6 +361,7 @@ public class DataLoader extends BinObject {
 		}else if(sam) {
 			Timer t=new Timer(outstream);
 			HashMap<String, Contig> contigMap=toMap(contigs);
+			long readsUsed=0;
 			if(loadSamSerial) {
 				for(int i=0; i<readFiles.size(); i++) {
 					FileFormat ff=FileFormat.testInput(readFiles.get(i), FileFormat.SAM, null, true, false);
@@ -250,10 +369,28 @@ public class DataLoader extends BinObject {
 				}
 			}else {
 				if(makePairGraph) {graph=new IntHashMap[contigMap.size()];}
+
+				SamLine.PARSE_0=false;
+				SamLine.PARSE_7=false;
+				SamLine.PARSE_8=false;
+				SamLine.PARSE_10=false;
+				SamLine.PARSE_OPTIONAL_MATEQ_ONLY=true;
+//				public static boolean PARSE_OPTIONAL=true;
+//				public static boolean PARSE_OPTIONAL_MD_ONLY=false;
+				
 				SamLoader samLoader=new SamLoader(outstream);
 				samLoader.minMapq=minMapq;
 				samLoader.minMateq=minMapq;
+
+				samLoader.minID=minID;
+				samLoader.minMateID=minMateID;
+				samLoader.maxSubs=maxSubs;
+				samLoader.tipLimit=tipLimit;
+				samLoader.minEntropy=minEntropy;
+				samLoader.minAlignedBases=minAlignedBases;
+				
 				samLoader.load(readFiles, contigMap, contigs, graph);
+				readsUsed=samLoader.readsUsed;
 				if(makePairGraph) {
 					synchronized(graph) {
 						for(int i=0; i<contigs.size(); i++) {
@@ -269,7 +406,7 @@ public class DataLoader extends BinObject {
 				}
 				depthCalculated=true;
 			}
-			t.stop("Loaded "+Tools.plural(" read file", readFiles.size())+": ");
+			t.stop("Loaded "+Tools.plural("file", readFiles.size())+" and "+readsUsed+" reads: ");
 		}
 		
 		if(readFiles.isEmpty() && !depthCalculated) {
@@ -334,6 +471,7 @@ public class DataLoader extends BinObject {
 			}
 		}
 		phaseTimer.stopAndPrint();
+		if(!loud) {return;}
 		outstream.println("Type:       \tGood\tBad\tOther");
 		outstream.println("Edges:      \t"+goodEdges+"\t"+badEdges+"\t"+otherEdges);
 		outstream.println("Reciprocal: \t"+reciprocalGood+"\t"+reciprocalBad+"\t"+reciprocalOther);
@@ -363,10 +501,12 @@ public class DataLoader extends BinObject {
 		return map;
 	}
 	
-	ArrayList<Contig> loadContigs(String fname, int minlen){
+	ArrayList<Contig> loadContigsST(String fname, int minlen){
+		//Turn off read validation in the input threads to increase speed
 		assert(fname!=null) : "No contigs specified.";
 		outstream.print("Loading contigs:\t");
 		phaseTimer.start();
+		sizeMap=new IntLongHashMap(1023);
 		FileFormat ff=FileFormat.testInput(fname, FileFormat.FASTA, null, true, true);
 		ArrayList<Contig> list=new ArrayList<Contig>();
 
@@ -403,6 +543,7 @@ public class DataLoader extends BinObject {
 		if(ln!=null){
 			cris.returnList(ln.id, ln.list==null || ln.list.isEmpty());
 		}
+		errorState|=ReadWrite.closeStream(cris);
 		phaseTimer.stopAndPrint();
 		Collections.sort(list);
 		for(int i=0; i<list.size(); i++) {list.get(i).setID(i);}
@@ -412,12 +553,16 @@ public class DataLoader extends BinObject {
 	Contig loadContig(Read r, int minlen) {
 		contigsLoaded++;
 		basesLoaded+=r.length();
-//		final int tid=parseTaxID(r.name());
-//		if(tid>0) {sizeMap.increment(tid, r.length());}
+		int tid=-1;
+		if(validation) {
+			tid=parseTaxID(r.name());
+			if(tid>0) {sizeMap.increment(tid, r.length());}
+		}
 		if(r.length()<minlen) {return null;}
 		contigsRetained++;
 		basesRetained+=r.length();
 		Contig c=new Contig(r.name(), r.bases, (int)contigsRetained);
+		c.labelTaxid=tid;
 //		if(tid>0) {
 //			c.labelTaxid=tid;
 //			if(!validation) {c.taxid=tid;}
@@ -564,6 +709,14 @@ public class DataLoader extends BinObject {
 			lpt.set(name);
 			float depth=lpt.parseFloat(3);
 			c.setDepth(depth, 0);
+		}else if(name.contains("_cov_")) {//Generic
+			lps.set(name);
+			for(int i=0; i<lps.terms()-1; i++) {
+				if(lps.termEquals("cov", i)) {
+					i++;
+					c.appendDepth(lps.parseFloat(i));
+				}
+			}
 		}else {
 			return false;
 		}
@@ -602,7 +755,7 @@ public class DataLoader extends BinObject {
 			int edges=(lp.terms()-edgeStart)/2;
 			Contig c=contigs.get(id);
 			assert(c.id()==id);
-			assert(c.size()==size);
+			assert(c.size()==size) : c.name()+", "+c.size()+", "+size+"\n"+new String(line);
 			assert(lp.termEquals(c.shortName, 0));
 			assert(c.numDepths()==0);
 			for(int i=0; i<samples; i++) {
@@ -624,6 +777,39 @@ public class DataLoader extends BinObject {
 		phaseTimer.stopAndPrint();
 	}
 	
+	public long trimEdges(ArrayList<Contig> contigs, int maxEdges, int minWeight, boolean reciprocal) {
+		phaseTimer.start();
+		long trimmed=trimEdgesPass(contigs, maxEdges+99, minWeight, reciprocal);
+		trimmed+=trimEdgesPass(contigs, maxEdges, minWeight, reciprocal);
+		phaseTimer.stop("Trimmed "+trimmed+" edges: ");
+		return trimmed;
+	}
+	
+	public long trimEdgesPass(ArrayList<Contig> contigs, int maxEdges, int minWeight, boolean reciprocal) {
+//		Timer t=new Timer(outstream);
+		long trimmed=0;
+		for(int i=0; i<contigs.size(); i++) {
+			Contig c=contigs.get(i);
+			assert(c.id()==i);
+			if(c.pairMap!=null) {
+				trimmed+=c.pairMap.size();
+				ArrayList<KeyValue> list=KeyValue.toList(c.pairMap);
+				c.pairMap.clear();
+				for(KeyValue kv : list) {
+					if(c.pairMap.size()>=Binner.maxEdges) {break;}
+					if(kv.value>=minWeight && kv.key<contigs.size()) {
+						if(!reciprocal || contigs.get(kv.key).countEdgesTo(c)>minWeight) {
+							c.pairMap.put(kv.key, kv.value);
+						}
+					}
+				}
+				trimmed-=c.pairMap.size();
+				if(c.pairMap.isEmpty()) {c.pairMap=null;}
+			}
+		}
+		return trimmed;
+	}
+	
 	public static void writeCov(String fname, Collection<Contig> contigs, int numDepths, PrintStream outstream) {
 		outstream.print("Writing coverage to "+fname+": ");
 		Timer t=new Timer(outstream);
@@ -651,9 +837,10 @@ public class DataLoader extends BinObject {
 	/** Assembly path */
 	String ref=null;
 	String covIn=null;
-	
-	String netFile=null;
-	float netCutoff=-9999;
+
+	String netFileSmall="auto";
+	String netFileMid="auto";
+	String netFileLarge="auto";
 	
 	private final ArrayList<String> covstats=new ArrayList<String>();
 	
@@ -680,6 +867,13 @@ public class DataLoader extends BinObject {
 
 	int minContigToLoad=100;
 	int minMapq=20;
+	float minID=0.96f;//Optimal results so far are from 0.98 but that is pretty high
+	float minMateID=0.97f;
+	int maxSubs=999;
+	float minEntropy=0;
+	int tipLimit=100;
+	int minAlignedBases=1;
+	int gap=0;
 	
 	/** Quit after processing this many input reads; -1 means no limit */
 	private long maxReads=-1;
@@ -691,9 +885,14 @@ public class DataLoader extends BinObject {
 	IntHashMap[] graph;
 	
 	static int MAX_DEPTH_COUNT=999;
+	static int MAX_EDGES_TO_PRINT=8;
 	static boolean loadSamSerial=false;
 	boolean makePairGraph=true;
 	int numDepths=0;
+	static boolean streamContigs=true;
+	boolean errorState=false;
+	
+	static ArrayList<Contig> allContigs;
 	
 	/*--------------------------------------------------------------*/
 	/*----------------         Final Fields         ----------------*/
