@@ -95,6 +95,7 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 		sketcher=(sketchContigs || sketchClusters || sketchOutput) ? new BinSketcher(16, 2000) : null;
 		binner.sketcher=loader.sketcher=sketcher;
 		Sketch.defaultParams.format=DisplayParams.FORMAT_JSON;
+		KmerProb.load();
 	}
 	
 	/*--------------------------------------------------------------*/
@@ -123,10 +124,34 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 			
 			if(a.equals("verbose")){
 				verbose=Parse.parseBoolean(b);
+			}else if(a.equals("loud")){
+				loud=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equals("vectorout")){
 				vectorOut=b;
+			}else if(a.equalsIgnoreCase("emitTP")){
+				Oracle.emitTP=Parse.parseBoolean(b);
+			}else if(a.equalsIgnoreCase("emitTN")){
+				Oracle.emitTN=Parse.parseBoolean(b);
+			}else if(a.equalsIgnoreCase("emitFP")){
+				Oracle.emitFP=Parse.parseBoolean(b);
+			}else if(a.equalsIgnoreCase("emitFN")){
+				Oracle.emitFN=Parse.parseBoolean(b);
+			}else if(a.equalsIgnoreCase("minEmitSize")){
+				Oracle.minEmitSize=Parse.parseIntKMG(b);
+			}else if(a.equalsIgnoreCase("maxEmitSize")){
+				Oracle.maxEmitSize=Parse.parseIntKMG(b);
+			}else if(a.equalsIgnoreCase("negativeEmitProb")){
+				Oracle.negativeEmitProb=Double.parseDouble(b);
+			}
+			
+			else if(a.equals("sizehist")){
+				sizeHist=b;
+			}else if(a.equals("report")){
+				report=b;
+			}else if(a.equalsIgnoreCase("writeChaff") || a.equalsIgnoreCase("chaff")){
+				writeChaff=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equals("clusterbytax") || a.equals("clusterbytaxid")){
@@ -139,8 +164,12 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 				processResidue=Parse.parseBoolean(b);
 			}else if(a.equals("purify") || a.equalsIgnoreCase("purifyClusters")){
 				purifyClusters=Parse.parseBoolean(b);
+			}else if(a.equals("fuse") || a.equalsIgnoreCase("fuseclusters")){
+				fuseClusters=Parse.parseBoolean(b);
 			}else if(a.equals("entropy") || a.equals("calcentropy")){
 				SpectraCounter.calcEntropy=Parse.parseBoolean(b);
+			}else if(a.equals("counttrimers") || a.equals("trimers")){
+				SpectraCounter.countTrimers=Parse.parseBoolean(b);
 			}else if(a.equals("strandedness") || a.equals("calcstrandedness")){
 				SpectraCounter.calcStrandedness=Parse.parseBoolean(b);
 			}else if(a.equals("entropyk")){
@@ -170,8 +199,8 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 				BinObject.setQuant(Tools.max(1, Integer.parseInt(b)));
 			}
 			
-			else if(a.equals("mincluster") || a.equals("minclustersize")){
-				minBasesPerCluster=Parse.parseIntKMG(b);
+			else if(a.equals("mincluster") || a.equals("minclustersize") || a.equals("mcs")){
+				minClusterSize=Parse.parseIntKMG(b);
 			}else if(a.equals("mincontigs")){
 				minContigsPerCluster=Parse.parseIntKMG(b);
 			}else if(a.equals("validate") || a.equals("validation")){
@@ -188,24 +217,24 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 				edgeStringency2=Float.parseFloat(b);
 			}
 			
-			else if(a.equalsIgnoreCase("xstrict")){
+			else if(a.equalsIgnoreCase("xstrict") || a.equalsIgnoreCase("xs")){
 				strictnessMult=(Parse.parseBoolean(b) ? 0.6f : 1);
-			}else if(a.equalsIgnoreCase("ustrict")){
+			}else if(a.equalsIgnoreCase("ustrict") || a.equalsIgnoreCase("us")){
 				strictnessMult=(Parse.parseBoolean(b) ? 0.7f : 1);
-			}else if(a.equalsIgnoreCase("vstrict")){
+			}else if(a.equalsIgnoreCase("vstrict") || a.equalsIgnoreCase("vs")){
 				strictnessMult=(Parse.parseBoolean(b) ? 0.8f : 1);
-			}else if(a.equalsIgnoreCase("strict")){
+			}else if(a.equalsIgnoreCase("strict") || a.equalsIgnoreCase("s")){
 				strictnessMult=(Parse.parseBoolean(b) ? 0.9f : 1);
-			}else if(a.equalsIgnoreCase("normal")){
+			}else if(a.equalsIgnoreCase("normal") || a.equalsIgnoreCase("n")){
 				strictnessMult=(Parse.parseBoolean(b) ? 1 : 1);
-			}else if(a.equalsIgnoreCase("loose") || a.equalsIgnoreCase("sensitive")){
-				strictnessMult=(Parse.parseBoolean(b) ? 1.1f : 1);
-			}else if(a.equalsIgnoreCase("vloose") || a.equalsIgnoreCase("vsensitive")){
-				strictnessMult=(Parse.parseBoolean(b) ? 1.2f : 1);
-			}else if(a.equalsIgnoreCase("uloose") || a.equalsIgnoreCase("usensitive")){
-				strictnessMult=(Parse.parseBoolean(b) ? 1.3f : 1);
-			}else if(a.equalsIgnoreCase("xloose") || a.equalsIgnoreCase("xsensitive")){
-				strictnessMult=(Parse.parseBoolean(b) ? 1.4f : 1);
+			}else if(a.equalsIgnoreCase("loose") || a.equalsIgnoreCase("l")){
+				strictnessMult=(Parse.parseBoolean(b) ? 1.125f : 1);
+			}else if(a.equalsIgnoreCase("vloose") || a.equalsIgnoreCase("vl")){
+				strictnessMult=(Parse.parseBoolean(b) ? 1.25f : 1);
+			}else if(a.equalsIgnoreCase("uloose") || a.equalsIgnoreCase("ul")){
+				strictnessMult=(Parse.parseBoolean(b) ? 1.375f : 1);
+			}else if(a.equalsIgnoreCase("xloose") || a.equalsIgnoreCase("xl")){
+				strictnessMult=(Parse.parseBoolean(b) ? 1.5f : 1);
 			}else if(a.equalsIgnoreCase("strictness")){
 				strictnessMult=Float.parseFloat(b);
 			}
@@ -244,8 +273,15 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 			String[] split=arg.split("=");
 			String a=split[0].toLowerCase();
 			String b=split.length>1 ? split[1] : null;
-			if(b!=null){binner.parse(arg, a, b);}
+			if(b!=null){
+				binner.parse(arg, a, b);
+				loader.parse(arg, a, b);
+			}
 		}
+		if(net0small!=null) {net0small.cutoff=Binner.netCutoff_small;}
+		if(net0small!=null) {net0mid.cutoff=Binner.netCutoff_mid;}
+		if(net0small!=null) {net0large.cutoff=Binner.netCutoff_large;}
+		binner.printThresholds();
 	}
 	
 	/** Ensure parameter ranges are within bounds and required parameters are set */
@@ -276,6 +312,7 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 		contigList=loader.loadData();
 		assert(isValid(contigList, false));
 		if(covOut!=null) {DataLoader.writeCov(covOut, contigList, loader.numDepths, outstream);}
+		loader.trimEdges(contigList, Binner.maxEdges, Binner.minEdgeWeight, Binner.reciprocalEdges);
 //		System.err.println("Thresholds:");
 //		binner.printThresholds();
 		binner.setSamples(loader.numDepths, strictnessMult);
@@ -309,17 +346,18 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 			long merges=binner.followEdges(contigList, contigList, oracle);
 			sum+=merges;
 			for(int i=1; i<followEdge1Passes && merges>0; i++) {
-				binList=Binner.toBinList(contigList);
+				binList=Binner.toBinList(contigList, 0);
 				merges=binner.followEdges(contigList, binList, oracle);
 				sum+=merges;
 			}
 			assert(binList==null ? isValid(contigList, true) : isValid(binList, false));
 			if(merges>0) {
-				binList=Binner.toBinList(contigList);
+				binList=Binner.toBinList(contigList, 0);
 			}
 			t2.stop("Merged "+sum+" bins:   ");
 			fastComparisonsEdge+=oracle.fastComparisons;
 			slowComparisonsEdge+=oracle.slowComparisons;
+			netComparisonsEdge+=oracle.netComparisons;
 		}
 		
 		long fastComp=0, slowComp=0;
@@ -348,7 +386,7 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 			Oracle oracle=new Oracle(edgeStringency2, 2);
 			for(int i=0; i<followEdge2Passes && merges>1; i++) {
 //				assert(isValid(contigList, true));
-				binList=Binner.toBinList(contigList);
+				binList=Binner.toBinList(contigList, 0);
 //				assert(isValid(binList, false));
 				merges=binner.followEdges(contigList, binList, oracle);
 				sum+=merges;
@@ -356,7 +394,7 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 			t2.stop("Merged "+sum+" bins:   ");
 			if(sum>0) {
 				binMap.clear(true);
-				binList=Binner.toBinList(contigList);
+				binList=Binner.toBinList(contigList, 0);
 				assert(isValid(binList, false));
 				binMap.addAll(binList, Binner.minSizeToMerge);
 			}
@@ -376,15 +414,36 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 				slowComp=binner.slowComparisons.get();
 				//it would be best to have a bigger compare size limit for residue prior to this
 				//Possibly do this in 2 passes, with range +0 and +2
-				int removedThisPhase=binner.refinePhase(binMap, 
-						"f", 0.9f, -1, true, true, binner.baseRange, binner.basePasses+0);
-				removedThisPhase=binner.refinePhase(binMap, 
-						"g", 1.0f, -1, true, true, binner.baseRange+2, binner.basePasses+1);
+				if(binner.runPassF) {
+					int removedThisPhase=binner.refinePhase(binMap, 
+							"f", 0.9f, -1, true, true, binner.baseRange, Binner.minSizeToMerge, binner.basePasses+0);
+				}
+				if(binner.runPassG) {
+					int removedThisPhase=binner.refinePhase(binMap, 
+							"g", 1.0f, -1, true, true, binner.baseRange+2, Binner.minSizeToMerge, binner.basePasses+1);
+				}
 			}
 			fastComparisonsRefine+=(binner.fastComparisons.get()-fastComp);
 			slowComparisonsRefine+=(binner.slowComparisons.get()-slowComp);
 		}
 		
+		if(fuseClusters) {
+			long fused=99999, total=0;
+			for(int i=0; i<4 && fused>1; i++) {
+				ArrayList<Bin> bins=Binner.toBinList(contigList, Binner.fuseLowerLimit);
+				Collections.sort(bins);
+				fused=binner.fuse(contigList, bins, Binner.fuseStringency);
+				total+=fused;
+			}
+			if(total>0) {
+				binMap.clear(true);
+				binList=Binner.toBinList(contigList, 0);
+				assert(isValid(binList, false));
+				binMap.addAll(binList, Binner.minSizeToMerge);
+			}
+			System.err.println("Fused "+total+" clusters.");
+		}
+		
 		if(Oracle.bsw!=null) {
 			Oracle.bsw.poisonAndWait();
 			Oracle.bsw=null;
@@ -396,7 +455,7 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 			fastComp=(binner.fastComparisons.get());
 			slowComp=(binner.slowComparisons.get());
 			int purified=binner.purify(binMap, 
-					2f, binner.baseRange+4, minBasesPerCluster, Tools.min(minBasesPerCluster/2, 20000));
+					Binner.purifyStringency, binner.baseRange+4, minClusterSize, Tools.min(minClusterSize/2, 20000));
 			fastComparisonsPurify+=(binner.fastComparisons.get()-fastComp);
 			slowComparisonsPurify+=(binner.slowComparisons.get()-slowComp);
 			t2.stop("Removed "+purified+" contigs:   ");
@@ -424,7 +483,7 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 //		t2.start();
 //		System.err.print("Calculating statistics.");
 		for(Bin b : bins) {
-			if(b.size()<minBasesPerCluster) {continue;}
+			if(b.size()<minClusterSize) {continue;}
 			if(validation) {b.calcContam(sizeMap);}
 			long contam=(int)(b.size()*b.contam);
 			compltScore+=((b.size()-contam)*b.completeness);
@@ -438,7 +497,7 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 				cleanBins++;
 				cleanSize+=b.size();
 			}
-			if(b.size()>=minBasesPerCluster) {
+			if(b.size()>=minClusterSize) {
 				sizeOverLimit+=b.size();
 				binsOverLimit++;
 				contigsOverLimit+=b.numContigs();
@@ -457,50 +516,39 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 //			if(a.size()<1000 || i>=4) {break;}
 //		}
 		
-		outputClusters(outPattern, bins, minBasesPerCluster, minContigsPerCluster);
-//		
-//		//Create a read input stream
-//		final ConcurrentReadInputStream cris=makeCris(ffin1, ffin2);
-//		
-//		//Optionally create a read output stream
-//		final ConcurrentReadOutputStream ros=makeCros(outPattern);
-//		
-//		//Reset counters
-//		readsProcessed=readsOut=0;
-//		basesProcessed=basesOut=0;
-//		
-//		//Process the reads in separate threads
-//		spawnThreads(cris, ros);
+		if(report!=null) {GradeBins.printClusterReport(bins, minClusterSize, report);}
+		outputClusters(outPattern, bins, minClusterSize, minContigsPerCluster);
 		
 		if(verbose){outstream.println("Finished; closing streams.");}
 		
-//		//Write anything that was accumulated by ReadStats
-//		errorState|=ReadStats.writeAll();
-//		//Close the read streams
-//		errorState|=ReadWrite.closeStreams(cris, ros);
-		
 		//Report timing and results
 		outstream.println();
 		t.stopAndPrint();
-//		outstream.println(Tools.timeReadsBasesProcessed(t, readsProcessed, basesProcessed, 8));
-//		outstream.println(Tools.readsBasesOut(readsProcessed, basesProcessed, readsOut, basesOut, 8, false));
 
 		long totalComp=binner.slowComparisons.get()+slowComparisonsEdge;
-		float cps=(totalComp/(float)ct.elapsed)*1000000000;
-		outstream.println("Initial Fast Comparisons: \t"+fastComparisonsCreate);
-		outstream.println("Initial Slow Comparisons: \t"+slowComparisonsCreate);
-		outstream.println("Grid Fast Comparisons:    \t"+fastComparisonsRefine);
-		outstream.println("Grid Slow Comparisons:    \t"+slowComparisonsRefine);
-		outstream.println("Edge Fast Comparisons:    \t"+fastComparisonsEdge);
-		outstream.println("Edge Slow Comparisons:    \t"+slowComparisonsEdge);
-		outstream.println("Residue Fast Comparisons: \t"+fastComparisonsResidue);
-		outstream.println("Residue Slow Comparisons: \t"+slowComparisonsResidue);
-		outstream.println("Purify Fast Comparisons:  \t"+fastComparisonsPurify);
-		outstream.println("Purify Slow Comparisons:  \t"+slowComparisonsPurify);
-		outstream.println("Total Slow Comparisons:   \t"+totalComp+" \t"+Tools.padKMB((long)cps, 0)+" cps");
+		fastComp=binner.fastComparisons.get()+fastComparisonsEdge;
+		long netComp=binner.netComparisons.get()+netComparisonsEdge;
+		float scps=(totalComp/(float)ct.elapsed)*1000000000;
+		float fcps=(fastComp/(float)ct.elapsed)*1000000000;
+		float ncps=(netComp/(float)ct.elapsed)*1000000000;
+		if(loud) {
+			outstream.println("Initial Fast Comparisons: \t"+fastComparisonsCreate);
+			outstream.println("Initial Slow Comparisons: \t"+slowComparisonsCreate);
+			outstream.println("Grid Fast Comparisons:    \t"+fastComparisonsRefine);
+			outstream.println("Grid Slow Comparisons:    \t"+slowComparisonsRefine);
+			outstream.println("Edge Fast Comparisons:    \t"+fastComparisonsEdge);
+			outstream.println("Edge Slow Comparisons:    \t"+slowComparisonsEdge);
+			outstream.println("Residue Fast Comparisons: \t"+fastComparisonsResidue);
+			outstream.println("Residue Slow Comparisons: \t"+slowComparisonsResidue);
+			outstream.println("Purify Fast Comparisons:  \t"+fastComparisonsPurify);
+			outstream.println("Purify Slow Comparisons:  \t"+slowComparisonsPurify);
+		}
+		outstream.println("Total Fast Comparisons:   \t"+fastComp+" \t"+Tools.padKMB((long)fcps, 0)+" cps");
+		outstream.println("Total Slow Comparisons:   \t"+totalComp+" \t"+Tools.padKMB((long)scps, 0)+" cps");
+		outstream.println("Total Net Comparisons:    \t"+netComp+" \t"+Tools.padKMB((long)ncps, 0)+" cps");
 		outstream.println();
 
-		if(validation) {
+		if(validation && loud) {
 			outstream.println(formatString("Good Merges Follow", 29, binner.goodMergesFollow, binner.badMergesFollow));
 			outstream.println(formatString("Bad Merges Follow", 29, binner.badMergesFollow, binner.goodMergesFollow));
 			outstream.println(formatString("Bad Merge Size Follow", 29, binner.badMergeSizeFollow, binner.goodMergeSizeFollow));
@@ -523,24 +571,40 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 			outstream.println();
 		}
 
-		outstream.println("Sequence Recovery:           \t"+
-				String.format("%.3f", sizeOverLimit*100.0/loader.basesLoaded));
-		outstream.println("Contig Recovery:             \t"+
-				String.format("%.3f", contigsOverLimit*100.0/loader.contigsLoaded));
+//		outstream.println("Sequence Recovery:           \t"+
+//				String.format("%.3f", sizeOverLimit*100.0/loader.basesLoaded));
+//		outstream.println("Contig Recovery:             \t"+
+//				String.format("%.3f", contigsOverLimit*100.0/loader.contigsLoaded));
+//
+//		if(validation) {
+//			outstream.println("Bad Contigs:                 \t"+
+//					String.format("%.3f", badContigsOverLimit*100.0/contigsOverLimit));
+//			outstream.println("Genomes Represented:         \t"+
+//					String.format("%.3f", (tidBins.size())*100.0/sizeMap.size()));
+//			outstream.println("Completeness Score:          \t"+
+//					String.format("%.3f", 100*compltScore/loader.basesLoaded));
+//			outstream.println("Contamination Score:         \t"+
+//					String.format("%.4f", 100*contamScore/loader.basesLoaded));
+//		}
+//		outstream.println();
+//		
 
-		if(validation) {
-			outstream.println("Bad Contigs:                 \t"+
-					String.format("%.3f", badContigsOverLimit*100.0/contigsOverLimit));
-			outstream.println("Genomes Represented:         \t"+
-					String.format("%.3f", (tidBins.size())*100.0/sizeMap.size()));
-			outstream.println("Completeness Score:          \t"+
-					String.format("%.3f", 100*compltScore/loader.basesLoaded));
-			outstream.println("Contamination Score:         \t"+
-					String.format("%.4f", 100*contamScore/loader.basesLoaded));
-		}
-		outstream.println();
+		ArrayList<BinStats> stats=GradeBins.toStats(bins, minClusterSize);
 		
-		GradeBins.printL90(bins, loader.basesLoaded);
+		if(loud && validation) {
+			outstream.println();
+			GradeBins.printCleanDirty(stats);
+		}
+		
+		GradeBins.printL90(stats, loader.basesLoaded);
+		
+		outstream.println();
+		GradeBins.printScore(stats, loader.basesLoaded, loader.contigsLoaded, sizeMap.size(), validation);
+		
+		if(validation) {
+			outstream.println();
+			GradeBins.printBinQuality(stats, minClusterSize, outstream);
+		}
 		
 		//Throw an exception of there was an error in a thread
 		if(errorState){
@@ -558,10 +622,21 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 	
 	private void outputClusters(String pattern, ArrayList<? extends Bin> clusters, long minBases, int minContigs) {
 //		if(pattern==null) {return;}
-		if(pattern!=null) {outstream.println("Writing clusters to "+pattern);}
+		if(pattern!=null) {
+			if(!pattern.contains(".") && !pattern.contains("%")) {
+				if(!pattern.endsWith("/")) {pattern=pattern+"/";}
+				pattern=pattern+"bin_%.fa";
+			}
+			outstream.println("Writing clusters to "+pattern);
+		}
 		long sizeOverLimit=0;
 		if(pattern!=null && pattern.indexOf('%')>=0) {
-			final ByteStreamWriter chaff=ByteStreamWriter.makeBSW(pattern.replace("%", "chaff"), overwrite, append, true);
+			
+			ByteStreamWriter chaff=null;
+			if(writeChaff) {
+				chaff=ByteStreamWriter.makeBSW(pattern.replace("%", "chaff"), overwrite, append, true);
+			}
+			
 			final ByteBuilder bb=new ByteBuilder(8192);
 			for(int i=0; i<clusters.size(); i++) {
 				Bin a=clusters.get(i);
@@ -577,7 +652,7 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 					printBin(a, chaff, bb, i+1);
 				}
 			}
-			chaff.poisonAndWait();
+			if(chaff!=null) {chaff.poisonAndWait();}
 		}else {
 			final ByteBuilder bb=new ByteBuilder(8192);
 			final ByteStreamWriter bsw=ByteStreamWriter.makeBSW(pattern, overwrite, append, true);
@@ -592,12 +667,23 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 		}
 		float cpct=contigsWritten*100f/loader.contigsLoaded;
 		float bpct=basesWritten*100f/loader.basesLoaded;
-		outstream.println("\nMetric   \t        In\t       Out\tPercent");
-		outstream.println("Clusters \t"+Tools.padLeft(0, 10)+"\t"+Tools.padLeft(clustersWritten, 10));
-		outstream.println("Contigs  \t"+Tools.padLeft(loader.contigsLoaded, 10)+"\t"+
-				Tools.padLeft(contigsWritten, 10)+"\t"+Tools.format("%.2f%%", cpct));
-		outstream.println("Bases    \t"+Tools.padLeft(loader.basesLoaded, 10)+"\t"+
-				Tools.padLeft(basesWritten, 10)+"\t"+Tools.format("%.2f%%", bpct));
+		if(loud) {
+			outstream.println("\nMetric   \t        In\t       Out\tPercent");
+			outstream.println("Clusters \t"+Tools.padLeft(0, 10)+"\t"+Tools.padLeft(clustersWritten, 10));
+			outstream.println("Contigs  \t"+Tools.padLeft(loader.contigsLoaded, 10)+"\t"+
+					Tools.padLeft(contigsWritten, 10)+"\t"+Tools.format("%.2f%%", cpct));
+			outstream.println("Bases    \t"+Tools.padLeft(loader.basesLoaded, 10)+"\t"+
+					Tools.padLeft(basesWritten, 10)+"\t"+Tools.format("%.2f%%", bpct));
+		}
+		if(sizeHist!=null) {
+			final ByteStreamWriter bsw=ByteStreamWriter.makeBSW(sizeHist, overwrite, append, true);
+			bsw.print("#Size\tGood\tBad\n");
+			for(int i=0; i<binner.goodMergeSize.length; i++) {
+				long size=1L<<i;
+				bsw.print(size).tab().print(binner.goodMergeSize[i]).tab().print(binner.badMergeSize[i]).nl();
+			}
+			bsw.poisonAndWait();
+		}
 	}
 	
 	private void printBin(Bin a, ByteStreamWriter bsw, ByteBuilder bb, int id) {
@@ -829,12 +915,15 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 
 	/** Primary output file path; should contain % symbol for bins */
 	private String outPattern=null;
+	private boolean writeChaff=false;
 	
 	/** Override output file extension */
 	private String extout=null;
 	
 	private String covOut=null;
 	private String vectorOut=null;
+	private String sizeHist=null;
+	private String report=null;
 	
 	private ArrayList<Contig> contigList;
 	
@@ -843,8 +932,9 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 	boolean refineClusters=true;
 	boolean processResidue=true;
 	boolean purifyClusters=true;
+	boolean fuseClusters=true;
 	int followEdge1Passes=0;
-	int followEdge2Passes=4;
+	int followEdge2Passes=5;
 	float edgeStringency1=0.25f;
 	float edgeStringency2=1.1f;
 	
@@ -871,8 +961,8 @@ public class QuickBin extends BinObject implements Accumulator<QuickBin.ProcessT
 	
 
 	private long fastComparisonsCreate=0, slowComparisonsCreate=0;
-	private long fastComparisonsRefine=0, slowComparisonsRefine=0;
-	private long fastComparisonsEdge=0, slowComparisonsEdge=0;
+	private long fastComparisonsRefine=0, slowComparisonsRefine=0, netComparisonsRefine=0;
+	private long fastComparisonsEdge=0, slowComparisonsEdge=0, netComparisonsEdge=0;
 	private long fastComparisonsResidue=0, slowComparisonsResidue=0;
 	private long fastComparisonsPurify=0, slowComparisonsPurify=0;
 	
