@@ -30,12 +30,10 @@ import tax.TaxTree;
 import tracker.ReadStats;
 
 /**
- * This class does nothing.
- * It serves as a template for generating reads,
- * potentially based on some input sequence.
+ * Generates synthetic reads from multiple input fastas.
  * 
  * @author Brian Bushnell
- * @date June 8, 2019
+ * @date Feb 8, 2025
  *
  */
 public class RandomReadsMG {
@@ -140,7 +138,7 @@ public class RandomReadsMG {
 				minDepth=Float.parseFloat(b);
 			}else if(a.equals("maxdepth") || a.equals("maxcov")){
 				maxDepth=Float.parseFloat(b);
-			}else if(a.equals("depthvariance")){
+			}else if(a.equals("depthvariance") || a.equals("variance")){
 				depthVariance=Float.parseFloat(b);
 			}else if(a.equals("mode") || a.equals("depthmode")){
 				depthMode=Tools.find(b.toUpperCase(), modes);
@@ -150,10 +148,10 @@ public class RandomReadsMG {
 				readlen=Integer.parseInt(b);
 			}else if(a.equals("paired") || a.equals("int") || a.equals("interleaved")){
 				paired=Parse.parseBoolean(b);
-			}else if(a.equals("depthvariance")){
-				depthVariance=Float.parseFloat(b);
 			}else if(a.equals("seed")){
 				seed=Long.parseLong(b);
+			}else if(b==null && Tools.find(arg.toUpperCase(), modes)>=0){
+				depthMode=Tools.find(arg.toUpperCase(), modes);
 			}else if(a.equals("parse_flag_goes_here")){
 				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
@@ -443,13 +441,16 @@ public class RandomReadsMG {
 				taxID=TaxTree.parseHeaderStatic2(c0.id, tree);
 			}
 			System.err.println("File "+fnum+", tid "+taxID+": depth="+String.format("%.2f", fileDepth));
-			assert(taxID>0) : "Can't parse taxID from "+fname;
+//			assert(taxID>0) : "Can't parse taxID from "+fname;
 
 			//As long as there is a nonempty read list...
 			while(ln!=null && ln.size()>0){
 				
 				for(Read c : ln) {
-					float depthRatio=1f+(depthVariance*(randy.nextFloat()+randy.nextFloat()))-depthVariance;
+					float depthRatio=1f;
+					if(varyDepthPerContig) {
+						depthRatio=1f+(depthVariance*(randy.nextFloat()+randy.nextFloat()))-depthVariance;
+					}
 					float contigDepth=depthRatio*fileDepth;
 //					System.err.println("depthRatio = "+depthRatio+"; contigDepth="+contigDepth);
 					processContig(c, contigDepth, taxID, fnum);
@@ -480,11 +481,12 @@ public class RandomReadsMG {
 			long readsGenerated=0;
 			long basesGenerated=0;
 			ArrayList<Read> list=new ArrayList<Read>(200);
+			float variance=varyDepthPerContig ? 0 : randy.nextFloat()*depthVariance;
 			
 //			System.err.println("Generating "+basesToGenerate+" for depth-"+depth+" contig "+contig.id);
 			
 			for(long i=0; basesGenerated<basesToGenerate; i++) {
-				Read r=generateRead(contig, i, taxID, fnum, contig.numericID);
+				Read r=generateRead(contig, i, taxID, fnum, contig.numericID, variance);
 				if(r!=null) {
 					list.add(r);
 					readsGenerated+=r.pairCount();
@@ -502,14 +504,15 @@ public class RandomReadsMG {
 			basesOutT+=basesGenerated;
 		}
 		
-		private Read generateRead(Read contig, long rnum, int taxID, int fnum, long cnum) {
-			if(paired) {return generateReadPair(contig, rnum, taxID, fnum, cnum);}
-			else {return generateReadSingle(contig, rnum, taxID, fnum, cnum);}
+		private Read generateRead(Read contig, long rnum, int taxID, int fnum, long cnum, float variance) {
+			if(paired) {return generateReadPair(contig, rnum, taxID, fnum, cnum, variance);}
+			else {return generateReadSingle(contig, rnum, taxID, fnum, cnum, variance);}
 		}
 		
-		private Read generateReadSingle(Read contig, long rnum, int taxID, int fnum, long cnum) {
+		private Read generateReadSingle(Read contig, long rnum, int taxID, int fnum, long cnum, float variance) {
 			int insert=readlen;
 			int start=randy.nextInt(contig.length()-insert);
+			if(skip((start+insert)/2, contig.length(), variance)){return null;}
 			int strand=randy.nextInt(2);
 			byte[] bases=Arrays.copyOfRange(contig.bases, start, start+readlen);
 			if(strand==1) {AminoAcid.reverseComplementBasesInPlace(bases);}
@@ -518,7 +521,7 @@ public class RandomReadsMG {
 			return r;
 		}
 		
-		private Read generateReadPair(Read contig, long rnum, int taxID, int fnum, long cnum) {
+		private Read generateReadPair(Read contig, long rnum, int taxID, int fnum, long cnum, float variance) {
 			double g=randy.nextGaussian()*0.25f;
 			int insert=(int)((1+g)*avgInsert);
 			while(insert>=contig.length() || insert<readlen) {
@@ -528,6 +531,7 @@ public class RandomReadsMG {
 			int start1=randy.nextInt(contig.length()-insert);
 			int strand=randy.nextInt(2);
 			int start2=start1+insert-readlen;
+			if(skip((start1+insert)/2, contig.length(), variance)){return null;}
 
 			byte[] bases1=Arrays.copyOfRange(contig.bases, start1, start1+readlen);
 			byte[] bases2=Arrays.copyOfRange(contig.bases, start2, start2+readlen);
@@ -547,6 +551,16 @@ public class RandomReadsMG {
 			return r1;
 		}
 		
+		//Skip making a read to vary depth within the contig
+		private boolean skip(int midpoint, int clen, float variance) {
+			if(variance<=0) {return false;}
+			//Then we want to vary within contigs
+			float maxSkipProb=1f-1f/(1f+variance);
+			float relativePosition=midpoint/(float)clen;
+			float skipProb=relativePosition*maxSkipProb;
+			return randy.nextFloat()<skipProb;
+		}
+		
 		private String makeHeader(int start, int strand, int insert, int taxID, int fnum, long cnum, int pnum) {
 			bb.clear().append('f').under().append(fnum).under().append('c').under().append(cnum);
 			bb.under().append('s').under().append(strand).under().append('p').under().append(start);
@@ -633,11 +647,12 @@ public class RandomReadsMG {
 	
 	private float minDepth=1;
 	private float maxDepth=256;
-	private float depthVariance=0.3f;
+	private float depthVariance=0.5f;
 	private float avgInsert=300;
 	private int readlen=150;
 	private boolean paired=true;
 	private long seed=-1;
+	private boolean varyDepthPerContig=false;
 	
 	static final String[] modes={"MIN4", "EXP", "ROOT", "LINEAR"};
 	static final int MIN4=0, EXP=1, ROOT=2, LINEAR=3;
