@@ -77,8 +77,9 @@ public class SimilarityMeasures {
         float hellingerDistance=(HELLINGER? hellingerDistance(a, b, inva, invb) : 0);
         float ksDifference=(KST ? ksTest(a, b, inva, invb) : 0);
         int div=(COSINE ? 1 : 0)+(EUCLID ? 1 : 0)+(ABSOLUTE ? 1 : 0)+(JSD ? 1 : 0)+(HELLINGER ? 1 : 0)+(KST ? 1 : 0);
-        return (cosineDifference+euclideanDistance+absoluteDifference+
+        float ret=(cosineDifference+euclideanDistance+absoluteDifference+
         		jensenShannonDivergence+hellingerDistance+ksDifference)/div;
+        return (Float.isFinite(ret) && ret>0 ? ret : 0);
     }
 
     public static float[] calculateDifferenceVector(int[] a, int[] b) {
@@ -118,19 +119,27 @@ public class SimilarityMeasures {
             normVec2+=bi*bi;
         }
 
-        return (float)(dotProduct/(Math.sqrt(normVec1)*Math.sqrt(normVec2)));
+        float ret=(float)(dotProduct/(Math.sqrt(normVec1)*Math.sqrt(normVec2)));
+        return (Float.isFinite(ret) && ret>0 ? ret : 0);
+    }
+
+    public static float cosineDifference(int[] a, int[] b) {
+    	float inva=1f/Tools.max(1, Tools.sum(a));
+    	float invb=1f/Tools.max(1, Tools.sum(b));
+    	float ret=1-cosineSimilarity(a, b, inva, invb);
+    	return (Float.isFinite(ret) && ret>0 ? ret : 0);
     }
 
     public static float cosineDifference(int[] a, int[] b, float inva, float invb) {
     	return 1-cosineSimilarity(a, b, inva, invb);
     }
 
-    public static float cosineDifferenceCompensated(int[] a, int[] b) {
-    	return 1-cosineSimilarityCompensated(a, b, BinObject.k(), BinObject.gcmap);
+    public static float cosineDifferenceCompensated(int[] a, int[] b, int k) {
+    	return 1-cosineSimilarityCompensated(a, b, k, BinObject.gcmapMatrix[k]);
     }
     
     public static float cosineSimilarity(int[] a, int[] b, float inva, float invb) {
-    	if(GC_COMPENSATED) {return cosineSimilarityCompensated(a, b, BinObject.k(), BinObject.gcmap);}
+    	if(GC_COMPENSATED) {return cosineSimilarityCompensated(a, b, 4, BinObject.gcmapMatrix[4]);}
         float dotProduct=0f;
         float normVec1=0f;
         float normVec2=0f;
@@ -187,6 +196,14 @@ public class SimilarityMeasures {
 
         return (float)Math.sqrt(sumSquaredDifferences);
     }
+    
+
+    public static float euclideanDistance(int[] a, int[] b) {
+    	float inva=1f/Tools.max(1, Tools.sum(a));
+    	float invb=1f/Tools.max(1, Tools.sum(b));
+    	float ret=euclideanDistance(a, b, inva, invb);
+    	return (Float.isFinite(ret) && ret>0 ? ret : 0);
+    }
 
     public static float euclideanDistance(int[] a, int[] b, float inva, float invb) {
         float sumSquaredDifferences=0f;
@@ -342,21 +359,33 @@ public class SimilarityMeasures {
     
     //2531 kcps (times include contig loading)
     //26 clusters
+//    Completeness Score:             60.278
+//    Contamination Score:            2.1925
     public static boolean COSINE=true;
     //2796 kcps
     //21 clusters
-    public static boolean EUCLID=false;
+    //Completeness Score:             60.909
+    //Contamination Score:            2.3108
+    public static boolean EUCLID=false;//0.008
     //2636 kcps
     //23 clusters at 4x threshold of cosine
-    public static boolean ABSOLUTE=false;
+//    Completeness Score:             60.947
+//    Contamination Score:            1.7679
+    public static boolean ABSOLUTE=false; //Best at 0.089
     //183 kcps
     //22 clusters
+//  Completeness Score:             59.169
+//  Contamination Score:            2.1959
     public static boolean JSD=false;
     //953 kcps
     //~22 at 2x threshold of cosine
-    public static boolean HELLINGER=false;
+//    Completeness Score:             61.072
+//    Contamination Score:            1.9358
+    public static boolean HELLINGER=false;//0.0425
     //1859 kcps
-    //20 clusters 
+    //20 clusters
+//    Completeness Score:             26.380
+//    Contamination Score:            3.1930
     public static boolean KST=false;
     
 }
