@@ -282,6 +282,38 @@ public class BloomFilter implements Serializable {
 		return pass && passes(r2, thresh);
 	}
 	
+	public float averageCount(final byte[] bases) {
+		if(bases==null || bases.length<k-1){return 0;}
+
+		long kmer=0;
+		long rkmer=0;
+		long sum=0;
+		int len=0;
+		int counted=0;
+		
+		int prev2=0, prev=0, count=0;
+		
+		for(int i=0; i<bases.length; i++){
+			byte b=bases[i];
+			long x=AminoAcid.baseToNumber[b];
+			long x2=AminoAcid.baseToComplementNumber[b];
+			kmer=((kmer<<bitsPerBase)|x)&mask;
+			rkmer=((rkmer>>>bitsPerBase)|(x2<<shift2))&mask;
+			if(x<0){len=0; rkmer=0;}else{len++;}
+			if(len>=k){
+				prev2=prev;
+				prev=count;
+				count=getCount(kmer, rkmer);
+				//This should get rid of collision spikes.
+				prev=Tools.min(prev, Tools.max(prev2, count));
+				sum+=prev;
+				counted++;
+			}
+		}
+		sum+=count; //Last kmer did not get counted; a 0 was used instead.
+		return sum/Tools.max(counted, 1f);
+	}
+	
 	public int minCount(Read r) {
 		if(r==null || r.length()<k-1){return -1;}
 		final byte[] bases=r.bases;
