@@ -36,7 +36,7 @@ public class BloomFilterCorrector {
 		return errorCorrect(r, leftCounts, rightCounts, kmers, counts, counts2, bb, bb2, tracker, bs);
 	}
 	
-	boolean hasErrorsFast(LongList kmers){
+	public boolean hasErrorsFast(LongList kmers){
 		if(kmers.size<1){return false;}
 		int prev=-1;
 		
@@ -69,7 +69,7 @@ public class BloomFilterCorrector {
 		tracker.clear();
 		int valid=fillKmers(bases, kmers);
 		if(valid<2){return 0;}
-		if(!r.containsUndefined() && !hasErrorsFast(kmers)){return 0;}
+//		if(!r.containsUndefined() && !hasErrorsFast(kmers)){return 0;}//TODO: This does not seem useful
 		
 
 		fillCounts(bases, kmers, counts);
