@@ -4,7 +4,6 @@ import java.io.File;
 import java.io.PrintStream;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Locale;
 
 import assemble.ErrorTracker;
 import cardinality.CardinalityTracker;
@@ -377,7 +376,7 @@ public class BloomFilterCorrectorWrapper {
 				double usedFraction2=filter.filter.usedFraction(2);
 				double b=filter.filter.estimateUniqueKmersFromUsedFraction(hashes, usedFraction2);
 				outstream.println("Estimated kmers of depth 2+: \t"+(long)b);
-				outstream.println("Used fraction for depth 2+:  \t"+String.format(Locale.ROOT, "%.3f%%", usedFraction2*100));
+				outstream.println("Used fraction for depth 2+:  \t"+Tools.format("%.3f%%", usedFraction2*100));
 				if(usedFraction2>maxLoad){
 					KillSwitch.kill("Max load exceeded, quitting: "+usedFraction2+" > "+maxLoad);
 				}
@@ -503,16 +502,16 @@ public class BloomFilterCorrectorWrapper {
 				outstream.println(sb);
 			}
 			if(ecco || merge){outstream.println("Reads merged:               \t"+Tools.padRight(readsMerged, 7)+
-					String.format(Locale.ROOT, " \t(%.2f%%)", readsMerged*200.0/readsProcessed));}
+					Tools.format(" \t(%.2f%%)", readsMerged*200.0/readsProcessed));}
 			outstream.println("Reads with errors detected: \t"+Tools.padRight(readsDetected, 7)+
-					String.format(Locale.ROOT, " \t(%.2f%%)", readsDetected*100.0/readsProcessed));
+					Tools.format(" \t(%.2f%%)", readsDetected*100.0/readsProcessed));
 			outstream.println("Reads fully corrected:      \t"+Tools.padRight(readsFullyCorrected, 7)+
-					String.format(Locale.ROOT, " \t(%.2f%% of detected)", readsFullyCorrected*100.0/readsDetected));
+					Tools.format(" \t(%.2f%% of detected)", readsFullyCorrected*100.0/readsDetected));
 			outstream.println("Reads partly corrected:     \t"+Tools.padRight(partial, 7)+
-					String.format(Locale.ROOT, " \t(%.2f%% of detected)", partial*100.0/readsDetected));
+					Tools.format(" \t(%.2f%% of detected)", partial*100.0/readsDetected));
 			if(corrector.ECC_ROLLBACK || rollbacks>0){
 				outstream.println("Rollbacks:                  \t"+Tools.padRight(rollbacks, 7)+
-						String.format(Locale.ROOT, " \t(%.2f%% of detected)", rollbacks*100.0/readsDetected));
+						Tools.format(" \t(%.2f%% of detected)", rollbacks*100.0/readsDetected));
 			}
 			
 		}
