@@ -3,7 +3,6 @@ package bloom;
 import java.io.File;
 import java.io.PrintStream;
 import java.util.ArrayList;
-import java.util.Locale;
 
 import dna.AminoAcid;
 import fileIO.ByteFile;
@@ -390,8 +389,8 @@ public class BloomFilterWrapper {
 			String rstring=Tools.padKMB(readsMatched, 8);
 			String bstring=Tools.padKMB(basesMatched, 8);
 			StringBuilder sb=new StringBuilder();
-			sb.append("Reads Matched:      ").append(rstring).append(String.format(Locale.ROOT, " \t%.2f%%", rpct)).append('\n');
-			sb.append("Bases Matched:      ").append(bstring).append(String.format(Locale.ROOT, " \t%.2f%%", bpct));
+			sb.append("Reads Matched:      ").append(rstring).append(Tools.format(" \t%.2f%%", rpct)).append('\n');
+			sb.append("Bases Matched:      ").append(bstring).append(Tools.format(" \t%.2f%%", bpct));
 			outstream.println(sb);
 		}
 		
