@@ -50,7 +50,7 @@ public class ErrorCorrect extends Thread{
 		int buildStepsize=4;
 		String output=null;
 		boolean ordered=true;
-		boolean overwrite=false;
+		boolean overwrite=true;
 		boolean append=false;
 		
 		for(int i=2; i<args.length; i++){
