@@ -809,7 +809,7 @@ public final class KCountArray7MTA extends KCountArray {
 	
 	private boolean finished=false;
 	
-	private long cellsUsed;
+	private long cellsUsed=-1;
 	private final AtomicIntegerArray[] matrix;
 	private final int hashes;
 	private final int wordsPerArray;
