@@ -2,11 +2,11 @@ package bloom;
 
 import java.util.ArrayList;
 import java.util.BitSet;
-import java.util.Locale;
 
 import dna.AminoAcid;
 import fileIO.FileFormat;
 import shared.Timer;
+import shared.Tools;
 import stream.ConcurrentReadInputStream;
 import stream.FastaReadInputStream;
 import stream.Read;
@@ -79,7 +79,7 @@ public class KmerCount5 extends KmerCountAbstract {
 		for(int i=0; i<lim1; i++){
 			String prefix=i+"";
 			while(prefix.length()<8){prefix=prefix+" ";}
-			System.out.println(prefix+"\t"+String.format(Locale.ROOT, "%.3f%%   ",(100l*freq[i]/(double)sum))+"\t"+freq[i]);
+			System.out.println(prefix+"\t"+Tools.format("%.3f%%   ",(100l*freq[i]/(double)sum))+"\t"+freq[i]);
 		}
 		while(lim1<=freq.length){
 			int x=0;
@@ -89,7 +89,7 @@ public class KmerCount5 extends KmerCountAbstract {
 			String prefix=lim1+"-"+(lim2-1);
 			if(lim2>=freq.length){prefix=lim1+"+";}
 			while(prefix.length()<8){prefix=prefix+" ";}
-			System.out.println(prefix+"\t"+String.format(Locale.ROOT, "%.3f%%   ",(100l*x/(double)sum))+"\t"+x);
+			System.out.println(prefix+"\t"+Tools.format("%.3f%%   ",(100l*x/(double)sum))+"\t"+x);
 			lim1*=2;
 			lim2=min(lim2*2, freq.length);
 		}
@@ -99,11 +99,11 @@ public class KmerCount5 extends KmerCountAbstract {
 		System.out.println();
 		System.out.println("Keys Counted:  \t         \t"+keysCounted);
 		System.out.println("Unique:        \t         \t"+sum2);
-		System.out.println("Avg Sites/Key: \t         \t"+String.format(Locale.ROOT, "%.3f    ",(keysCounted*1d/sum2)));
+		System.out.println("Avg Sites/Key: \t         \t"+Tools.format("%.3f    ",(keysCounted*1d/sum2)));
 		System.out.println();
-		System.out.println("Singleton:     \t"+String.format(Locale.ROOT, "%.3f%%   ",(100l*x/(double)sum2))+"\t"+x);
+		System.out.println("Singleton:     \t"+Tools.format("%.3f%%   ",(100l*x/(double)sum2))+"\t"+x);
 		x=sum2-x;
-		System.out.println("Useful:        \t"+String.format(Locale.ROOT, "%.3f%%   ",(100l*x/(double)sum2))+"\t"+x);
+		System.out.println("Useful:        \t"+Tools.format("%.3f%%   ",(100l*x/(double)sum2))+"\t"+x);
 	}
 
 	public static KCountArray count(String reads1, String reads2, int k, int cbits, boolean rcomp){
@@ -228,7 +228,7 @@ public class KmerCount5 extends KmerCountAbstract {
 							r.quality[i]=0;
 						}
 						//						System.out.println(new String(r.bases));
-						//						System.out.println("used = "+String.format(Locale.ROOT, "%.3f%%",count.usedFraction()*100));
+						//						System.out.println("used = "+Tools.format("%.3f%%",count.usedFraction()*100));
 						//						System.out.println("used = "+((KCountArray4)count).cellsUsed());
 						//						if(bs.length()<r.length()){r=null;}
 					}
