@@ -1,7 +1,5 @@
 package bloom;
 
-import shared.Shared;
-
 /**
  * @author Brian Bushnell
  * @date Dec 2, 2014
@@ -40,7 +38,7 @@ public abstract class KmerCountAbstract {
 	public static long maxReads=-1;
 	
 	public static float minProb=0.5f;
-
+	
 	public static long keysCounted=0;
 	public static long increments=0;
 	
@@ -48,7 +46,9 @@ public abstract class KmerCountAbstract {
 	public static boolean PREJOIN=false;
 	public static boolean CANONICAL=false;
 	public static boolean KEEP_DUPLICATE_KMERS=true;
-	public static boolean PICK_ONLY_ONE_KMER=false;
+	public static int KMERS_PER_READ=0;
+	public static int IDMASK=0;
+	public static int MAX_COUNT_THREADS=1024;
 	public static boolean SKETCH_MODE=false;
 	public static boolean STORE_HASHED=false;
 	public static boolean BUFFERED=false;
