@@ -403,7 +403,7 @@ public abstract class CardinalityTracker {
 	/** Sum of counts array, if present */
 	public final long countSum(){
 		int[] counts=getCounts();
-		return counts==null ? 0 : Tools.sum(counts);
+		return counts==null ? 0 : shared.Vector.sum(counts);
 	}
 	
 	/*--------------------------------------------------------------*/
