@@ -12,6 +12,7 @@ import shared.Parse;
 import shared.Parser;
 import shared.Shared;
 import shared.Timer;
+import shared.Tools;
 import stream.ConcurrentGenericReadInputStream;
 import stream.ConcurrentReadInputStream;
 import stream.FastaReadInputStream;
@@ -128,7 +129,7 @@ class LogLogWrapper {
 				//do nothing
 			}else if(a.equals("parse_flag_goes_here")){
 				//Set a variable here
-			}else if(in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+			}else if(in1==null && i==0 && Tools.looksLikeInputStream(arg)){
 				parser.in1=b;
 			}
 			
@@ -370,7 +371,7 @@ class LogLogWrapper {
 	
 	private long maxReads=-1;
 	
-	boolean overwrite=false;
+	boolean overwrite=true;
 	boolean append=false;
 	boolean errorState=false;
 
