@@ -367,7 +367,7 @@ public class LogLog_old {
 //					atomic=Parse.parseBoolean(b);
 				}else if(a.equals("parse_flag_goes_here")){
 					//Set a variable here
-				}else if(in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+				}else if(in1==null && i==0 && Tools.looksLikeInputStream(arg)){
 					parser.in1=b;
 				}else{
 					outstream.println("Unknown parameter "+args[i]);
@@ -526,7 +526,7 @@ public class LogLog_old {
 		
 		private long maxReads=-1;
 		
-		boolean overwrite=false;
+		boolean overwrite=true;
 		boolean append=false;
 		boolean errorState=false;
 		
