@@ -3,6 +3,7 @@ package clump;
 import java.util.ArrayList;
 
 import dna.AminoAcid;
+import hiseq.FlowcellCoordinate;
 import shared.KillSwitch;
 import shared.Parse;
 import shared.Tools;
@@ -255,6 +256,7 @@ public class Clump extends ArrayList<Read> implements Comparable<Clump> {
 //						if(optical && keyA.lane!=keyB.lane){break;} //Already in equals method
 //						if(breakOnTile && keyA.tile!=keyB.tile){break;} //Already in equals method
 						if(optical && xySorted && !keyA.nearXY(keyB, dist)){break;}
+						if(compareUMI && !keyA.umiMatches(keyB, umiSubs)) {break;}
 //						if(System.nanoTime()-start>200000000000L){
 //							TextStreamWriter tsw=new TextStreamWriter("foo.fq", true, false, false);
 //							tsw.start();
@@ -1034,6 +1036,10 @@ public class Clump extends ArrayList<Read> implements Comparable<Clump> {
 			allowNs=Parse.parseBoolean(b);
 		}else if(a.equals("containment") || a.equals("absorbcontainment") || a.equals("ac") || a.equals("contains")){
 			containment=Parse.parseBoolean(b);
+		}else if(a.equals("compareumi") || a.equals("umi")){
+			compareUMI=FlowcellCoordinate.parseUMI=Parse.parseBoolean(b);
+		}else if(a.equals("umisubs")){
+			umiSubs=Integer.parseInt(b);
 		}else if(a.equalsIgnoreCase("prefixOrSuffix") || a.equalsIgnoreCase("suffixOrPrefix") || a.equals("affix") || a.equals("pos")){
 			affix=Parse.parseBoolean(b);
 		}else if(a.equals("printduplicates")){
@@ -1105,6 +1111,8 @@ public class Clump extends ArrayList<Read> implements Comparable<Clump> {
 	static boolean markOnly=false;
 	static boolean opticalOnly=false;
 	static boolean containment=false;
+	static boolean compareUMI=false;
+	static int umiSubs=0;
 	static boolean affix=false;
 	static boolean printDuplicates=false; //For debugging
 	
