@@ -442,7 +442,7 @@ public class Clumpify {
 			for(int i=0; i<groups; i++){
 				names.add(namesorted.replaceFirst("%", ""+i));
 			}
-			ReadWrite.MAX_ZIP_THREADS=Shared.threads();
+			ReadWrite.setZipThreads(Shared.threads());
 			
 			ReadWrite.USE_PIGZ=true;
 			ReadWrite.ZIPLEVEL=Tools.max(ReadWrite.ZIPLEVEL, 6);
