@@ -36,16 +36,16 @@ public class KmerSort2 extends KmerSort {
 	 */
 	public static void main(String[] args){
 		final boolean pigz=ReadWrite.USE_PIGZ, unpigz=ReadWrite.USE_UNPIGZ;
-		final float ztd=ReadWrite.ZIP_THREAD_MULT;
-		final int mzt=ReadWrite.MAX_ZIP_THREADS;
+		final float ztd=ReadWrite.ZIP_THREAD_MULT();
+		final int mzt=ReadWrite.MAX_ZIP_THREADS();
 		final int oldzl=ReadWrite.ZIPLEVEL;
 		Timer t=new Timer();
 		KmerSort2 x=new KmerSort2(args);
 		x.process(t);
 		ReadWrite.USE_PIGZ=pigz;
 		ReadWrite.USE_UNPIGZ=unpigz;
-		ReadWrite.ZIP_THREAD_MULT=ztd;
-		ReadWrite.MAX_ZIP_THREADS=mzt;
+		ReadWrite.setZipThreadMult(ztd);
+		ReadWrite.setZipThreads(mzt);
 		ReadWrite.ZIPLEVEL=oldzl;
 		
 		//Close the print stream if it was redirected
@@ -65,7 +65,7 @@ public class KmerSort2 extends KmerSort {
 		}
 		
 		ReadWrite.USE_PIGZ=ReadWrite.USE_UNPIGZ=true;
-		ReadWrite.MAX_ZIP_THREADS=Shared.threads();
+		ReadWrite.setZipThreads(Shared.threads());
 		
 		Parser parser=new Parser();
 		for(int i=0; i<args.length; i++){
