@@ -74,7 +74,7 @@ public class PivotSet {
 		}
 		
 		ReadWrite.USE_PIGZ=ReadWrite.USE_UNPIGZ=true;
-		ReadWrite.MAX_ZIP_THREADS=Shared.threads();
+		ReadWrite.setZipThreads(Shared.threads());
 		
 		Parser parser=new Parser();
 		for(int i=0; i<args.length; i++){
@@ -168,7 +168,7 @@ public class PivotSet {
 		float fraction=0.1f;
 		long cells=getCells(fraction, cbits);
 		ReadCounter rc=new ReadCounter(k, true, ecco, false, amino);
-		KCountArray kca=rc.makeKca(null, null, null, cbits, cells, filterHashes, 0, maxReads, 1, 1, 1, 1, null, 0);
+		KCountArray kca=rc.makeKca(null, null, null, cbits, cells, filterHashes, 0, maxReads, 1, 1, 1, null, 0);
 		
 		final ConcurrentReadInputStream cris;
 		{
@@ -213,7 +213,7 @@ public class PivotSet {
 		float fraction=0.1f;
 		long cells=getCells(fraction, cbits);
 		ReadCounter rc=new ReadCounter(k, true, false, false, amino);
-		KCountArray kca=rc.makeKca(null, null, null, cbits, cells, filterHashes, 0, -1, 1, 1, 1, 1, null, 0);
+		KCountArray kca=rc.makeKca(null, null, null, cbits, cells, filterHashes, 0, -1, 1, 1, 1, null, 0);
 		
 		if(verbose){System.err.println("Making hash threads.");}
 		final int threads=Shared.threads();
