@@ -2,6 +2,7 @@ package clump;
 
 import java.io.Serializable;
 
+import barcode.Barcode;
 import hiseq.FlowcellCoordinate;
 import shared.KillSwitch;
 import shared.Tools;
@@ -41,13 +42,14 @@ class ReadKey implements Serializable, Comparable<ReadKey> {
 		flipped=false;
 		kmerMinusStrand=!plus_;
 		
-		if(Clump.opticalOnly){
+		if(Clump.opticalOnly || clump.compareUMI){
 			FlowcellCoordinate fc=FlowcellCoordinate.getFC();
 			fc.setFrom(r.id);
 			lane=fc.lane;
 			tile=fc.tile;
 			x=fc.x;
 			y=fc.y;
+			umi=fc.umi;
 		}
 //		expectedErrors=r.expectedErrorsIncludingMate(true);
 	}
@@ -201,6 +203,12 @@ class ReadKey implements Serializable, Comparable<ReadKey> {
 		long a=Tools.absdif(x, rkb.x), b=Tools.absdif(y, rkb.y);
 		return Tools.min(a,b)<=dist;
 	}
+	
+	public boolean umiMatches(ReadKey rkb, int maxSubs) {
+		if(umi==null || rkb.umi==null) {return false;}
+		int hdist=Barcode.hdist(umi, rkb.umi);
+		return hdist<=maxSubs;
+	}
 
 	public int flag;
 	
@@ -214,6 +222,7 @@ class ReadKey implements Serializable, Comparable<ReadKey> {
 //	public float expectedErrors;
 	
 	public int lane, tile, x, y;
+	public String umi;
 	
 	public static final int overhead=overhead();
 	private static int overhead(){
