@@ -43,13 +43,18 @@ class Splitter {
 			}else{
 				assert(pivots.size==1 || pivots.size==2) : pivot+", "+pivots.size+", "+pivots;
 				assert(pivots.get(0)==pivot);
-				splitAndAdd(clump, pivots.get(0), (pivots.size>1 ? pivots.get(1) : -1), list);
+				int added=splitAndAdd(clump, pivots.get(0), (pivots.size>1 ? pivots.get(1) : -1), list);
+				if(added<2) {//Rare case that caused an assertion once
+					assert(added==1);
+					out.add(clump);
+					i++;
+				}
 			}
 		}
 		return out;
 	}
 	
-	static void splitAndAdd(Clump c, final int var1, final int var2, ArrayList<Clump> out) {
+	static int splitAndAdd(Clump c, final int var1, final int var2, ArrayList<Clump> list) {
 		final int maxLeft=c.maxLeft();
 		
 		final Clump major=Clump.makeClump(c.kmer), minor=Clump.makeClump(c.kmer);
@@ -61,9 +66,32 @@ class Splitter {
 				major.add(r);
 			}
 		}
-//		System.err.println(major.size()+"\t"+minor.size());
-		out.add(major);
-		out.add(minor);
+		
+//		assert(major.size()>0) : c.size()+", "+major.size()+", "+minor.size()+
+//			", "+(var1>>2)+", "+(var1&alleleMask)+", "+(var2>>2)+", "+(var2&alleleMask)+
+//			", "+list.size()+", "+c.get(0);
+//		assert(minor.size()>0) : c.size()+", "+major.size()+", "+minor.size()+
+//			", "+(var1>>2)+", "+(var1&alleleMask)+", "+(var2>>2)+", "+(var2&alleleMask)+
+//			", "+list.size()+", "+c.get(0);
+//		assert(major.size()+minor.size()==c.size()) : c.size()+", "+major.size()+", "+minor.size()+
+//			", "+(var1>>2)+", "+(var1&alleleMask)+", "+(var2>>2)+", "+(var2&alleleMask)+
+//			", "+list.size()+", "+c.get(0);
+		
+//		Exception in thread "Thread-110" java.lang.AssertionError: 21, 0, 21, 163, 1, 104, 2, 71,      
+//		TTTTGGCAGCCCCCCCCCCCCCCCCCCCCCCCCCCCGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGCGCCACGCCGCCCCCCCCCCCC <-90
+//		CCCCCCCCCCGGGGGGGGGGGGCAGGGGGGGGGGGGGGGGGGGGGGGCGCCCCCCCCCC
+//		        at clump.Splitter.splitAndAdd(Splitter.java:72)
+//		        at clump.Splitter.splitOnPivot(Splitter.java:46)
+//		        at clump.Splitter.splitOnPivot(Splitter.java:29)
+//		        at clump.Clump.splitAndErrorCorrect(Clump.java:612)
+//		        at clump.ClumpList$ProcessThread.run(ClumpList.java:342)
+		
+		
+		int added=(major.size()>0 ? 1 : 0)+(minor.size()>0 ? 1 : 0);
+		if(major.size()>0) {list.add(major);}
+		if(minor.size()>0) {list.add(minor);}
+		assert(added>0) : c.size()+", "+major.size()+", "+minor.size();
+		return added;
 	}
 	
 	//Returns the c
