@@ -108,7 +108,7 @@ public class MergeReadHeaders {
 				append=ReadStats.append=Parse.parseBoolean(b);
 			}else if(a.equals("overwrite") || a.equals("ow")){
 				overwrite=Parse.parseBoolean(b);
-			}else if(in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+			}else if(in1==null && i==0 && Tools.looksLikeInputStream(arg)){
 				in1=arg;
 			}else if(out1==null && i==1 && !arg.contains("=")){
 				out1=arg;
@@ -283,7 +283,7 @@ public class MergeReadHeaders {
 	private String extin=null;
 	private String extout=null;
 	
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	private boolean append=false;
 	
 	private long maxReads=-1;
