@@ -88,7 +88,7 @@ public class ReclusterByKmer {
 				ReadWrite.verbose=verbose;
 			}else if(a.equals("build") || a.equals("genome")){
 				Data.setGenome(Integer.parseInt(b));
-			}else if(in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+			}else if(in1==null && i==0 && Tools.looksLikeInputStream(arg)){
 				in1=arg;
 			}else{
 				System.err.println("Unknown parameter "+args[i]);
@@ -553,7 +553,7 @@ public class ReclusterByKmer {
 	private String extin=null;
 	private String extout=null;
 	
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	private boolean append=false;
 	
 	private long maxReads=-1;
