@@ -156,7 +156,7 @@ public class Data {
 								else{assert(id==g.id) : gs+"\n"+gs.genes+"\n";}
 							}
 							assert(id>-1);
-							Integer key=new Integer(id);
+							Integer key=Integer.valueOf(id);
 							ArrayList<GeneSet> value=temp.get(key);
 							//					assert(old==null || chrom>22) : "\nCollision!\n\n"+gs+"\n\nis overwriting\n\n"+old;
 							if(value==null){
