@@ -12,8 +12,8 @@ import fileIO.TextFile;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Timer;
+import tracker.ReadStats;
 
 public class ConcatenateTextFiles {
 	
