@@ -158,7 +158,7 @@ public class CorrelateIdentity {
 	private float samplerate=1;
 	private float sampleseed=-1;
 	private int columnLength=Integer.MAX_VALUE;
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	private boolean append=false;
 	
 	/*--------------------------------------------------------------*/
