@@ -55,7 +55,7 @@ public class FilterAssemblySummary {
 			}else if(a.equals("verbose")){
 				verbose=Parse.parseBoolean(b);
 				ReadWrite.verbose=verbose;
-			}else if(parser.in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+			}else if(parser.in1==null && i==0 && Tools.looksLikeInputStream(arg)){
 				parser.in1=arg;
 			}else if(TaxFilter.validArgument(a)){
 				//do nothing
@@ -185,7 +185,7 @@ public class FilterAssemblySummary {
 	private PrintStream outstream=System.err;
 	public static boolean verbose=false;
 	public boolean errorState=false;
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	private boolean append=false;
 	
 }
