@@ -3,7 +3,6 @@ package driver;
 import java.io.File;
 import java.io.PrintStream;
 import java.util.ArrayList;
-import java.util.Locale;
 
 import fileIO.ByteFile;
 import fileIO.FileFormat;
@@ -247,24 +246,24 @@ public class LoadReads {
 		outstream.println("Disk Estimate 0:    \t"+(diskEst0/1000000+" m"));
 		outstream.println("Disk Bytes:         \t"+((diskBytesProcessed)/1000000)+" m");
 		outstream.println();
-		outstream.println("Memory Ratio Est 0: \t"+(String.format(Locale.ROOT, "%.2f", memRatio0)));
-		outstream.println("Memory Ratio Est 1: \t"+(String.format(Locale.ROOT, "%.2f", memRatio1)));
-		outstream.println("Memory Ratio:       \t"+(String.format(Locale.ROOT, "%.2f", memRatio)));
+		outstream.println("Memory Ratio Est 0: \t"+(Tools.format("%.2f", memRatio0)));
+		outstream.println("Memory Ratio Est 1: \t"+(Tools.format("%.2f", memRatio1)));
+		outstream.println("Memory Ratio:       \t"+(Tools.format("%.2f", memRatio)));
 		outstream.println();
-		outstream.println("Disk Ratio Est 0:   \t"+(String.format(Locale.ROOT, "%.2f", diskRatio0)));
-		outstream.println("Disk Ratio:         \t"+(String.format(Locale.ROOT, "%.2f", diskRatio)));
+		outstream.println("Disk Ratio Est 0:   \t"+(Tools.format("%.2f", diskRatio0)));
+		outstream.println("Disk Ratio:         \t"+(Tools.format("%.2f", diskRatio)));
 		outstream.println();
-		outstream.println("Read Estimate 0:    \t"+(String.format(Locale.ROOT, "%d", (long)Math.ceil(readEst0))));
-		outstream.println("Read Ratio 1:       \t"+(String.format(Locale.ROOT, "%.2f", readRatio)));
-		outstream.println("Reads:              \t"+(String.format(Locale.ROOT, "%d", readsProcessed)));
+		outstream.println("Read Estimate 0:    \t"+(Tools.format("%d", (long)Math.ceil(readEst0))));
+		outstream.println("Read Ratio 1:       \t"+(Tools.format("%.2f", readRatio)));
+		outstream.println("Reads:              \t"+(Tools.format("%d", readsProcessed)));
 		outstream.println();
-//		outstream.println("Average Memory 0:   \t"+(String.format(Locale.ROOT, "%.2f", mem0PerRead)));
-		outstream.println("Average Memory 1:   \t"+(String.format(Locale.ROOT, "%.2f", mem1PerRead)));
-		outstream.println("Average Memory:     \t"+(String.format(Locale.ROOT, "%.2f", memPerRead)));
-		outstream.println("Average Bases:      \t"+(String.format(Locale.ROOT, "%.2f", basesPerRead)));
-		outstream.println("Average Q-Scores:   \t"+(String.format(Locale.ROOT, "%.2f", qualsPerRead)));
-		outstream.println("Average Header Len: \t"+(String.format(Locale.ROOT, "%.2f", headerPerRead)));
-		outstream.println("Average Overhead:   \t"+(String.format(Locale.ROOT, "%.2f", overheadPerRead)));
+//		outstream.println("Average Memory 0:   \t"+(Tools.format("%.2f", mem0PerRead)));
+		outstream.println("Average Memory 1:   \t"+(Tools.format("%.2f", mem1PerRead)));
+		outstream.println("Average Memory:     \t"+(Tools.format("%.2f", memPerRead)));
+		outstream.println("Average Bases:      \t"+(Tools.format("%.2f", basesPerRead)));
+		outstream.println("Average Q-Scores:   \t"+(Tools.format("%.2f", qualsPerRead)));
+		outstream.println("Average Header Len: \t"+(Tools.format("%.2f", headerPerRead)));
+		outstream.println("Average Overhead:   \t"+(Tools.format("%.2f", overheadPerRead)));
 		outstream.println();
 		
 		
@@ -285,8 +284,8 @@ public class LoadReads {
 			while(mpstring.length()<8){mpstring=" "+mpstring;}
 			
 			outstream.println(Tools.timeReadsBasesProcessed(t, readsProcessed, basesProcessed, 8));
-			outstream.println("Disk Bytes Processed: "+dpstring+" \t"+String.format(Locale.ROOT, "%.2fm bytes/sec", dpnano*1000));
-			outstream.println("Mem Bytes Processed:  "+mpstring+" \t"+String.format(Locale.ROOT, "%.2fm bytes/sec", mpnano*1000));
+			outstream.println("Disk Bytes Processed: "+dpstring+" \t"+Tools.format("%.2fm bytes/sec", dpnano*1000));
+			outstream.println("Mem Bytes Processed:  "+mpstring+" \t"+Tools.format("%.2fm bytes/sec", mpnano*1000));
 		}
 		
 		//Throw an exception of there was an error in a thread
@@ -445,7 +444,7 @@ public class LoadReads {
 	/** True if an error was encountered */
 	public boolean errorState=false;
 	/** Overwrite existing output files */
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	/** Append to existing output files */
 	private boolean append=false;
 	/** This flag has no effect on singlethreaded programs */
