@@ -4,7 +4,6 @@ import java.io.File;
 import java.io.PrintStream;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Locale;
 
 import dna.AminoAcid;
 import fileIO.ByteFile;
@@ -81,7 +80,7 @@ public class PlotGC {
 				out1=b;
 			}else if(parser.parse(arg, a, b)){
 				//do nothing
-			}else if(parser.in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+			}else if(parser.in1==null && i==0 && Tools.looksLikeInputStream(arg)){
 				parser.in1=arg;
 			}else if(parser.out1==null && i==1 && !arg.contains("=")){
 				parser.out1=arg;
@@ -239,7 +238,7 @@ public class PlotGC {
 		int gc=acgt[1]+acgt[2];
 		float sum=Tools.max(1, at+gc);
 		float gcf=gc/sum;
-		return String.format(Locale.ROOT, "%s\t%d\t%d\t%d\t%d\t%d\t%.3f\n", name, stop-start+1, start+offset, stop+offset, rstart+offset, rstop+offset, gcf);
+		return Tools.format("%s\t%d\t%d\t%d\t%d\t%d\t%.3f\n", name, stop-start+1, start+offset, stop+offset, rstart+offset, rstop+offset, gcf);
 	}
 	
 	/*--------------------------------------------------------------*/
@@ -275,7 +274,7 @@ public class PlotGC {
 	private PrintStream outstream=System.err;
 	public static boolean verbose=false;
 	public boolean errorState=false;
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	private boolean append=false;
 	
 }
