@@ -1,8 +1,7 @@
 package driver;
 
-import java.util.Locale;
-
 import fileIO.TextFile;
+import shared.Tools;
 
 /**
  * For generic data collation
@@ -22,15 +21,15 @@ public class ProcessSpeed2 {
 			if(line.startsWith("real\t")){
 				String time=line.split("\t")[1];
 				double seconds=toSeconds(time);
-				System.out.print(String.format(Locale.ROOT, "%.3f\t", seconds));
+				System.out.print(Tools.format("%.3f\t", seconds));
 			}else if(line.startsWith("user\t")){
 				String time=line.split("\t")[1];
 				double seconds=toSeconds(time);
-				System.out.print(String.format(Locale.ROOT, "%.3f\t", seconds));
+				System.out.print(Tools.format("%.3f\t", seconds));
 			}else if(line.startsWith("sys\t")){
 				String time=line.split("\t")[1];
 				double seconds=toSeconds(time);
-				System.out.print(String.format(Locale.ROOT, "%.3f\n", seconds));
+				System.out.print(Tools.format("%.3f\n", seconds));
 			}
 			
 		}
