@@ -2,7 +2,6 @@ package driver;
 
 import java.io.File;
 import java.util.ArrayList;
-import java.util.Locale;
 
 import fileIO.TextFile;
 import fileIO.TextStreamWriter;
@@ -136,7 +135,7 @@ public class SummarizeSealStats {
 		
 		@Override
 		public String toString(){
-			return String.format(Locale.ROOT, "%s\t%s\t%d\t%d\t%d\t%d\t%.2f", fname, pname, pcount, ocount, pbases, obases, ppm);
+			return Tools.format("%s\t%s\t%d\t%d\t%d\t%d\t%.2f", fname, pname, pcount, ocount, pbases, obases, ppm);
 		}
 		
 		private void summarize(){
