@@ -259,7 +259,7 @@ public final class FileFormat {
 		append=append_;
 		allowSubprocess=allowSubprocess_;
 		ordered=ordered_;
-		amino="faa".equals(rawExtension());
+		amino=isAminoExt(rawExtension());
 		
 //		interleaved=interleaved_;
 //		maxReads=write() ? -1 : maxReads_;
@@ -364,6 +364,7 @@ public final class FileFormat {
 		else if(ext.equals("gbff")){r[0]=GBFF;}
 		else if(ext.equals("alm")){r[0]=ALM;}
 		else if(ext.equals("bbnet")){r[0]=BBNET;}
+		else if(ext.equals("tsv")){r[0]=TEXT;}
 		
 		if(comp!=null){
 			r[1]=Tools.find(comp, COMPRESSION_ARRAY);
@@ -456,6 +457,11 @@ public final class FileFormat {
 		return r[0]==FQ || r[0]==FA;
 	}
 	
+	public static boolean hasTextExtension(String fname){
+		String ext=ReadWrite.rawExtension(fname);
+		return ("txt".equals(ext) || "tsv".equals(ext) || "csv".equals(ext));
+	}
+	
 	public static boolean hasSamOrBamExtension(String fname){
 		int[] r=testFormat(fname, false, false);
 		return r[0]==SAM || r[0]==BAM;
@@ -630,7 +636,7 @@ public final class FileFormat {
 	public static boolean isFastaExt(String ext){
 		if(ext==null){return false;}
 		return (ext.equals("fa") || ext.equals("fasta") || ext.equals("fas") || ext.equals("fna") || ext.equals("ffn")
-			|| ext.equals("frn") || ext.equals("seq") || ext.equals("fsa") || ext.equals("faa"));
+			|| ext.equals("frn") || ext.equals("seq") || ext.equals("fsa") || ext.equals("faa") || ext.equals("prot"));
 	}
 	
 	public static boolean isFastaFile(String fname){
@@ -647,7 +653,7 @@ public final class FileFormat {
 	
 	public static boolean isAminoExt(String ext){
 		if(ext==null){return false;}
-		return ext.equals("faa"); //TODO: Investigate whether other extensions imply AA.
+		return ext.equals("faa") || ext.equals("prot"); //TODO: Investigate whether other extensions imply AA.
 	}
 	
 	public static boolean isStdin(String s) {
@@ -691,12 +697,12 @@ public final class FileFormat {
 	
 	public static boolean isFastqExt(String ext){
 		if(ext==null){return false;}
-		return (ext.equals("fq") || ext.equals("fastq"));
+		return (ext.equalsIgnoreCase("fq") || ext.equalsIgnoreCase("fastq"));
 	}
 	
 	public static boolean isPgmExt(String ext){
 		if(ext==null){return false;}
-		return (ext.equals("pgm") || ext.equals("pkm"));
+		return (ext.equalsIgnoreCase("pgm") || ext.equalsIgnoreCase("pkm"));
 	}
 	
 	public static boolean isFastqFile(String fname){
@@ -707,7 +713,12 @@ public final class FileFormat {
 	
 	public static boolean isSamOrBamExt(String ext){
 		if(ext==null){return false;}
-		return (ext.equals("sam") || ext.equals("bam"));
+		return (ext.equalsIgnoreCase("sam") || ext.equalsIgnoreCase("bam"));
+	}
+	
+	public static boolean isGffExt(String ext){
+		if(ext==null){return false;}
+		return (ext.equalsIgnoreCase("gff"));
 	}
 	
 	public static boolean isSamOrBamFile(String fname){
@@ -855,6 +866,7 @@ public final class FileFormat {
 	public final boolean gbk(){return format==GBK;}
 	public final boolean gbff(){return format==GBFF;}
 	public final boolean alm(){return format==ALM;}
+	public final boolean bbnet(){return format==BBNET;}
 	
 	public final boolean preferShreds(){
 		return preferShreds;
