@@ -1,8 +1,8 @@
 package fun;
 
-import java.util.Locale;
 import java.util.Random;
 
+import shared.Parse;
 import shared.Shared;
 import shared.Tools;
 
@@ -16,10 +16,10 @@ public class Chance {
 		float prob;
 		long rounds;
 		try {
-			draws = Tools.parseIntKMG(args[0]);
-			minSuccess = Tools.parseIntKMG(args[1]);
+			draws = Parse.parseIntKMG(args[0]);
+			minSuccess = Parse.parseIntKMG(args[1]);
 			prob = Float.parseFloat(args[2]);
-			rounds = Tools.parseKMG(args[3]);
+			rounds = Parse.parseKMG(args[3]);
 		} catch (Exception e) {
 			System.err.println("Chance (int)draws (int)minSuccess (float)prob (int)rounds");
 			System.exit(1);
@@ -35,7 +35,7 @@ public class Chance {
 		}
 		
 		double odds=passes*1.0/rounds;
-		System.err.println("Probability: "+String.format(Locale.ROOT, "%.6f%%", 100*odds));
+		System.err.println("Probability: "+Tools.format("%.6f%%", 100*odds));
 	}
 
 	private static int runOneRound(Random randy, int draws, int minSuccess, float prob) {
