@@ -7,6 +7,8 @@ import java.util.Arrays;
 import java.util.HashMap;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicLong;
+import java.util.concurrent.locks.ReadWriteLock;
+import java.util.concurrent.locks.ReentrantReadWriteLock;
 
 import aligner.Alignment;
 import fileIO.ByteFile;
@@ -70,7 +72,7 @@ public class CutGff implements Accumulator<CutGff.ProcessThread>  {
 		
 		//Set shared static variables prior to parsing
 		ReadWrite.USE_PIGZ=ReadWrite.USE_UNPIGZ=true;
-		ReadWrite.MAX_ZIP_THREADS=Shared.threads();
+		ReadWrite.setZipThreads(Shared.threads());
 		
 		Shared.TRIM_READ_COMMENTS=Shared.TRIM_RNAME=true;
 		Read.TO_UPPER_CASE=true;
@@ -795,6 +797,10 @@ public class CutGff implements Accumulator<CutGff.ProcessThread>  {
 	private final FileFormat ffout;
 	private final ArrayList<Read> dummy=new ArrayList<Read>();
 	
+	@Override
+	public final ReadWriteLock rwlock() {return rwlock;}
+	private final ReadWriteLock rwlock=new ReentrantReadWriteLock();
+	
 	/*--------------------------------------------------------------*/
 	/*----------------        Common Fields         ----------------*/
 	/*--------------------------------------------------------------*/
