@@ -58,7 +58,7 @@ public class CutGff_ST {
 		
 		//Set shared static variables prior to parsing
 		ReadWrite.USE_PIGZ=ReadWrite.USE_UNPIGZ=true;
-		ReadWrite.MAX_ZIP_THREADS=Shared.threads();
+		ReadWrite.setZipThreads(Shared.threads());
 		
 		Shared.TRIM_READ_COMMENTS=Shared.TRIM_RNAME=true;
 		GffLine.parseAttributes=true;
