@@ -38,7 +38,6 @@ import stream.FastaReadInputStream;
 import stream.Read;
 import stream.SamLine;
 import stream.SamLineStreamer;
-import stream.SamReadStreamer;
 import structures.AtomicStringNum;
 import structures.ByteBuilder;
 import structures.IntList;
@@ -547,8 +546,9 @@ public class AnalyzeFlowCell implements Accumulator<AnalyzeFlowCell.ProcessThrea
 		
 
 		if(align) {
-			sidechannel=new SideChannel3(alignRef, alignOut, alignK1, alignK2, 
+			sidechannel=new SideChannel3(alignRef, alignOut, null, alignK1, alignK2, 
 					alignMinid1, alignMinid2, alignMM1, alignMM2, overwrite, ordered);
+			sidechannel.start();
 		}else {
 			sidechannel=null;
 		}
@@ -559,7 +559,8 @@ public class AnalyzeFlowCell implements Accumulator<AnalyzeFlowCell.ProcessThrea
 		if(verbose){outstream.println("Finished; closing streams.");}
 		
 		//Close the read streams
-		errorState|=ReadWrite.closeStreams(cris, sidechannel==null ? null : sidechannel.cros);
+		errorState|=ReadWrite.closeStreams(cris);
+		if(sidechannel!=null) {errorState|=sidechannel.shutdown();}
 	}
 	
 //	/** Singlethreaded version. */
@@ -1281,9 +1282,15 @@ public class AnalyzeFlowCell implements Accumulator<AnalyzeFlowCell.ProcessThrea
 			errorState|=(!pt.success);
 			synchronized(flowcell) {
 				flowcell.xMin=(flowcell.xMin<0 ? pt.xmin : Tools.min(pt.xmin, flowcell.xMin));
-				flowcell.yMin=(flowcell.yMin<0 ? pt.ymin : Tools.min(pt.ymin, flowcell.yMin));
 				flowcell.xMax=(flowcell.xMax<0 ? pt.xmax : Tools.max(pt.xmax, flowcell.xMax));
+				flowcell.yMin=(flowcell.yMin<0 ? pt.ymin : Tools.min(pt.ymin, flowcell.yMin));
 				flowcell.yMax=(flowcell.yMax<0 ? pt.ymax : Tools.max(pt.ymax, flowcell.yMax));
+				flowcell.tMin=(flowcell.tMin<0 ? pt.tmin : Tools.min(pt.tmin, flowcell.tMin));
+				flowcell.tMax=(flowcell.tMax<0 ? pt.tmax : Tools.max(pt.tmax, flowcell.tMax));
+				if(pt.flowcellName!=null) {
+					assert(flowcell.name==null || flowcell.name.equals(pt.flowcellName));
+					flowcell.name=pt.flowcellName;
+				}
 //				for(Lane lane : flowcell.lanes) {
 //					if(lane!=null) {
 //						for(int pairnum=0; pairnum<2; pairnum++) {
@@ -1363,7 +1370,6 @@ public class AnalyzeFlowCell implements Accumulator<AnalyzeFlowCell.ProcessThrea
 			//Grab the actual read list from the ListNum
 			final ArrayList<Read> reads=ln.list;
 			
-			ArrayList<Read> alignedList=(sidechannel==null ? null : new ArrayList<Read>());
 			//Loop through each read in the list
 			for(int idx=0; idx<reads.size(); idx++){
 				final Read r1=reads.get(idx);
@@ -1382,11 +1388,8 @@ public class AnalyzeFlowCell implements Accumulator<AnalyzeFlowCell.ProcessThrea
 				basesProcessedT+=initialLength1+initialLength2;
 				
 				processReadPair(r1, r2);
-				if(alignedList!=null && (r1.mapped() || r1.mateMapped())) {
-					alignedList.add(r1);
-				}
 			}
-			if(sidechannel!=null) {sidechannel.write(alignedList, ln.id);}
+			if(sidechannel!=null) {sidechannel.writeByStatus(reads, ln.id);}
 		}
 		
 		/**
@@ -1404,9 +1407,14 @@ public class AnalyzeFlowCell implements Accumulator<AnalyzeFlowCell.ProcessThrea
 			ihp.parse(r1.id);
 			final int lnum=ihp.lane(), tile=ihp.tile(), x=ihp.xPos(), y=ihp.yPos();
 			xmin=Tools.min(x, xmin);
-			ymin=Tools.min(y, ymin);
 			xmax=Tools.max(x, xmax);
+			ymin=Tools.min(y, ymin);
 			ymax=Tools.max(y, ymax);
+			tmin=Tools.min(tile, tmin);
+			tmax=Tools.max(tile, tmax);
+			if(flowcellName==null) {
+				flowcellName=ihp.machine()+":"+ihp.run()+":"+ihp.flowcell();
+			}
 			
 			long hits1=0, hits2=0, misses=0, depthSum=0;
 			if(loadKmers){//All kmer processing is outside of the sync block
@@ -1603,8 +1611,9 @@ public class AnalyzeFlowCell implements Accumulator<AnalyzeFlowCell.ProcessThrea
 		/** Number of bases processed by this thread */
 		protected long basesProcessedT=0;
 
-		int xmin=Integer.MAX_VALUE, ymin=Integer.MAX_VALUE;
-		int xmax=-1, ymax=-1;
+		int xmin=Integer.MAX_VALUE, ymin=Integer.MAX_VALUE, tmin=Integer.MAX_VALUE;
+		int xmax=-1, ymax=-1, tmax=-1;
+		public String flowcellName=null;
 		
 		private IntList kmerDepths0=new IntList(151);
 		private IntList kmerDepths1=new IntList(151);
@@ -1682,7 +1691,7 @@ public class AnalyzeFlowCell implements Accumulator<AnalyzeFlowCell.ProcessThrea
 	String alignRef="phix";
 	float alignMinid1=0.66f;
 	float alignMinid2=0.56f;
-	int alignK1=17; //Phix is unique down to k=13
+	int alignK1=17; //Phix is unique down to k=13 solid; unsure about gapped
 	int alignK2=13;
 	int alignMM1=1;
 	int alignMM2=1;
@@ -1716,7 +1725,7 @@ public class AnalyzeFlowCell implements Accumulator<AnalyzeFlowCell.ProcessThrea
 	//64 is not enough with merge enabled
 	private int fillThreads=64;
 	//128 threads only ran at 5600% utilization...  may be too many.
-	private static final int fillThreadsM=96;
+	private static final int fillThreadsM=96;//threads when merge is enabled
 	private BloomFilter bloomFilter;
 
 	int idmask_read=7;
