@@ -274,11 +274,14 @@ public class FlowCell {
 		basesAligned=fc.basesAligned;
 		readErrors=fc.readErrors;
 		baseErrors=fc.baseErrors;
-
+		
+		name=fc.name;
 		xMin=fc.xMin;
-		yMin=fc.yMin;
 		xMax=fc.xMax;
+		yMin=fc.yMin;
 		yMax=fc.yMax;
+		tMin=fc.tMin;
+		tMax=fc.tMax;
 		k=fc.k;
 
 		uniqueToReadErrorRateFormula=fc.uniqueToReadErrorRateFormula==null ? null : 
@@ -304,11 +307,15 @@ public class FlowCell {
 	long basesAligned;
 	long readErrors;
 	long baseErrors;
+	
+	String name;
 
 	int xMin=-1;
-	int yMin=-1;
 	int xMax=-1;
+	int yMin=-1;
 	int yMax=-1;
+	int tMin=-1;
+	int tMax=-1;
 	int k=31;
 
 	public double avgReads;
