@@ -257,7 +257,7 @@ public class PlotFlowCell implements Accumulator<PlotFlowCell.WorkerThread> {
 		basesProcessed=0;
 		
 		MicroIndex3 index=(refPath==null ? null : new MicroIndex3(alignK, 0, refPath, false));
-		mapper=(index==null ? null : new MicroAligner3(index, minIdentity));
+		mapper=(index==null ? null : new MicroAligner3(index, minIdentity, true));
 
 		if(dumpIn==null){
 			flowcell=new FlowCell(k);
