@@ -215,16 +215,32 @@ public class TileDump {
 		bsw.start();
 
 		bsw.print("#Version\t").print(TileDump.VERSION_OUT).nl();
+		
+		bsw.print("#id\t").print(fc.name).nl();
+		bsw.print("#lane\t");
+		{
+			String comma="";
+			for(Lane lane : fc.lanes) {
+				if(lane!=null && !lane.isEmpty()) {
+					bsw.print(comma).print(lane.lane);
+					comma=",";
+				}
+			}
+			bsw.println();
+		}
+		assert(fc.k>0) : fc.k;
+		bsw.print("#k\t").print(fc.k).nl();
+		
 		bsw.print("#xSize\t").print(Tile.xSize).nl();
 		bsw.print("#ySize\t").print(Tile.ySize).nl();
 		if(fc.xMax>=0 || fc.yMax>=0 || fc.xMin>=0 || fc.yMin>=0) {
 			bsw.print("#xMin\t").print(fc.xMin).nl();
-			bsw.print("#yMin\t").print(fc.yMin).nl();
 			bsw.print("#xMax\t").print(fc.xMax).nl();
+			bsw.print("#yMin\t").print(fc.yMin).nl();
 			bsw.print("#yMax\t").print(fc.yMax).nl();
+			bsw.print("#tMin\t").print(fc.tMin).nl();
+			bsw.print("#tMax\t").print(fc.tMax).nl();
 		}
-		assert(fc.k>0) : fc.k;
-		bsw.print("#k\t").print(fc.k).nl();
 		bsw.print("#reads\t").print(fc.readsProcessed).nl();
 		bsw.print("#avgReads\t").print(fc.avgReads, 1).nl();
 		bsw.print("#avgLen\t").print(fc.basesProcessed/(1.0*fc.readsProcessed), 1).nl();
@@ -331,14 +347,22 @@ public class TileDump {
 					Tile.ySize=lp.parseInt(1);
 				}else if(Tools.startsWith(line, "#xMin")){
 					fc.xMin=lp.parseInt(1);
-				}else if(Tools.startsWith(line, "#yMin")){
-					fc.yMin=lp.parseInt(1);
 				}else if(Tools.startsWith(line, "#xMax")){
 					fc.xMax=lp.parseInt(1);
+				}else if(Tools.startsWith(line, "#yMin")){
+					fc.yMin=lp.parseInt(1);
 				}else if(Tools.startsWith(line, "#yMax")){
 					fc.yMax=lp.parseInt(1);
+				}else if(Tools.startsWith(line, "#tMin")){
+					fc.tMin=lp.parseInt(1);
+				}else if(Tools.startsWith(line, "#tMax")){
+					fc.tMax=lp.parseInt(1);
 				}else if(Tools.startsWith(line, "#k")){
 					fc.k=lp.parseInt(1);
+				}else if(Tools.startsWith(line, "#id")){
+					fc.name=lp.parseString(1);
+				}else if(Tools.startsWith(line, "#lane")){
+					//ignore
 				}
 				
 				else if(Tools.startsWith(line, "#avgQuality")){
