@@ -80,7 +80,7 @@ public class IceCreamGrader {
 				//do nothing
 			}
 			
-			else if(parser.in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+			else if(parser.in1==null && i==0 && Tools.looksLikeInputStream(arg)){
 				parser.in1=arg;
 			}else if(parser.out1==null && i==1 && !arg.contains("=")){
 				parser.out1=arg;
@@ -223,7 +223,7 @@ public class IceCreamGrader {
 	private PrintStream outstream=System.err;
 	public static boolean verbose=false;
 	public boolean errorState=false;
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	private boolean append=false;
 	
 }
