@@ -1,7 +1,6 @@
 package jasper;
 
 import java.util.ArrayList;
-import java.util.Locale;
 
 import dna.AminoAcid;
 import fileIO.ByteStreamWriter;
@@ -238,8 +237,8 @@ public class KmerPosition3 {
 		//Stop timer after all processes have competed and before printing runtime.
 		t.stop();
 		outstream.println("Time:                         \t"+t);
-		outstream.println("Reads Processed:    "+readsProcessed+" \t"+String.format(Locale.ROOT, "%.2fk reads/sec", (readsProcessed/(double)(t.elapsed))*1000000));
-		outstream.println("Bases Processed:    "+basesProcessed+" \t"+String.format(Locale.ROOT, "%.2fk bases/sec", (basesProcessed/(double)(t.elapsed))*1000000));
+		outstream.println("Reads Processed:    "+readsProcessed+" \t"+Tools.format("%.2fk reads/sec", (readsProcessed/(double)(t.elapsed))*1000000));
+		outstream.println("Bases Processed:    "+basesProcessed+" \t"+Tools.format("%.2fk bases/sec", (basesProcessed/(double)(t.elapsed))*1000000));
 		
 		//If an error statement was encountered, report this and crash program (exit with 1, not 0).
 		assert(!errorState) : "An error was encountered.";
