@@ -1087,8 +1087,8 @@ public final class AssemblyStats2 {
 		
 		if(FORMAT==0){
 		}else if(FORMAT==1){
-			sb.append("Main genome scaffold sequence total:\t"+Tools.format("%.3f MB",scaflen/1000000f)+"\n");
-			sb.append("Main genome contig sequence total:  \t"+Tools.format("%.3f MB  \t%.3f%% gap",contiglen/1000000f,(scaflen-contiglen)*100f/scaflen)+"\n");
+			sb.append("Main genome scaffold sequence total:\t"+Tools.format("%.3f Mb",scaflen/1000000f)+"\n");
+			sb.append("Main genome contig sequence total:  \t"+Tools.format("%.3f Mb  \t%.3f%% gap",contiglen/1000000f,(scaflen-contiglen)*100f/scaflen)+"\n");
 		}else if(FORMAT==2){
 			sb.append("Main genome scaffold sequence total:\t"+scaflen+"\n");
 			sb.append("Main genome contig sequence total:  \t"+Tools.format("%d  \t%.3f%% gap",contiglen,(scaflen-contiglen)*100f/scaflen)+"\n");
@@ -1101,7 +1101,7 @@ public final class AssemblyStats2 {
 		}else if(FORMAT==8){
 			
 		}else if(FORMAT==7){
-			sb.append("Main genome contig sequence total:  \t"+Tools.format("%.3f MB",contiglen/1000000f)+"\n");
+			sb.append("Main genome contig sequence total:  \t"+Tools.format("%.3f Mb",contiglen/1000000f)+"\n");
 		}else{throw new RuntimeException("Unknown format");}
 		
 		if(FORMAT<3){
@@ -1948,11 +1948,11 @@ public final class AssemblyStats2 {
 		}else if(x<1000000){
 			s=Tools.format("%."+precision+"f",x/1000f);
 			while(s.contains(".") && (s.endsWith("0") || s.endsWith("."))){s=s.substring(0, s.length()-1);}
-			s=s+" KB";
+			s=s+" Kbp";
 		}else{
 			s=Tools.format("%."+precision+"f",x/1000000f);
 			while(s.contains(".") && (s.endsWith("0") || s.endsWith("."))){s=s.substring(0, s.length()-1);}
-			s=s+" MB";
+			s=s+" Mbp";
 		}
 		while(s.length()<width){s=" "+s;}
 		return s;
@@ -1967,11 +1967,11 @@ public final class AssemblyStats2 {
 		}else if(x<1000000){
 			s=Tools.format("%."+precision+"f",x/1000f);
 			while(s.contains(".") && (s.endsWith("0") || s.endsWith("."))){s=s.substring(0, s.length()-1);}
-			s=s+" KB";
+			s=s+" Kbp";
 		}else{
 			s=Tools.format("%."+precision+"f",x/1000000f);
 			while(s.contains(".") && (s.endsWith("0") || s.endsWith("."))){s=s.substring(0, s.length()-1);}
-			s=s+" MB";
+			s=s+" Mbp";
 		}
 		
 		while(s.length()<width){s=" "+s;}
