@@ -7,7 +7,6 @@ import java.util.Arrays;
 import java.util.BitSet;
 import java.util.HashMap;
 import java.util.LinkedHashMap;
-import java.util.Locale;
 import java.util.concurrent.ArrayBlockingQueue;
 import java.util.concurrent.ConcurrentHashMap;
 
@@ -175,7 +174,7 @@ public class BBMask{
 				inSam.add(arg);
 			}
 			
-			else if(inRef==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+			else if(inRef==null && i==0 && Tools.looksLikeInputStream(arg)){
 				inRef=arg;
 			}
 //			else if(outRef==null && i==1 && !arg.contains("=")){
@@ -270,8 +269,8 @@ public class BBMask{
 			while(bmstring.length()<12){bmstring=" "+bmstring;}
 	
 			outstream.println("Repeat Masking Time:          \t"+t);
-			//outstream.println("Ref Scaffolds:          "+rpstring+" \t"+String.format(Locale.ROOT, "%.2fk scafs/sec", rpnano*1000000));
-			outstream.println("Ref Bases:              "+bpstring+" \t"+String.format(Locale.ROOT, "%.2fm bases/sec", bpnano*1000));
+			//outstream.println("Ref Scaffolds:          "+rpstring+" \t"+Tools.format("%.2fk scafs/sec", rpnano*1000000));
+			outstream.println("Ref Bases:              "+bpstring+" \t"+Tools.format("%.2fm bases/sec", bpnano*1000));
 			outstream.println("Repeat Bases Masked:    "+bmstring);
 		}
 
@@ -298,8 +297,8 @@ public class BBMask{
 			while(bmstring.length()<12){bmstring=" "+bmstring;}
 	
 			outstream.println("Low Complexity Masking Time:  \t"+t);
-			//outstream.println("Ref Scaffolds:          "+rpstring+" \t"+String.format(Locale.ROOT, "%.2fk scafs/sec", rpnano*1000000));
-			outstream.println("Ref Bases:              "+bpstring+" \t"+String.format(Locale.ROOT, "%.2fm bases/sec", bpnano*1000));
+			//outstream.println("Ref Scaffolds:          "+rpstring+" \t"+Tools.format("%.2fk scafs/sec", rpnano*1000000));
+			outstream.println("Ref Bases:              "+bpstring+" \t"+Tools.format("%.2fm bases/sec", bpnano*1000));
 			outstream.println("Low Complexity Bases:   "+bmstring);
 		}
 		
@@ -321,8 +320,8 @@ public class BBMask{
 			while(bmstring.length()<12){bmstring=" "+bmstring;}
 			
 			outstream.println("Sam Masking Time:             \t"+t);
-			outstream.println("Sam Reads Processed:    "+rpstring+" \t"+String.format(Locale.ROOT, "%.2fk reads/sec", rpnano*1000000));
-			outstream.println("Sam Bases Processed:    "+bpstring+" \t"+String.format(Locale.ROOT, "%.2fm bases/sec", bpnano*1000));
+			outstream.println("Sam Reads Processed:    "+rpstring+" \t"+Tools.format("%.2fk reads/sec", rpnano*1000000));
+			outstream.println("Sam Bases Processed:    "+bpstring+" \t"+Tools.format("%.2fm bases/sec", bpnano*1000));
 			outstream.println("Sam Bases Masked:       "+bmstring);
 		}
 		long total=repeats+mapping+lowcomplexity, masked=0;
@@ -351,7 +350,7 @@ public class BBMask{
 			t0.stop();
 			String tstring=""+total;
 			while(tstring.length()<12){tstring=" "+tstring;}
-			outstream.println("\nTotal Bases Masked:     "+tstring+"/"+refBases+String.format(Locale.ROOT, "\t%.3f%%", total*100.0/refBases));
+			outstream.println("\nTotal Bases Masked:     "+tstring+"/"+refBases+Tools.format("\t%.3f%%", total*100.0/refBases));
 			outstream.println("Total Time:                   \t"+t0);
 		}
 		
@@ -1205,7 +1204,7 @@ public class BBMask{
 	private String extinRef=null;
 	private String extoutRef=null;
 	
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	private boolean append=false;
 
 	private long maxReads=-1;
