@@ -53,7 +53,7 @@ public final class BBMergeOverlapper {
 		return x;
 	}
 	
-	protected static final int mateByOverlapRatio(Read a, Read b, float[] aprob, float[] bprob, int[] rvector,
+	public static final int mateByOverlapRatio(Read a, Read b, float[] aprob, float[] bprob, int[] rvector,
 			int minOverlap0, int minOverlap, int minInsert0, int minInsert, final float maxRatio, final float minSecondRatio,
 			final float margin, final float offset, final float gIncr, final float bIncr, boolean useQuality) {
 		if(rvector==null){rvector=KillSwitch.allocInt1D(5);}
@@ -946,7 +946,7 @@ public final class BBMergeOverlapper {
 	 * @param overlap
 	 * @return
 	 */
-	protected static final float expectedMismatches(Read a, Read b, int overlap) {
+	public static final float expectedMismatches(Read a, Read b, int overlap) {
 		
 		final byte[] abases=a.bases, bbases=b.bases, aqual=a.quality, bqual=b.quality;
 		final int alen=abases.length, blen=bbases.length;
@@ -1007,7 +1007,7 @@ public final class BBMergeOverlapper {
 	
 	/** Attempt at quantifying probability of an event like this.
 	 * TODO: This returns an incorrect answer if reads are unequal lengths. */
-	protected static final float probability(Read a, Read b, int insert) {
+	public static final float probability(Read a, Read b, int insert) {
 		final byte[] abases=a.bases, bbases=b.bases, aqual=a.quality, bqual=b.quality;
 		final int alen=abases.length, blen=bbases.length;
 		final int istart=(insert<=blen ? 0 : insert-blen);
