@@ -259,7 +259,7 @@ public class BBQC {
 				}
 			}else if(a.equals("maxns")){
 				maxNs=Integer.parseInt(b);
-			}else if(in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+			}else if(in1==null && i==0 && Tools.looksLikeInputStream(arg)){
 				in1=arg;
 				if(arg.indexOf('#')>-1 && !new File(arg).exists()){
 					in1=arg.replace("#", "1");
