@@ -3,7 +3,6 @@ package jgi;
 import java.io.File;
 import java.io.PrintStream;
 import java.util.ArrayList;
-import java.util.Locale;
 import java.util.Random;
 
 import fileIO.ByteFile;
@@ -102,7 +101,7 @@ public class CalcUniqueness {
 				fixSpikes=Parse.parseBoolean(b);
 			}else if(a.equals("bin") || a.equals("interval")){
 				interval=Parse.parseKMG(b);
-			}else if(parser.in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+			}else if(parser.in1==null && i==0 && Tools.looksLikeInputStream(arg)){
 				parser.in1=arg;
 			}else{
 //				System.err.println("Unknown parameter "+args[i]);
@@ -262,7 +261,7 @@ public class CalcUniqueness {
 		}
 		
 		String percentS(){
-			return String.format(Locale.ROOT, "%.3f",percent());
+			return Tools.format("%.3f",percent());
 		}
 
 		long hits(){return cumulative ? chits : hits;}
@@ -470,7 +469,7 @@ public class CalcUniqueness {
 			double xpnano=bytesProcessed/(double)(t.elapsed);
 			String xpstring=(bytesProcessed<100000 ? ""+bytesProcessed : bytesProcessed<100000000 ? (bytesProcessed/1000)+"k" : (bytesProcessed/1000000)+"m");
 			while(xpstring.length()<8){xpstring=" "+xpstring;}
-			outstream.println("Bytes Processed:    "+xpstring+" \t"+String.format(Locale.ROOT, "%.2fm bytes/sec", xpnano*1000));
+			outstream.println("Bytes Processed:    "+xpstring+" \t"+Tools.format("%.2fm bytes/sec", xpnano*1000));
 		}
 		
 		if(errorState){
@@ -523,8 +522,8 @@ public class CalcUniqueness {
 		}
 		
 		if(showQuality){
-			sb.append('\t').append(String.format(Locale.ROOT, "%.2f", bothCounterFirst.averageQuality()));
-			sb.append('\t').append(String.format(Locale.ROOT, "%.2f", bothCounterFirst.averagePerfectProb()));
+			sb.append('\t').append(Tools.format("%.2f", bothCounterFirst.averageQuality()));
+			sb.append('\t').append(Tools.format("%.2f", bothCounterFirst.averagePerfectProb()));
 		}
 		
 		sb.append('\n');
@@ -659,7 +658,7 @@ public class CalcUniqueness {
 	private PrintStream outstream=System.err;
 	public static boolean verbose=false;
 	public boolean errorState=false;
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	private boolean append=false;
 	private boolean testsize=false;
 	
