@@ -4,7 +4,6 @@ import java.io.File;
 import java.io.PrintStream;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Locale;
 
 import fileIO.ByteFile1;
 import fileIO.ByteFile2;
@@ -115,7 +114,7 @@ public class CallPeaks {
 				weightByRelief=Parse.parseBoolean(b);
 			}
 			
-			else if(in==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+			else if(in==null && i==0 && Tools.looksLikeInputStream(arg)){
 				in=arg;
 			}else{
 				outstream.println("Unknown parameter "+args[i]);
@@ -368,20 +367,20 @@ public class CallPeaks {
 				bsw.println("#genome_size_in_peaks\t"+genomeSizeInPeaks);
 				bsw.println("#genome_size\t"+totalGenomeSize);
 				if(mainPeak.gc>0){
-					bsw.println("#main_peak_gc\t"+String.format(Locale.ROOT, "%.3f", Tools.mid(0, 1, mainPeak.gc*gcmult/mainPeak.volume)));
+					bsw.println("#main_peak_gc\t"+Tools.format("%.3f", Tools.mid(0, 1, mainPeak.gc*gcmult/mainPeak.volume)));
 				}
 				if(gcHist!=null){
-					bsw.println("#gc_content_in_peaks\t"+String.format(Locale.ROOT, "%.3f", Tools.mid(0, 1, gcContent)));
-					bsw.println("#gc_content\t"+String.format(Locale.ROOT, "%.3f", Tools.mid(0, 1, gcContent2)));
+					bsw.println("#gc_content_in_peaks\t"+Tools.format("%.3f", Tools.mid(0, 1, gcContent)));
+					bsw.println("#gc_content\t"+Tools.format("%.3f", Tools.mid(0, 1, gcContent2)));
 				}
 				if(ploidy>1 || true){bsw.println("#haploid_genome_size\t"+haploidSize);}
 				bsw.println("#fold_coverage\t"+Math.round(haploidPeakCenter));
 				if(ploidy>1 || true){bsw.println("#haploid_fold_coverage\t"+haploidCov);}
 				bsw.println("#ploidy\t"+ploidy);
 				if(ploidy!=ploidyEstimate){bsw.println("#ploidy_detected\t"+ploidyEstimate);}
-				if(ploidy>1){bsw.println("#het_rate\t"+String.format(Locale.ROOT, "%.5f", hetRate));}
-				bsw.println("#percent_repeat_in_peaks\t"+String.format(Locale.ROOT, "%.3f", (100*repeatRate)));
-				if(repeatSize2>=0){bsw.println("#percent_repeat\t"+String.format(Locale.ROOT, "%.3f", (100*repeatRate2)));}
+				if(ploidy>1){bsw.println("#het_rate\t"+Tools.format("%.5f", hetRate));}
+				bsw.println("#percent_repeat_in_peaks\t"+Tools.format("%.3f", (100*repeatRate)));
+				if(repeatSize2>=0){bsw.println("#percent_repeat\t"+Tools.format("%.3f", (100*repeatRate2)));}
 			} catch (Exception e) {
 				e.printStackTrace();
 			}
@@ -1195,7 +1194,7 @@ public class CallPeaks {
 	private PrintStream outstream=System.err;
 	public static boolean verbose=false;
 	public boolean errorState=false;
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	private boolean append=false;
 	public static boolean printClass=true;
 
