@@ -91,6 +91,8 @@ public class CheckStrand {
 				samplerate=Float.parseFloat(b);
 			}else if(a.equals("sampleseed") || a.equals("seed")){
 				sampleseed=Long.parseLong(b);
+			}else if(a.equals("normalize")){
+				normalize=Parse.parseBoolean(b);
 			}else if(a.equals("ref") || a.equals("fna")){
 				fna=b;
 			}else if(a.equals("gff")){
@@ -141,6 +143,7 @@ public class CheckStrand {
 		
 		outstream.println();
 		double[] results=calcStrandedness(canonSketch, fwdSketch);
+		if(normalize) {results=calcStrandednessNormalized(canonSketch, fwdSketch);}
 		
 		outputResults(results, refResults);
 		
@@ -397,6 +400,127 @@ public class CheckStrand {
 				strandedness, depth, matches, nonUniqueFraction};
 	}
 	
+	/**
+	 * Determine the strandedness of a set of reads by comparing a Sketch of
+	 * canonical kmers to forward kmers.
+	 * In this mode, each kmer contributes 0-1.0 strandedness regardless of its depth.
+	 * @param saCanon Sketch of canonical kmers.
+	 * @param sbFwd Sketch of forward kmers.
+	 * @return Results vector: {totalSum, minSum, expectedMinSum, maxPossibleMinSum, 
+	 * strandedness, depth, matches, nonUniqueFraction}
+	 */
+	static double[] calcStrandednessNormalized(Sketch saCanon, Sketch sbFwd) {
+		final long[] a=saCanon.keys, b=sbFwd.keys;
+		final int[] aCounts=saCanon.keyCounts, bCounts=sbFwd.keyCounts;
+		
+		int matches=0;
+		int totalCount=0;
+		long sharedSum=0;
+		long nonUniqueCount=0;
+		double totalSum=0;
+		double minSum=0;
+		double expectedMinSum=0;
+		double maxPossibleMinSum=0;
+		
+		//Here we walk down the Sketches and find where they share kmers.
+		//In those cases, the counts are compared to determine balance.
+		for(int i=0, j=0; i<a.length && j<b.length; ){
+			final long ka=a[i], kb=b[j];
+			if(ka==kb){//Match
+				final int ca=aCounts[i];
+				final int cb=bCounts[j];
+				if(ca>1) {
+					matches++;
+					final int cmin=Tools.min(cb, ca-cb);
+					assert(cmin>=0) : ca+", "+cb;
+					nonUniqueCount+=(ca>1 ? 1 : 0);
+					double expectedMinor=expectedMinorAlleleCount(ca);
+					assert(expectedMinor>0);
+					double ratio=cmin/(double)ca;
+					totalSum+=ca;
+					totalCount++;
+					sharedSum+=ca;
+					minSum+=ratio;
+					maxPossibleMinSum+=((ca/2)/(double)ca);
+					expectedMinSum+=(expectedMinor/ca);
+				}
+				i++;
+				j++;
+			}else if(ka<kb){//kb was missing; thus it had a minor count of 0
+				final int ca=aCounts[i];//TODO
+				final int cb=0;
+				if(ca>1) {
+					final int cmin=Tools.min(cb, ca-cb);//Should always be cb
+					assert(cmin>=0);//Should always be 0
+					nonUniqueCount+=(ca>1 ? 1 : 0);
+					double expectedMinor=expectedMinorAlleleCount(ca);
+					double ratio=cmin/(double)ca;
+					totalSum+=ca;
+					totalCount++;
+					sharedSum+=ca;
+					minSum+=ratio;
+					maxPossibleMinSum+=((ca/2)/(double)ca);
+					expectedMinSum+=(expectedMinor/ca);
+				}
+				i++;
+			}else{//ka was missing; thus this is a noncanonical key
+				j++;
+			}
+		}
+		
+		//Strandedness will be (0.5-1.0) for normal (fully unstranded-fully stranded) libraries.
+		//Synthetic or binned libraries with a perfectly flat distribution will get 0.0,
+		//but anything between 0.0 and 0.5 would be unusual.
+		//Basically 1.0 is preference for a strand, 0.5 is no preference for a strand,
+		//and 0.0 is preference for perfect balance between strands - as you would get
+		//if you treated paired reads as single-ended.
+		double strandedness;
+		if(minSum<=expectedMinSum) {//Normal case; strandedness between 0 and 50%
+//			strandedness=1-(minSum/(expectedMinSum+minSum));//Not sure about the proper formula; needs thought
+			strandedness=0.5+(1-(minSum/expectedMinSum))*0.5;
+		}else{//Odd case; distribution is more even than expected by chance
+			assert(minSum<=maxPossibleMinSum) : minSum+", "+maxPossibleMinSum;
+			double range=(maxPossibleMinSum-expectedMinSum);
+			double delta=minSum-expectedMinSum;
+			assert(delta>=0 && delta<=range);
+			double x=0.5*(1-(delta/range));
+			strandedness=x;//Not really sure about this either
+		}
+		double depth=totalSum/totalCount;
+		double nonUniqueFraction=nonUniqueCount/(1.0*totalCount);
+		return new double[] {totalSum, minSum, expectedMinSum, maxPossibleMinSum, 
+				strandedness, depth, matches, nonUniqueFraction};
+	}
+	
+	static float strandedness(long plus, long minus) {
+		long sum=plus+minus;
+		long maxPossibleMinor=sum/2;
+		float expectedMinor=(float)expectedMinorAlleleCount(sum);
+		assert(expectedMinor>0);
+		
+		return strandedness(plus, minus, maxPossibleMinor, expectedMinor);
+	}
+	
+	static float strandedness(long plus, long minus, long maxPossibleMinor, float expectedMinor) {
+		long sum=plus+minus;
+		long min=Math.min(plus, minus);
+		assert(expectedMinor>0);
+		
+		if(min<=expectedMinor) {//Expected case
+			float strandedness=1-0.5f*(min/expectedMinor);//0.5-1
+			assert(strandedness>=0 && strandedness<=1.01) : strandedness+
+				", "+plus+", "+minus+", "+sum+", "+min+", "+expectedMinor;
+			return strandedness;
+		}else{//Rare case; overly unstranded
+			float range=maxPossibleMinor-expectedMinor;
+			float dif=min-expectedMinor;
+			float strandedness=0.5f*(1-(dif/range));
+			assert(strandedness>=0 && strandedness<=1.01) : strandedness+", "+plus+", "+minus+
+				", "+sum+", "+min+", "+expectedMinor+", "+range+", "+dif;
+			return strandedness;
+		}
+	}
+	
 	/**
 	 * Counts the fraction of total kmers shared between sketches, which includes their counts.
 	 * @param saFwd Forward sketch of reads.
@@ -743,6 +867,7 @@ public class CheckStrand {
 	
 	/*--------------------------------------------------------------*/
 
+	private boolean normalize=false;
 	private long maxReads=-1;
 	private float samplerate=1;
 	private long sampleseed=17;
