@@ -5,6 +5,7 @@ import java.io.PrintStream;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
+import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.locks.ReadWriteLock;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
 
@@ -40,6 +41,7 @@ import stream.Read;
 import stream.ReadInputStream;
 import stream.SamLine;
 import structures.ListNum;
+import structures.LongPair;
 import structures.Range;
 import template.Accumulator;
 import template.ThreadWaiter;
@@ -140,7 +142,7 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 		}
 		
 		//Decide whether gene-calling is needed, and pick a gene model.
-		if((fna!=null && (gff==null || passes>1) && !transcriptome) || scoreReadGenes) {
+		if((fna!=null && (gff==null || passes>1) && !transcriptome && !rnaContigs) || scoreReadGenes) {
 			if(pgmFile==null){pgmFile=Data.findPath("?model.pgm");}
 			final GeneModel pgm0=GeneModelParser.loadModel(pgmFile);
 			if(passes<2 || fna==null || transcriptome) {pgm=pgm0;}
@@ -200,6 +202,8 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 				gff=b;
 			}else if(a.equals("merge")){
 				mergePairs=Parse.parseBoolean(b);
+			}else if(a.equals("bin") || a.equals("binlen")){
+				binlen=Parse.parseIntKMG(b);
 			}else if(a.equals("scoregenes") || a.equals("scorereads") || a.equals("callgenes")
 					|| a.equals("callreads") || a.equals("kfa")){
 				scoreReadGenes=Parse.parseBoolean(b);
@@ -213,6 +217,12 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 				testPolyA=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("transcriptome")){
 				transcriptome=Parse.parseBoolean(b);
+			}else if(a.equalsIgnoreCase("rnacontigs")){
+				rnaContigs=Parse.parseBoolean(b);
+			}else if(a.equalsIgnoreCase("normalize")){
+				normalize=Parse.parseBoolean(b);
+			}else if(a.equalsIgnoreCase("minreads")){
+				minReads=Integer.parseInt(b);
 			}else if(a.equalsIgnoreCase("genome")){
 				transcriptome=!Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("outp") || a.equalsIgnoreCase("outplus")){
@@ -231,8 +241,30 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 			}else if(parser.parse(arg, a, b)){//Parse standard flags in the parser
 				//do nothing
 			}else{
-				outstream.println("Unknown parameter "+args[i]);
-				assert(false) : "Unknown parameter "+args[i];
+				boolean parsed=false;
+				if(b==null && arg.indexOf('=')<0) {
+					File f=new File(arg);
+					String ext=ReadWrite.rawExtension(a);
+					if(f.isFile() && f.canRead()) {
+						if(parser.in1==null && (FileFormat.isSamOrBamExt(ext) || FileFormat.isFastqExt(ext))) {
+							outstream.println("Set input to "+f.getName());
+							parser.in1=arg;
+							parsed=true;
+						}else if(gff==null && FileFormat.isGffExt(ext)) {
+							outstream.println("Set gff to "+f.getName());
+							gff=arg;
+							parsed=true;
+						}else if(fna==null && FileFormat.isFastaExt(ext)) {
+							outstream.println("Set ref to "+f.getName());
+							fna=arg;
+							parsed=true;
+						}
+					}
+				}
+				if(!parsed) {
+					outstream.println("Unknown parameter "+args[i]);
+					assert(false) : "Unknown parameter "+args[i];
+				}
 			}
 		}
 		
@@ -324,12 +356,27 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 		final boolean vic=Read.VALIDATE_IN_CONSTRUCTOR;
 		Read.VALIDATE_IN_CONSTRUCTOR=Shared.threads()<4;
 		
-		if(gff!=null) {
-			gffLines=CheckStrand.getGffLines(gff, types);
-			if(ffin1.samOrBam()) {
+		makeTools();
+		makeGeneSketches();
+		
+		if(ffin1.samOrBam()) {//Aligned reads
+			if(gffLines==null) {//Features not yet loaded
+				if(gff!=null) {
+					gffLines=CheckStrand.getGffLines(gff, types);
+				}else if(fna!=null && !transcriptome && !rnaContigs) {
+					ArrayList<Read> reads=genomeSequence();
+					System.err.print("Calling genes from genome: ");
+					ArrayList<Orf> orfs=gCaller.callGenes(reads);
+					gffLines=Orf.toGffLines(orfs);
+				}
+			}
+			if(gffLines!=null) {
 				SamLine.RNAME_AS_BYTES=false;//Must come before cris starts
 				rangeMap=GffLine.makeRangeMap(gffLines);
 			}
+			if(binlen>0) {
+				binMap=new ConcurrentHashMap<String, ArrayList<LongPair>>();
+			}
 		}
 		
 		//Create a read input stream
@@ -342,8 +389,6 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 		basesIn=basesProcessed=0;
 		readsMerged=0;
 		
-		makeTools();
-		
 		//Process the reads in separate threads
 		spawnThreads(cris, crosP, crosM);
 		
@@ -376,9 +421,11 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 	/** Do math on the raw results to determine strandedness and major strand */
 	void analyze() {
 		double[] results=CheckStrand.calcStrandedness(canonSketch, fwdSketch);
+		double[] resultsN=CheckStrand.calcStrandednessNormalized(canonSketch, fwdSketch);
+		
 		double[] refResults=(canonGeneSketch==null ? null : CheckStrand.calcPMRatioWithGeneSketches(
 				canonSketch, fwdSketch, canonGeneSketch, plusSketch, minusSketch));
-		outputResults(results, refResults);
+		outputResults(results, resultsN, refResults);
 	}
 	
 	/**
@@ -468,9 +515,9 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 		
 		//Start the threads and wait for them to finish
 		ThreadWaiter.startThreads(alpt);
-		
-		//While that's going, process the ref
-		makeGeneSketches();
+//		
+//		//While that's going, process the ref
+//		makeGeneSketches();
 		
 		boolean success=ThreadWaiter.waitForThreadsToFinish(alpt, this);
 		outstream.println("Finished processing "+readsIn+" reads and "+basesIn+" bases.");
@@ -512,6 +559,7 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 
 			plusAlignedReads+=pt.plusAlignedReadsT;
 			minusAlignedReads+=pt.minusAlignedReadsT;
+			allAlignedReads+=pt.allAlignedReadsT;
 
 			samLinesProcessed+=pt.samLinesProcessedT;
 			samLinesAlignedToFeatures+=pt.samLinesAlignedToFeaturesT;
@@ -567,7 +615,7 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 		final ArrayList<Read> genes;
 		Timer t=new Timer();
 		
-		if(transcriptome) {
+		if(transcriptome || rnaContigs) {
 			System.err.print("Loading genes from transcriptome: ");
 			genes=genomeSequence(); //Skips loading if already cached
 		}else if(gff!=null) {
@@ -576,16 +624,14 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 					CheckStrand.getSequenceMap(fna) : CheckStrand.getSequenceMap(genomeSequence()));
 			genes=CheckStrand.grabGenes(gffLines, map);
 		}else{
-			System.err.print("Calling genes from genome: ");
-			if(streamGenome) {
-				genes=callGenes(fna);//This path is slow; don't use it.  Not clear why.
-			}else {
-				ArrayList<Read> reads=genomeSequence();
-				HashMap<String, Read> map=CheckStrand.getSequenceMap(reads);
+			ArrayList<Read> reads=genomeSequence();
+			if(gffLines==null) {
+				System.err.print("Calling genes from genome: ");
 				ArrayList<Orf> orfs=gCaller.callGenes(reads);
-				//ArrayList<GffLine> allGffLines=Orf.toGffLines(orfs);
-				genes=CheckStrand.grabGenes(orfs, map);
+				gffLines=Orf.toGffLines(orfs);
 			}
+			HashMap<String, Read> map=CheckStrand.getSequenceMap(reads);
+			genes=CheckStrand.grabGenes(gffLines, map);
 		}
 		t.stopAndPrint();
 		
@@ -627,7 +673,7 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 	 * @param results Results from read kmer depth analysis
 	 * @param refResults Results based on transcriptome kmer comparison
 	 */
-	private void outputResults(double[] results, double[] refResults){
+	private void outputResults(double[] results, double[] resultsN, double[] refResults){
 		if(ffout1==null) {return;}
 		ByteStreamWriter bsw=new ByteStreamWriter(ffout1);
 		bsw.start();
@@ -638,11 +684,13 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 		//Results based on read kmer depth
 		if(doDepthAnalysis){
 			double strandedness=results[4];
+			double strandednessN=resultsN[4];
 			double depth=results[5];
 			double nonUniqueFraction=results[7];
 			
 			bsw.println("Depth_Analysis:");
 			bsw.println(String.format("Strandedness:\t%.2f%%", strandedness*100));
+			bsw.println(String.format("StrandednessN:\t%.2f%%", strandednessN*100));
 			bsw.println(String.format("AvgKmerDepth:\t%.3f", depth));
 			bsw.println(String.format("Kmers>Depth1:\t%.4f", nonUniqueFraction));
 		}
@@ -727,22 +775,77 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 		
 		//Alignment-based results
 		//TODO: Add a flag; should probably be disabled for euks with no gff
-		if(ffin1.samOrBam() && (transcriptome || gff!=null || fna!=null)) {
-			boolean plus=(plusAlignedReads>=minusAlignedReads);
-			long readsAligned0=plusAlignedReads+minusAlignedReads;
-			long readsAligned=Tools.max(1, readsAligned0);
-			double alignmentRate=readsAligned/(1.0*samLinesProcessed);
-			double alignmentRate2=samLinesAlignedToFeatures/(1.0*samLinesProcessed);
-			double pmRatio=plusAlignedReads/(1.0*readsAligned);
+		if(ffin1.samOrBam() && (transcriptome || rnaContigs || gff!=null || fna!=null)) {
+			long genesAligned=0;
+			long genesGT1=0;
+			double strandednessSumNorm=0;
+			double pmRatioSum=0;
+			long plusGeneCount=0;
+			double minorSum=0, majorSum=0, maxMinorSum=0, expectedSum=0;
+			{//Normalized Statistics
+				for(LongPair p : geneMap.values()) {
+					if(p.a+p.b>0) {
+						float pmRatio=p.a/(float)(p.a+p.b);
+						genesAligned++;
+						pmRatioSum+=pmRatio;
+						plusGeneCount+=(pmRatio>0.5f ? 1 : 0);
+						if(p.a+p.b>=minReads) {
+							float strandedness=CheckStrand.strandedness(p.a, p.b);
+							assert(strandedness>=0 && strandedness<=1.01) : strandedness+", "+p.a+", "+p.b;
+							strandednessSumNorm+=strandedness;
+							genesGT1++;
+							assert(strandednessSumNorm<=genesGT1) : strandednessSumNorm+", "+genesGT1;
+							minorSum+=p.min();
+							majorSum+=p.max();
+							maxMinorSum+=p.sum()/2;
+							expectedSum+=CheckStrand.expectedMinorAlleleCount(p.sum());
+						}
+					}
+				}
+			}
+			final double[] binStrandedness=binStrandedness();
+			
+			final boolean plus=(plusAlignedReads>=minusAlignedReads);
+			final long readsAligned0=plusAlignedReads+minusAlignedReads;
+			final long readsAligned=Tools.max(1, readsAligned0);
+			final double alignmentRate=allAlignedReads/(1.0*samLinesProcessed);
+			final double alignmentRate2=samLinesAlignedToFeatures/(1.0*samLinesProcessed);
+			final double pmRatio=plusAlignedReads/(1.0*readsAligned);
 			double strandednessALN=Tools.max(plusAlignedReads, minusAlignedReads)/(1.0*readsAligned);
+			if(rnaContigs) {
+				//strandednessALN=CheckStrand.strandedness(minorSum, majorSum);
+				if(minorSum<=expectedSum) {//Expected case
+					strandednessALN=1-0.5f*(minorSum/expectedSum);//0.5-1
+				}else{//Rare case; overly unstranded
+					double range=maxMinorSum-expectedSum;
+					double dif=minorSum-expectedSum;
+					strandednessALN=0.5f*(1-(dif/range));
+				}
+			}
 			
 			bsw.println();
 			bsw.println("Alignment_Results:");
 			bsw.println(String.format("StrandednessAL:\t%.2f%%", strandednessALN*100));
-			bsw.println("MajorStrandAL:\t"+(plus ? "Plus" : "Minus"));
-			bsw.println(String.format("P/(P+M)_Ratio:\t%.6f", pmRatio));
+			assert(strandednessSumNorm<=genesGT1) : strandednessSumNorm+", "+genesGT1;
+			bsw.println(String.format("StrandednessAN:\t%.2f%%", 100*strandednessSumNorm/genesGT1));
+//			assert(false) : strandednessSumNorm+", "+genesGT1;
+			if(binStrandedness!=null) {
+				bsw.println(String.format("StrandednessB:\t%.2f%%", binStrandedness[0]*100));
+				bsw.println(String.format("StrandednessBN:\t%.2f%%", binStrandedness[1]*100));
+				bsw.println(String.format("StrandednessBS:\t%.2f%%", binStrandedness[2]*100));
+				bsw.println(String.format("StrandednessBNS:\t%.2f%%", binStrandedness[3]*100));
+			}
+			if(!rnaContigs) {
+				bsw.println("MajorStrandAL:\t"+(plus ? "Plus" : "Minus"));
+				bsw.println(String.format("P/(P+M)_Ratio:\t%.6f", pmRatio));
+				bsw.println(String.format("P/(P+M)_RatioN:\t%.6f", pmRatioSum/genesAligned));
+			}
+			if(!transcriptome) {
+				bsw.println(String.format("PlusFeatures:\t%.6f", plusGeneCount/(float)genesAligned));
+			}
 			bsw.println(String.format("AlignmentRate:\t%.6f", alignmentRate));
-			if(!transcriptome) {bsw.println(String.format("Feature-Mapped:\t%.6f", alignmentRate2));}
+			if(!transcriptome && !rnaContigs) {bsw.println(String.format("Feature-Mapped:\t%.6f", alignmentRate2));}
+			
 //			bsw.println(String.format("Plus-mapped:\t%d", plusAlignedReads));
 //			bsw.println(String.format("Minus-mapped:\t%d", minusAlignedReads));
 		}
@@ -756,6 +859,44 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 		errorState=bsw.poisonAndWait() | errorState;
 	}
 	
+	double[] binStrandedness() {
+		if(binMap==null || binMap.isEmpty()) {return null;}
+		long binsAligned=0;
+		long binsGT1=0;
+		double strandednessSumNorm=0;
+		double pmRatioSum=0;
+		double simpleSumNorm=0;
+		long plusBinCount=0;
+		double minorSum=0, majorSum=0, maxMinorSum=0, expectedSum=0;
+		for(ArrayList<LongPair> list : binMap.values()) {
+			for(LongPair p : list) {
+				if(p!=null && p.a+p.b>0) {
+					float pmRatio=p.a/(float)(p.a+p.b);
+					binsAligned++;
+					pmRatioSum+=pmRatio;
+					plusBinCount+=(pmRatio>0.5f ? 1 : 0);
+					if(p.a+p.b>=minReads) {
+						float strandedness=CheckStrand.strandedness(p.a, p.b);
+						assert(strandedness>=0 && strandedness<=1.01) : strandedness+", "+p.a+", "+p.b;
+						strandednessSumNorm+=strandedness;
+						binsGT1++;
+						assert(strandednessSumNorm<=binsGT1) : strandednessSumNorm+", "+binsGT1;
+						minorSum+=p.min();
+						majorSum+=p.max();
+						maxMinorSum+=p.sum()/2;
+						expectedSum+=CheckStrand.expectedMinorAlleleCount(p.sum());
+						simpleSumNorm+=p.max()/(double)p.sum();
+					}
+				}
+			}
+		}
+		double strandedness=CheckStrand.strandedness((long)minorSum, (long)majorSum, (long)maxMinorSum, (float)expectedSum);
+		double strandednessN=strandednessSumNorm/binsGT1;
+		double strandednessS=majorSum/(majorSum+minorSum);
+		double strandednessNS=simpleSumNorm/binsGT1;
+		return new double[] {strandedness, strandednessN, strandednessS, strandednessNS};
+	}
+	
 	/**
 	 * Manages a cached copy of the ref fasta to prevent reading it multiple times.
 	 * @return The reference, as Read objects.
@@ -768,6 +909,48 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 		return genomeSequenceCache;
 	}
 	
+	/*--------------------------------------------------------------*/
+	
+	void incrementGeneMap(String gene, ConcurrentHashMap<String, LongPair> map, int senseStrand, int amt){
+		if(gene==null) {return;}
+		LongPair pair=map.get(gene);
+		if(pair==null) {
+			map.putIfAbsent(gene, new LongPair());
+			pair=map.get(gene);
+		}
+		synchronized(pair) {
+			if(senseStrand==0) {pair.a+=amt;}
+			else {pair.b+=amt;}
+		}
+	}
+	
+	void incrementBinMap(String gene, ConcurrentHashMap<String, ArrayList<LongPair>> map, int pos, int strand, int amt){
+		if(gene==null || map==null) {return;}
+		ArrayList<LongPair> list=map.get(gene);
+		if(list==null) {
+			map.putIfAbsent(gene, new ArrayList<LongPair>());
+			list=map.get(gene);
+		}
+		int idx=Tools.max(0, pos)/binlen;
+		increment(list, idx, strand, amt);
+	}
+	
+	void increment(ArrayList<LongPair> list, int idx, int strand, int amt) {
+		LongPair bin;
+		synchronized(list) {
+			while(list.size()<=idx) {list.add(null);}
+			bin=list.get(idx);
+			if(bin==null) {
+				bin=new LongPair();
+				list.set(idx, bin);
+			}
+		}
+		synchronized(bin) {
+			if(strand==0) {bin.a+=amt;}
+			else {bin.b+=amt;}
+		}
+	}
+	
 	/*--------------------------------------------------------------*/
 	/*----------------         Inner Classes        ----------------*/
 	/*--------------------------------------------------------------*/
@@ -1089,14 +1272,20 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 			if(!sl.primary() || sl.supplementary()) {return;}
 			samLinesProcessedT++;
 			if(!sl.mapped()) {return;}
+			allAlignedReadsT++;
 			
 			//Flip read 2's associated strand.
 			final int mappedStrand=(sl.strand()^sl.pairnum());
 			
 			//The strand on which the gene is located.
 			int senseStrand=-1;
+			String gene=null;
 			if(transcriptome) {
 				senseStrand=mappedStrand;
+				gene=sl.rnameS();
+			}else if(rnaContigs) {
+				senseStrand=mappedStrand;
+				gene=sl.rnameS();
 			}else if(gffLines!=null){//Try to figure out the sense strand
 				final int start=sl.start(false, false);
 //				final int stop=sl.stop(start, false, false);
@@ -1104,41 +1293,50 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 				final int p=start;//A point used as proxy for the read location
 				
 				//Get the ranges for the contig
-				Range[] ranges=rangeMap.get(sl.rnameS());
+				String rname=sl.rnameS();
+				Range[] ranges=rangeMap.get(rname);
 				
 				//Retry the name, trimmed to the first whitespace
 				if(ranges==null) {ranges=rangeMap.get(sl.rnamePrefix());}
-				assert(ranges!=null) : "Can't find "+sl.rnameS()+" in "+rangeMap.keySet()+"\n"+sl;
+//				assert(ranges!=null) : "Can't find rname "+sl.rnameS()+":\n"+sl+"\n";// in "+rangeMap.keySet()+"\n"+sl;
 				
-				//Find the range containing the proxy point
-				int idx=Range.findIndex(p, ranges);
-				if(idx<0) {idx=-idx-1;}
-				if(idx<0 || idx>=ranges.length){return;}
-				final Range r=ranges[idx];
-				
-				//List of features overlapping the point
-				final ArrayList<GffLine> lines=(ArrayList<GffLine>) r.obj1;
-				for(int i=lines.size()-1; i>=0; i--) {//Now to select a line...
-					final GffLine line=lines.get(i);
-					//TODO: With multiple overlapping features, this may or may not be the best one
-					if(r.intersects(line.start, line.stop)) {
-						senseStrand=mappedStrand^line.strand;
-						break;
+				if(ranges!=null) {
+					//Find the range containing the proxy point
+					int idx=Range.findIndex(p, ranges);
+					if(idx<0) {idx=-idx-1;}
+					if(idx<0 || idx>=ranges.length){return;}
+					final Range r=ranges[idx];
+
+					//List of features overlapping the point
+					final ArrayList<GffLine> lines=(ArrayList<GffLine>) r.obj1;
+					for(int i=lines.size()-1; i>=0; i--) {//Now to select a line...
+						final GffLine line=lines.get(i);
+						//TODO: With multiple overlapping features, this may or may not be the best one
+						if(r.intersects(line.start, line.stop)) {
+							senseStrand=mappedStrand^line.strand;
+							gene=sl.rnameS();
+							break;
+						}
 					}
 				}
 			}
 			
-			//Track results according to the determined strand
-			if(senseStrand==0) {
-				samLinesAlignedToFeaturesT++;
-				plusAlignedReadsT++;
-				if(crosP!=null) {pReads.add(r1);}
-			}else if(senseStrand==1){
-				samLinesAlignedToFeaturesT++;
-				minusAlignedReadsT++;
-				if(crosM!=null) {mReads.add(r1);}
-			}else {
-				assert(senseStrand==-1);
+			if(gene!=null) {
+				incrementGeneMap(gene, geneMap, senseStrand, 1);
+				incrementBinMap(gene, binMap, sl.pos, mappedStrand, 1);
+
+				//Track results according to the determined strand
+				if(senseStrand==0) {
+					samLinesAlignedToFeaturesT++;
+					plusAlignedReadsT++;
+					if(crosP!=null) {pReads.add(r1);}
+				}else if(senseStrand==1){
+					samLinesAlignedToFeaturesT++;
+					minusAlignedReadsT++;
+					if(crosM!=null) {mReads.add(r1);}
+				}else {
+					assert(senseStrand==-1);
+				}
 			}
 			
 		}
@@ -1210,6 +1408,7 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 		
 		private long plusAlignedReadsT=0;
 		private long minusAlignedReadsT=0;
+		private long allAlignedReadsT=0;
 
 		private long samLinesProcessedT=0;
 		private long samLinesAlignedToFeaturesT=0;
@@ -1238,6 +1437,8 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 	private String types="CDS,rRNA,tRNA,ncRNA,exon,5S,16S,23S";
 	private ArrayList<GffLine> gffLines=null;
 	
+	private ConcurrentHashMap<String, ArrayList<LongPair>> binMap;
+	
 	/** 
 	 * Map associating with contig names with ordered arrays of nonoverlapping ranges
 	 * Each range has attached a list of features that fully contain it. */
@@ -1260,6 +1461,8 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 	/** Whether interleaved was explicitly set. */
 	private boolean setInterleaved=false;
 	
+	private int binlen=0;
+	
 	/*--------------------------------------------------------------*/
 
 	/** Number of reads processed */
@@ -1327,6 +1530,7 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 	
 	private long plusAlignedReads=0;
 	private long minusAlignedReads=0;
+	private long allAlignedReads=0;
 	private long samLinesProcessed=0;
 	private long samLinesAlignedToFeatures=0;
 	
@@ -1338,9 +1542,16 @@ public class CheckStrand2 implements Accumulator<CheckStrand2.ProcessThread> {
 	private int passes=2;
 	private boolean streamGenome=false;
 	private ArrayList<Read> genomeSequenceCache=null;
+
+	ConcurrentHashMap<String, LongPair> geneMap=new ConcurrentHashMap<String, LongPair>();
 	
 	/** Whether the input reference is a transcriptome or genome */
 	private boolean transcriptome=false;
+	/** True for unknown sense contigs from RNA-seq data */
+	private boolean rnaContigs=false;
+	
+	private boolean normalize=false;
+	private int minReads=2;//Don't calculate strandedness from fewer reads
 	
 	/*--------------------------------------------------------------*/
 	/*----------------         Final Fields         ----------------*/
