@@ -5,7 +5,6 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.PrintStream;
 import java.util.Arrays;
-import java.util.Locale;
 
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
@@ -146,8 +145,8 @@ public class CountGC {
 			if(bytes<1){bytes=LIMSUM;}
 			double mbps1=bytes*1000d/t.elapsed;
 			double mbps2=sum*1000d/t.elapsed;
-			outstream.println(String.format(Locale.ROOT, "Raw Speed:         \t%.2f MBytes/s",mbps1));
-			outstream.println(String.format(Locale.ROOT, "Uncompressed Speed:\t%.2f MBytes/s",mbps2));
+			outstream.println(Tools.format("Raw Speed:         \t%.2f MBytes/s",mbps1));
+			outstream.println(Tools.format("Uncompressed Speed:\t%.2f MBytes/s",mbps2));
 		}else{
 			outstream.println(toString2(new StringBuilder("Overall"), counts));
 			outstream.println("Time: \t"+t);
@@ -155,8 +154,8 @@ public class CountGC {
 			if(bytes<1){bytes=LIMSUM;}
 			double mbps=bytes*1000d/t.elapsed;
 			double mbpps=shared.Vector.sum(counts)*1000d/t.elapsed;
-			outstream.println(String.format(Locale.ROOT, "Speed:\t%.2f MBytes/s",mbps));
-			outstream.println(String.format(Locale.ROOT, "      \t%.2f MBases/s",mbpps));
+			outstream.println(Tools.format("Speed:\t%.2f MBytes/s",mbps));
+			outstream.println(Tools.format("      \t%.2f MBases/s",mbpps));
 		}
 		
 		//Close the print stream if it was redirected
@@ -345,12 +344,12 @@ public class CountGC {
 		final float inv1=1f/Tools.max(1, sum1);
 		final float inv2=1f/Tools.max(1, sum2);
 		if(FORMAT==1){
-			return sb.append(String.format(Locale.ROOT, "\t%d\t%.5f\t%.5f\t%.5f\t%.5f\t%.5f\t%.5f\n",
+			return sb.append(Tools.format("\t%d\t%.5f\t%.5f\t%.5f\t%.5f\t%.5f\t%.5f\n",
 					sum2, counts[0]*inv1, counts[1]*inv1, counts[2]*inv1, counts[3]*inv1, counts[4]*inv2, (counts[1]+counts[2])*inv1)).toString();
 		}else if(FORMAT==2){
-			return sb.append(String.format(Locale.ROOT, "\t%.5f\n", (counts[1]+counts[2])*inv1)).toString();
+			return sb.append(Tools.format("\t%.5f\n", (counts[1]+counts[2])*inv1)).toString();
 		}else if(FORMAT==4){
-			return sb.append(String.format(Locale.ROOT, "\t%d\t%.5f\n", sum2, (counts[1]+counts[2])*inv1)).toString();
+			return sb.append(Tools.format("\t%d\t%.5f\n", sum2, (counts[1]+counts[2])*inv1)).toString();
 		}else{
 			throw new RuntimeException("Unknown format.");
 		}
@@ -362,12 +361,12 @@ public class CountGC {
 		final float inv1=1f/Tools.max(1, sum1);
 		final float inv2=1f/Tools.max(1, sum2);
 		if(FORMAT==1){
-			return sb.append(String.format(Locale.ROOT, "\t%d\t%.5f\t%.5f\t%.5f\t%.5f\t%.5f\t%.5f\n",
+			return sb.append(Tools.format("\t%d\t%.5f\t%.5f\t%.5f\t%.5f\t%.5f\t%.5f\n",
 					sum2, counts[0]*inv1, counts[1]*inv1, counts[2]*inv1, counts[3]*inv1, counts[4]*inv2, (counts[1]+counts[2])*inv1)).toString();
 		}else if(FORMAT==2){
-			return sb.append(String.format(Locale.ROOT, "\t%.5f\n", (counts[1]+counts[2])*inv1)).toString();
+			return sb.append(Tools.format("\t%.5f\n", (counts[1]+counts[2])*inv1)).toString();
 		}else if(FORMAT==4){
-			return sb.append(String.format(Locale.ROOT, "\t%d\t%.5f\n", sum2, (counts[1]+counts[2])*inv1)).toString();
+			return sb.append(Tools.format("\t%d\t%.5f\n", sum2, (counts[1]+counts[2])*inv1)).toString();
 		}else{
 			throw new RuntimeException("Unknown format.");
 		}
