@@ -6,7 +6,6 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.BitSet;
 import java.util.HashMap;
-import java.util.Locale;
 
 import align2.QualityTools;
 import dna.ChromosomeArray;
@@ -145,6 +144,10 @@ public class CoveragePileup {
 				orffasta=b;
 			}else if(a.equals("basecov") || a.equals("outcov")){
 				basecov=b;
+			}else if(a.equals("ranges") || a.equals("rangecov")){
+				rangecov=b;
+//			}else if(a.equals("mincov") || a.equals("mindepth")){
+//				mincov=Integer.parseInt(b);
 			}else if(a.equals("bincov") || a.equals("outbinned")){
 				bincov=b;
 			}else if(a.equals("normcov") || a.equals("outnormalized")){
@@ -274,7 +277,7 @@ public class CoveragePileup {
 			USE_BITSETS=(vectorMode==BITSET_MODE);
 			USE_COVERAGE_ARRAYS=(vectorMode==ARRAY_MODE);
 		}else{
-			if(histogram==null && basecov==null && bincov==null && normcov==null &&
+			if(histogram==null && basecov==null && bincov==null && normcov==null && rangecov==null &&
 					normcovOverall==null && outorf==null && !calcCovStdev){//No need for coverage array!
 				USE_COVERAGE_ARRAYS=false;
 				if(TWOCOLUMN){//No need for bitset, either!
@@ -319,9 +322,9 @@ public class CoveragePileup {
 			throw new RuntimeException("\nCan't read some input files.\n");  
 		}
 		
-		if(!Tools.testOutputFiles(overwrite, append, false, basecov, bincov, normcov, normcovOverall, histogram, covstats, outrpkm)){
+		if(!Tools.testOutputFiles(overwrite, append, false, basecov, rangecov, bincov, normcov, normcovOverall, histogram, covstats, outrpkm)){
 			throw new RuntimeException("\n\noverwrite="+overwrite+"; Can't write to output files "+
-					basecov+", "+bincov+", "+normcov+", "+normcovOverall+", "+histogram+", "+covstats+", "+outrpkm+"\n");
+					basecov+", "+rangecov+", "+bincov+", "+normcov+", "+normcovOverall+", "+histogram+", "+covstats+", "+outrpkm+"\n");
 		}
 	}
 
@@ -766,21 +769,21 @@ public class CoveragePileup {
 				}
 				
 //				{
-//					tsw.print(String.format(Locale.ROOT, "%s\t%d\t", args));
+//					tsw.print(Tools.format("%s\t%d\t", args));
 //				}
 				
 				sb.append(orf.name).append('\t');
 				sb.append(orf.length()).append('\t');
 				sb.append(orf.baseDepth).append('\t');
-				sb.append(String.format(Locale.ROOT, "%.4f", orf.avgCoverage())).append('\t');
+				sb.append(Tools.format("%.4f", orf.avgCoverage())).append('\t');
 				sb.append(orf.avgCoverage()/mappedNonClippedBases);
 
 				sb.append('\t');
 				sb.append(orf.minDepth).append('\t');
 				sb.append(orf.maxDepth).append('\t');
 				sb.append(orf.medianDepth).append('\t');
-				sb.append(String.format(Locale.ROOT, "%.4f",orf.stdevDepth)).append('\t');
-				sb.append(String.format(Locale.ROOT, "%.4f",orf.fractionCovered()));
+				sb.append(Tools.format("%.4f",orf.stdevDepth)).append('\t');
+				sb.append(Tools.format("%.4f",orf.fractionCovered()));
 
 				sb.append('\n');
 				tsw.print(sb.toString());
@@ -1152,8 +1155,9 @@ public class CoveragePileup {
 			refBases2+=sc.length;
 			if(sc.length>=k){refKmers+=sc.length-k+1;}
 		}
-		
+
 		String basecov1=(basecov==null ? null : (STRANDED ? basecov.replaceFirst("#", "1") : basecov));
+		String rangecov1=(rangecov==null ? null : (STRANDED ? rangecov.replaceFirst("#", "1") : rangecov));
 		String bincov1=(bincov==null ? null : (STRANDED ? bincov.replaceFirst("#", "1") : bincov));
 		String normcov1=(normcov==null ? null : (STRANDED ? normcov.replaceFirst("#", "1") : normcov));
 		String normcovOverall1=(normcovOverall==null ? null : (STRANDED ? normcovOverall.replaceFirst("#", "1") : normcovOverall));
@@ -1161,6 +1165,7 @@ public class CoveragePileup {
 		String stats1=(covstats==null ? null : (STRANDED ? covstats.replaceFirst("#", "1") : covstats));
 
 		String basecov2=(basecov==null || !STRANDED ? null : basecov.replaceFirst("#", "2"));
+		String rangecov2=(rangecov==null || !STRANDED ? null : rangecov.replaceFirst("#", "2"));
 		String bincov2=(bincov==null || !STRANDED ? null : bincov.replaceFirst("#", "2"));
 		String normcov2=(normcov==null || !STRANDED ? null : normcov.replaceFirst("#", "2"));
 		String normcovOverall2=(normcovOverall==null ? null : (STRANDED ? normcovOverall.replaceFirst("#", "2") : normcovOverall));
@@ -1181,6 +1186,10 @@ public class CoveragePileup {
 			writeCoveragePerBaseBinned(bincov1, list, binsize, 0, minscaf);
 			writeCoveragePerBaseBinned(bincov2, list, binsize, 1, minscaf);
 		}
+		if(rangecov!=null) {
+			writeCoverageRanges(rangecov1, list, 0, minscaf);
+			writeCoverageRanges(rangecov2, list, 1, minscaf);
+		}
 		if(normcov!=null){
 			writeCoveragePerBaseNormalized(normcov1, list, binsize, 0, minscaf);
 			writeCoveragePerBaseNormalized(normcov2, list, binsize, 1, minscaf);
@@ -1224,23 +1233,23 @@ public class CoveragePileup {
 				String kcorrectS="Percent correct "+k+"-mers:";
 				while(kcovS.length()<26){kcovS=kcovS+" ";}
 				while(kcovS.length()<26){kcorrectS=kcorrectS+" ";}
-				outstream.println(String.format(Locale.ROOT, "\n"+kcovS+"           \t%.3f", mappedKmers*1.0/refKmers));
-				outstream.println(String.format(Locale.ROOT, kcorrectS+"           \t%.3f", 100*correctKmers/kmersProcessed));
+				outstream.println(Tools.format("\n"+kcovS+"           \t%.3f", mappedKmers*1.0/refKmers));
+				outstream.println(Tools.format(kcorrectS+"           \t%.3f", 100*correctKmers/kmersProcessed));
 				//			outstream.println(kmersProcessed+", "+correctKmers);
 			}
 
-			outstream.println(String.format(Locale.ROOT, "\nPercent mapped:                      \t%.3f", mappedReads*100f/readsProcessed));
-			outstream.println(String.format(Locale.ROOT, "Percent proper pairs:                \t%.3f", properPairs*100f/readsProcessed));
+			outstream.println(Tools.format("\nPercent mapped:                      \t%.3f", mappedReads*100f/readsProcessed));
+			outstream.println(Tools.format("Percent proper pairs:                \t%.3f", properPairs*100f/readsProcessed));
 //			outstream.println(depthCovered);
-			outstream.println(String.format(Locale.ROOT, "Average coverage:                    \t%.3f", depthCovered2));
-			outstream.println(String.format(Locale.ROOT, "Average coverage with deletions:     \t%.3f", depthCovered3));
+			outstream.println(Tools.format("Average coverage:                    \t%.3f", depthCovered2));
+			outstream.println(Tools.format("Average coverage with deletions:     \t%.3f", depthCovered3));
 			if(USE_COVERAGE_ARRAYS && calcCovStdev){
 				double[] stdev=standardDeviation(list, 0, minscaf);
-				outstream.println(String.format(Locale.ROOT, "Standard deviation:                    \t%.3f", stdev[1]));
+				outstream.println(Tools.format("Standard deviation:                    \t%.3f", stdev[1]));
 			}
-			outstream.println(String.format(Locale.ROOT, "Percent scaffolds with any coverage: \t%.2f", pctScaffoldsWithCoverage));
+			outstream.println(Tools.format("Percent scaffolds with any coverage: \t%.2f", pctScaffoldsWithCoverage));
 			if(USE_COVERAGE_ARRAYS || USE_BITSETS){
-				outstream.println(String.format(Locale.ROOT, "Percent of reference bases covered:  \t%.2f", pctCovered));
+				outstream.println(Tools.format("Percent of reference bases covered:  \t%.2f", pctCovered));
 			}
 		}else{
 			outstream.println("reads="+readsProcessed);
@@ -1249,16 +1258,16 @@ public class CoveragePileup {
 			outstream.println("mappedBasesWithDels="+mappedBasesWithDels);
 			outstream.println("refScaffolds="+totalScaffolds);
 			outstream.println("refBases="+refBases);
-			outstream.println(String.format(Locale.ROOT, "percentMapped=%.3f", mappedReads*100f/readsProcessed));
-			outstream.println(String.format(Locale.ROOT, "percentPaired=%.3f", properPairs*100f/readsProcessed));
-			outstream.println(String.format(Locale.ROOT, "averageCoverage=%.3f", depthCovered2));
+			outstream.println(Tools.format("percentMapped=%.3f", mappedReads*100f/readsProcessed));
+			outstream.println(Tools.format("percentPaired=%.3f", properPairs*100f/readsProcessed));
+			outstream.println(Tools.format("averageCoverage=%.3f", depthCovered2));
 			if(USE_COVERAGE_ARRAYS && calcCovStdev){
 				double[] stdev=standardDeviation(list, 0, minscaf);
-				outstream.println(String.format(Locale.ROOT, "standardDeviation=%.3f", stdev[1]));
+				outstream.println(Tools.format("standardDeviation=%.3f", stdev[1]));
 			}
-			outstream.println(String.format(Locale.ROOT, "percentCoveredScaffolds=%.2f", pctScaffoldsWithCoverage));
+			outstream.println(Tools.format("percentCoveredScaffolds=%.2f", pctScaffoldsWithCoverage));
 			if(USE_COVERAGE_ARRAYS || USE_BITSETS){
-				outstream.println(String.format(Locale.ROOT, "percentCoveredBases=%.2f", pctCovered));
+				outstream.println(Tools.format("percentCoveredBases=%.2f", pctCovered));
 			}
 		}
 	}
@@ -1367,7 +1376,7 @@ public class CoveragePileup {
 					tsw.println(pound+"ID\tAvg_fold\tLength\tRef_GC\tCovered_percent\tCovered_bases\tPlus_reads\tMinus_reads"+
 							(COUNT_GC ? "\tRead_GC" : "")+
 							(USE_COVERAGE_ARRAYS ? ("\tMedian_fold\tStd_Dev") : "")+
-							(USE_WINDOW ? "\tUnder_"+String.format(Locale.ROOT, "%.0f",LOW_COV_DEPTH)+"/"+LOW_COV_WINDOW : ""));
+							(USE_WINDOW ? "\tUnder_"+Tools.format("%.0f",LOW_COV_DEPTH)+"/"+LOW_COV_WINDOW : ""));
 				}
 			}
 			//Maximally:
@@ -1428,7 +1437,7 @@ public class CoveragePileup {
 			//			pw.print(scaf.name);
 			if(tsw!=null && (sum>0 || !NONZERO_ONLY) && scaf.length>=minscaf){
 				if(TWOCOLUMN){
-					tsw.print(String.format(Locale.ROOT, "%s\t%.4f\n", scaf.name, sum/(double)scaf.length));
+					tsw.print(Tools.format("%s\t%.4f\n", scaf.name, sum/(double)scaf.length));
 				}else if(COUNT_GC){
 					long[] bc=scaf.basecount;
 					double gc=(bc[1]+bc[2])*1d/Data.max(1, bc[0]+bc[1]+bc[2]+bc[3]);
@@ -1439,32 +1448,32 @@ public class CoveragePileup {
 							//"\tRead_GC\tMedian_fold\tStd_Dev\tUnder_X\n"
 							//\t%.4f\t%d\t%.2f\t%d\n
 							
-							tsw.print(String.format(Locale.ROOT, "%s\t%.4f\t%d\t%.4f\t%.4f\t%d\t%d\t%d\t%.4f\t%d\t%.2f\t%d\n", scaf.name, sum/(double)scaf.length, scaf.length,
+							tsw.print(Tools.format("%s\t%.4f\t%d\t%.4f\t%.4f\t%d\t%d\t%d\t%.4f\t%d\t%.2f\t%d\n", scaf.name, sum/(double)scaf.length, scaf.length,
 									scaf.gc, covered*100d/scaf.length, covered, (scaf.readhits-scaf.readhitsMinus), scaf.readhitsMinus,
 									gc, median, stdev, underWindowAverage));
 						}else{
-							tsw.print(String.format(Locale.ROOT, "%s\t%.4f\t%d\t%.4f\t%.4f\t%d\t%d\t%d\t%.4f\t%d\t%.2f\n", scaf.name, sum/(double)scaf.length, scaf.length,
+							tsw.print(Tools.format("%s\t%.4f\t%d\t%.4f\t%.4f\t%d\t%d\t%d\t%.4f\t%d\t%.2f\n", scaf.name, sum/(double)scaf.length, scaf.length,
 									scaf.gc, covered*100d/scaf.length, covered, (scaf.readhits-scaf.readhitsMinus), scaf.readhitsMinus,
 									gc, median, stdev));
 						}
 					}else{
-						tsw.print(String.format(Locale.ROOT, "%s\t%.4f\t%d\t%.4f\t%.4f\t%d\t%d\t%d\t%.4f\n", scaf.name, sum/(double)scaf.length, scaf.length,
+						tsw.print(Tools.format("%s\t%.4f\t%d\t%.4f\t%.4f\t%d\t%d\t%d\t%.4f\n", scaf.name, sum/(double)scaf.length, scaf.length,
 								scaf.gc, covered*100d/scaf.length, covered, (scaf.readhits-scaf.readhitsMinus), scaf.readhitsMinus,
 								gc));
 					}
 				}else{
 					if(USE_COVERAGE_ARRAYS){
 						if(USE_WINDOW){
-							tsw.print(String.format(Locale.ROOT, "%s\t%.4f\t%d\t%.4f\t%.4f\t%d\t%d\t%d\t%d\t%.2f\t%d\n", scaf.name, sum/(double)scaf.length, scaf.length,
+							tsw.print(Tools.format("%s\t%.4f\t%d\t%.4f\t%.4f\t%d\t%d\t%d\t%d\t%.2f\t%d\n", scaf.name, sum/(double)scaf.length, scaf.length,
 									scaf.gc, covered*100d/scaf.length, covered, (scaf.readhits-scaf.readhitsMinus), scaf.readhitsMinus,
 									median, stdev, underWindowAverage));
 						}else{
-							tsw.print(String.format(Locale.ROOT, "%s\t%.4f\t%d\t%.4f\t%.4f\t%d\t%d\t%d\t%d\t%.2f\n", scaf.name, sum/(double)scaf.length, scaf.length,
+							tsw.print(Tools.format("%s\t%.4f\t%d\t%.4f\t%.4f\t%d\t%d\t%d\t%d\t%.2f\n", scaf.name, sum/(double)scaf.length, scaf.length,
 									scaf.gc, covered*100d/scaf.length, covered, (scaf.readhits-scaf.readhitsMinus), scaf.readhitsMinus,
 									median, stdev));
 						}
 					}else{
-						tsw.print(String.format(Locale.ROOT, "%s\t%.4f\t%d\t%.4f\t%.4f\t%d\t%d\t%d\n", scaf.name, sum/(double)scaf.length, scaf.length,
+						tsw.print(Tools.format("%s\t%.4f\t%d\t%.4f\t%.4f\t%d\t%d\t%d\n", scaf.name, sum/(double)scaf.length, scaf.length,
 								scaf.gc, covered*100d/scaf.length, covered, (scaf.readhits-scaf.readhitsMinus), scaf.readhitsMinus));
 					}
 				}
@@ -1597,6 +1606,61 @@ public class CoveragePileup {
 //		assert(false);
 	}
 	
+	/**
+	 * Prints coverage in this format, skipping zero-coverage positions:
+	 * #scafname
+	 * position TAB coverage
+	 * position TAB coverage
+	 * @param fname Output filename
+	 * @param list List of reference scaffolds
+	 * @param strand Only use coverage from reads mapped to this strand (0=plus, 1=minus)
+	 */
+	public void writeCoverageRanges(String fname, ArrayList<Scaffold> list, int strand, int minscaf){
+		if(fname==null || (!STRANDED && strand>0)){return;}
+		
+		if(verbose){outstream.println("Starting tsw "+fname);}
+		ByteStreamWriter tsw=new ByteStreamWriter(fname, overwrite, false, true);
+		tsw.start();
+		if(verbose){outstream.println("Started tsw "+fname);}
+//		tsw.print(pound+"RefName\tPos\tCoverage\n");
+		
+		for(Scaffold scaf : list){
+			tsw.print('#');
+			tsw.println(scaf.name);
+			CoverageArray ca=(CoverageArray)(STRANDED && strand==1 ? scaf.obj1 : scaf.obj0);
+			if(scaf.length>=minscaf){
+				int start=-1;
+				int prev=-1;
+				long sum=0;
+				
+				for(int i=0; i<scaf.length; i++){
+					int x=(ca==null ? 0 : ca.get(i));
+					if(x>=minDepthToBeCovered){
+						if(prev<minDepthToBeCovered) {//open range
+							start=i;
+						}
+						sum+=x;
+					}else if(prev>=minDepthToBeCovered){//close range
+						float len=i-start+1;
+						tsw.print(start).print('-').print(i-1).tab().println(sum/len, 2);
+						sum=0;
+					}
+					prev=x;
+				}
+				if(prev>=minDepthToBeCovered){//close final range
+					float len=scaf.length-start;
+					tsw.print(start).print('-').print(scaf.length-1).tab().println(sum/len, 2);
+					sum=0;
+				}
+			}
+		}
+
+		if(verbose){outstream.println("Closing tsw "+fname);}
+		tsw.poisonAndWait();
+		if(verbose){outstream.println("Closed tsw "+fname);}
+//		assert(false);
+	}
+	
 	/**
 	 * Note.  As written, this will truncate all trailing bases of each scaffold's length modulo binsize.
 	 * For example, with binsize 1000, the last 500 bases of a 1500 base scaffold will be ignored.
@@ -1614,8 +1678,8 @@ public class CoveragePileup {
 			if(calcCovStdev){
 				double[] stdev=standardDeviation(list, strand, minscaf);
 				if(stdev!=null){
-					tsw.print(pound+"Mean\t"+String.format(Locale.ROOT, "%.3f", stdev[0])+"\n");
-					tsw.print(pound+"STDev\t"+String.format(Locale.ROOT, "%.3f", stdev[1])+"\n");
+					tsw.print(pound+"Mean\t"+Tools.format("%.3f", stdev[0])+"\n");
+					tsw.print(pound+"STDev\t"+Tools.format("%.3f", stdev[1])+"\n");
 				}
 			}
 			tsw.print(pound+"RefName\tCov\tPos\tRunningPos\n");
@@ -1633,7 +1697,7 @@ public class CoveragePileup {
 					sum+=x;
 					if(i>=nextPos){
 						if(sum>0 || !NONZERO_ONLY){
-							tsw.print(String.format(Locale.ROOT, "%s\t%.2f\t%d\t%d\n", scaf.name, sum*invbin, (i+1), running));
+							tsw.print(Tools.format("%s\t%.2f\t%d\t%d\n", scaf.name, sum*invbin, (i+1), running));
 						}
 						lastPos=i;
 						running+=binsize;
@@ -1663,8 +1727,8 @@ public class CoveragePileup {
 			if(calcCovStdev){
 				double[] stdev=standardDeviationBinned(list, binsize, strand, minscaf);
 				if(stdev!=null){
-					tsw.print(pound+"Mean\t"+String.format(Locale.ROOT, "%.3f", stdev[0])+"\n");
-					tsw.print(pound+"STDev\t"+String.format(Locale.ROOT, "%.3f", stdev[1])+"\n");
+					tsw.print(pound+"Mean\t"+Tools.format("%.3f", stdev[0])+"\n");
+					tsw.print(pound+"STDev\t"+Tools.format("%.3f", stdev[1])+"\n");
 				}
 			}
 			tsw.print(pound+"RefName\tCov\tPos\tRunningPos\n");
@@ -1683,7 +1747,7 @@ public class CoveragePileup {
 					int bin=(i-lastPos);
 					if(scaf.length>=minscaf){
 						if(sum>0 || !NONZERO_ONLY){
-							tsw.print(String.format(Locale.ROOT, "%s\t%.2f\t%d\t%d\n", scaf.name, sum/(float)bin, (i+1), running));
+							tsw.print(Tools.format("%s\t%.2f\t%d\t%d\n", scaf.name, sum/(float)bin, (i+1), running));
 						}
 					}
 					running+=bin;
@@ -1990,7 +2054,7 @@ public class CoveragePileup {
 		for(int bin=1; bin<normalized.length; bin++){
 //			assert((absolute[bin]*invScafs)!=Double.NaN && (normalized[bin]*invScafs)!=Double.NaN) : invScafs+", "+absolute[bin]+", "+normalized[bin];
 //			assert(false) : invScafs+", "+absolute[bin]+", "+normalized[bin]+", "+(absolute[bin]*invScafs)+", "+(normalized[bin]*invScafs);
-			tsw.print(String.format(Locale.ROOT, "%s\t%d\t%.5f\t%.5f\n", "all", bin, absolute[bin]*invScafs, normalized[bin]*normMult));
+			tsw.print(Tools.format("%s\t%d\t%.5f\t%.5f\n", "all", bin, absolute[bin]*invScafs, normalized[bin]*normMult));
 		}
 		
 		tsw.poisonAndWait();
@@ -2017,9 +2081,9 @@ public class CoveragePileup {
 		
 		/* Print header */
 		tsw.print("#File\t"+(in1==null ? "" : in1)+(in2==null ? "" : "\t"+in2)+"\n");
-		tsw.print(String.format(Locale.ROOT, "#Reads\t%d\n",readsIn));
-		tsw.print(String.format(Locale.ROOT, "#Mapped\t%d\n",mappedReads));
-		tsw.print(String.format(Locale.ROOT, "#RefSequences\t%d\n",list.size()));
+		tsw.print(Tools.format("#Reads\t%d\n",readsIn));
+		tsw.print(Tools.format("#Mapped\t%d\n",mappedReads));
+		tsw.print(Tools.format("#RefSequences\t%d\n",list.size()));
 		tsw.print("#Name\tLength\tBases\tCoverage\tReads\tRPKM\tFrags\tFPKM\n");
 		
 		final float readMult=1000000000f/Tools.max(1, mappedReads);
@@ -2036,7 +2100,7 @@ public class CoveragePileup {
 			final double readMult2=readMult*invlen;
 			final double fragMult2=fragMult*invlen;
 			if(reads>0 || !printNonZeroOnly){
-				tsw.print(String.format(Locale.ROOT, "%s\t%d\t%d\t%.4f\t%d\t%.4f\t%d\t%.4f\n",s,len,bases,bases*invlen,reads,reads*readMult2,frags,frags*fragMult2));
+				tsw.print(Tools.format("%s\t%d\t%d\t%.4f\t%d\t%.4f\t%d\t%.4f\n",s,len,bases,bases*invlen,reads,reads*readMult2,frags,frags*fragMult2));
 			}
 		}
 		tsw.poisonAndWait();
@@ -2091,6 +2155,8 @@ public class CoveragePileup {
 	/** rpkm/fpkm output, similar to Seal */
 	public String outrpkm=null;
 	
+	public String rangecov=null;
+	
 	/** Typically indicates that a header line was encountered in an unexpected place, e.g. with concatenated sam files. */
 	private boolean error=false;
 	
@@ -2150,7 +2216,7 @@ public class CoveragePileup {
 	
 
 	/** Permission to overwrite existing files */
-	public static boolean overwrite=false;
+	public static boolean overwrite=true;
 	/** Permission to append to existing files */
 	public static boolean append=false;
 	/** Print verbose log messages */
