@@ -300,15 +300,6 @@ public class CoveragePileupMT implements Accumulator<CoveragePileupMT.LoadThread
 			throw new RuntimeException("\nCan't read some input files.\n");  
 		}
 		if(inputFiles.isEmpty()) {throw new RuntimeException("\nAt least one input file is required.\n");}
-		stdin=FileFormat.isStdio(inputFiles.get(0));
-		if(stdin) {
-			assert(inputFiles.size()==1) : "stdin must be the only input: "+inputFiles.get(1);
-//			throw new RuntimeException(
-//					"\n"+getClass().getSimpleName()+" does not support stdin;"
-//							+ " please specify all input files on the command line "
-//							+ " (wildcard is allowed, e.g. 'pileup.sh *.sam'),"
-//							+ " or use pileup_old.sh for streamed input.\n");
-		}
 		
 		if(!Tools.testInputFiles(false, true, reference)){
 			throw new RuntimeException("\nCan't read some input files.\n");  
@@ -426,13 +417,11 @@ public class CoveragePileupMT implements Accumulator<CoveragePileupMT.LoadThread
 			if(Data.SAMTOOLS()){ReadWrite.USE_SAMBAMBA=false;} //Disable because it takes forever to read the header
 		}
 		
-		if(!stdin) {
-			ByteFile tf=ByteFile.makeByteFile(inputFiles.get(0), false);
-			
-			processHeader(tf);
-			errorState=tf.close()|errorState;
-			if(verboseTime) {t.stopAndStart("Process Header:");}
-		}
+		ByteFile tf=ByteFile.makeByteFile(inputFiles.get(0), false);
+
+		processHeader(tf);
+		errorState=tf.close()|errorState;
+		if(verboseTime) {t.stopAndStart("Process Header:");}
 		
 		ReadWrite.USE_SAMBAMBA=true;
 		
@@ -569,7 +558,7 @@ public class CoveragePileupMT implements Accumulator<CoveragePileupMT.LoadThread
 		boolean addLen=false;
 		for(byte[] s=bf.nextLine(); s!=null; s=bf.nextLine()){
 			if(s.length>0 && s[0]=='>'){
-				if(scaf!=null){
+				if(scaf!=null){//Then evict the old scaf and start a new one
 					if(scaf.length>0 && scaf.length!=len){
 						outstream.println("ERROR: Scaffold "+scaf.name+" has contradictory lengths of "+scaf.length+" and "+len+"\n"
 								+ "This probably indicates a corrupt or incorrect reference.");
@@ -591,20 +580,17 @@ public class CoveragePileupMT implements Accumulator<CoveragePileupMT.LoadThread
 				}
 				
 				String name=new String(s, 1, s.length-1);
-				scaf=table.get(name);
-				if(ADD_FROM_REF && scaf==null){//TODO: This needs to calculate the scaffold length...
+				String shortName=Tools.trimToWhitespace(name);
+				
+				scaf=table.get(shortName);
+				if(ADD_FROM_REF && scaf==null){
 					scaf=new Scaffold(name, 0);
-					assert(false) : "SAM header did not include "+name;
-//					if(prealloc && USE_COVERAGE_ARRAYS) {
-//						scaf.obj1=makeCA(scaf.length);
-//						if(STRANDED){scaf.obj2=makeCA(scaf.length);}
-//					}
 					if(!warned){
 						outstream.println("Warning - SAM header did not include "+name+"\nAbsent scaffolds will be added; further warnings will be suppressed.");
 						warned=true;
 					}
 					if(COUNT_GC){scaf.basecount=KillSwitch.allocLong1D(8);}
-					table.put(name, scaf);
+					table.put(shortName, scaf);
 					list.add(scaf);
 					addLen=true;
 				}
@@ -1444,7 +1430,7 @@ public class CoveragePileupMT implements Accumulator<CoveragePileupMT.LoadThread
 		}
 		
 		private void processViaStreamer(String fname){
-			final boolean processHeader=(stdin && true);
+			final boolean processHeader=false;
 //			assert(false) : processHeader+", "+fname;//Should be 
 			SamLineStreamer ss=new SamLineStreamer(fname, streamerThreads, processHeader, maxReads);
 			ss.start();
@@ -1767,9 +1753,7 @@ public class CoveragePileupMT implements Accumulator<CoveragePileupMT.LoadThread
 	/*--------------------------------------------------------------*/
 	/*----------------            Fields            ----------------*/
 	/*--------------------------------------------------------------*/
-
-
-	private final boolean stdin;
+	
 	private boolean atomic=false;
 	private boolean prealloc=false;
 	private Class<? extends CoverageArray> caType;
