@@ -61,7 +61,7 @@ public class DecontaminateByNormalization {
 		
 //		Shared.READ_BUFFER_NUM_BUFFERS=Shared.READ_BUFFER_NUM_BUFFERS;
 		ReadWrite.USE_PIGZ=ReadWrite.USE_UNPIGZ=true;
-		ReadWrite.MAX_ZIP_THREADS=Shared.threads();
+		ReadWrite.setZipThreads(Shared.threads());
 		
 		CoveragePileup.USE_WINDOW=true;
 
@@ -406,7 +406,7 @@ public class DecontaminateByNormalization {
 		String[] args=argList.toArray(new String[0]);
 		
 		{//Run Mux
-			int oldZT=ReadWrite.MAX_ZIP_THREADS;
+			int oldZT=ReadWrite.MAX_ZIP_THREADS();
 			boolean oldUP=ReadWrite.USE_PIGZ;
 			boolean oldUU=ReadWrite.USE_UNPIGZ;
 			try {
@@ -416,7 +416,7 @@ public class DecontaminateByNormalization {
 				log("failed", true);
 				System.exit(1);
 			}
-			ReadWrite.MAX_ZIP_THREADS=oldZT;
+			ReadWrite.setZipThreads(oldZT);
 			ReadWrite.USE_PIGZ=oldUP;
 			ReadWrite.USE_UNPIGZ=oldUU;
 		}
@@ -451,7 +451,7 @@ public class DecontaminateByNormalization {
 		String[] args=argList.toArray(new String[0]);
 		
 		{//Run Mux
-			int oldZT=ReadWrite.MAX_ZIP_THREADS;
+			int oldZT=ReadWrite.MAX_ZIP_THREADS();
 			boolean oldUP=ReadWrite.USE_PIGZ;
 			boolean oldUU=ReadWrite.USE_UNPIGZ;
 			try {
@@ -461,7 +461,7 @@ public class DecontaminateByNormalization {
 				log("failed", true);
 				System.exit(1);
 			}
-			ReadWrite.MAX_ZIP_THREADS=oldZT;
+			ReadWrite.setZipThreads(oldZT);
 			ReadWrite.USE_PIGZ=oldUP;
 			ReadWrite.USE_UNPIGZ=oldUU;
 		}
@@ -536,10 +536,10 @@ public class DecontaminateByNormalization {
 		String[] args=argList.toArray(new String[0]);
 		
 		{//Run Demux
-			int oldZT=ReadWrite.MAX_ZIP_THREADS;
+			int oldZT=ReadWrite.MAX_ZIP_THREADS();
 			boolean oldUP=ReadWrite.USE_PIGZ;
 			boolean oldUU=ReadWrite.USE_UNPIGZ;
-			ReadWrite.MAX_ZIP_THREADS=Tools.mid(ReadWrite.MAX_ZIP_THREADS, 2, 4);
+			ReadWrite.setZipThreads(Tools.mid(ReadWrite.MAX_ZIP_THREADS(), 2, 4));
 			try {
 				DemuxByName.main(args);
 			} catch (Exception e) {
@@ -547,7 +547,7 @@ public class DecontaminateByNormalization {
 				log("failed", true);
 				System.exit(1);
 			}
-			ReadWrite.MAX_ZIP_THREADS=oldZT;
+			ReadWrite.setZipThreads(oldZT);
 			ReadWrite.USE_PIGZ=oldUP;
 			ReadWrite.USE_UNPIGZ=oldUU;
 		}
