@@ -255,8 +255,7 @@ public class DemuxByName {
 		ffin2=FileFormat.testInput(in2, FileFormat.FASTQ, extin, true, true);
 		
 		if(ffin1!=null && out1!=null && ffin1.samOrBam()){
-			String ext=ReadWrite.rawExtension(out1);
-			useSharedHeader=FileFormat.isSamOrBam(ext);
+			useSharedHeader=FileFormat.isSamOrBamFile(out1);
 		}
 		
 		if(perheader){
