@@ -166,8 +166,7 @@ public class DemuxByName2 {
 		
 		//If the input and output are in sam/bam format, print the sam header
 		if(ffin1!=null && out1!=null && ffin1.samOrBam()){
-			String ext=ReadWrite.rawExtension(out1);
-			useSharedHeader=FileFormat.isSamOrBam(ext);
+			useSharedHeader=FileFormat.isSamOrBamFile(out1);
 		}
 		
 		//Set up data structures
