@@ -120,7 +120,7 @@ public class FakeReads {
 			}else if(a.equals("overlap")){
 				SPLITMODE=true;
 				overlap=Integer.parseInt(b);
-			}else if(in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+			}else if(in1==null && i==0 && Tools.looksLikeInputStream(arg)){
 				in1=arg;
 				if(arg.indexOf('#')>-1 && !new File(arg).exists() && b!=null){//b!=null is implied
 					in1=b.replace("#", "1");
@@ -302,7 +302,7 @@ public class FakeReads {
 	private String extin=null;
 	private String extout=null;
 	
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	private boolean append=false;
 	
 	private long maxReads=-1;
