@@ -2,7 +2,6 @@ package jgi;
 
 import java.io.File;
 import java.util.ArrayList;
-import java.util.Locale;
 import java.util.concurrent.atomic.AtomicIntegerArray;
 import java.util.concurrent.locks.ReadWriteLock;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
@@ -233,8 +232,8 @@ public class FindPrimers implements Accumulator<FindPrimers.ProcessThread> {
 		
 		t.stop();
 		outstream.println("Time:                         \t"+t);
-		outstream.println("Reads Processed:    "+readsProcessed+" \t"+String.format(Locale.ROOT, "%.2fk reads/sec", (readsProcessed/(double)(t.elapsed))*1000000));
-		outstream.println("Average Identity:   "+String.format(Locale.ROOT, "%.3f%%", (identitySum*100/identityCount)));
+		outstream.println("Reads Processed:    "+readsProcessed+" \t"+Tools.format("%.2fk reads/sec", (readsProcessed/(double)(t.elapsed))*1000000));
+		outstream.println("Average Identity:   "+Tools.format("%.3f%%", (identitySum*100/identityCount)));
 		outstream.println("Min Identity:       "+minid);
 	}
 	
