@@ -2,7 +2,6 @@ package jgi;
 
 import java.io.PrintStream;
 import java.util.ArrayList;
-import java.util.Locale;
 
 import assemble.Shaver;
 import assemble.Tadpole;
@@ -331,12 +330,12 @@ public class KmerCountExact {
 		}
 		
 		if(tables.qtrimLeft() || tables.qtrimRight()){
-			outstream.println("QTrimmed:               \t"+tables.readsTrimmed+" reads ("+String.format(Locale.ROOT, "%.2f",tables.readsTrimmed*100.0/tables.readsIn)+"%) \t"+
-					tables.basesTrimmed+" bases ("+String.format(Locale.ROOT, "%.2f",tables.basesTrimmed*100.0/tables.basesIn)+"%)");
+			outstream.println("QTrimmed:               \t"+tables.readsTrimmed+" reads ("+Tools.format("%.2f",tables.readsTrimmed*100.0/tables.readsIn)+"%) \t"+
+					tables.basesTrimmed+" bases ("+Tools.format("%.2f",tables.basesTrimmed*100.0/tables.basesIn)+"%)");
 		}
 		if(tables.minAvgQuality()>0){
-			outstream.println("Low quality discards:   \t"+tables.lowqReads+" reads ("+String.format(Locale.ROOT, "%.2f",tables.lowqReads*100.0/tables.readsIn)+"%) \t"+
-					tables.lowqBases+" bases ("+String.format(Locale.ROOT, "%.2f",tables.lowqBases*100.0/tables.basesIn)+"%)");
+			outstream.println("Low quality discards:   \t"+tables.lowqReads+" reads ("+Tools.format("%.2f",tables.lowqReads*100.0/tables.readsIn)+"%) \t"+
+					tables.lowqBases+" bases ("+Tools.format("%.2f",tables.lowqBases*100.0/tables.basesIn)+"%)");
 		}
 		
 		if(shave || rinse){
@@ -353,9 +352,9 @@ public class KmerCountExact {
 		double actualDepth=Tools.observedToActualCoverage(averageCount);
 		double readDepth=(actualDepth*tables.basesIn)/(tables.kmersIn);
 		
-		outstream.println("Average Kmer Count:         \t"+String.format(Locale.ROOT, "%."+decimals+"f", averageCount));
-		outstream.println("Estimated Kmer Depth:       \t"+String.format(Locale.ROOT, "%."+decimals+"f", actualDepth));
-		outstream.println("Estimated Read Depth:       \t"+String.format(Locale.ROOT, "%."+decimals+"f", readDepth));
+		outstream.println("Average Kmer Count:         \t"+Tools.format("%."+decimals+"f", averageCount));
+		outstream.println("Estimated Kmer Depth:       \t"+Tools.format("%."+decimals+"f", actualDepth));
+		outstream.println("Estimated Read Depth:       \t"+Tools.format("%."+decimals+"f", readDepth));
 		outstream.println();
 		
 		outstream.println("Load Time:                  \t"+t);
@@ -1007,7 +1006,7 @@ public class KmerCountExact {
 	/** Print messages to this stream */
 	private static PrintStream outstream=System.err;
 	/** Permission to overwrite existing files */
-	public static boolean overwrite=false;
+	public static boolean overwrite=true;
 	/** Permission to append to existing files */
 	public static boolean append=false;
 	/** Display progress messages such as memory usage */
