@@ -4,7 +4,6 @@ import java.io.File;
 import java.io.PrintStream;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Locale;
 
 import cardinality.MultiLogLog;
 import fileIO.ByteFile;
@@ -341,9 +340,9 @@ public class KmerCountMulti {
 			String avgs=""+(long)Math.round(useWavg ? wavg : avg);
 			while(avgs.length()<11){avgs=avgs+" ";}
 			if(ways>1 && showStdev){
-				tsw.print(String.format(Locale.ROOT, "%d\t%s\t%.2f%%\n",k,avgs,stdev));
+				tsw.print(Tools.format("%d\t%s\t%.2f%%\n",k,avgs,stdev));
 			}else{
-				tsw.print(String.format(Locale.ROOT, "%d\t%s\n",k,avgs));
+				tsw.print(Tools.format("%d\t%s\n",k,avgs));
 			}
 				
 		}
@@ -513,7 +512,7 @@ public class KmerCountMulti {
 	/** True if an error was encountered */
 	public boolean errorState=false;
 	/** Overwrite existing output files */
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	/** Append to existing output files */
 	private boolean append=false;
 	
