@@ -6,12 +6,11 @@ import java.lang.Thread.State;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
-import java.util.Locale;
 import java.util.concurrent.atomic.AtomicLong;
 
 import bloom.KCountArray;
-import bloom.ReadCounter;
 import bloom.KmerCountAbstract;
+import bloom.ReadCounter;
 import dna.AminoAcid;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
@@ -373,7 +372,7 @@ public class KmerCoverage {
 		outstream.println("Estimated unique kmers:     \t"+estUnique);//+", or "+estUnique+" counting forward kmers only.");
 //		outstream.println("(Includes forward and reverse kmers)");
 		outstream.println();
-		outstream.println("Table creation time:\t\t"+ht);//+"   \t"+String.format(Locale.ROOT, "%.2f", totalBases*1000000.0/(ht.elapsed))+" kb/sec");
+		outstream.println("Table creation time:\t\t"+ht);//+"   \t"+Tools.format("%.2f", totalBases*1000000.0/(ht.elapsed))+" kb/sec");
 		
 		long bases=0;
 		
@@ -387,7 +386,7 @@ public class KmerCoverage {
 		printTopology();
 		
 		t.stop();
-		outstream.println("\nTotal time:      \t\t"+t+"   \t"+String.format(Locale.ROOT, "%.2f", bases*1000000.0/(t.elapsed))+" kb/sec");
+		outstream.println("\nTotal time:      \t\t"+t+"   \t"+Tools.format("%.2f", bases*1000000.0/(t.elapsed))+" kb/sec");
 		
 		//Close the print stream if it was redirected
 		Shared.closeStream(outstream);
@@ -410,11 +409,11 @@ public class KmerCoverage {
 		double dfl=mult*fl;
 		
 		System.err.println("\nDepth Topology\t");
-		System.err.println("Spikes:     \t\t\t"+(dsp<10 ? " " : "")+String.format(Locale.ROOT, "%.3f%%  \t%d",dsp,sp));
-		System.err.println("Peaks:      \t\t\t"+(dpe<10 ? " " : "")+String.format(Locale.ROOT, "%.3f%%  \t%d",dpe,pe));
-		System.err.println("Valleys:    \t\t\t"+(dva<10 ? " " : "")+String.format(Locale.ROOT, "%.3f%%  \t%d",dva,va));
-		System.err.println("Slopes:     \t\t\t"+(dsl<10 ? " " : "")+String.format(Locale.ROOT, "%.3f%%  \t%d",dsl,sl));
-		System.err.println("Flats:      \t\t\t"+(dfl<10 ? " " : "")+String.format(Locale.ROOT, "%.3f%%  \t%d",dfl,fl));
+		System.err.println("Spikes:     \t\t\t"+(dsp<10 ? " " : "")+Tools.format("%.3f%%  \t%d",dsp,sp));
+		System.err.println("Peaks:      \t\t\t"+(dpe<10 ? " " : "")+Tools.format("%.3f%%  \t%d",dpe,pe));
+		System.err.println("Valleys:    \t\t\t"+(dva<10 ? " " : "")+Tools.format("%.3f%%  \t%d",dva,va));
+		System.err.println("Slopes:     \t\t\t"+(dsl<10 ? " " : "")+Tools.format("%.3f%%  \t%d",dsl,sl));
+		System.err.println("Flats:      \t\t\t"+(dfl<10 ? " " : "")+Tools.format("%.3f%%  \t%d",dfl,fl));
 	}
 
 
@@ -591,7 +590,7 @@ public class KmerCoverage {
 		
 //		outstream.println();
 		tdetect.stop();
-		outstream.println("Table read time: \t\t"+tdetect+"   \t"+String.format(Locale.ROOT, "%.2f", totalBases*1000000.0/(tdetect.elapsed))+" kb/sec");
+		outstream.println("Table read time: \t\t"+tdetect+"   \t"+Tools.format("%.2f", totalBases*1000000.0/(tdetect.elapsed))+" kb/sec");
 		outstream.println("Total reads:     \t\t"+totalReads);
 		outstream.println("Total bases:     \t\t"+totalBases);
 //		outstream.println();
@@ -686,15 +685,15 @@ public class KmerCoverage {
 			outstream.println("The most accurate value is the greater of the two.");
 			outstream.println();
 			
-			outstream.println("Percent unique:               \t"+(uniqueM<10 ? " " : "")+String.format(Locale.ROOT, "%.2f%%", uniqueM));
+			outstream.println("Percent unique:               \t"+(uniqueM<10 ? " " : "")+Tools.format("%.2f%%", uniqueM));
 
-			outstream.println("Depth average:                \t"+String.format(Locale.ROOT, "%.2f\t(unique kmers)", avg_unique));
-			outstream.println("Depth median:                 \t"+String.format(Locale.ROOT, "%d\t(unique kmers)", median_unique));
-			outstream.println("Depth standard deviation:     \t"+String.format(Locale.ROOT, "%.2f\t(unique kmers)", stdev_unique));
+			outstream.println("Depth average:                \t"+Tools.format("%.2f\t(unique kmers)", avg_unique));
+			outstream.println("Depth median:                 \t"+Tools.format("%d\t(unique kmers)", median_unique));
+			outstream.println("Depth standard deviation:     \t"+Tools.format("%.2f\t(unique kmers)", stdev_unique));
 			
-			outstream.println("\nDepth average:                \t"+String.format(Locale.ROOT, "%.2f\t(all kmers)", avg_all));
-			outstream.println("Depth median:                 \t"+String.format(Locale.ROOT, "%d\t(all kmers)", median_all));
-			outstream.println("Depth standard deviation:     \t"+String.format(Locale.ROOT, "%.2f\t(all kmers)", stdev_all));
+			outstream.println("\nDepth average:                \t"+Tools.format("%.2f\t(all kmers)", avg_all));
+			outstream.println("Depth median:                 \t"+Tools.format("%d\t(all kmers)", median_all));
+			outstream.println("Depth standard deviation:     \t"+Tools.format("%.2f\t(all kmers)", stdev_all));
 		}
 		
 		return totalBases;
@@ -1065,8 +1064,8 @@ public class KmerCoverage {
 					Arrays.sort(cov);
 					int median=cov[cov.length/2];
 					sb.append(median).append(' ');
-					sb.append(String.format(Locale.ROOT, "%.3f ", sum/(float)cov.length));
-					sb.append(String.format(Locale.ROOT, "%.3f ", Tools.standardDeviation(cov)));
+					sb.append(Tools.format("%.3f ", sum/(float)cov.length));
+					sb.append(Tools.format("%.3f ", Tools.standardDeviation(cov)));
 					sb.append(min).append(' ');
 					sb.append(max).append('\n');
 					
@@ -1091,8 +1090,8 @@ public class KmerCoverage {
 					Arrays.sort(cov);
 					int median=cov[cov.length/2];
 					sb.append(median).append(' ');
-					sb.append(String.format(Locale.ROOT, "%.3f ", sum/(float)cov.length));
-					sb.append(String.format(Locale.ROOT, "%.3f ", Tools.standardDeviation(cov)));
+					sb.append(Tools.format("%.3f ", sum/(float)cov.length));
+					sb.append(Tools.format("%.3f ", Tools.standardDeviation(cov)));
 					sb.append(min).append(' ');
 					sb.append(max);
 					
@@ -1134,8 +1133,8 @@ public class KmerCoverage {
 				Arrays.sort(cov);
 				int median=cov[cov.length/2];
 				sb.append(median).append(' ');
-				sb.append(String.format(Locale.ROOT, "%.3f ", sum/(float)cov.length));
-				sb.append(String.format(Locale.ROOT, "%.3f ", Tools.standardDeviation(cov)));
+				sb.append(Tools.format("%.3f ", sum/(float)cov.length));
+				sb.append(Tools.format("%.3f ", Tools.standardDeviation(cov)));
 				sb.append(min).append(' ');
 				sb.append(max);
 
