@@ -412,7 +412,7 @@ public class KmerFilterSetMaker {
 	/** Print messages to this stream */
 	private static PrintStream outstream=System.err;
 	/** Permission to overwrite existing files */
-	public static boolean overwrite=false;
+	public static boolean overwrite=true;
 	/** Permission to append to existing files */
 	public static boolean append=false;
 	/** Display progress messages such as memory usage */
