@@ -4,7 +4,6 @@ import java.io.File;
 import java.io.PrintStream;
 import java.util.ArrayList;
 import java.util.HashMap;
-import java.util.Locale;
 
 import fileIO.ByteFile;
 import fileIO.ByteFile1;
@@ -87,7 +86,7 @@ public class MergeBarcodes {
 			}else if(a.equals("rcomp") || a.equals("rc")){
 				reverseComplement=Parse.parseBoolean(b);
 				outstream.println("Set RCOMP to "+reverseComplement);
-			}else if(parser.in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+			}else if(parser.in1==null && i==0 && Tools.looksLikeInputStream(arg)){
 				parser.in1=arg;
 			}else{
 				outstream.println("Unknown parameter "+args[i]);
@@ -265,8 +264,8 @@ public class MergeBarcodes {
 		
 		outstream.println("Loaded barcodes.");
 		outstream.println("Time:                         \t"+t);
-		outstream.println("Barcodes Processed: "+rpstring+" \t"+String.format(Locale.ROOT, "%.2fk reads/sec", rpnano*1000000));
-		outstream.println("Bases Processed:    "+bpstring+" \t"+String.format(Locale.ROOT, "%.2fm bases/sec", bpnano*1000));
+		outstream.println("Barcodes Processed: "+rpstring+" \t"+Tools.format("%.2fk reads/sec", rpnano*1000000));
+		outstream.println("Bases Processed:    "+bpstring+" \t"+Tools.format("%.2fm bases/sec", bpnano*1000));
 		outstream.println();
 		
 		if(errorState){
@@ -384,8 +383,8 @@ public class MergeBarcodes {
 		t.stop();
 
 		outstream.println(Tools.timeReadsBasesProcessed(t, readsProcessed, basesProcessed, 8));
-		outstream.println("Barcodes Found:         \t"+barcodesFound+" reads ("+String.format(Locale.ROOT, "%.2f",barcodesFound*100.0/readsProcessed)+"%)");
-		outstream.println("Barcodes Not Found:     \t"+barcodesNotFound+" reads ("+String.format(Locale.ROOT, "%.2f",barcodesNotFound*100.0/readsProcessed)+"%)");
+		outstream.println("Barcodes Found:         \t"+barcodesFound+" reads ("+Tools.format("%.2f",barcodesFound*100.0/readsProcessed)+"%)");
+		outstream.println("Barcodes Not Found:     \t"+barcodesNotFound+" reads ("+Tools.format("%.2f",barcodesNotFound*100.0/readsProcessed)+"%)");
 
 		if(errorState){
 			throw new RuntimeException("ReformatReads terminated in an error state; the output may be corrupt.");
@@ -440,7 +439,7 @@ public class MergeBarcodes {
 	private PrintStream outstream=System.err;
 	public static boolean verbose=false;
 	public boolean errorState=false;
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	private boolean append=false;
 	
 }
