@@ -193,7 +193,7 @@ public class MergeSam {
 	private PrintStream outstream=System.err;
 	public static boolean verbose=false;
 	public boolean errorState=false;
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	private boolean append=false;
 	
 }
