@@ -1,7 +1,6 @@
 package jgi;
 
 import java.util.ArrayList;
-import java.util.Locale;
 import java.util.Random;
 
 import dna.AminoAcid;
@@ -108,9 +107,9 @@ public class MutateGenome {
 		assert(indelRate>=0 && indelRate<=1) : "Indel rate must be between 0 and 1, inclusive.  Invalid value: "+indelRate;
 		assert(errorRate>=0 && errorRate<=1) : "Total error rate must be between 0 and 1, inclusive.  Invalid value: "+errorRate;
 		
-		System.err.println(String.format(Locale.ROOT, "Target Identity:   \t%.2f%%", (1-errorRate2)*100));
-		System.err.println(String.format(Locale.ROOT, "Substitution Rate: \t%.2f%%", subRate*100));
-		System.err.println(String.format(Locale.ROOT, "Indel Rate:        \t%.2f%%", indelRate*100));
+		System.err.println(Tools.format("Target Identity:   \t%.2f%%", (1-errorRate2)*100));
+		System.err.println(Tools.format("Substitution Rate: \t%.2f%%", subRate*100));
+		System.err.println(Tools.format("Indel Rate:        \t%.2f%%", indelRate*100));
 		
 		randy=Shared.threadLocalRandom(seed);
 		
@@ -254,8 +253,8 @@ public class MutateGenome {
 			while(jastring.length()<8){jastring=" "+jastring;}
 			
 			outstream.println(Tools.timeReadsBasesProcessed(t, readsProcessed, basesProcessed, 8));
-			if(genomeFraction<1){outstream.println("Bases Retained:     "+brstring+" \t"+String.format(Locale.ROOT, "%.2fm bases/sec", brnano*1000));}
-			outstream.println("Mutations Added:    "+mastring+" \t"+String.format(Locale.ROOT, "%.2f%% Identity", 100f-mutationLengthAdded*100f/basesProcessed));
+			if(genomeFraction<1){outstream.println("Bases Retained:     "+brstring+" \t"+Tools.format("%.2fm bases/sec", brnano*1000));}
+			outstream.println("Mutations Added:    "+mastring+" \t"+Tools.format("%.2f%% Identity", 100f-mutationLengthAdded*100f/basesProcessed));
 			outstream.println("Subs Added:         "+sastring);
 			outstream.println("Insertions Added:   "+iastring);
 			outstream.println("Deletions Added:    "+dastring);
