@@ -1,9 +1,8 @@
 package jgi;
 
-import java.util.Locale;
-
 import fileIO.TextFile;
 import shared.KillSwitch;
+import shared.Tools;
 
 public class RQCFilterStats {
 	
@@ -147,7 +146,7 @@ public class RQCFilterStats {
 	
 	private static String toPercent(long numerator, long denominator, int decimals){
 		if(denominator<1){denominator=1;}
-		return String.format(Locale.ROOT, "%."+decimals+"f",numerator*100.0/denominator);
+		return Tools.format("%."+decimals+"f",numerator*100.0/denominator);
 	}
 	
 	void parseHuman(String fname){
