@@ -6,9 +6,7 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.Locale;
 import java.util.Random;
-import java.util.regex.Pattern;
 
 import cardinality.CardinalityTracker;
 import dna.AminoAcid;
@@ -18,9 +16,9 @@ import fileIO.ByteFile1;
 import fileIO.ByteFile2;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import hiseq.IlluminaHeaderParser2;
+import hiseq.ReadHeaderParser;
 import shared.KillSwitch;
-import shared.LineParser2;
-import shared.LineParserS2;
 import shared.MetadataWriter;
 import shared.Parse;
 import shared.Parser;
@@ -183,7 +181,13 @@ public class ReformatReads {
 				skipreads=Parse.parseKMG(b);
 			}else if(a.equals("undefinedton") || a.equals("iupacton") || a.equals("itn")){
 				iupacToN=Parse.parseBoolean(b);
-			}else if(a.equals("quantize") || a.equals("quantizesticky")){
+			}else if(a.equals("bottom")){
+				bottom=Parse.parseBoolean(b);
+			}else if(a.equals("top")){
+				top=Parse.parseBoolean(b);
+			}
+			
+			else if(a.equals("quantize") || a.equals("quantizesticky")){
 				quantizeQuality=Quantizer.parse(arg, a, b);
 			}else if(a.equals("samversion") || a.equals("samv") || a.equals("sam")){
 				parser.parse(arg, a, b);
@@ -194,6 +198,10 @@ public class ReformatReads {
 				invertFilters=Parse.parseBoolean(b);
 			}else if(a.equals("k")){
 				k=Integer.parseInt(b);
+			}else if(a.equals("top")){
+				top=Parse.parseBoolean(b);
+			}else if(a.equals("bottom")){
+				bottom=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equalsIgnoreCase("lastUnderscoreToSpace") || a.equalsIgnoreCase("underscoreToSpace")){
@@ -239,7 +247,7 @@ public class ReformatReads {
 			
 			else if(parser.parse(arg, a, b)){
 				//do nothing
-			}else if(parser.in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+			}else if(parser.in1==null && i==0 && Tools.looksLikeInputStream(arg)){
 				parser.in1=arg;
 			}else{
 				outstream.println("Unknown parameter "+args[i]);
@@ -692,6 +700,18 @@ public class ReformatReads {
 						if(complement){r2.complement();}
 					}
 					
+					if(!bottom || !top) {
+						rhp.parse(r1);
+						if(!bottom && rhp.surface()==1) {
+							r1.setDiscarded(true);
+							r2.setDiscarded(true);
+						}
+						if(!top && rhp.surface()==2) {
+							r1.setDiscarded(true);
+							r2.setDiscarded(true);
+						}
+					}
+					
 					if(verifypairing){
 						String s1=r1==null ? null : r1.id;
 						String s2=r2==null ? null : r2.id;
@@ -1229,41 +1249,41 @@ public class ReformatReads {
 		}
 		
 		if(remap1!=null || remap2!=null){
-			outstream.println("Base Transforms:        \t"+readsSwappedT+" reads ("+String.format(Locale.ROOT, "%.2f",readsSwappedT*rpmult)+"%) \t"+
-					basesSwappedT+" bases ("+String.format(Locale.ROOT, "%.2f",basesSwappedT*bpmult)+"%)");
+			outstream.println("Base Transforms:        \t"+readsSwappedT+" reads ("+Tools.format("%.2f",readsSwappedT*rpmult)+"%) \t"+
+					basesSwappedT+" bases ("+Tools.format("%.2f",basesSwappedT*bpmult)+"%)");
 		}
 		if(qtrim || trimBadSequence){
-			outstream.println("QTrimmed:               \t"+readsQTrimmedT+" reads ("+String.format(Locale.ROOT, "%.2f",readsQTrimmedT*rpmult)+"%) \t"+
-					basesQTrimmedT+" bases ("+String.format(Locale.ROOT, "%.2f",basesQTrimmedT*bpmult)+"%)");
+			outstream.println("QTrimmed:               \t"+readsQTrimmedT+" reads ("+Tools.format("%.2f",readsQTrimmedT*rpmult)+"%) \t"+
+					basesQTrimmedT+" bases ("+Tools.format("%.2f",basesQTrimmedT*bpmult)+"%)");
 		}
 		if(forceTrimLeft>0 || forceTrimRight>0 || forceTrimRight2>0 || forceTrimModulo>0){
-			outstream.println("FTrimmed:               \t"+readsFTrimmedT+" reads ("+String.format(Locale.ROOT, "%.2f",readsFTrimmedT*rpmult)+"%) \t"+
-					basesFTrimmedT+" bases ("+String.format(Locale.ROOT, "%.2f",basesFTrimmedT*bpmult)+"%)");
+			outstream.println("FTrimmed:               \t"+readsFTrimmedT+" reads ("+Tools.format("%.2f",readsFTrimmedT*rpmult)+"%) \t"+
+					basesFTrimmedT+" bases ("+Tools.format("%.2f",basesFTrimmedT*bpmult)+"%)");
 		}
 		if(minReadLength>0 || maxReadLength>0){
-			outstream.println("Short Read Discards:    \t"+readShortDiscardsT+" reads ("+String.format(Locale.ROOT, "%.2f",readShortDiscardsT*rpmult)+"%) \t"+
-					baseShortDiscardsT+" bases ("+String.format(Locale.ROOT, "%.2f",baseShortDiscardsT*bpmult)+"%)");
+			outstream.println("Short Read Discards:    \t"+readShortDiscardsT+" reads ("+Tools.format("%.2f",readShortDiscardsT*rpmult)+"%) \t"+
+					baseShortDiscardsT+" bases ("+Tools.format("%.2f",baseShortDiscardsT*bpmult)+"%)");
 		}
 		if(minAvgQuality>0 || maxNs>=0 || chastityFilter || tossJunk || removeBadBarcodes){
-			outstream.println("Low quality discards:   \t"+lowqReadsT+" reads ("+String.format(Locale.ROOT, "%.2f",lowqReadsT*rpmult)+"%) \t"+
-					lowqBasesT+" bases ("+String.format(Locale.ROOT, "%.2f",lowqBasesT*bpmult)+"%)");
+			outstream.println("Low quality discards:   \t"+lowqReadsT+" reads ("+Tools.format("%.2f",lowqReadsT*rpmult)+"%) \t"+
+					lowqBasesT+" bases ("+Tools.format("%.2f",lowqBasesT*bpmult)+"%)");
 		}
 		if(minIdFilter>=0 || maxIdFilter<1 || USE_EDIT_FILTER){
-			outstream.println("Identity/edit discards: \t"+idfilteredReadsT+" reads ("+String.format(Locale.ROOT, "%.2f",idfilteredReadsT*rpmult)+"%) \t"+
-					idfilteredBasesT+" bases ("+String.format(Locale.ROOT, "%.2f",idfilteredBasesT*bpmult)+"%)");
+			outstream.println("Identity/edit discards: \t"+idfilteredReadsT+" reads ("+Tools.format("%.2f",idfilteredReadsT*rpmult)+"%) \t"+
+					idfilteredBasesT+" bases ("+Tools.format("%.2f",idfilteredBasesT*bpmult)+"%)");
 		}
 		
 		if(filterGC){
-			outstream.println("GC content discards:    \t"+badGcReadsT+" reads ("+String.format(Locale.ROOT, "%.2f",badGcReadsT*rpmult)+"%) \t"+
-					badGcBasesT+" bases ("+String.format(Locale.ROOT, "%.2f",badGcBasesT*bpmult)+"%)");
+			outstream.println("GC content discards:    \t"+badGcReadsT+" reads ("+Tools.format("%.2f",badGcReadsT*rpmult)+"%) \t"+
+					badGcBasesT+" bases ("+Tools.format("%.2f",badGcBasesT*bpmult)+"%)");
 		}
 		final long ro=readsOut1+readsOut2+readsOutSingle, bo=basesOut1+basesOut2+basesOutSingle;
-		outstream.println("Output:                 \t"+ro+" reads ("+String.format(Locale.ROOT, "%.2f",ro*rmult)+"%) \t"+
-				bo+" bases ("+String.format(Locale.ROOT, "%.2f",bo*bmult)+"%)");
+		outstream.println("Output:                 \t"+ro+" reads ("+Tools.format("%.2f",ro*rmult)+"%) \t"+
+				bo+" bases ("+Tools.format("%.2f",bo*bmult)+"%)");
 		
 		if(k>0){
 			outstream.println(k+"-mers processed:        \t"+kmersProcessed);
-			outstream.println("Correct "+k+"-mers:          \t"+String.format(Locale.ROOT, "%.2f%%", correctKmers*100.0/kmersProcessed));
+			outstream.println("Correct "+k+"-mers:          \t"+Tools.format("%.2f%%", correctKmers*100.0/kmersProcessed));
 		}
 		if(loglog!=null){
 			outstream.println("Unique "+loglog.k+"-mers:           \t"+loglog.cardinality());
@@ -1287,7 +1307,7 @@ public class ReformatReads {
 			double xpnano=bytesProcessed/(double)(t.elapsed);
 			String xpstring=(bytesProcessed<100000 ? ""+bytesProcessed : bytesProcessed<100000000 ? (bytesProcessed/1000)+"k" : (bytesProcessed/1000000)+"m");
 			while(xpstring.length()<8){xpstring=" "+xpstring;}
-			outstream.println("Bytes Processed:    "+xpstring+" \t"+String.format(Locale.ROOT, "%.2fm bytes/sec", xpnano*1000));
+			outstream.println("Bytes Processed:    "+xpstring+" \t"+Tools.format("%.2fm bytes/sec", xpnano*1000));
 		}
 		
 		if(verifypairing){
@@ -1638,6 +1658,9 @@ public class ReformatReads {
 	private boolean addunderscore=false;
 	private boolean stoptag=false;
 	private boolean iupacToN=false;
+	
+	boolean bottom=true;
+	boolean top=true;
 
 	private float minIdFilter=-1;
 	private float maxIdFilter=-1;
@@ -1732,6 +1755,8 @@ public class ReformatReads {
 //	private final LineParser2S lp;
 //	private Pattern splitter;
 	
+	ReadHeaderParser rhp=new IlluminaHeaderParser2();
+	
 	/*--------------------------------------------------------------*/
 	
 	private final FileFormat ffin1;
@@ -1755,7 +1780,7 @@ public class ReformatReads {
 	public static boolean verbose=false;
 	public boolean silent=false;
 	public boolean errorState=false;
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	private boolean append=false;
 	private boolean testsize=false;
 	private boolean deleteInput=false;
