@@ -11,6 +11,7 @@ import fileIO.ByteFile1;
 import fileIO.ByteFile2;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import hiseq.IlluminaHeaderParser2;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
@@ -23,7 +24,9 @@ import stream.ConcurrentReadOutputStream;
 import stream.FASTQ;
 import stream.FastaReadInputStream;
 import stream.Read;
+import structures.ByteBuilder;
 import structures.ListNum;
+import structures.Quantizer;
 import tracker.ReadStats;
 
 /**
@@ -135,6 +138,10 @@ public class RenameReads {
 				renameByInsert=Parse.parseBoolean(b);
 			}else if(a.equals("renamebytrim")){
 				renameByTrim=Parse.parseBoolean(b);
+			}else if(a.equals("renamebycoordinates") || a.equals("coordinates") || a.equals("coords")){
+				renameByCoords=Parse.parseBoolean(b);
+			}else if(a.equals("quantize") || a.equals("quantizesticky")){
+				quantizeQuality=Quantizer.parse(arg, a, b);
 			}else if(a.equals("addprefix")){
 				addPrefix=Parse.parseBoolean(b);
 			}else if(a.equals("addpairnum")){
@@ -145,7 +152,7 @@ public class RenameReads {
 				addUnderscore=Parse.parseBoolean(b);
 			}else if(a.startsWith("minscaf") || a.startsWith("mincontig")){
 				stream.FastaReadInputStream.MIN_READ_LEN=Integer.parseInt(b);
-			}else if(in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+			}else if(in1==null && i==0 && Tools.looksLikeInputStream(arg)){
 				in1=arg;
 			}else{
 				System.err.println("Unknown parameter "+args[i]);
@@ -259,6 +266,8 @@ public class RenameReads {
 		
 		ListNum<Read> ln=cris.nextList();
 		ArrayList<Read> reads=(ln!=null ? ln.list : null);
+		IlluminaHeaderParser2 ihp=new IlluminaHeaderParser2();
+		ByteBuilder bb=new ByteBuilder();
 		
 		long x=0;
 		while(ln!=null && reads!=null && reads.size()>0){//ln!=null prevents a compiler potential null access warning
@@ -267,6 +276,12 @@ public class RenameReads {
 				final Read r2=r1.mate;
 //				assert(false) : trimBeforeSymbol+", '"+symbol+"'";
 				
+				if(quantizeQuality){
+					final byte[] quals1=r1.quality, quals2=(r2==null ? null : r2.quality);
+					Quantizer.quantize(quals1);
+					Quantizer.quantize(quals2);
+				}
+				
 				if(trimRight>0 || trimLeft>0 || trimBeforeSymbol>0) {
 					if(trimRight>0 || trimLeft>0){
 						r1.id=trim(r1.id, trimLeft, trimRight);
@@ -279,6 +294,15 @@ public class RenameReads {
 				}else if(fixSRA){
 					fixSRA(r1);
 					fixSRA(r2);
+				}else if(renameByCoords){
+					bb.clear().colon().colon().colon();
+					ihp.parse(r1);
+					ihp.appendCoordinates(bb).space().append(1).colon();
+					r1.id=bb.toString();
+					if(r2!=null) {
+						bb.set(bb.length-2, (byte)'2');
+						r2.id=bb.toString();
+					}
 				}else if(renameByMapping){
 					//Should be handled automatically, if output is fastq.
 				}else if(r2!=null && (renameByInsert || renameByTrim)){
@@ -407,10 +431,12 @@ public class RenameReads {
 	public boolean renameByMapping=false;
 	public boolean renameByInsert=false;
 	public boolean renameByTrim=false;
+	public boolean renameByCoords=false;
 	public boolean addPrefix=false;
 	public boolean prefixOnly=false;
 	public boolean fixSRA=false;
 	public boolean addPairnum=true;
+	public boolean quantizeQuality=false;
 	private String[] pairnums={" 1:", " 2:"};
 
 	private static final Pattern spacePattern=Pattern.compile("\\s+");
