@@ -6,7 +6,6 @@ import java.io.PrintStream;
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.Locale;
 
 import dna.Data;
 import dna.Scaffold;
@@ -83,7 +82,7 @@ public class SamToEst {
 				append=ReadStats.append=Parse.parseBoolean(b);
 			}else if(a.equals("overwrite") || a.equals("ow")){
 				overwrite=Parse.parseBoolean(b);
-			}else if(sam==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+			}else if(sam==null && i==0 && Tools.looksLikeInputStream(arg)){
 				sam=arg;
 			}else if(stats==null && i==1 && !arg.contains("=")){
 				stats=arg;
@@ -344,18 +343,18 @@ public class SamToEst {
 				}
 			}
 			
-			tsw.println("all:\t"+allBasesMapped+"\t"+String.format(Locale.ROOT, "%.4f%%",allBasesPct)+"\t"+allBasesMappedB+"\t"+String.format(Locale.ROOT, "%.4f%%",allBasesPctB));
-			tsw.println("most:\t"+mostBasesMapped+"\t"+String.format(Locale.ROOT, "%.4f%%",mostBasesPct)+"\t"+mostBasesMappedB+"\t"+String.format(Locale.ROOT, "%.4f%%",mostBasesPctB));
-			tsw.println("some:\t"+someBasesMapped+"\t"+String.format(Locale.ROOT, "%.4f%%",someBasesPct)+"\t"+someBasesMappedB+"\t"+String.format(Locale.ROOT, "%.4f%%",someBasesPctB));
-			tsw.println("zero:\t"+noBasesMapped+"\t"+String.format(Locale.ROOT, "%.4f%%",noBasesPct)+"\t"+noBasesMappedB+"\t"+String.format(Locale.ROOT, "%.4f%%",noBasesPctB));
-			tsw.println("multi:\t"+multiScaffold+"\t"+String.format(Locale.ROOT, "%.4f%%",multiScaffoldPct)+"\t"+multiScaffoldB+"\t"+String.format(Locale.ROOT, "%.4f%%",multiScaffoldPctB));
+			tsw.println("all:\t"+allBasesMapped+"\t"+Tools.format("%.4f%%",allBasesPct)+"\t"+allBasesMappedB+"\t"+Tools.format("%.4f%%",allBasesPctB));
+			tsw.println("most:\t"+mostBasesMapped+"\t"+Tools.format("%.4f%%",mostBasesPct)+"\t"+mostBasesMappedB+"\t"+Tools.format("%.4f%%",mostBasesPctB));
+			tsw.println("some:\t"+someBasesMapped+"\t"+Tools.format("%.4f%%",someBasesPct)+"\t"+someBasesMappedB+"\t"+Tools.format("%.4f%%",someBasesPctB));
+			tsw.println("zero:\t"+noBasesMapped+"\t"+Tools.format("%.4f%%",noBasesPct)+"\t"+noBasesMappedB+"\t"+Tools.format("%.4f%%",noBasesPctB));
+			tsw.println("multi:\t"+multiScaffold+"\t"+Tools.format("%.4f%%",multiScaffoldPct)+"\t"+multiScaffoldB+"\t"+Tools.format("%.4f%%",multiScaffoldPctB));
 //			tsw.println("numIntrons:\t"+count);
 //			tsw.println("minIntron:\t"+min);
 //			tsw.println("maxIntron:\t"+max);
 //			tsw.println("medIntron:\t"+median);
 //			tsw.println("avgIntron:\t"+(long)(sum/(double)(Tools.max(count,1))));
 			tsw.println("introns\tmin\tmax\tmedian\taverage");
-			tsw.println(count+"\t"+min+"\t"+max+"\t"+median+"\t"+String.format(Locale.ROOT, "%.1f", (sum/(double)(Tools.max(count,1)))));
+			tsw.println(count+"\t"+min+"\t"+max+"\t"+median+"\t"+Tools.format("%.1f", (sum/(double)(Tools.max(count,1)))));
 
 			tsw.poisonAndWait();
 		}
