@@ -3,7 +3,6 @@ package jgi;
 import java.io.File;
 import java.io.PrintStream;
 import java.util.ArrayList;
-import java.util.Locale;
 import java.util.concurrent.atomic.AtomicLongArray;
 
 import dna.Data;
@@ -50,7 +49,7 @@ public class SealRefInfo {
 				}else{
 					String fname=null;
 					if("phix".equalsIgnoreCase(s)){
-						fname=Data.findPath("?phix174_ill.ref.fa.gz");
+						fname=Data.findPath("?phix2.fa.gz");
 					}else if("polya".equalsIgnoreCase(s) || "polyt".equalsIgnoreCase(s)){
 						fname=Data.findPath("?polyA.fa.gz");
 					}else if("lambda".equalsIgnoreCase(s)){
@@ -169,9 +168,9 @@ public class SealRefInfo {
 		
 		/* Print header */
 		tsw.print("#File\t"+in1+(in2==null ? "" : "\t"+in2)+"\n");
-		tsw.print(String.format(Locale.ROOT, "#Reads\t%d\n",readsIn));
-		tsw.print(String.format(Locale.ROOT, "#Mapped\t%d\n",mapped));
-		tsw.print(String.format(Locale.ROOT, "#References\t%d\n",refNames.size()-1));
+		tsw.print(Tools.format("#Reads\t%d\n",readsIn));
+		tsw.print(Tools.format("#Mapped\t%d\n",mapped));
+		tsw.print(Tools.format("#References\t%d\n",refNames.size()-1));
 		tsw.print("#Name\tLength\tScaffolds\tBases\tCoverage\tReads\tRPKM\tFrags\tFPKM\n");
 		
 		final float mult=1000000000f/Tools.max(1, mapped);
@@ -187,7 +186,7 @@ public class SealRefInfo {
 			final double invlen=1.0/Tools.max(1, len);
 			final double mult2=mult*invlen;
 			if(reads>0 || !printNonZeroOnly){
-				tsw.print(String.format(Locale.ROOT, "%s\t%d\t%d\t%d\t%.4f\t%d\t%.4f\t%d\t%.4f\n",name,len,scafs,bases,bases*invlen,reads,reads*mult2,frags,frags*mult2));
+				tsw.print(Tools.format("%s\t%d\t%d\t%d\t%.4f\t%d\t%.4f\t%d\t%.4f\n",name,len,scafs,bases,bases*invlen,reads,reads*mult2,frags,frags*mult2));
 			}
 		}
 		tsw.poisonAndWait();
@@ -235,7 +234,7 @@ public class SealRefInfo {
 			final double unambigReadP=rmult*reads;
 			final double ambigReadP=rmult*ambigReads;
 			if(reads>0 || !printNonZeroOnly){
-				tsw.print(String.format(Locale.ROOT, "%s\t%.5f\t%.5f\t%.5f\t%.5f\t%d\t%d\n",name,unambigReadP,unambigMB,ambigReadP,ambigMB,reads,ambigReads));
+				tsw.print(Tools.format("%s\t%.5f\t%.5f\t%.5f\t%.5f\t%d\t%d\n",name,unambigReadP,unambigMB,ambigReadP,ambigMB,reads,ambigReads));
 			}
 		}
 		tsw.poisonAndWait();
