@@ -91,11 +91,21 @@ public class Shred {
 				median=Parse.parseIntKMG(b);
 			}else if(a.equals("variance")){
 				variance=Parse.parseIntKMG(b);
+			}else if(a.equals("mode")){
+				mode=Tools.find(b.toUpperCase(), modes);
+			}else if(Tools.find(a.toUpperCase(), modes)>=0){
+				mode=Tools.find(a.toUpperCase(), modes);
+				assert(Parse.parseBoolean(b)) : "Modes should only be true: '"+arg+"'";
+			}else if(a.equals("filetid")){
+				parseFileTID=Parse.parseBoolean(b);
+			}else if(a.equals("sequencetid") || a.equals("headertid")){
+				parseSequenceTID=Parse.parseBoolean(b);
+			}else if(a.equals("prefix")){
+				prefix=b;
 			}else if(a.equals("parse_flag_goes_here")){
 				//Set a variable here
 			}else if(parser.parse(arg, a, b)){
 				//do nothing
-				
 			}else{
 				outstream.println("Unknown parameter "+args[i]);
 				assert(false) : "Unknown parameter "+args[i];
@@ -162,6 +172,7 @@ public class Shred {
 			minLength=Tools.max(1, median-variance);
 			maxLength=median+variance;
 		}
+		System.err.println("minlen="+minLength+", maxlen="+maxLength);
 		if(minLength>-1 && maxLength>-1) {
 			assert(maxLength>=minLength);
 			range=maxLength-minLength+1;
@@ -245,6 +256,11 @@ public class Shred {
 			Read r=reads.get(0);
 			assert((ffin1==null || ffin1.samOrBam()) || (r.mate!=null)==cris.paired());
 		}
+		
+		int tid=-1;
+		if(parseFileTID) {
+			tid=bin.DataLoader.parseTaxID(in1);
+		}
 
 		while(ln!=null && reads!=null && reads.size()>0){//ln!=null prevents a compiler potential null access warning
 			if(verbose){outstream.println("Fetched "+reads.size()+" reads.");}
@@ -258,12 +274,16 @@ public class Shred {
 				readsProcessed++;
 				basesProcessed+=initialLength1;
 				
+				if(parseSequenceTID) {
+					tid=bin.DataLoader.parseTaxID(r1.id);
+				}
+				
 				if(range>1){
-					processRandomly(r1, listOut);
+					processRandomly(r1, listOut, tid);
 				}else if(evenLengths){
-					processEvenly(r1, listOut);
+					processEvenly(r1, listOut, tid);
 				}else{
-					processUnevenly(r1, listOut);
+					processUnevenly(r1, listOut, tid);
 				}
 			}
 
@@ -283,26 +303,26 @@ public class Shred {
 	/*----------------         Inner Methods        ----------------*/
 	/*--------------------------------------------------------------*/
 	
-	void processRead(final Read r1, final ArrayList<Read> list){
-		if(r1.length()<minLength){return;}
-		if(r1.length()<=shredLength){
-			r1.numericID=readsOut;
-			list.add(r1);
-			readsOut++;
-			basesOut+=r1.length();
-			return;
-		}
-		if(evenLengths){
-			processEvenly(r1, list);
-		}else{
-			processUnevenly(r1, list);
-		}
-	}
+//	void processRead(final Read r1, final ArrayList<Read> list, int tid){
+//		if(r1.length()<minLength){return;}
+//		if(r1.length()<=shredLength){
+//			r1.numericID=readsOut;
+//			list.add(r1);
+//			readsOut++;
+//			basesOut+=r1.length();
+//			return;
+//		}
+//		if(evenLengths){
+//			processEvenly(r1, list, tid);
+//		}else{
+//			processUnevenly(r1, list, tid);
+//		}
+//	}
 	
-	void processEvenly(final Read r1, final ArrayList<Read> list){
+	void processEvenly(final Read r1, final ArrayList<Read> list, int tid){
 		final byte[] bases=r1.bases;
 		final byte[] quals=r1.quality;
-		final String name=r1.id;
+		final String name=(prefix==null ? r1.id : prefix+r1.numericID);
 		
 		final int chunks=(int)Math.ceil((bases.length-overlap)*incMult);
 		assert(chunks>0);
@@ -316,7 +336,7 @@ public class Shred {
 			if(length<minLength){return;}
 			final byte[] bases2=KillSwitch.copyOfRange(bases, a, b);
 			final byte[] quals2=(quals==null ? null : KillSwitch.copyOfRange(quals, a, b));
-			Read shred=new Read(bases2, quals2, name+"_"+a+"-"+(b-1), readsOut);
+			Read shred=new Read(bases2, quals2, toName(name, a, (b-1), tid), readsOut);
 			boolean pass=true;
 			if(pass && maxNs>=0 && shred.countUndefined()>maxNs) {pass=false;}
 			if(pass) {
@@ -327,17 +347,17 @@ public class Shred {
 		}
 	}
 	
-	void processUnevenly(final Read r1, final ArrayList<Read> list){
+	void processUnevenly(final Read r1, final ArrayList<Read> list, int tid){
 		final byte[] bases=r1.bases;
 		final byte[] quals=r1.quality;
-		final String name=r1.id;
+		final String name=(prefix==null ? r1.id : prefix+r1.numericID);
 		for(int i=0; i<bases.length; i+=increment){
 			final int limit=Tools.min(i+shredLength, bases.length);
 			final int length=limit-i;
 			if(length<minLength){return;}
 			final byte[] bases2=KillSwitch.copyOfRange(bases, i, limit);
 			final byte[] quals2=(quals==null ? null : KillSwitch.copyOfRange(quals, i, limit));
-			Read shred=new Read(bases2, quals2, name+"_"+i+"-"+(limit-1), readsOut, r1.flags);
+			Read shred=new Read(bases2, quals2, toName(name, i, (limit-1), tid), readsOut, r1.flags);
 			boolean pass=true;
 			if(pass && maxNs>=0 && shred.countUndefined()>maxNs) {pass=false;}
 			if(pass) {
@@ -350,20 +370,23 @@ public class Shred {
 		}
 	}
 	
-	void processRandomly(final Read r1, final ArrayList<Read> list){
+	void processRandomly(final Read r1, final ArrayList<Read> list, int tid){
 		final byte[] bases=r1.bases;
 		final byte[] quals=r1.quality;
-		final String name=r1.id;
+		final String name=(prefix==null ? r1.id : prefix+r1.numericID);
 		for(int i=0; i<bases.length;){
 //			int rand=Tools.min(randy.nextInt(2*variance), randy.nextInt(3*variance), 2*variance);
 //			final int limit=Tools.max(i+minLength, Tools.min(i+rand+median-variance, bases.length));
-			final int rand=randy.nextInt(range);
-			final int limit=Tools.min(i+rand+minLength, bases.length);
-			final int length=limit-i;
+//			final int rand=randy.nextInt(range);
+//			final int limit=Tools.min(i+rand+minLength, bases.length);
+//			final int length=limit-i;
+			final int length=randomLength(bases.length-i);
 			if(length<minLength){return;}
+			final int limit=i+length;
+			assert(limit<=bases.length) : "i="+i+", length="+length+", limit="+limit+", blen="+bases.length;
 			final byte[] bases2=KillSwitch.copyOfRange(bases, i, limit);
 			final byte[] quals2=(quals==null ? null : KillSwitch.copyOfRange(quals, i, limit));
-			Read shred=new Read(bases2, quals2, name+"_"+i+"-"+(limit-1), readsOut);
+			Read shred=new Read(bases2, quals2, toName(name, i, (limit-1), tid), readsOut);
 			readsOut++;
 			basesOut+=shred.length();
 			list.add(shred);
@@ -373,6 +396,53 @@ public class Shred {
 		}
 	}
 	
+	final String toName(String name, int start, int stop, int tid) {
+		return (name==null ? "" : name+"_")+start+"-"+stop+(tid>0 ? "_tid_"+tid : "");
+	}
+	
+	final int randomLength(final int remainder) {
+		if(mode==LINEAR) {return randomLengthLinear(remainder);}
+		else if(mode==LOG) {return logUniformLength(remainder);}
+		else if(mode==EXP) {return randomLengthExp(remainder);}
+		else {
+			throw new RuntimeException("Unknown mode "+mode);
+		}
+	}
+	
+	final int randomLengthLinear(final int remainder) {
+		return Tools.min(minLength+randy.nextInt(range), remainder);
+	}
+	
+	final int randomLengthExp(final int remainder) {
+		if(remainder<=minLength) {return remainder;}
+		long max=Tools.min(maxLength, remainder);
+		float invlambda=(float)(1/Math.sqrt(minLength*max));
+//		System.err.println("1/Lambda="+invlambda);
+		int rand=(int)Tools.exponential(randy, invlambda);
+		for(int i=0; i<20 && (rand>max || rand<minLength); i++) {
+			rand=(int)Tools.exponential(randy, invlambda);
+		}
+//		System.err.println("Rand.exp="+rand);
+		return (rand<minLength || rand>max ? remainder : rand);
+	}
+	
+    /**
+     * Samples a length from a continuous log-uniform distribution.
+     * Written by Claude 3.7
+     */
+    private int logUniformLength(int remainder) {
+        double u = randy.nextDouble(); // Uniform between 0 and 1
+        
+        // Calculate log-uniform value between minLength and maxLength
+        double logMin = Math.log(minLength);
+        double logMax = Math.log(maxLength);
+        double logValue = logMin + u * (logMax - logMin);
+        
+        // Convert back from log space and round to integer
+        int len=(int) Math.round(Math.exp(logValue));
+        return Math.min(remainder, len);
+    }
+	
 	/*--------------------------------------------------------------*/
 	/*----------------            Fields            ----------------*/
 	/*--------------------------------------------------------------*/
@@ -383,6 +453,10 @@ public class Shred {
 	private String extin=null;
 	private String extout=null;
 	
+	boolean parseFileTID=false;
+	boolean parseSequenceTID=false;
+	String prefix=null;
+	
 	/*--------------------------------------------------------------*/
 
 	protected long readsProcessed=0;
@@ -408,6 +482,10 @@ public class Shred {
 	
 	private final Random randy;
 	
+	int mode=LINEAR;
+	static final int LINEAR=0, LOG=1, EXP=2;
+	static final String[] modes={"LINEAR", "LOG", "EXP"};
+	
 	/*--------------------------------------------------------------*/
 	/*----------------         Final Fields         ----------------*/
 	/*--------------------------------------------------------------*/
