@@ -1,7 +1,6 @@
 package jgi;
 
 import java.util.ArrayList;
-import java.util.Locale;
 
 import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
@@ -68,9 +67,9 @@ public class SplitNexteraLMP extends BBTool_ST {
 			System.err.println("Testing merge rate.");
 			float rate=FileFormat.testInput(in1, FileFormat.FASTQ, null, true, true).stdio() ? 1 : BBMerge.mergeableFraction(in1, in2, 1000000, 0.2f);
 			merge=rate>0.1;
-			System.err.println("Merge rate: "+String.format(Locale.ROOT, "%.2f%%", rate));
+			System.err.println("Merge rate: "+Tools.format("%.2f%%", rate));
 			if(!merge){
-				System.err.println("Merging was disabled due to a low merge rate of "+String.format(Locale.ROOT, "%.3f", rate));
+				System.err.println("Merging was disabled due to a low merge rate of "+Tools.format("%.3f", rate));
 			}
 		}
 	}
@@ -329,23 +328,23 @@ public class SplitNexteraLMP extends BBTool_ST {
 		final double bmult=100.0/basesIn;
 		
 		//Note that this can go over 100%
-		tsw.println("Long Mate Pairs:        \t"+readsLmp+" reads ("+String.format(Locale.ROOT, "%.2f",readsLmp*rmult)+"%) \t"+
-				basesLmp+" bases ("+String.format(Locale.ROOT, "%.2f",basesLmp*bmult)+"%)");
-		tsw.println("Fragment Pairs:         \t"+readsFrag+" reads ("+String.format(Locale.ROOT, "%.2f",readsFrag*rmult)+"%) \t"+
-				basesFrag+" bases ("+String.format(Locale.ROOT, "%.2f",basesFrag*bmult)+"%)");
-		tsw.println("Unknown Pairs:          \t"+readsUnk+" reads ("+String.format(Locale.ROOT, "%.2f",readsUnk*rmult)+"%) \t"+
-				basesUnk+" bases ("+String.format(Locale.ROOT, "%.2f",basesUnk*bmult)+"%)");
-		tsw.println("Singletons:             \t"+readsSingle+" reads ("+String.format(Locale.ROOT, "%.2f",readsSingle*100.0/readsIn)+"%) \t"+
-				basesSingle+" bases ("+String.format(Locale.ROOT, "%.2f",basesSingle*bmult)+"%)");
+		tsw.println("Long Mate Pairs:        \t"+readsLmp+" reads ("+Tools.format("%.2f",readsLmp*rmult)+"%) \t"+
+				basesLmp+" bases ("+Tools.format("%.2f",basesLmp*bmult)+"%)");
+		tsw.println("Fragment Pairs:         \t"+readsFrag+" reads ("+Tools.format("%.2f",readsFrag*rmult)+"%) \t"+
+				basesFrag+" bases ("+Tools.format("%.2f",basesFrag*bmult)+"%)");
+		tsw.println("Unknown Pairs:          \t"+readsUnk+" reads ("+Tools.format("%.2f",readsUnk*rmult)+"%) \t"+
+				basesUnk+" bases ("+Tools.format("%.2f",basesUnk*bmult)+"%)");
+		tsw.println("Singletons:             \t"+readsSingle+" reads ("+Tools.format("%.2f",readsSingle*100.0/readsIn)+"%) \t"+
+				basesSingle+" bases ("+Tools.format("%.2f",basesSingle*bmult)+"%)");
 		tsw.println("\n(Note: Read totals may exceed 100%, though base totals should not.)");
 		tsw.println("");
-		tsw.println("Adapters Detected:      \t"+junctionsDetected+" ("+String.format(Locale.ROOT, "%.2f%%)",junctionsDetected*100.0/junctionsSought));
+		tsw.println("Adapters Detected:      \t"+junctionsDetected+" ("+Tools.format("%.2f%%)",junctionsDetected*100.0/junctionsSought));
 		tsw.println("Bases Recovered:        \t"+(basesLmp+basesFrag+basesUnk+basesSingle)+
-				" ("+String.format(Locale.ROOT, "%.2f%%)",(basesLmp+basesFrag+basesUnk+basesSingle)*bmult));
+				" ("+Tools.format("%.2f%%)",(basesLmp+basesFrag+basesUnk+basesSingle)*bmult));
 		if(merge){
 			tsw.println("");
-			tsw.println("Merged Pairs:           \t"+mergedReadCount+" ("+String.format(Locale.ROOT, "%.2f%%)",mergedReadCount*200.0/readsProcessed));
-			tsw.println("Merged Bases:           \t"+mergedBaseCount+" ("+String.format(Locale.ROOT, "%.2f%%)",mergedBaseCount*100.0/basesProcessed));
+			tsw.println("Merged Pairs:           \t"+mergedReadCount+" ("+Tools.format("%.2f%%)",mergedReadCount*200.0/readsProcessed));
+			tsw.println("Merged Bases:           \t"+mergedBaseCount+" ("+Tools.format("%.2f%%)",mergedBaseCount*100.0/basesProcessed));
 		}
 		
 		errorState|=tsw.poisonAndWait();
