@@ -93,7 +93,7 @@ public class TranslateSixFrames {
 			}else if(a.equals("frames")){
 				frames=Integer.parseInt(b);
 				assert(frames>=0 && frames<=6) : "Frames must be in the range of 0 to 6";
-			}else if(parser.in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+			}else if(parser.in1==null && i==0 && Tools.looksLikeInputStream(arg)){
 				parser.in1=arg;
 			}else if(parser.out1==null && i==1 && !arg.contains("=")){
 				parser.out1=arg;
@@ -410,7 +410,7 @@ public class TranslateSixFrames {
 	private PrintStream outstream=System.err;
 	public static boolean verbose=false;
 	public boolean errorState=false;
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	private boolean append=false;
 	private boolean useSharedHeader;
 	
