@@ -259,7 +259,7 @@ public class Unzip {
 	public static boolean verbose=false;
 	public boolean errorState=false;
 	public boolean showSpeed=false;
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	private boolean append=false;
 	
 }
