@@ -1,6 +1,6 @@
 package json;
 
-import java.util.Locale;
+import shared.Tools;
 
 public class JsonLiteral {
 	
@@ -9,7 +9,7 @@ public class JsonLiteral {
 	}
 	
 	public JsonLiteral(double value, int decimals){
-		s=String.format(Locale.ROOT, "%."+decimals+"f", value);
+		s=Tools.format("%."+decimals+"f", value);
 	}
 	
 	@Override
