@@ -5,12 +5,11 @@ import java.io.PrintStream;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.BitSet;
-import java.util.Locale;
 import java.util.concurrent.atomic.AtomicLong;
 
 import bloom.KCountArray;
-import bloom.ReadCounter;
 import bloom.KmerCountAbstract;
+import bloom.ReadCounter;
 import fileIO.ByteStreamWriter;
 import jgi.CallPeaks;
 import shared.Shared;
@@ -396,7 +395,7 @@ public abstract class AbstractKmerTableSet {
 					bsw.print('\t').print(logScale[i]);
 				}
 				if(gcHist!=null){
-					bsw.print(String.format(Locale.ROOT, "\t%.2f", 100f*gcHist[i]));
+					bsw.print(Tools.format("\t%.2f", 100f*gcHist[i]));
 				}
 				bsw.print('\n');
 			}
@@ -492,7 +491,7 @@ public abstract class AbstractKmerTableSet {
 	/** Print messages to this stream */
 	public static PrintStream outstream=System.err;
 	/** Permission to overwrite existing files */
-	public static boolean overwrite=false;
+	public static boolean overwrite=true;
 	/** Permission to append to existing files */
 	public static boolean append=false;
 	/** Print speed statistics upon completion */
