@@ -17,7 +17,6 @@ import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Primes;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -29,6 +28,7 @@ import structures.ByteBuilder;
 import structures.IntList;
 import structures.ListNum;
 import structures.LongList;
+import tracker.ReadStats;
 import ukmer.Kmer;
 
 
@@ -298,6 +298,9 @@ public class KmerTableSet extends AbstractKmerTableSet {
 		int mask=(amino ? 31 : 3);
 		coreMask=(AbstractKmerTableSet.MASK_CORE ? ~(((-1L)<<(bitsPerBase*(k_-1)))|mask) : -1L);
 		
+		middleMask=AbstractKmerTableSet.MASK_MIDDLE ? AbstractKmerTable.makeMiddleMask(k, amino) : -1L;
+		cmMask=coreMask&middleMask;
+		
 		if(k<1 || k>31){throw new RuntimeException("\nk needs an integer value from 1 to 31, such as k=27.  Default is 31.\n");}
 		
 		if(initialSize<1){
@@ -476,6 +479,7 @@ public class KmerTableSet extends AbstractKmerTableSet {
 		public LoadThread(ConcurrentReadInputStream cris_){
 			cris=cris_;
 			table=new HashBuffer(tables, buflen, k, false, true);
+			//TODO: handle MASK_MIDDLE in this thread.
 		}
 		
 		@Override
@@ -1626,8 +1630,10 @@ public class KmerTableSet extends AbstractKmerTableSet {
 	public final long toValue(long kmer, long rkmer){
 //		long value=(rcomp ? Tools.max(kmer, rkmer) : kmer);
 //		return value;
-		if(!rcomp){return kmer;}
-		final long a=kmer&coreMask, b=rkmer&coreMask;
+		if(!rcomp){return kmer&middleMask;}
+		final long a=kmer&cmMask, b=rkmer&cmMask;
+		kmer&=middleMask;//Usually -1, so it does nothing.
+		rkmer&=middleMask;
 		return a>b ? kmer : a<b ? rkmer : Tools.max(kmer, rkmer);
 	}
 	
@@ -1657,7 +1663,7 @@ public class KmerTableSet extends AbstractKmerTableSet {
 	public boolean rcomp(){return rcomp;}
 	
 	public final int kmerToWay(final long kmer){
-		final int way=(int)((kmer&coreMask)%ways);
+		final int way=(int)((kmer&cmMask)%ways);
 		return way;
 	}
 	
@@ -1690,6 +1696,8 @@ public class KmerTableSet extends AbstractKmerTableSet {
 	public final int k2;
 	
 	public final long coreMask;
+	public final long middleMask;
+	public final long cmMask;
 	
 	/** Look for reverse-complements as well as forward kmers.  Default: true */
 	private final boolean rcomp;
