@@ -446,7 +446,7 @@ public class TableLoaderLockFree {
 					long x=AminoAcid.baseToNumber[b];
 					long x2=AminoAcid.baseToComplementNumber[b];
 					kmer=((kmer<<2)|x)&mask;
-					rkmer=(rkmer>>>2)|(x2<<shift2);
+					rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 					if(x<0){len=0; rkmer=0;}else{len++;}
 					if(verbose){outstream.println("Scanning1 i="+i+", kmer="+kmer+", rkmer="+rkmer+", bases="+new String(bases, Tools.max(0, i-k2), Tools.min(i+1, k)));}
 					if(len>=k){
@@ -467,7 +467,7 @@ public class TableLoaderLockFree {
 					long x=AminoAcid.baseToNumber[b];
 					long x2=AminoAcid.baseToComplementNumber[b];
 					kmer=((kmer<<2)|x)&mask;
-					rkmer=(rkmer>>>2)|(x2<<shift2);
+					rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 					if(x<0){len=0; rkmer=0;}else{len++;}
 					if(verbose){outstream.println("Scanning2 i="+i+", kmer="+kmer+", rkmer="+rkmer+", bases="+new String(bases, Tools.max(0, i-k2), Tools.min(i+1, k)));}
 					if(len>=k){
@@ -566,7 +566,7 @@ public class TableLoaderLockFree {
 			final long added;
 			if(hdist==0){
 				final long key=toValue(kmer, rkmer, kmask0);
-				if(speed>0 && ((key/WAYS)&15)<speed){return 0;}
+				if(failsSpeed(key)){return 0;}
 				if(key%WAYS!=tnum){return 0;}
 				if(verbose){outstream.println("addToMap_B: "+AminoAcid.kmerToString(kmer&~kMasks[len], len)+" = "+key);}
 				if(storeMode==SET_IF_NOT_PRESENT){
@@ -697,6 +697,14 @@ public class TableLoaderLockFree {
 		return (value&middleMask)|lengthMask;
 	}
 	
+	final boolean passesSpeed(long key){
+		return speed<1 || ((key&Long.MAX_VALUE)%17)>=speed;
+	}
+	
+	final boolean failsSpeed(long key){
+		return speed>0 && ((key&Long.MAX_VALUE)%17)<speed;
+	}
+	
 	/*--------------------------------------------------------------*/
 	/*----------------            Fields            ----------------*/
 	/*--------------------------------------------------------------*/
@@ -768,7 +776,7 @@ public class TableLoaderLockFree {
 	/** Attempt to match kmers shorter than normal k on read ends when doing kTrimming. */
 	private final boolean useShortKmers;
 	
-	/** Fraction of kmers to skip, 0 to 15 out of 16 */
+	/** Fraction of kmers to skip, 0 to 16 out of 17 */
 	private final int speed;
 	
 	/*--------------------------------------------------------------*/
