@@ -165,7 +165,7 @@ public class TableReader {
 			long x=AminoAcid.baseToNumber0[b];
 			long x2=AminoAcid.baseToComplementNumber0[b];
 			kmer=((kmer<<2)|x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			if(b=='N' && forbidNs){len=0; rkmer=0;}else{len++;}
 			if(verbose){outstream.println("Scanning6 i="+i+", kmer="+kmer+", rkmer="+rkmer+", bases="+new String(bases, Tools.max(0, i-k2), Tools.min(i+1, k)));}
 			if(len>=minlen2 && i>=minlen){
@@ -214,7 +214,7 @@ public class TableReader {
 			long x=AminoAcid.baseToNumber0[b];
 			long x2=AminoAcid.baseToComplementNumber0[b];
 			kmer=((kmer<<2)|x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			if(b=='N' && forbidNs){len=0; rkmer=0;}else{len++;}
 			if(verbose){outstream.println("Scanning6 i="+i+", kmer="+kmer+", rkmer="+rkmer+", bases="+new String(bases, Tools.max(0, i-k2), Tools.min(i+1, k)));}
 			if(len>=minlen2 && i>=minlen){
@@ -289,7 +289,7 @@ public class TableReader {
 			long x=AminoAcid.baseToNumber0[b];
 			long x2=AminoAcid.baseToComplementNumber0[b];
 			kmer=((kmer<<2)|x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			if(b=='N' && forbidNs){len=0; rkmer=0;}else{len++;}
 			if(verbose){outstream.println("Scanning3 i="+i+", kmer="+kmer+", rkmer="+rkmer+", len="+len+", bases="+new String(bases, Tools.max(0, i-k2), Tools.min(i+1, k)));}
 			if(len>=minlen2 && i>=minlen){
