@@ -550,6 +550,72 @@ public class CellNet implements Cloneable, Comparable<CellNet> {
 			}
 		}
 		//assert(check());
+		if(normalization_factor>0.0001f) {
+			if(NORMALIZE_BIAS) {normalizeBiasDense();}
+			if(NORMALIZE_WEIGHTS) {normalizeWeightsDense();}
+			normalization_factor*=normalization_shrink_rate;
+		}
+	}
+	
+	/**
+	 * Normalizes the biases of the dense layers in the network.
+	 */
+	public void normalizeBiasDense() {
+		FloatList list=new FloatList();
+		for(int lnum=layers-2; lnum>0; lnum--) {
+			list.clear();
+			Cell[] layer=net[lnum];
+			for(int i=0; i<layer.length; i++){
+				Cell c=layer[i];
+				list.add(c.bias);
+			}
+			float mean=(float)list.mean();
+			float stdev=list.stdev();
+			if(stdev<0.001f) {stdev=0.001f;}//Avoid division by zero
+			float invStdev=1f/stdev;
+			for(int i=0; i<layer.length; i++){
+				Cell c=layer[i];
+				float f=c.bias;
+				float target=(f-mean)*invStdev;
+				f=(1f-normalization_factor)*f+normalization_factor*target;
+				c.bias=f;
+			}
+		}
+	}
+	
+	public void normalizeWeightsDense() {
+		FloatList list=new FloatList();
+		for(int layer=0; layer<weightsIn.length-1; layer++) {
+			float[][] weightsInL=weightsIn[layer+1];
+			normalizeDense(weightsInL, list);
+		}
+		transposeDense();
+	}
+	
+	public void normalizeDense(float[][] weights, FloatList list) {
+		if(weights==null) {return;}
+		list.clear();
+		for(float[] array : weights) {
+			for(float f : array) {
+				if(f!=0) {
+					list.add(f);
+				}
+			}
+		}
+		float mean=(float)list.mean();
+		float stdev=list.stdev();
+		if(stdev<0.001f) {stdev=0.001f;}
+		float invStdev=1f/stdev;
+		for(float[] array : weights) {
+			for(int i=0; i<array.length; i++) {
+				float f=array[i];
+				if(f!=0) {
+					float target=(f-mean)*invStdev;
+					f=(1f-normalization_factor)*f+normalization_factor*target;
+					array[i]=(Math.abs(f)<1e-12f) ? 1e-12f : f;
+				}
+			}
+		}
 	}
 	
 	void transpose() {
@@ -1038,6 +1104,10 @@ public class CellNet implements Cloneable, Comparable<CellNet> {
 	/*--------------------------------------------------------------*/
 	
 	public static final boolean SPECIAL_FMA=true;//~20% faster when true, but needs ml.Cell class
+	public static boolean NORMALIZE_BIAS=false;
+	public static boolean NORMALIZE_WEIGHTS=false;
+	public static float normalization_factor=0.5f;
+	public static float normalization_shrink_rate=0.999f;
 	public static boolean CONCISE=true;
 	public static boolean DENSE=true;
 	public static boolean OUT_HEX=false;
