@@ -856,7 +856,7 @@ public class NetFilter implements Accumulator<NetFilter.ProcessThread> {
 	/** True if an error was encountered */
 	public boolean errorState=false;
 	/** Overwrite existing output files */
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	/** Append to existing output files */
 	private boolean append=false;
 	/** Reads are output in input order */
