@@ -2,11 +2,16 @@ package ml;
 
 public class Seed implements Comparable<Seed>{
 
-	Seed(long netSeed_, long annealSeed_, float pivot_){
+	Seed(long netSeed_, float pivot_){
 		netSeed=netSeed_;
-		annealSeed=annealSeed_;
 		pivot=pivot_;
 	}
+
+//	Seed(long netSeed_, long annealSeed_, float pivot_){
+//		netSeed=netSeed_;
+//		annealSeed=annealSeed_;
+//		pivot=pivot_;
+//	}
 	
 	@Override
 	public int compareTo(Seed s) {
@@ -16,9 +21,9 @@ public class Seed implements Comparable<Seed>{
 		if(netSeed!=s.netSeed) {
 			return netSeed>s.netSeed ? 1 : -1;
 		}
-		if(annealSeed!=s.annealSeed) {
-			return annealSeed>s.annealSeed ? 1 : -1;
-		}
+//		if(annealSeed!=s.annealSeed) {
+//			return annealSeed>s.annealSeed ? 1 : -1;
+//		}
 		return 0;
 	}
 
@@ -28,16 +33,16 @@ public class Seed implements Comparable<Seed>{
 	}
 	
 	public boolean equals(Seed s) {
-		return s.netSeed==netSeed && s.annealSeed==annealSeed;
+		return s.netSeed==netSeed;// && s.annealSeed==annealSeed;
 	}
 	
 	@Override
 	public String toString() {
-		return netSeed+", "+annealSeed+", "+pivot;
+		return netSeed+/*", "+annealSeed+*/", "+pivot;
 	}
 	
 	final long netSeed;
-	final long annealSeed;
+//	final long annealSeed;
 	final float pivot;
 	
 }
