@@ -205,6 +205,12 @@ public class Trainer implements Accumulator<WorkerThread> {
 				}else{
 					balance=Float.parseFloat(b);
 				}
+			}else if(a.equals("normalizebias")){
+				CellNet.NORMALIZE_BIAS=Parse.parseBoolean(b);
+			}else if(a.equals("normalizeweights")){
+				CellNet.NORMALIZE_WEIGHTS=Parse.parseBoolean(b);
+			}else if(a.equals("normalize")){
+				CellNet.NORMALIZE_BIAS=CellNet.NORMALIZE_WEIGHTS=Parse.parseBoolean(b);
 			}else if(a.equals("concise")){
 				CellNet.CONCISE=Parse.parseBoolean(b);
 			}else if(a.equals("dense")){
