@@ -8,6 +8,7 @@ import java.util.concurrent.ArrayBlockingQueue;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
 
 import shared.Tools;
+import structures.FloatList;
 
 public class TrainerThread extends Thread {
 	
@@ -15,8 +16,7 @@ public class TrainerThread extends Thread {
 		parent=parent_;
 		net0=net0_;
 		net00=net0.copy(false);
-		annealSeed=net0.annealSeed;
-		randyAnneal=new Random(annealSeed);
+		randyAnneal=new Random(net00.seed);
 		
 		jobsPerEpoch=parent.jobsPerEpoch;
 		
@@ -79,6 +79,7 @@ public class TrainerThread extends Thread {
 		}
 		
 		setLock=parent.useSetLock ? new ReentrantReadWriteLock() : null;
+		flist=new FloatList(Tools.max(256, parent.data.maxSubsetSize()));
 	}
 	
 	@Override
@@ -141,7 +142,7 @@ public class TrainerThread extends Thread {
 			}
 			
 			if(validated) {
-				reviseCutoff();
+				calcNetStats(!training || Trainer.setCutoffForEvaluation);
 				parent.compareWithBest(net0.copy(false));
 			}
 			
@@ -151,7 +152,8 @@ public class TrainerThread extends Thread {
 		return currentEpoch;
 	}
 	
-	private void dump(SampleSet data){
+	@Deprecated
+	private void dump_old(SampleSet data){
 //		System.err.println("Before: samples="+data.samples.length);
 //		System.err.println("Before: subsets="+parent.subsets);
 //		System.err.println("Before: fpeMult="+fpeMult);
@@ -195,7 +197,7 @@ public class TrainerThread extends Thread {
 		if(parent.partialDumpFraction<1) {
 			float x=0;
 			final float y=1-parent.partialDumpFraction;
-			for(int i=pcount; i<plist.size(); i+=1, x+=y){//Retain only some element for the low-error samples
+			for(int i=pcount; i<plist.size(); i+=1, x+=y){//Retain only some elements for the low-error samples
 				if(x>=1){
 					list.add(plist.get(i));
 					x-=1;
@@ -255,6 +257,97 @@ public class TrainerThread extends Thread {
 
 	}
 	
+	private void dump(SampleSet data){
+		final float retainFraction=(1-dumpRate);//Fraction completely retained
+		final float retainFraction2=(parent.partialDumpFraction<1 ? 1-parent.partialDumpFraction*dumpRate : retainFraction);//Total fraction retained, including the partials
+		runTestingInterval(data.samples);
+		ArrayList<Sample> plist=new ArrayList<Sample>();
+		ArrayList<Sample> nlist=new ArrayList<Sample>();
+		
+//		System.err.println("len="+data.samples.length+", ret="+retainFraction+", +ret2="+retainFraction2);
+		
+		for(Sample s : data.samples) {
+			s.setPivot();//Necessary because the assertion failed once.  Usually works, though.
+			assert(s.checkPivot()) : s.pivot+", "+s.calcPivot(); //TODO: Slow
+			if(s.positive) {plist.add(s);}
+			else {nlist.add(s);}
+		}
+//		
+		
+		final int minRetainCount=(int)Math.ceil(Tools.max(plist.size(), nlist.size())*retainFraction);
+		final int pcount=Tools.mid(minRetainCount, (int)Math.ceil(plist.size()*retainFraction), plist.size());
+		final int ncount=Tools.mid(minRetainCount, (int)Math.ceil(nlist.size()*retainFraction), nlist.size());
+		ArrayList<Sample> list=new ArrayList<Sample>(parent.partialDumpFraction<1 ? 
+				data.samples.length : pcount+ncount);
+//		System.err.println("samples="+data.samples.length+
+//				", pcount="+pcount+"/"+plist.size()+", ncount="+ncount+"/"+nlist.size());
+
+		dumpList(plist, list, pcount);
+		dumpList(nlist, list, ncount);
+		
+//		System.err.println("len="+list.size());
+		assert(data.samples.length>=list.size());
+//		System.err.println(data.samples.length+", "+list.size()+", "+pcount+", "+ncount);
+		final float sampleRatio=data.samples.length/(float)Tools.max(1, list.size());
+		Collections.shuffle(list, new Random(SampleSet.shuffleSeed+1));
+		data.samples=list.toArray(new Sample[0]);
+//		System.err.println("samples="+data.samples.length);
+		data.samplesSortedByResult=data.samples.clone();
+		data.numPositive=pcount;
+		data.numNegative=ncount;
+		
+		
+		int subsets;
+		boolean shrinkSubsets=parent.shrinkSubsets;
+		//Note: shrinkSubsets is hard-coded as TRUE because it works better
+		if(!shrinkSubsets){//This method of reducing subsets did not improve speed much.
+			final int setsize=parent.setsize;
+			subsets=(int)Math.ceil(parent.subsets*retainFraction2);
+			if(setsize>0) {
+				assert(setsize>=100) : "Setsize should be at least 100";
+				subsets=Tools.max(1, data.samples.length/setsize);
+				//			System.err.println("Data was organized into "+subsets+(subsets==1 ? " set." : " sets."));
+			}
+			subsets=Tools.mid(1, subsets, data.samples.length);
+			fpeMult=1.0f;
+		}else{//This method makes subsets smaller for less sorting, but also does not improve speed much (~10%).  Messes up convergence though.
+			subsets=parent.subsets;
+			fpeMult=sampleRatio;//1f/retainFraction2;
+			assert(fpeMult>=1) : fpeMult;
+//			System.err.println(fpeMult);
+//			System.err.println(1f/retainFraction2);
+		}
+		data.makeSubsets(subsets);
+		
+//		System.err.println("retainFraction2="+retainFraction2);
+//		System.err.println("After:  samples="+data.samples.length);
+//		System.err.println("After:  subsets="+subsets);
+//		System.err.println("After:  fpeMult="+fpeMult);
+//		System.err.println("After:  subslen="+data.currentSubset(currentEpoch).samples.length);
+//		System.err.println("After:  fpe=    "+calcFractionPerEpoch());
+//		System.err.println("After:  active ="+(int)(data.currentSubset(currentEpoch).samples.length*calcFractionPerEpoch()));
+
+	}
+	
+	private void dumpList(ArrayList<Sample> inList, ArrayList<Sample> outList, int retainCount) {
+		Collections.sort(inList);
+		for(int i=0; i<retainCount; i++){
+			outList.add(inList.get(i));
+			assert(i==0 || inList.get(i).pivot<=inList.get(i-1).pivot);
+		}
+		
+		if(parent.partialDumpFraction<1) {
+			float x=0;
+			final float y=1-parent.partialDumpFraction;
+			for(int i=retainCount; i<inList.size(); i+=1, x+=y){//Retain only some elements for the low-error samples
+				if(x>=1){
+					outList.add(inList.get(i));
+					x-=1;
+				}
+			}
+		}
+	}
+	
 	private void runTrainingInterval() {
 //		synchronized(LOCK) {
 		
@@ -291,7 +384,7 @@ public class TrainerThread extends Thread {
 			mergeStats(samplesThisEpoch);
 			//		errorRate=weightedErrorRate;
 			mprof.log();//4: 154/143
-
+			
 			net0.applyChanges(samplesThisEpoch, (float)alpha);
 			mprof.log();//5: 2356/2134
 			anneal();
@@ -665,16 +758,22 @@ public class TrainerThread extends Thread {
 		currentSamples=currentSubset.samples;
 		samplesThisEpoch=calcSamplesThisEpoch(currentSubset);
 		assert(setLock==null || setLock.writeLock().isHeldByCurrentThread());
-		final int mod8=currentEpoch&7, mod4=currentEpoch&4;
+		final int mod8=currentEpoch&7, mod64=currentEpoch&7;
 		if(shuffleSubset && mod8==Trainer.SHUFFLEMOD) {
 			currentSubset.shuffle();
 			return;
 		}else if(!sort || sortInThread) {
 			return;
-		}else if(sortAll || mod4==1 || mod8==5) {
+		}else if(mod64==5) {
 			currentSubset.sortSamples(1f, allowMTSort);
+		}else if(sortAll || mod8==5) {
+//			currentSubset.sortSamples(1f, allowMTSort);
+			currentSubset.sortSamples2(1f, samplesThisEpoch, allowMTSort, flist);
+		}else if(mod8==1) {
+			currentSubset.sortSamples2(fractionPerEpoch0*6, samplesThisEpoch, allowMTSort, flist);
 		}else if(mod8==3 || mod8==7){
-			currentSubset.sortSamples(fractionPerEpoch0*3, allowMTSort);
+//			currentSubset.sortSamples(fractionPerEpoch0*3, allowMTSort);
+			currentSubset.sortSamples2(fractionPerEpoch0*3, samplesThisEpoch, allowMTSort, flist);
 		}
 	}
 	
@@ -715,11 +814,16 @@ public class TrainerThread extends Thread {
 		setNetStats(net0);
 	}
 	
-	void reviseCutoff() {
+	void calcNetStats(boolean retainOldCutoff) {
 		
 		SampleSet set=validateSet;
 		if(validateThisEpoch){
-			if(crossoverFpMult>0) {
+			if(retainOldCutoff) {
+				set.sortByValue();
+				lastCutoff=net0.cutoff;
+				fpRate=set.calcFPRFromCutoff(lastCutoff);
+				fnRate=set.calcFNRFromCutoff(lastCutoff);
+			}else if(crossoverFpMult>0) {
 				set.sortByValue();
 				lastCutoff=set.calcCutoffFromCrossover(crossoverFpMult);
 				fpRate=set.calcFPRFromCutoff(lastCutoff);
@@ -744,6 +848,7 @@ public class TrainerThread extends Thread {
 			tpRate=(set.numPositive/(double)set.samples.length)-fnRate;
 			tnRate=(set.numNegative/(double)set.samples.length)-fpRate;
 		}else {
+			//Not sure what to do here if retainOldCutoff=true
 			lastCutoff=Trainer.cutoffForEvaluation;
 		}
 		
@@ -762,7 +867,7 @@ public class TrainerThread extends Thread {
 		net.alpha=(float) alpha;
 		net.annealStrength=(float) annealStrength;
 		net.epoch=currentEpoch;
-		net.cutoff=(float) lastCutoff;
+		if(lastCutoff!=999) {net.setCutoff((float)lastCutoff);}
 	}
 	
 	/*--------------------------------------------------------------*/
@@ -784,6 +889,7 @@ public class TrainerThread extends Thread {
 	private SampleSet data;
 	private SampleSet validateSet;
 	
+	private final FloatList flist;
 	private Subset currentSubset;
 	private Sample[] currentSamples;
 	
@@ -791,7 +897,7 @@ public class TrainerThread extends Thread {
 
 	/*--------------------------------------------------------------*/
 	
-	private final long annealSeed;
+//	private final long annealSeed;
 	private final int jobsPerEpoch;
 //	private final int jobsPerBatch; //TODO: Change threads to this.
 	
@@ -871,7 +977,7 @@ public class TrainerThread extends Thread {
 	double weightedErrorRate=999f;
 	
 	double fpRate=0, fnRate=0, tpRate, tnRate;
-	double lastCutoff=1.0f;
+	double lastCutoff=999f;
 	
 	double annealStrength;
 	double annealDropoff;
