@@ -11,12 +11,12 @@ import fileIO.TextStreamWriter;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Timer;
 import stream.ConcurrentReadInputStream;
 import stream.FASTQ;
 import stream.Read;
 import structures.ListNum;
+import tracker.ReadStats;
 
 /**
  * @author Brian Bushnell
