@@ -41,7 +41,7 @@ public class MergeReadsAndGenome {
 		String out=null;
 		long reads=-1;
 		int readlen=300;
-		boolean overwrite=false;
+		boolean overwrite=true;
 		boolean append=false;
 		int sequentialOverlap=5;
 		boolean sequentialStrandAlt=true;
