@@ -1,7 +1,6 @@
 package pacbio;
 
 import java.util.ArrayList;
-import java.util.Locale;
 
 import fileIO.TextFile;
 import fileIO.TextStreamWriter;
@@ -64,7 +63,7 @@ public class ProcessStackedSitesNormalized {
 //				throw new RuntimeException("Deprecated - use minfractionfromreadends instead.");
 				int x=Integer.parseInt(b);
 				float f=x/((150-INTERVAL)*.5f);
-				System.err.println("Warning - mindistfromreadends is deprecated.  Setting minfractionfromreadends = "+String.format(Locale.ROOT, "%.3f",f));
+				System.err.println("Warning - mindistfromreadends is deprecated.  Setting minfractionfromreadends = "+Tools.format("%.3f",f));
 				MIN_FRACTION_FROM_READ_ENDS=f;
 			}else if(a.equals("minfractionfromreadends")){
 				MIN_FRACTION_FROM_READ_ENDS=Float.parseFloat(b);
@@ -75,8 +74,8 @@ public class ProcessStackedSitesNormalized {
 		
 		process(infile, outfile);
 		
-		System.out.println("Sites In:\t"+sitesIn+"    \t"+String.format(Locale.ROOT, "%.3f%% correct",correctIn*100d/sitesIn));
-		System.out.println("Sites Out:\t"+sitesOut+"    \t"+String.format(Locale.ROOT, "%.3f%% correct",correctOut*100d/sitesOut));
+		System.out.println("Sites In:\t"+sitesIn+"    \t"+Tools.format("%.3f%% correct",correctIn*100d/sitesIn));
+		System.out.println("Sites Out:\t"+sitesOut+"    \t"+Tools.format("%.3f%% correct",correctOut*100d/sitesOut));
 		t.stop();
 		System.out.println("Time: \t"+t);
 	}
