@@ -1,7 +1,6 @@
 package pacbio;
 
 import java.util.ArrayList;
-import java.util.Locale;
 
 import aligner.MultiStateAligner9PacBioAdapter;
 import aligner.MultiStateAligner9PacBioAdapter2;
@@ -13,7 +12,6 @@ import shared.KillSwitch;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -22,6 +20,7 @@ import stream.ConcurrentReadOutputStream;
 import stream.FastaReadInputStream;
 import stream.Read;
 import structures.ListNum;
+import tracker.ReadStats;
 
 /**
  * Increased sensitivity to nearby adapters.
@@ -250,15 +249,15 @@ public class RemoveAdapters2 {
 		System.out.println("Bad reads:               \t"+badReadsFound+"  \t("+totalAdapters+" adapters)");
 		System.out.println("Plus adapters:           \t"+plusAdaptersFound);
 		System.out.println("Minus adapters:          \t"+minusAdaptersFound);
-		System.out.println("Adapters per megabase:   \t"+String.format(Locale.ROOT, "%.3f",totalAdapters*1000000f/basesIn));
+		System.out.println("Adapters per megabase:   \t"+Tools.format("%.3f",totalAdapters*1000000f/basesIn));
 		if(readsOut>0){System.out.println("Reads Out:               \t"+readsOut+"  \t("+basesOut+" bases, avg length "+(basesOut/readsOut)+")");}
 		System.out.println();
 		if(truepositive>0 || truenegative>0 || falsepositive>0 || falsenegative>0){
 			System.out.println("Adapters Expected:       \t"+expected);
-			System.out.println("True Positive:           \t"+truepositive+" \t"+String.format(Locale.ROOT, "%.3f%%", truepositive*100f/expected));
-			System.out.println("True Negative:           \t"+truenegative+" \t"+String.format(Locale.ROOT, "%.3f%%", truenegative*100f/unexpected));
-			System.out.println("False Positive:          \t"+falsepositive+" \t"+String.format(Locale.ROOT, "%.3f%%", falsepositive*100f/unexpected));
-			System.out.println("False Negative:          \t"+falsenegative+" \t"+String.format(Locale.ROOT, "%.3f%%", falsenegative*100f/expected));
+			System.out.println("True Positive:           \t"+truepositive+" \t"+Tools.format("%.3f%%", truepositive*100f/expected));
+			System.out.println("True Negative:           \t"+truenegative+" \t"+Tools.format("%.3f%%", truenegative*100f/unexpected));
+			System.out.println("False Positive:          \t"+falsepositive+" \t"+Tools.format("%.3f%%", falsepositive*100f/unexpected));
+			System.out.println("False Negative:          \t"+falsenegative+" \t"+Tools.format("%.3f%%", falsenegative*100f/expected));
 		}
 		
 	}
@@ -624,7 +623,7 @@ public class RemoveAdapters2 {
 
 	public static boolean DONT_OUTPUT_BROKEN_READS;
 	/** Permission to overwrite existing files */
-	private static boolean overwrite=false;
+	private static boolean overwrite=true;
 	/** Permission to append to existing files */
 	private static boolean append=false;
 	private static int THREADS=Shared.LOGICAL_PROCESSORS;
