@@ -1,7 +1,6 @@
 package pacbio;
 
 import java.util.ArrayList;
-import java.util.Locale;
 
 import align2.MultiStateAligner9PacBio;
 import aligner.MultiStateAligner9PacBioAdapter;
@@ -229,10 +228,10 @@ public class RemoveAdapters3 {
 		System.out.println();
 		if(truepositive>0 || truenegative>0 || falsepositive>0 || falsenegative>0){
 			System.out.println("Adapters Expected:       \t"+expected);
-			System.out.println("True Positive:           \t"+truepositive+" \t"+String.format(Locale.ROOT, "%.3f%%", truepositive*100f/expected));
-			System.out.println("True Negative:           \t"+truenegative+" \t"+String.format(Locale.ROOT, "%.3f%%", truenegative*100f/unexpected));
-			System.out.println("False Positive:          \t"+falsepositive+" \t"+String.format(Locale.ROOT, "%.3f%%", falsepositive*100f/unexpected));
-			System.out.println("False Negative:          \t"+falsenegative+" \t"+String.format(Locale.ROOT, "%.3f%%", falsenegative*100f/expected));
+			System.out.println("True Positive:           \t"+truepositive+" \t"+Tools.format("%.3f%%", truepositive*100f/expected));
+			System.out.println("True Negative:           \t"+truenegative+" \t"+Tools.format("%.3f%%", truenegative*100f/unexpected));
+			System.out.println("False Positive:          \t"+falsepositive+" \t"+Tools.format("%.3f%%", falsepositive*100f/unexpected));
+			System.out.println("False Negative:          \t"+falsenegative+" \t"+Tools.format("%.3f%%", falsenegative*100f/expected));
 		}
 		
 	}
