@@ -181,7 +181,7 @@ public class SplitOffPerfectContigs {
 		
 		if(BREAK_BAD_CONTIGS){
 			for(Range r : list){
-				if(r.length>=minContig){
+				if(r.length()>=minContig){
 //					int uncovered=0;
 //					for(int i=r.a; i<=r.b; i++){
 //						int cov=ca.get(i);
@@ -241,7 +241,8 @@ public class SplitOffPerfectContigs {
 		int badlen=0;
 		
 		for(Range r : list){
-			if(r.length>=minContig){
+			final int length=r.length();
+			if(length>=minContig){
 				int minCov=Integer.MAX_VALUE;
 				for(int i=r.a+tipbuffer; i<=r.b-tipbuffer; i++){
 					minCov=Tools.min(minCov, ca.get(i));
@@ -261,7 +262,7 @@ public class SplitOffPerfectContigs {
 					}
 				}else{
 					bad.add(r);
-					badlen+=r.length+N_PAD_LENGTH;
+					badlen+=length+N_PAD_LENGTH;
 					if(verbose){
 						StringBuilder sb0=new StringBuilder(), sb1=new StringBuilder(), sb2=new StringBuilder();
 						for(int i=r.a; i<=r.b; i++){
@@ -276,13 +277,13 @@ public class SplitOffPerfectContigs {
 				}
 			}else{
 				contigsDropped++;
-				basesDropped+=r.length;
+				basesDropped+=length;
 			}
 		}
 		
 		for(Range r : good){
 			contigsWritten++;
-			basesWritten+=r.length;
+			basesWritten+=r.length();
 			String s=cha.getString(r.a, r.b);
 			tsw.print(">"+contig+"\n");
 			contig++;
@@ -299,7 +300,7 @@ public class SplitOffPerfectContigs {
 		}
 		for(Range r : bad){
 			contigsKept++;
-			basesKept+=r.length;
+			basesKept+=r.length();
 			
 			String s=cha.getString(r.a, r.b);
 			for(int i=0; i<s.length(); i++){
