@@ -171,7 +171,7 @@ public class CallGenes extends ProkObject {
 			}else if(a.equals("bins")){
 				geneHistBins=Integer.parseInt(b);
 			}else if(a.equals("binlen") || a.equals("binlength") || a.equals("histdiv")){
-				geneHistBins=Integer.parseInt(b);
+				geneHistDiv=Integer.parseInt(b);
 			}else if(a.equals("printzero") || a.equals("pz")){
 				printZeroCountHist=Parse.parseBoolean(b);
 			}
@@ -684,6 +684,7 @@ public class CallGenes extends ProkObject {
 	/*--------------------------------------------------------------*/
 	
 	public static GeneModel makeMultipassModel(GeneModel pgm0, String fna, String gff, int passes/*, long maxReads*/) {
+		if(passes<2) {return pgm0;}
 		ArrayList<Read> reads=ReadInputStream.toReads(fna, FileFormat.FASTA, -1/*maxReads*/);
 		return makeMultipassModel(pgm0, reads, gff, passes);
 	}
@@ -1188,8 +1189,8 @@ public class CallGenes extends ProkObject {
 	
 	ScoreTracker[] trackers=new ScoreTracker[] {stCdsPass, sttRNA, st16s, st23s, st5s, st18s};
 	
-	private int geneHistBins=2000;
-	private int geneHistDiv=20;
+	private int geneHistBins=1000;
+	private int geneHistDiv=21;
 	private final long[] geneHist;
 	private boolean printZeroCountHist=false;
 	
