@@ -8,6 +8,7 @@ import dna.Data;
 import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -61,9 +62,11 @@ public class PGMTools extends ProkObject {
 				}else if(parseStatic(arg, a, b)){
 					//do nothing
 				}else if(a.equals("allowdupes") || a.equals("allowduplicates") || a.equals("dupes")){
-					allowDupes=Tools.parseBoolean(b);
+					allowDupes=Parse.parseBoolean(b);
+				}else if(a.equals("addcdsonly")){
+					GeneModel.ADD_CDS_ONLY=Parse.parseBoolean(b);
 				}else if(a.equals("verbose")){
-					verbose=Tools.parseBoolean(b);
+					verbose=Parse.parseBoolean(b);
 					ReadWrite.verbose=verbose;
 				}
 
@@ -123,43 +126,43 @@ public class PGMTools extends ProkObject {
 			int x=Integer.parseInt(b);
 			GeneModel.setStopRightOffset(x);
 		}else if(a.equalsIgnoreCase("callcdsonly") || a.equalsIgnoreCase("cdsonly")){
-			callCDS=Tools.parseBoolean(b);
+			callCDS=Parse.parseBoolean(b);
 			calltRNA=call16S=call23S=call5S=call18S=!callCDS;
 		}else if(a.equalsIgnoreCase("call16sonly") || a.equalsIgnoreCase("16sonly")){
-			call16S=Tools.parseBoolean(b);
+			call16S=Parse.parseBoolean(b);
 			calltRNA=call23S=call5S=call18S=callCDS=!call16S;
 		}else if(a.equalsIgnoreCase("call23sonly") || a.equalsIgnoreCase("23sonly")){
-			call23S=Tools.parseBoolean(b);
+			call23S=Parse.parseBoolean(b);
 			calltRNA=call16S=call5S=call18S=callCDS=!call23S;
 		}else if(a.equalsIgnoreCase("call5sonly") || a.equalsIgnoreCase("5sonly")){
-			call5S=Tools.parseBoolean(b);
+			call5S=Parse.parseBoolean(b);
 			calltRNA=call16S=call23S=call18S=callCDS=!call5S;
 		}else if(a.equalsIgnoreCase("calltrnaonly") || a.equalsIgnoreCase("trnaonly")){
-			calltRNA=Tools.parseBoolean(b);
+			calltRNA=Parse.parseBoolean(b);
 			call16S=call23S=call5S=call18S=callCDS=!calltRNA;
 		}else if(a.equalsIgnoreCase("call18sonly") || a.equalsIgnoreCase("18sonly")){
-			call18S=Tools.parseBoolean(b);
+			call18S=Parse.parseBoolean(b);
 			calltRNA=call16S=call23S=call5S=callCDS=!call18S;
 		}
 		
 		else if(a.equalsIgnoreCase("callcds") || a.equalsIgnoreCase("cds")){
-			callCDS=Tools.parseBoolean(b);
+			callCDS=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("calltrna") || a.equalsIgnoreCase("trna")){
-			calltRNA=Tools.parseBoolean(b);
+			calltRNA=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("call16s") || a.equalsIgnoreCase("16s")){
-			call16S=Tools.parseBoolean(b);
+			call16S=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("call18s") || a.equalsIgnoreCase("18s")){
-			call18S=Tools.parseBoolean(b);
+			call18S=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("call23s") || a.equalsIgnoreCase("23s")){
-			call23S=Tools.parseBoolean(b);
+			call23S=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("call5s") || a.equalsIgnoreCase("5s")){
-			call5S=Tools.parseBoolean(b);
+			call5S=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("callrna") || a.equalsIgnoreCase("rna")){
-			calltRNA=call16S=call18S=call5S=call23S=Tools.parseBoolean(b);
+			calltRNA=call16S=call18S=call5S=call23S=Parse.parseBoolean(b);
 		}
 		
 		else if(a.equalsIgnoreCase("normalize")){
-			normalize=Tools.parseBoolean(b);
+			normalize=Parse.parseBoolean(b);
 		}
 		
 		else{
@@ -191,14 +194,21 @@ public class PGMTools extends ProkObject {
 			for(GeneModel gm : models){
 				if(max!=gm.basesProcessed){
 					double mult=max/(double)(Tools.max(100, gm.basesProcessed));
-					gm.multiplyBy(mult);
+					if(mult!=1) {
+						gm.multiplyBy(mult);
+						gm.stats5S.multiplyBy(0.01);
+//						System.err.println("Multiplied by "+mult);
+					}
 				}
 			}
 		}
 		for(int i=0; i<models.size(); i++){
 			double mult=mults.get(i);
 			GeneModel gm=models.get(i);
-			if(mult!=1){gm.multiplyBy(mult);}
+			if(mult!=1){
+				gm.multiplyBy(mult);
+//				System.err.println("Multiplied by "+mult);
+			}
 		}
 		return models;
 	}
@@ -212,6 +222,31 @@ public class PGMTools extends ProkObject {
 		return pgmSum;
 	}
 	
+	/** The first gene model is the dominant one */
+	public static GeneModel mix(double cdsMult, double rRnaMult, double tRnaMult, boolean normalize, GeneModel...models) {
+		assert(models.length>1);
+		GeneModel pgm0=models[0];
+		GeneModel pgm=new GeneModel(true);
+		pgm.add(pgm0);
+		long max=Tools.max(100, pgm0.basesProcessed);
+		for(int i=1; i<models.length; i++) {
+			GeneModel pgmI=models[i];
+			GeneModel temp=new GeneModel(true);
+			temp.add(pgmI);
+			
+			assert(temp.basesProcessed<max) : temp.basesProcessed+", "+max+"\nThis function is specifically for mixing a small model in with a large model.";
+			double mult=max/(double)(Tools.max(100, temp.basesProcessed));
+			temp.statsCDS.multiplyBy(mult*cdsMult);
+			temp.stats5S.multiplyBy(mult*rRnaMult);
+			temp.stats16S.multiplyBy(mult*rRnaMult);
+			temp.stats18S.multiplyBy(mult*rRnaMult);
+			temp.stats23S.multiplyBy(mult*rRnaMult);
+			temp.statstRNA.multiplyBy(mult*tRnaMult);
+			pgm.add(temp);
+		}
+		return pgm;
+	}
+	
 	public static GeneModel loadAndMerge(ArrayList<String> in) {
 		ArrayList<GeneModel> models=loadModels(in);
 		return mergeModels(models);
