@@ -623,7 +623,7 @@ public class SplitRibo implements Accumulator<SplitRibo.ProcessThread> {
 	/** True if an error was encountered */
 	public boolean errorState=false;
 	/** Overwrite existing output files */
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	/** Append to existing output files */
 	private boolean append=false;
 	/** Reads are output in input order */
