@@ -1110,7 +1110,7 @@ public class RepeatFinder implements Accumulator<RepeatFinder.ProcessThread> {
 	/** True if an error was encountered */
 	public boolean errorState=false;
 	/** Overwrite existing output files */
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	/** Append to existing output files */
 	private boolean append=false;
 	/** Reads are output in input order */
