@@ -1,6 +1,7 @@
 package server;
 
 import java.io.BufferedReader;
+import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
@@ -8,17 +9,28 @@ import java.io.OutputStream;
 import java.net.HttpURLConnection;
 import java.net.InetSocketAddress;
 import java.net.MalformedURLException;
+import java.net.URI;
 import java.net.URL;
 import java.net.URLConnection;
+import java.net.http.HttpClient;
+import java.net.http.HttpRequest;
+import java.net.http.HttpResponse;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.HashMap;
 import java.util.List;
 import java.util.Map.Entry;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ExecutorService;
+import java.util.concurrent.Executors;
+import java.util.concurrent.ThreadFactory;
+import java.util.zip.GZIPOutputStream;
 
 import com.sun.net.httpserver.Headers;
 import com.sun.net.httpserver.HttpExchange;
 
 import fileIO.ReadWrite;
+import shared.Shared;
 import shared.Timer;
 import shared.Tools;
 import structures.ByteBuilder;
@@ -86,10 +98,20 @@ public class ServerTools {
         return bb;
     }
 	
-	
 	/** Send a message to a remote URL, and return the response.
 	 * Set message to null if there is no message. */
 	public static StringNum sendAndReceive(byte[] message, String address){
+		//This may or may not work since the client is statically initialized.
+		if(Shared.javaVersion>=11) {
+			return sendAndReceive_httpClient(message, address);
+		}
+		return sendAndReceive_httpUrlConnection(message, address);
+	}
+	
+	
+	/** Send a message to a remote URL, and return the response.
+	 * Set message to null if there is no message. */
+	public static StringNum sendAndReceive_httpUrlConnection(byte[] message, String address){
     	address=PercentEncoding.commonSymbolToCode(address);
 		URL url=null;
 		InputStream is=null;
@@ -139,6 +161,9 @@ public class ServerTools {
 				responseCode=connection.getResponseCode();
 				if(!suppressErrors && (responseCode<200 || responseCode>299)){
 					System.err.println("Error: Server returned response code "+responseCode);
+//					System.err.println(connection.getRequestProperties());//Can't do this - throws exception while connected
+//					System.err.println(connection.getResponseMessage());
+					new Exception().printStackTrace();
 				}
 			} catch (IOException e) {
 				if(!suppressErrors) {
@@ -158,10 +183,61 @@ public class ServerTools {
 				noInputStream.printStackTrace();
 			}
 		}
-		
+		if(result!=null && result.length()<1) {result=null;}
 		return new StringNum(result, responseCode);
 	}
 	
+	/** Send a message to a remote URL, and return the response.
+	 * Set message to null if there is no message. */
+	public static StringNum sendAndReceive_httpClient(byte[] message, String address){
+    	address=PercentEncoding.commonSymbolToCode(address);
+    	
+		HttpRequest request = HttpRequest.newBuilder()
+				  .uri(URI.create(address))
+//				  .header("Accept-Encoding", "gzip")
+				  .POST(HttpRequest.BodyPublishers.ofByteArray(message))
+				  .build();
+		HttpResponse<String> response=null;
+		
+		int responseCode=-1;
+		String result=null;
+		
+		for(int i=0; i<12 && (result==null || responseCode<200 || responseCode>299); i++) {
+			try {
+				if(i>0) {Tools.sleep(20*i*i);}
+				response = client.send(request, HttpResponse.BodyHandlers.ofString());
+				result=response.body();
+				responseCode=response.statusCode();
+			} catch (IOException | InterruptedException e2) {
+				e2.printStackTrace();
+//				return null;
+			}
+			if(!suppressErrors && (responseCode<200 || responseCode>299) && i>0){
+				System.err.println("Warning: Server returned response code "+responseCode);
+				new Exception().printStackTrace();
+			}
+		}
+		if(result!=null && result.length()<1) {result=null;}
+		return new StringNum(result, responseCode);
+	}
+	
+	public static byte[] gzipCompress(byte[] data) {
+		ByteArrayOutputStream bos = new ByteArrayOutputStream();
+		try {
+			 GZIPOutputStream gzip = new GZIPOutputStream(bos);
+			gzip.write(data);
+		} catch (IOException e) {
+			// TODO Auto-generated catch block
+			e.printStackTrace();
+		}
+        return bos.toByteArray();
+    }
+	
+	public static String determineContentEncoding(
+	        HttpResponse<?> httpResponse) {
+	    return httpResponse.headers().firstValue("Content-Encoding").orElse("");
+	}
+	
 	
 	/** Send a message to a remote URL, and return the response.
 	 * Set message to null if there is no message. */
@@ -224,6 +300,9 @@ public class ServerTools {
 				responseCode=connection.getResponseCode();
 				if(!suppressErrors && (responseCode<200 || responseCode>299)){
 					System.err.println("Error: Server returned response code "+responseCode);
+//					System.err.println(connection.getRequestProperties());//Can't do this - throws exception while connected
+//					System.err.println(connection.getResponseMessage());
+					new Exception().printStackTrace();
 				}
 			} catch (IOException e) {
 				if(!suppressErrors) {
@@ -592,4 +671,31 @@ public class ServerTools {
 	/** Don't print caught exceptions */
 	public static boolean suppressErrors=false;
 	
+	private static HttpClient client;
+	static{
+		try {
+
+			//Without make the threads Daemons the process won't terminate
+			ThreadFactory daemonThreadFactory = new ThreadFactory() {
+				public Thread newThread(Runnable r) {
+					Thread t = new Thread(r);
+					t.setDaemon(true);
+					return t;
+				}
+			};
+
+			ExecutorService executor = Executors.newFixedThreadPool(4, daemonThreadFactory);
+//			ExecutorService executor = Executors.newFixedThreadPool(8);
+	        client = HttpClient.newBuilder()
+	                .version(HttpClient.Version.HTTP_2)
+	                .executor(executor)
+	                .build();
+			
+//			client=HttpClient.newHttpClient();
+		} catch (Throwable e) {
+			System.err.println("You may need a more recent version of Java, specifically, 11 or higher.  Your version: "+Shared.javaVersion);
+			e.printStackTrace();
+		}
+	}
+	
 }
