@@ -617,6 +617,8 @@ public class Parse {
 			return "\"";
 		}else if(b.equalsIgnoreCase("singlequote") || b.equalsIgnoreCase("apostrophe")){
 			return "'";
+		}else if(b.equalsIgnoreCase("underscore")){
+			return "_";
 		}
 		
 		//Java meta characters
