@@ -1074,6 +1074,8 @@ public class Parser {
 			SamLine.MAKE_MD_TAG=Parse.parseBoolean(b);
 		}else if(a.equals("idtag")){
 			SamLine.MAKE_IDENTITY_TAG=Parse.parseBoolean(b);
+		}else if(a.equals("mateqtag")){
+			SamLine.MAKE_MATEQ_TAG=Parse.parseBoolean(b);
 		}else if(a.equals("xmtag") || a.equals("xm")){
 			SamLine.MAKE_XM_TAG=Parse.parseBoolean(b);
 		}else if(a.equals("smtag")){
@@ -1082,6 +1084,8 @@ public class Parser {
 			SamLine.MAKE_AM_TAG=Parse.parseBoolean(b);
 		}else if(a.equals("nmtag")){
 			SamLine.MAKE_NM_TAG=Parse.parseBoolean(b);
+		}else if(a.equals("xttag")){
+			SamLine.MAKE_XT_TAG=Parse.parseBoolean(b);
 		}else if(a.equals("stoptag")){
 			SamLine.MAKE_STOP_TAG=Parse.parseBoolean(b);
 		}else if(a.equals("lengthtag")){
