@@ -277,7 +277,7 @@ public final class TrimRead implements Serializable {
 		
 		if(r.match!=null){
 			return trimReadWithMatch(r, r.samline, leftTrimAmount, rightTrimAmount, minResultingLength, Integer.MAX_VALUE, trimClip);
-		}else if(r.samline!=null){
+		}else if(r.samline!=null && r.samline.cigar!=null && r.samline.cigarContainsOnlyME()){
 			return trimReadWithMatchFast(r, r.samline, leftTrimAmount, rightTrimAmount, minResultingLength);
 		}
 		
@@ -680,7 +680,7 @@ public final class TrimRead implements Serializable {
 	public static int trimReadWithMatch(final Read r, final SamLine sl, 
 			int leftTrimAmount, int rightTrimAmount, int minFinalLength, long scafLen, boolean trimClip){
 		if(r.bases==null || (leftTrimAmount<1 && rightTrimAmount<1 && !trimClip)){return 0;}
-		if(!r.containsNonM() && !trimClip){
+		if(!r.containsNonM() && !trimClip){//TODO: H not handled
 			return trimReadWithMatchFast(r, sl, leftTrimAmount, rightTrimAmount, minFinalLength);
 		}
 		
