@@ -87,7 +87,7 @@ public class Blacklist extends SketchObject {
 		if(!PreParser.silent){System.err.println("Adding "+fname+" to blacklist.");}
 		assert(!added.contains(fname));
 		added.add(fname);
-		SketchTool tool=new SketchTool(1000000, 1, false, false);
+		SketchTool tool=new SketchTool(1000000, 1, false, false, rcomp);
 		ArrayList<Sketch> sketches=tool.loadSketchesFromFile(fname, null, 1, -1, ONE_SKETCH, 1f, 0f, 0f, (byte)0, false);
 		return sketches;
 	}
