@@ -8,8 +8,8 @@ import java.util.Map.Entry;
 import java.util.concurrent.atomic.AtomicInteger;
 
 import bloom.KCountArray;
-import bloom.ReadCounter;
 import bloom.KmerCountAbstract;
+import bloom.ReadCounter;
 import dna.AminoAcid;
 import fileIO.ByteFile;
 import fileIO.ByteStreamWriter;
@@ -935,7 +935,7 @@ public class BlacklistMaker extends SketchObject {
 	/** True if an error was encountered */
 	public boolean errorState=false;
 	/** Overwrite existing output files */
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	/** Append to existing output files */
 	private boolean append=false;
 	/** Reads are output in input order */
