@@ -575,7 +575,7 @@ public class CompareSketch extends SketchObject {
 	/** True if an error was encountered */
 	public boolean errorState=false;
 	/** Overwrite existing output files */
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	/** Append to existing output files */
 	private boolean append=false;
 	private boolean ordered=true;
