@@ -1,7 +1,6 @@
 package sketch;
 
 import java.util.Comparator;
-import java.util.Locale;
 
 import aligner.Aligner;
 import prok.GeneCaller;
@@ -393,22 +392,22 @@ public final class Comparison extends SketchObject implements Comparable<Compari
 		if(x>=999.95){
 			return(""+(long)Math.round(x));
 		}else if(x>=99.995){
-			return String.format(Locale.ROOT, "%.1f", x);
+			return Tools.format("%.1f", x);
 		}else if(x>=9.9995){
-			return String.format(Locale.ROOT, "%.2f", x);
+			return Tools.format("%.2f", x);
 		}
-		return String.format(Locale.ROOT, "%.3f", x);
+		return Tools.format("%.3f", x);
 	}
 	
 	static String format2(double x){
 		if(x>=999.95){
 			return(""+(long)Math.round(x));
 		}else if(x>=99.995){
-			return String.format(Locale.ROOT, "%.1f", x);
+			return Tools.format("%.1f", x);
 		}else if(x>=9.9995){
-			return String.format(Locale.ROOT, "%.2f", x);
+			return Tools.format("%.2f", x);
 		}
-		return String.format(Locale.ROOT, "%.2f", x);
+		return Tools.format("%.2f", x);
 	}
 	
 	float volume(){
