@@ -4,7 +4,6 @@ import java.io.File;
 import java.io.PrintStream;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Locale;
 import java.util.Random;
 
 import dna.AminoAcid;
@@ -289,7 +288,7 @@ public class KmerLimit2 extends SketchObject {
 		final long reads=Tools.max(1, sketch.genomeSequences);
 		final long targetReads=calcTargetReads(sketch, targetKmers, minCount, trials, seed);
 		final double targetRate=Tools.min(1, targetReads/(double)reads);
-		final String targetRateS=String.format(Locale.ROOT, "%.4f%%",targetRate*100);
+		final String targetRateS=Tools.format("%.4f%%",targetRate*100);
 		
 		//Report timing and results
 		t.stop();
