@@ -136,7 +136,8 @@ public class SendSketch extends SketchObject {
 					a.equalsIgnoreCase("refseqprot") || a.equalsIgnoreCase("prokprot") || a.equalsIgnoreCase("protein") || 
 					a.equalsIgnoreCase("protien") || a.equalsIgnoreCase("prot") || a.equalsIgnoreCase("mito") || a.equalsIgnoreCase("fungi")){
 				address=a;
-				blacklist=a;
+				blacklist=Blacklist.toBlacklist(a);
+				System.err.println("Caught "+a);
 			}
 			
 			else if(a.equals("taxtree") || a.equals("tree")){
@@ -169,7 +170,8 @@ public class SendSketch extends SketchObject {
 				//do nothing
 			}
 			
-			else if(b==null && in.isEmpty() && new File(arg).exists()){
+			else if(b==null && new File(arg).isFile()){
+				System.err.println("Adding "+arg);
 				in.add(arg);
 			}
 			
@@ -196,7 +198,6 @@ public class SendSketch extends SketchObject {
 		}
 		
 		setFromAddress(address, setBlacklist);
-		
 		if(local){blacklist=null;}
 		
 		postParse();
