@@ -1,7 +1,6 @@
 package sketch;
 
 import java.util.Arrays;
-import java.util.Locale;
 
 import dna.AminoAcid;
 import shared.KillSwitch;
@@ -112,7 +111,7 @@ public class SketchHeap {
 			sb.append("\tBC:").append(baseCounts[0]).append(',').append(baseCounts[1]).append(',');
 			sb.append(baseCounts[2]).append(',').append(baseCounts[3]);
 		}
-		if(probSum>0){sb.append("\tPC:"+String.format(Locale.ROOT, "%.4f",probSum/genomeSizeKmers));}
+		if(probSum>0){sb.append("\tPC:"+Tools.format("%.4f",probSum/genomeSizeKmers));}
 		if(taxID>=0){sb.append("\tID:"+taxID);}
 		if(imgID>=0){sb.append("\tIMG:"+imgID);}
 		if(taxName!=null){sb.append("\tNM:"+taxName);}
