@@ -91,7 +91,7 @@ public class SketchMakerMini extends SketchObject {
 	/** Create read streams and process all data */
 	public ArrayList<Sketch> toSketches(final String fname, float samplerate, long reads){
 		final FileFormat ffin1, ffin2;
-		if(fname.indexOf('#')>=0 && FileFormat.isFastq(ReadWrite.rawExtension(fname)) && !new File(fname).exists()){
+		if(fname.indexOf('#')>=0 && FileFormat.isFastqExt(ReadWrite.rawExtension(fname)) && !new File(fname).exists()){
 			ffin1=FileFormat.testInput(fname.replaceFirst("#", "1"), FileFormat.FASTQ, null, true, true);
 			ffin2=FileFormat.testInput(fname.replaceFirst("#", "2"), FileFormat.FASTQ, null, true, true);
 		}else{
