@@ -1015,7 +1015,13 @@ public class SketchObject {
 	/*----------------          Constants           ----------------*/
 	/*--------------------------------------------------------------*/
 	
-	public static final int RAW=0, HEX=1, A48=2;
+	/** Plaintext decimal */
+	public static final int RAW=0;
+	/** Hexadecimal (4-bit) */
+	public static final int HEX=1;
+	/** ASCII-48 6-bit encoding */
+	public static final int A48=2;
+	
 	public static final char[] codingArray={'R', 'H', 'A'};
 	
 	static final byte[] hexTable=new byte[128];
