@@ -507,7 +507,7 @@ public class SketchSearcher extends SketchObject {
 	
 	public void makeTool(int minKeyOccuranceCount, boolean trackCounts, boolean mergePairs){
 		if(tool==null){
-			tool=new SketchTool(targetSketchSize, minKeyOccuranceCount, trackCounts, mergePairs);
+			tool=new SketchTool(targetSketchSize, minKeyOccuranceCount, trackCounts, mergePairs, rcomp);
 		}
 	}
 	
