@@ -1228,7 +1228,7 @@ public final class SketchTool extends SketchObject {
 	
 	public Sketch processReadsMT(String fname, int maxThreads, long reads, int mode, float samplerate,
 			float minEntropy, float minProb, byte minQual, boolean allowZeroSizeSketch){
-		if(fname.indexOf('#')>=0 && FileFormat.isFastq(ReadWrite.rawExtension(fname)) && !new File(fname).exists()){
+		if(fname.indexOf('#')>=0 && FileFormat.isFastqExt(ReadWrite.rawExtension(fname)) && !new File(fname).exists()){
 			return processReadsMT(fname.replaceFirst("#", "1"), fname.replaceFirst("#", "2"), maxThreads, reads, mode, samplerate,
 					minEntropy, minProb, minQual, allowZeroSizeSketch);
 		}else{
