@@ -112,7 +112,7 @@ public class Shuffle {
 				}
 			}else if(a.equals("showspeed") || a.equals("ss")){
 				showSpeed=Parse.parseBoolean(b);
-			}else if(parser.in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
+			}else if(parser.in1==null && i==0 && Tools.looksLikeInputStream(arg)){
 				parser.in1=arg;
 			}else{
 				outstream.println("Unknown parameter "+args[i]);
@@ -459,7 +459,7 @@ public class Shuffle {
 	private PrintStream outstream=System.err;
 	public static boolean verbose=false;
 	public boolean errorState=false;
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	private boolean append=false;
 	public static boolean showSpeed=true;
 	public static boolean printClass=true;
