@@ -741,7 +741,7 @@ public class Shuffle2 {
 	/** True if an error was encountered */
 	public boolean errorState=false;
 	/** Overwrite existing output files */
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	/** Append to existing output files */
 	private boolean append=false;
 	/** This flag has no effect on singlethreaded programs */
