@@ -1,7 +1,6 @@
 package stream;
 
 import java.util.ArrayList;
-import java.util.Locale;
 import java.util.concurrent.ArrayBlockingQueue;
 import java.util.concurrent.TimeUnit;
 
@@ -120,7 +119,7 @@ public class ConcurrentGenericReadInputStream extends ConcurrentReadInputStream
 
 		System.out.println("Reads:      \t"+readCount);
 		System.out.println("Bases:      \t"+baseCount);
-		System.out.println("Avg Length: \t"+String.format(Locale.ROOT, "%.2f",baseCount*1.0/readCount));
+		System.out.println("Avg Length: \t"+Tools.format("%.2f",baseCount*1.0/readCount));
 		System.out.println("Time:      \t"+t);
 	}
 	
@@ -778,7 +777,7 @@ public class ConcurrentGenericReadInputStream extends ConcurrentReadInputStream
 				long x=System.nanoTime();
 				long duration=x-lastTime;
 				lastTime=x;
-				Data.sysout.println(String.format(Locale.ROOT, "%.1f", duration*0.000000001));
+				Data.sysout.println(Tools.format("%.1f", duration*0.000000001));
 //				Data.sysout.println((long)(0.5+duration*0.000000001)+" ");
 			}else{
 				nextProgress+=PROGRESS_INCR;
