@@ -646,6 +646,22 @@ public class SamLine implements Serializable {
 					b++;
 					a=b;
 				}
+			}else if(PARSE_OPTIONAL_MATEQ_ONLY) {
+				optional=new ArrayList<String>(1);
+				while(b<s.length){
+					while(b<s.length && s[b]!='\t'){b++;}
+					if(b>a){
+						if(b>=a+3 && s[a]=='Y' && s[a+1]=='Q' && s[a+2]==':'){
+							String x=new String(s, a, b-a);
+							optional.add(x);
+							return;
+						}
+					}else{
+						//Empty field
+					}
+					b++;
+					a=b;
+				}
 			}else{
 				optional=new ArrayList<String>(4);
 				while(b<s.length){
@@ -1304,6 +1320,25 @@ public class SamLine implements Serializable {
 		return match/(float)Tools.max(match+other, 1);
 	}
 	
+	public int countSubs() {
+		if(cigar==null){return 0;}
+		
+		int current=0;
+		int subs=0;
+		for(int i=0; i<cigar.length(); i++){
+			char c=cigar.charAt(i);
+			if(Tools.isDigit(c)){
+				current=(current*10)+(c-'0');
+			}else{
+				if(c=='X'){
+					subs+=current;
+				}
+				current=0;
+			}
+		}
+		return subs;
+	}
+	
 	/**
 	 * @param cigar
 	 * @return Total number of match, sub, del, ins, or clip symbols
@@ -1933,8 +1968,11 @@ public class SamLine implements Serializable {
 
 			if(MAKE_IDENTITY_TAG && (perfect || r.match!=null)){optionalTags.add(makeIdentityTag(r.match, perfect));}
 
-			if(MAKE_MATEQ_TAG && r.mateMapped()){optionalTags.add("YQ:i:"+toMapq(r.mate, null));}
-
+			if(MAKE_MATEQ_TAG && r.mateMapped()){
+				optionalTags.add("YQ:i:"+toMapq(r.mate, null));
+				optionalTags.add(makeIdentityTag(r.mate.match, r.mate.perfect()).replace('I', 'J'));
+			}
+			
 			if(MAKE_SCORE_TAG && r.mapped()){optionalTags.add(makeScoreTag(r.mapScore));}
 
 			if(MAKE_INSERT_TAG && r2!=null){
@@ -2673,7 +2711,12 @@ public class SamLine implements Serializable {
 		String tag=findTag(prefix);
 		return tag==null ? Integer.MIN_VALUE : Parse.parseInt(tag, 5);
 	}
+	public float parseFloatFlag(String prefix) {
+		String tag=findTag(prefix);
+		return tag==null ? -1 : Parse.parseFloat(tag, 5);
+	}
 	public int mateq() {return parseIntFlag("YQ:i:");}
+	public float mateID() {return parseFloatFlag("YJ:f:");}
 
 	public int setScafnum(ScafMap scafMap) {
 		assert(scafnum<0);
@@ -2841,6 +2884,7 @@ public class SamLine implements Serializable {
 	public static boolean PARSE_10=true;
 	public static boolean PARSE_OPTIONAL=true;
 	public static boolean PARSE_OPTIONAL_MD_ONLY=false;
+	public static boolean PARSE_OPTIONAL_MATEQ_ONLY=false;
 	
 	public static boolean FLIP_ON_LOAD=true;
 	
