@@ -26,8 +26,8 @@ public abstract class AbstractIntHashMap{
 		for(int i=0; i<1000; i++){
 			assert(!set.contains(i));
 			assert(!set2.containsKey(i));
-			klist.add(new Integer(i));
-			vlist.add(new Integer(i*2+7));
+			klist.add(Integer.valueOf(i));
+			vlist.add(Integer.valueOf(i*2+7));
 		}
 		for(int i=0; i<1000; i++){
 			int r=randy2.nextInt();
