@@ -51,6 +51,32 @@ public final class ByteBuilder implements Serializable, CharSequence {
 		if(start<0 || end>=length()){throw new IndexOutOfBoundsException();}
 		return new ByteBuilder(KillSwitch.copyOfRange(array, start, end));
 	}
+	
+	public int indexOf(char c) {return indexOf((byte)c);}
+	public int lastIndexOf(char c) {return lastIndexOf((byte)c);}
+	public int count(char c) {return count((byte)c);}
+	
+	public int indexOf(byte c) {
+		for(int i=0; i<length; i++) {
+			if(array[i]==c) {return i;}
+		}
+		return -1;
+	}
+	
+	public int lastIndexOf(byte c) {
+		for(int i=length-1; i>=0; i--) {
+			if(array[i]==c) {return i;}
+		}
+		return -1;
+	}
+
+	public int count(byte c) {
+		int count=0;
+		for(int i=0; i<length; i++) {
+			count+=(array[i]==c) ? 1 : 0;
+		}
+		return count;
+	}
 
 //	public ByteBuilder append(float x, int places){return append(Tools.format(decimalFormat[places], x));}
 //	public ByteBuilder append(double x, int places){return append(Tools.format(decimalFormat[places], x));}
@@ -85,6 +111,12 @@ public final class ByteBuilder implements Serializable, CharSequence {
 		append(a);append(b);append(c);append(d);
 		return this;
 	}
+	public ByteBuilder append(char x, int y){
+		append(x); append(y); return this;
+	}
+	public ByteBuilder append(char x, long y){
+		append(x); append(y); return this;
+	}
 	
 	public ByteBuilder append(char x){
 		if(length>=array.length){expand();}
@@ -486,8 +518,10 @@ public final class ByteBuilder implements Serializable, CharSequence {
 	
 	public ByteBuilder append(byte[] x, int start, int len){
 //		if(x==null){x=nullBytes;}
+		final int lim=(int)Tools.min(start+(long)len, x.length);
+		len=Tools.min(len, x.length-start);
 		expand(len);
-		for(int i=start, lim=start+len; i<lim; i++){
+		for(int i=start; i<lim; i++){
 			array[length]=x[i];
 			length++;
 		}
