@@ -27,7 +27,7 @@ public class IntHashSet{
 		for(int i=0; i<1000; i++){
 			assert(!set.contains(i));
 			assert(!set2.contains(i));
-			list.add(new Integer(i));
+			list.add(Integer.valueOf(i));
 		}
 		for(int i=0; i<1000; i++){
 			int r=randy2.nextInt();
