@@ -8,6 +8,10 @@ public class LongPair implements Comparable<LongPair>{
 	}
 
 	public LongPair(){}
+
+	public long min() {return Math.min(a, b);}
+	public long max() {return Math.max(a, b);}
+	public long sum() {return a+b;}
 	
 	@Override
 	public int compareTo(LongPair other) {
