@@ -13,8 +13,11 @@ import fileIO.ByteFile1;
 import fileIO.ByteFile2;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import json.JsonObject;
+import json.JsonParser;
 import kmer.HashBuffer;
 import kmer.KmerTableSet;
+import server.ServerTools;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
@@ -23,6 +26,7 @@ import shared.Timer;
 import shared.Tools;
 import stream.ConcurrentGenericReadInputStream;
 import stream.FastaReadInputStream;
+import structures.LongLongHashMap;
 import structures.StringNum;
 
 /**
@@ -199,6 +203,8 @@ public class AccessionToTaxid {
 			tables.allocateTables();
 		}
 		
+		imgCache=new LongLongHashMap(2000);
+		
 		if(ffin.length>4){//Addresses a multithreaded read bug in Java
 //			FileFormat[] ffa1=Arrays.copyOf(ffin, 2);
 //			FileFormat[] ffa2=Arrays.copyOfRange(ffin, 2, ffin.length);
@@ -818,6 +824,41 @@ public class AccessionToTaxid {
 	
 	/*--------------------------------------------------------------*/
 	
+	public static int getImg(long imgID) {
+		long ncbi=-1;
+		synchronized(imgCache) {
+			long time=System.currentTimeMillis();
+			if(time-lastCacheClear>cacheClearInterval) {
+				imgCache.clear();
+				lastCacheClear=time;
+			}
+			ncbi=imgCache.get(imgID);
+		}
+		if(ncbi>-1) {return (int)ncbi;}
+		ncbi=getImgFromServer(imgID);
+		if(ncbi<0) {return -1;}
+		synchronized(imgCache) {imgCache.put(imgID, ncbi);}
+		return (int)ncbi;
+	}
+	
+	public static int getImgFromServer(long imgID) {
+		try {
+			byte[] message=null;
+			String path="https://img.jgi.doe.gov/cgi-bin/genomesMetadata.cgi?ids="+imgID;
+			StringNum sn=ServerTools.sendAndReceive(message, path);
+			if(sn==null) {return -1;}
+			String response=sn.s;
+			if(response==null) {return 0-(int)sn.n;}
+			JsonObject all=JsonParser.parseJsonObjectStatic(response);
+			JsonObject body=all.getJson(""+imgID);
+			long ncbi=body.getLong("ncbi_taxon_id");
+			return (int)ncbi;
+		} catch (Exception e) {
+			// TODO Auto-generated catch block
+			e.printStackTrace();
+		}
+		return -1;
+	}
 	
 	/*--------------------------------------------------------------*/
 	
@@ -850,6 +891,9 @@ public class AccessionToTaxid {
 	private static boolean LOADED=false;
 	private static HashMap<String, Integer>[] maps=null;
 	private static KmerTableSet tables;
+	private static LongLongHashMap imgCache;
+	private static final long cacheClearInterval=7L*24L*3600L*1000L;//millis
+	private static long lastCacheClear=0;
 	public static TaxTree tree=null;
 //	public static final boolean USE_MAPS=true;
 	public static final boolean USE_TABLES=true;
