@@ -802,6 +802,6 @@ public class AccessionToTaxid_old {
 	private PrintStream outstream=System.err;
 	public static boolean verbose=false;
 	public boolean errorState=false;
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	
 }
