@@ -3,6 +3,7 @@ package tax;
 import java.io.File;
 import java.io.PrintStream;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.LinkedHashSet;
 
 import fileIO.ByteFile;
@@ -548,9 +549,11 @@ public class RenameGiToTaxid {
 	private void updateHeadersFromServer_fasta(ArrayList<byte[]> lines, HashArray1D counts, ByteStreamWriter bswBadHeaders){
 		ByteBuilder bb=new ByteBuilder();
 		ArrayList<String> names=new ArrayList<String>();
+		int terms=0;
 		for(byte[] line : lines){
 			if(line[0]=='>' && !Tools.startsWith(line, ">tid")){
-				appendHeaderLine(line, bb);
+				terms++;
+				appendHeaderLine(line, bb);//At this point bb contains something like "GHE08303,ABC123,KR99,"
 				if(mode==UNITE_MODE){
 					int bar=Tools.indexOf(line, '|');
 					names.add(new String(line, 1, bar-1));
@@ -559,20 +562,18 @@ public class RenameGiToTaxid {
 		}
 		if(bb.length()<1){return;}
 		
-		assert(bb.endsWith(','));
-		bb.length--;
+		assert(terms>0) : bb.count(',')+", "+terms+"\n"+bb+"\n";
+		assert(bb.endsWith(',')) : bb.count(',')+", "+terms+"\n"+bb+"\n";
+		assert(bb.count(',')==terms) : bb.count(',')+", "+terms+"\n"+bb+"\n";
+		bb.length--;//At this point bb contains something like "GHE08303,ABC123,KR99"
 		
 //		System.err.println("Sending '"+bb+"'");
 		
-		final int[] serverIds;
-		if(mode==ACCESSION_MODE || mode==UNITE_MODE){
-			serverIds=TaxClient.accessionToTaxidArray(bb.toString());
-		}else if(mode==GI_MODE){
-			serverIds=TaxClient.giToTaxidArray(bb.toString());
-		}else{
-			serverIds=TaxClient.headerToTaxidArray(bb.toString());
-		}
+		final int[] serverIds=translateToTaxIDs(bb, terms);
 		assert(serverIds!=null) : "Null response for '"+bb.toString()+"'";
+		assert(serverIds.length==terms) : "Incorrect response length for query."
+				+"\nQuery size "+terms+":\n"+bb
+				+"\nResponse size "+serverIds.length+":\n"+Arrays.toString(serverIds)+"\n";
 		bb.clear();
 		
 		if(!names.isEmpty()){
@@ -643,6 +644,36 @@ public class RenameGiToTaxid {
 		}
 	}
 	
+	private int[] translateToTaxIDs(ByteBuilder bb, int terms) {
+		//This block was created due to mysterious crashes processing nr.faa.
+		//They seemed to be due to incomplete responses.
+		int[] response=null;
+		final String query=bb.toString();
+		for(int i=0; i<10 && response==null; i++) {
+			if(mode==ACCESSION_MODE || mode==UNITE_MODE){
+				response=TaxClient.accessionToTaxidArray(query);
+			}else if(mode==GI_MODE){
+				response=TaxClient.giToTaxidArray(query);
+			}else{
+				response=TaxClient.headerToTaxidArray(query);//TODO: Keep this as a ByteBuilder
+			}
+			if(response==null) {
+				System.err.println("Retrying null response for length "+terms+" query: "+query);
+			}else if(response.length!=terms) {
+				System.err.println("Retrying corrupt length "+response.length+" response for length "+terms+" query: "+query);
+				response=null;
+			}
+			if(response==null) {
+				try {
+					Thread.sleep(500*(i+2));
+				} catch (InterruptedException e) {
+					e.printStackTrace();
+				}
+			}
+		}
+		return response;
+	}
+	
 	private void updateHeadersFromServer_gff(ArrayList<byte[]> lines, HashArray1D counts, ByteStreamWriter bswBadHeaders){
 		ByteBuilder bb=new ByteBuilder();
 		ArrayList<String> names=new ArrayList<String>();
@@ -787,7 +818,16 @@ public class RenameGiToTaxid {
 					invalidLines++;
 					if(deleteInvalid){break;}
 				}else{
-					assert(Tools.startsWith(line, title));
+					//Somehow this line is firing:
+//					Exception in thread "main" java.lang.AssertionError:
+//						line: '>WP_330397346.1 spore protease YyaC [Maledivibacter halophilus]SKC56058.1 putative sporulation protein YyaC [Maledivibacter halophilus]'
+//						title: '>tid|'
+//
+//						        at tax.RenameGiToTaxid.dumpBuffer(RenameGiToTaxid.java:790)
+//						        at tax.RenameGiToTaxid.processInner_server(RenameGiToTaxid.java:751)
+//						        at tax.RenameGiToTaxid.process(RenameGiToTaxid.java:262)
+//						        at tax.RenameGiToTaxid.main(RenameGiToTaxid.java:39)
+					assert(Tools.startsWith(line, title)) : "\nline: '"+new String(line)+"'\ntitle: '"+new String(title)+"'\n";
 					valid=true;
 					validReads++;
 					validLines++;
