@@ -193,7 +193,10 @@ public class TaxServer {
 			}else if(a.equalsIgnoreCase("prealloc")){
 				if(b==null || Character.isLetter(b.charAt(0))){
 					if(Parse.parseBoolean(b)){
-						prealloc=0.78f;
+						//The hashtable for strings is getting huge.
+						//Setting this number lower gives more space for hashing long strings,
+						//and less space for hashing numbers
+						prealloc=0.75f;
 					}else{
 						prealloc=0;
 					}
@@ -617,21 +620,21 @@ public class TaxServer {
 				}
 				final boolean internal=incrementQueries(t, fileMode, refMode, false, false, false, false, false, false, false, false, -1);
 				if(verbose2){System.err.println("Incremented queries rparam.");}
-
+				
 				if(verbose2){System.err.println(rparam);}
 				if(verbose2){System.err.println("fileMode="+fileMode+", refMode="+refMode);}
 				
-				if(fileMode && !internal && !allowRemoteFileAccess){
+				if(fileMode && (!internal || !allowRemoteFileAccess)){
 					if(verbose){System.err.println("Illegal file query from "+ServerTools.getClientAddress(t));}
 					malformedQueries.incrementAndGet();
 //					if(verbose){System.err.println("test1");}
 //					String body=getBody(t);//123
 					ServerTools.reply("\nERROR: This server does not allow remote file access. "
-							+ "You may only use the 'local' flag from with the local intranet.\n", "text/plain", t, verbose2, 400, true);
+							+ "You may only use the 'local' flag from within the local intranet, for files on the server's filesystem.\n", "text/plain", t, verbose2, 400, true);
 //					if(verbose){System.err.println("test2");}
 					return;
 				}
-
+				
 				String body=getBody(t);
 				if(verbose2){System.err.println("Got body.");}
 				
@@ -671,12 +674,18 @@ public class TaxServer {
 				ArrayList<Sketch> sketches;
 				
 				if(fileMode){
+					assert(internal && allowRemoteFileAccess);
+					if(!allowRemoteFileAccess) {throw new RuntimeException("Bad access to "+rparam);}
 					File f=new File(rparam);
 					if(!f.exists() && !rparam.startsWith("/")){
 						String temp="/"+rparam;
 						f=new File(temp);
 						if(f.exists()){rparam=temp;}
 					}
+					if(!f.exists() || !f.canRead()) {
+						ServerTools.reply("\nERROR: This file cannot be read.\n", "text/plain", t, verbose2, 400, true);
+						return;
+					}
 //					if(f.exists()){
 //						if(f.length()>100000000L){
 //							if(params.reads<0){
@@ -1281,7 +1290,7 @@ public class TaxServer {
 		}else if(type2==IMG){
 			for(String name : names){
 				sb.append(comma);
-				int ncbi=TaxTree.imgToTaxid(Long.parseLong(name));
+				int ncbi=imgToTaxid(Long.parseLong(name));
 				sb.append(ncbi);
 				comma=",";
 			}
@@ -1307,7 +1316,7 @@ public class TaxServer {
 		}else if(type2==HEADER || type2==SILVAHEADER){
 			tn=getTaxNodeHeader(name, type2==SILVAHEADER);
 		}else if(type2==IMG){
-			int ncbi=TaxTree.imgToTaxid(Long.parseLong(name));
+			int ncbi=imgToTaxid(Long.parseLong(name));
 			tn=(ncbi<0 ? null : tree.getNode(ncbi));
 		}else{
 			tn=null;
@@ -1389,7 +1398,7 @@ public class TaxServer {
 		}else if(type2==IMG){
 			for(String name : names){
 				sb.append(comma);
-				final int tid=TaxTree.imgToTaxid(Long.parseLong(name));
+				final int tid=imgToTaxid(Long.parseLong(name));
 				TaxNode tn=tree.getNode(tid, true);
 				if(tn==null){sb.append("Not found");}
 				else{sb.append(tree.toSemicolon(tn, skipNonCanonical, mononomial));}
@@ -1425,7 +1434,7 @@ public class TaxServer {
 			tn0=getTaxNodeHeader(name, type==SILVAHEADER);
 		}else if(type==IMG){
 			img=Long.parseLong(name);
-			final int tid=TaxTree.imgToTaxid(img);
+			final int tid=imgToTaxid(img);
 			tn0=tree.getNode(tid, true);
 		}else{
 			JsonObject j=new JsonObject("error","Bad type; should be gi, taxid, or name; e.g. /name/homo_sapiens");
@@ -1569,7 +1578,7 @@ public class TaxServer {
 			}
 		}else if(type2==IMG){
 			for(String name : names){
-				final int tid=TaxTree.imgToTaxid(Long.parseLong(name));
+				final int tid=imgToTaxid(Long.parseLong(name));
 				if(tid>=0){list.add(tid);}
 				else{notFound.incrementAndGet();}
 			}
@@ -1588,6 +1597,18 @@ public class TaxServer {
 		}
 		return s;
 	}
+
+	private final int imgToTaxid(String imgID) {
+		return imgToTaxid(Long.parseLong(imgID));
+	}
+	private final int imgToTaxid(long imgID) {
+		int ncbi=-1;
+		if(imgFile!=null) {
+			ncbi=TaxTree.imgToTaxid(imgID);
+			if(ncbi>=0) {return ncbi;}
+		}
+		return AccessionToTaxid.getImg(imgID);
+	}
 	
 	private int accessionToTaxid(String accession){
 		if(accession==null){return -1;}
