@@ -2,7 +2,6 @@ package tax;
 
 import java.io.PrintStream;
 import java.util.Arrays;
-import java.util.Locale;
 
 import fileIO.ByteFile;
 import fileIO.ByteStreamWriter;
@@ -195,9 +194,9 @@ public class TaxSize {
 			outstream.println();
 			
 			outstream.println("Time:                         \t"+t);
-			outstream.println("Reads Processed:    "+rpstring+" \t"+String.format(Locale.ROOT, "%.2fk reads/sec", rpnano*1000000));
-			outstream.println("Lines Processed:    "+lpstring+" \t"+String.format(Locale.ROOT, "%.2fk reads/sec", lpnano*1000000));
-			outstream.println("Bases Processed:    "+bpstring+" \t"+String.format(Locale.ROOT, "%.2fm bases/sec", bpnano*1000));
+			outstream.println("Reads Processed:    "+rpstring+" \t"+Tools.format("%.2fk reads/sec", rpnano*1000000));
+			outstream.println("Lines Processed:    "+lpstring+" \t"+Tools.format("%.2fk reads/sec", lpnano*1000000));
+			outstream.println("Bases Processed:    "+bpstring+" \t"+Tools.format("%.2fm bases/sec", bpnano*1000));
 		}
 		
 		//Throw an exception of there was an error in a thread
