@@ -1,7 +1,6 @@
 package template;
 
 import java.util.ArrayList;
-import java.util.Locale;
 
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
@@ -9,6 +8,7 @@ import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
 import shared.Timer;
+import shared.Tools;
 import stream.ConcurrentReadInputStream;
 import stream.ConcurrentReadOutputStream;
 import stream.Read;
@@ -135,7 +135,7 @@ public class A_Sample2 {
 		
 		t.stop();
 		outstream.println("Time:                         \t"+t);
-		outstream.println("Reads Processed:    "+readsProcessed+" \t"+String.format(Locale.ROOT, "%.2fk reads/sec", (readsProcessed/(double)(t.elapsed))*1000000));
+		outstream.println("Reads Processed:    "+readsProcessed+" \t"+Tools.format("%.2fk reads/sec", (readsProcessed/(double)(t.elapsed))*1000000));
 	}
 	
 	/*--------------------------------------------------------------*/
