@@ -1,7 +1,6 @@
 package template;
 
 import java.util.ArrayList;
-import java.util.Locale;
 
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
@@ -10,6 +9,7 @@ import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
 import shared.Timer;
+import shared.Tools;
 import stream.ConcurrentReadInputStream;
 import stream.ConcurrentReadInputStreamD;
 import stream.ConcurrentReadOutputStream;
@@ -144,7 +144,7 @@ public class A_SampleD {
 		t.stop();
 		outstream.println("A_SampleD: Time:                         \t"+t);
 		outstream.println("A_SampleD: Rank "+ Shared.MPI_RANK + ": Reads Processed:    "+readsProcessed+" \t"+
-				String.format(Locale.ROOT, "%.2fk reads/sec", (readsProcessed/(double)(t.elapsed))*1000000));
+				Tools.format("%.2fk reads/sec", (readsProcessed/(double)(t.elapsed))*1000000));
 	}
 	
 	/*--------------------------------------------------------------*/
