@@ -445,7 +445,7 @@ public abstract class BBTool_ST {
 	protected PrintStream outstream=System.err;
 	public static boolean verbose=false;
 	public boolean errorState=false;
-	protected boolean overwrite=false;
+	protected boolean overwrite=true;
 	protected boolean append=false;
 	
 }
