@@ -315,6 +315,221 @@ public class EntropyTracker {
 	
 	/*--------------------------------------------------------------*/
 	
+	public static float strandedness(byte[] bases, int[] counts, int k) {
+		if(counts==null) {counts=new int[1<<(2*k)];}
+		countKmers(bases, counts, k);
+		return strandedness(counts, k);
+	}
+	
+	public static float strandedness(int[] counts, int k) {
+		final int mask=~((-1)<<(2*k));
+		assert(mask==counts.length-1);
+		long lower=0, upper=0;
+		for(int kmer=0, limit=counts.length/2; kmer<limit; kmer++) {
+			int a=counts[kmer];
+			int b=counts[mask&(~kmer)];
+			lower+=Math.min(a, b);
+			upper+=Math.max(a, b);
+		}
+		return lower/(float)(Long.max(1, upper));
+	}
+	
+	public static float strandednessK2(int[] counts) {
+		final int mask=15;
+		assert(counts.length==16);
+		long lower=0, upper=0;
+		for(int kmer=0; kmer<8; kmer++) {
+			int a=counts[kmer];
+			int b=counts[mask&(~kmer)];
+			lower+=Math.min(a, b);
+			upper+=a+b;
+		}
+		return lower/(float)(Long.max(1, upper-lower));
+	}
+	
+	public static float strandednessWindowed(byte[] bases, int[] counts, int k, int window) {
+		if(k==2) {return strandednessWindowedK2(bases, counts, window);}
+		assert(k>2);
+		if(counts==null) {counts=new int[1<<(2*k)];}
+		
+		final int shift=2*k;
+		final int mask=~((-1)<<shift);
+		assert(mask==counts.length-1);
+
+		int valid=0;
+		double sum=0;
+		int sums=0;
+		for(int i=0, j=-window, ikmer=0, jkmer=0, ilen=0, jlen=0; i<bases.length; i++, j++){
+			{
+				byte b=bases[i];
+				int x=AminoAcid.baseToNumber[b];
+				ikmer=((ikmer<<2)|x)&mask;
+				if(x>=0){
+					ilen++;
+					if(ilen>=k) {
+						valid++;
+						counts[ikmer]++;
+					}
+				}else{ilen=ikmer=0;}
+			}
+			
+			if(j>=0){
+				byte b=bases[i];
+				int y=AminoAcid.baseToNumber[b];
+				jkmer=((jkmer<<2)|y)&mask;
+				if(y>=0){
+					jlen++;
+					if(jlen>=k) {
+						valid--;
+						counts[jkmer]--;
+					}
+				}else{jlen=jkmer=0;}
+			}
+			
+			if(i>=window-1) {
+				sums++;
+				sum+=strandedness(counts, k);
+			}
+		}
+		if(sums<1) {
+			return strandedness(counts, k);
+		}
+		return (float)(sum/sums);
+	}
+	
+	public static float strandednessWindowedK2(byte[] bases, int[] counts, int window) {
+		if(counts==null) {counts=new int[16];}
+		
+		final int mask=15;
+		assert(mask==counts.length-1);
+
+		int valid=0;
+		double sum=0;
+		int sums=0;
+		for(int i=0, j=-window, ikmer=0, jkmer=0, ilen=0, jlen=0; i<bases.length; i++, j++){
+			{
+				byte b=bases[i];
+				int x=AminoAcid.baseToNumber[b];
+				ikmer=((ikmer<<2)|x)&mask;
+				if(x>=0){
+					ilen++;
+					if(ilen>=2) {
+						valid++;
+						counts[ikmer]++;
+					}
+				}else{ilen=ikmer=0;}
+			}
+			
+			if(j>=0){
+				byte b=bases[i];
+				int y=AminoAcid.baseToNumber[b];
+				jkmer=((jkmer<<2)|y)&mask;
+				if(y>=0){
+					jlen++;
+					if(jlen>=2) {
+						valid--;
+						counts[jkmer]--;
+					}
+				}else{jlen=jkmer=0;}
+			}
+			
+			if(i>=window-1) {
+				sums++;
+				sum+=strandednessK2(counts);
+			}
+		}
+		if(sums<1) {
+			return strandednessK2(counts);
+		}
+		return (float)(sum/sums);
+	}
+	
+	/*--------------------------------------------------------------*/
+	
+	public static float calcEntropy(byte[] bases, int[] counts, int k){
+		assert(k<=10) : k;//This is for small kmers
+		if(counts==null) {counts=new int[1<<(2*k)];}
+		countKmers(bases, counts, k);
+		return calcEntropyFromCounts(counts);
+	}
+	
+	/**
+	 * Static, non-windowed version.
+	 * Demonstrates explicit entropy calculation.
+	 * 
+	 * Definition:
+	 * Entropy, or information content, can be calculated using kmer counts of a sequence.
+	 * 
+	 * Probability of an event (unique kmer), pk, is that kmer's count divided by the number of kmers.
+	 * Entropy contribution from that kmer is -pk*log(pk).
+	 * Total entropy is sum of (-pk*log(pk)) for all kmer counts.
+	 * entropyMult is simply a multiplier to convert the entropy measure (in bits) to a convenient 0-1 scale,
+	 * corresponding to the inverse of the maximum possible entropy.
+	 */
+	public static float calcEntropyFromCounts(int[] counts){
+		//Sum of entropy contributions from each kmer
+		double eSum=0;
+		
+		long windowKmers=Tools.sum(counts);
+		double invKmers=1.0/windowKmers;
+		//Loop over all nonzero kmer counts
+		for(int count : counts){
+			//Prevent NaN and INF
+//			System.err.println("count="+count);
+			if(count>0){
+				//Fraction of total represented by this kmer
+				double pk=count*invKmers;
+//				System.err.println("pk="+pk);
+
+				//Entropy contribution for this kmer's count
+				double npklogpk=-pk*Math.log(pk);
+//				System.err.println("npklogpk="+npklogpk);
+				eSum+=npklogpk;
+//				System.err.println("eSum="+eSum);
+			}
+		}
+		//eSum now holds entropy in bits.
+		
+		//Multiplier to convert entropy to 0-1 scale.
+		double multiplier=1/Math.log(windowKmers);
+		
+		//Adjust entropy to 0-1 scale based on window size
+		float e=(float)(eSum*multiplier);
+		
+		//Get rid of negative zero
+		if(e<=0){e=0;}
+		
+		return e;
+	}
+	
+	public static int countKmers(final byte[] bases, final int[] counts, int k){
+		Arrays.fill(counts, 0);
+		if(bases==null || bases.length<k){return 0;}
+		
+		final int shift=2*k;
+		final int mask=~((-1)<<shift);
+		
+		int kmer=0;
+		int len=0;
+		int valid=0;
+		
+		for(int i=0; i<bases.length; i++){
+			byte b=bases[i];
+			int x=AminoAcid.baseToNumber[b];
+			kmer=((kmer<<2)|x)&mask;
+			if(x>=0){
+				len++;
+				if(len>=k) {
+					valid++;
+					counts[kmer]++;
+				}
+			}else{len=kmer=0;}
+		}
+		return valid;
+	}
+	
+	/*--------------------------------------------------------------*/
+	
 	/**
 	 * Calculate the average entropy of a sequence.
 	 * @param bases Sequence as bytes
