@@ -5,9 +5,9 @@ import java.io.PrintStream;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
-import java.util.Locale;
 
 import bloom.KCountArray7MTA;
+import dna.Data;
 import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
@@ -198,6 +198,11 @@ public class CallVariants {
 				prefilter=Parse.parseBoolean(b);
 			}else if(a.equals("ref")){
 				ref=b;
+				if(ref!=null && !Tools.isReadableFile(ref)) {
+					if(ref.equalsIgnoreCase("phix")) {
+						ref=Data.findPath("?phix2.fa.gz");
+					}
+				}
 			}else if(a.equals("vcf") || a.equals("vcfout") || a.equals("outvcf")){
 				vcf=b;
 			}else if(a.equals("invcf") || a.equals("vcfin") || a.equals("forced")){
@@ -556,7 +561,7 @@ public class CallVariants {
 			kca=prefilter(varFilter.minAlleleDepth, vcfin==null ? null : varMap);
 			double used=(100.0*kca.cellsUsed())/kca.cells;
 			outstream.println("Added "+varsProcessed+" events to prefilter; approximately "+(long)(kca.estimateUniqueKmers(2))+" were unique.");
-			outstream.println(String.format(Locale.ROOT, "The prefilter is %.2f%% full.", used));
+			outstream.println(Tools.format("The prefilter is %.2f%% full.", used));
 			varsProcessed=0;
 			t2.stop("Time: ");
 			outstream.println();
@@ -673,9 +678,9 @@ public class CallVariants {
 			double homozygousRate=homozygousCount*1.0/shared.Vector.sum(ploidyArray);
 //			outstream.println();
 			if(prefilter){
-				outstream.println(c+" of "+d+" events were screened by the prefilter ("+String.format(Locale.ROOT, "%.4f%%", c*100.0/d)+").");
+				outstream.println(c+" of "+d+" events were screened by the prefilter ("+Tools.format("%.4f%%", c*100.0/d)+").");
 			}
-			outstream.println(b+" of "+a+" variants passed primary filters ("+String.format(Locale.ROOT, "%.4f%%", b*amult)+").");
+			outstream.println(b+" of "+a+" variants passed primary filters ("+Tools.format("%.4f%%", b*amult)+").");
 			outstream.println();
 			final long sub=types[Var.SUB], del=types[Var.DEL], ins=types[Var.INS];
 			final double smult=1.0/Tools.max(1, sub), dmult=1.0/Tools.max(1, del), imult=1.0/Tools.max(1, ins);
@@ -691,17 +696,17 @@ public class CallVariants {
 			final double insQual=Tools.sumHistogram(avgQualityArray[Var.INS+1])*imult;
 			
 			outstream.println("Type           \tCount\tRate\tAD\tDepth\tAF\tScore\tQual");
-			outstream.println("Substitutions: \t"+sub+String.format(Locale.ROOT, "\t%.1f%%\t%."+(subAD>1000 ? 0 : 1)+"f\t%."+(subRD>1000 ? 0 : 1)+"f\t%.3f\t%.1f\t%.1f", 
+			outstream.println("Substitutions: \t"+sub+Tools.format("\t%.1f%%\t%."+(subAD>1000 ? 0 : 1)+"f\t%."+(subRD>1000 ? 0 : 1)+"f\t%.3f\t%.1f\t%.1f", 
 					sub*bmult, subAD, subRD, subAF, subScore, subQual));
-			outstream.println("Deletions:     \t"+del+String.format(Locale.ROOT, "\t%.1f%%\t%."+(delAD>1000 ? 0 : 1)+"f\t%."+(delRD>1000 ? 0 : 1)+"f\t%.3f\t%.1f\t%.1f", 
+			outstream.println("Deletions:     \t"+del+Tools.format("\t%.1f%%\t%."+(delAD>1000 ? 0 : 1)+"f\t%."+(delRD>1000 ? 0 : 1)+"f\t%.3f\t%.1f\t%.1f", 
 					del*bmult, delAD, delRD, delAF, delScore, delQual));
-			outstream.println("Insertions:    \t"+ins+String.format(Locale.ROOT, "\t%.1f%%\t%."+(insAD>1000 ? 0 : 1)+"f\t%."+(insRD>1000 ? 0 : 1)+"f\t%.3f\t%.1f\t%.1f", 
+			outstream.println("Insertions:    \t"+ins+Tools.format("\t%.1f%%\t%."+(insAD>1000 ? 0 : 1)+"f\t%."+(insRD>1000 ? 0 : 1)+"f\t%.3f\t%.1f\t%.1f", 
 					ins*bmult, insAD, insRD, insAF, insScore, insQual));
 			if(var2.Var.CALL_JUNCTION){
-				outstream.println("Junctions:     \t"+jun+String.format(Locale.ROOT, "\t%.1f%%", jun*bmult));
+				outstream.println("Junctions:     \t"+jun+Tools.format("\t%.1f%%", jun*bmult));
 			}
 			outstream.println("Variation Rate:\t"+(b==0 ? 0 : 1)+"/"+(size/Tools.max(1,b)));
-			outstream.println("Homozygous:    \t"+homozygousCount+String.format(Locale.ROOT, "\t%.1f%%", homozygousRate*100)+"\n");
+			outstream.println("Homozygous:    \t"+homozygousCount+Tools.format("\t%.1f%%", homozygousRate*100)+"\n");
 			
 			if(realign){
 				outstream.println("Realignments:  \t"+realignmentsAttempted);
@@ -874,7 +879,7 @@ public class CallVariants {
 		tsw.start();
 		tsw.println("#ScoreHist");
 		tsw.println("#Vars\t"+sum);
-		tsw.println("#Mean\t"+String.format(Locale.ROOT, "%.2f", sum2*1.0/sum));
+		tsw.println("#Mean\t"+Tools.format("%.2f", sum2*1.0/sum));
 		tsw.println("#Median\t"+Tools.medianHistogram(array));
 		tsw.println("#Mode\t"+Tools.calcModeHistogram(array));
 		tsw.println("#Quality\tCount");
@@ -896,8 +901,8 @@ public class CallVariants {
 		tsw.start();
 		tsw.println("#ZygoHist");
 		tsw.println("#Vars\t"+sum);
-		tsw.println("#Mean\t"+String.format(Locale.ROOT, "%.3f", sum2*1.0/sum));
-		tsw.println("#HomozygousFraction\t"+String.format(Locale.ROOT, "%.3f", array[max]*1.0/sum));
+		tsw.println("#Mean\t"+Tools.format("%.3f", sum2*1.0/sum));
+		tsw.println("#HomozygousFraction\t"+Tools.format("%.3f", array[max]*1.0/sum));
 		tsw.println("#Zygosity\tCount");
 		for(int i=0; i<=max; i++){
 			tsw.println(i+"\t"+array[i]);
@@ -920,7 +925,7 @@ public class CallVariants {
 		tsw.start();
 		tsw.println("#BaseQualityHist");
 		tsw.println("#Vars\t"+avgsum);
-		tsw.println("#Mean\t"+String.format(Locale.ROOT, "%.2f", avgsum2*1.0/avgsum));
+		tsw.println("#Mean\t"+Tools.format("%.2f", avgsum2*1.0/avgsum));
 		tsw.println("#Median\t"+Tools.medianHistogram(avgQualArray));
 		tsw.println("#Mode\t"+Tools.calcModeHistogram(avgQualArray));
 		tsw.println("#Quality\tAvgCount\tMaxCount");
@@ -1585,7 +1590,7 @@ public class CallVariants {
 	/** True if an error was encountered */
 	public boolean errorState=false;
 	/** Overwrite existing output files */
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	/** Append to existing output files */
 	private boolean append=false;
 	
