@@ -5,7 +5,6 @@ import java.io.PrintStream;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.Locale;
 
 import bloom.KCountArray7MTA;
 import fileIO.ByteFile;
@@ -477,13 +476,13 @@ public class CallVariants2 {
 			double bmult=100.0/b;
 			outstream.println();
 			if(prefilter){
-				outstream.println(c+" of "+d+" events were screened by the prefilter ("+String.format(Locale.ROOT, "%.4f%%", c*100.0/d)+").");
+				outstream.println(c+" of "+d+" events were screened by the prefilter ("+Tools.format("%.4f%%", c*100.0/d)+").");
 			}
-			outstream.println(b+" of "+a+" variants passed filters ("+String.format(Locale.ROOT, "%.4f%%", b*amult)+").");
+			outstream.println(b+" of "+a+" variants passed filters ("+Tools.format("%.4f%%", b*amult)+").");
 			outstream.println();
-			outstream.println("Substitutions: \t"+types[Var.SUB]+String.format(Locale.ROOT, "\t%.1f%%", types[Var.SUB]*bmult));
-			outstream.println("Deletions:     \t"+types[Var.DEL]+String.format(Locale.ROOT, "\t%.1f%%", types[Var.DEL]*bmult));
-			outstream.println("Insertions:    \t"+types[Var.INS]+String.format(Locale.ROOT, "\t%.1f%%", types[Var.INS]*bmult));
+			outstream.println("Substitutions: \t"+types[Var.SUB]+Tools.format("\t%.1f%%", types[Var.SUB]*bmult));
+			outstream.println("Deletions:     \t"+types[Var.DEL]+Tools.format("\t%.1f%%", types[Var.DEL]*bmult));
+			outstream.println("Insertions:    \t"+types[Var.INS]+Tools.format("\t%.1f%%", types[Var.INS]*bmult));
 			outstream.println("Variation Rate:\t"+(b==0 ? 0 : 1)+"/"+(size/Tools.max(1,b))+"\n");
 			
 			if(realign){
@@ -531,7 +530,7 @@ public class CallVariants2 {
 				kca=prefilter(varFilter.minAlleleDepth);
 				double used=(100.0*kca.cellsUsed())/kca.cells;
 				outstream.println("Added "+varsProcessed+" events to prefilter; approximately "+(long)(kca.estimateUniqueKmers(2))+" were unique.");
-				outstream.println(String.format(Locale.ROOT, "The prefilter is %.2f%% full.", used));
+				outstream.println(Tools.format("The prefilter is %.2f%% full.", used));
 				varsProcessed=0;
 				t2.stop("Time: ");
 				outstream.println();
@@ -1302,6 +1301,6 @@ public class CallVariants2 {
 	/** True if an error was encountered */
 	public boolean errorStateOverall=false;
 	/** Overwrite existing output files */
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	
 }
