@@ -2,7 +2,6 @@ package var2;
 
 import java.io.PrintStream;
 import java.util.ArrayList;
-import java.util.Locale;
 
 import fileIO.ByteFile;
 import fileIO.FileFormat;
@@ -330,25 +329,25 @@ public class FilterSam {
 			double avgMapQBad=(mapqSumBad/(double)mappedReadsDiscarded);
 			double avgVarsGood=(varSumGood/(double)mappedReadsRetained);
 			double avgVarsBad=(varSumBad/(double)mappedReadsDiscarded);
-			final String avgQGoodS=pad(String.format(Locale.ROOT, "%.2f", avgQGood), len);
-			final String avgQBadS=pad(String.format(Locale.ROOT, "%.2f", avgQBad), len);
-			final String avgMapQGoodS=pad(String.format(Locale.ROOT, "%.2f", avgMapQGood), len);
-			final String avgMapQBadS=pad(String.format(Locale.ROOT, "%.2f", avgMapQBad), len);
-			final String avgVarsGoodS=pad(String.format(Locale.ROOT, "%.2f", avgVarsGood), len);
-			final String avgVarsBadS=pad(String.format(Locale.ROOT, "%.2f", avgVarsBad), len);
+			final String avgQGoodS=pad(Tools.format("%.2f", avgQGood), len);
+			final String avgQBadS=pad(Tools.format("%.2f", avgQBad), len);
+			final String avgMapQGoodS=pad(Tools.format("%.2f", avgMapQGood), len);
+			final String avgMapQBadS=pad(Tools.format("%.2f", avgMapQBad), len);
+			final String avgVarsGoodS=pad(Tools.format("%.2f", avgVarsGood), len);
+			final String avgVarsBadS=pad(Tools.format("%.2f", avgVarsBad), len);
 			
 			outstream.println("Time:                         \t\t"+t);
-			outstream.println("Reads Processed:    "+rpstring+" \t"+String.format(Locale.ROOT, "%.2fk reads/sec", rpnano*1000000));
-			outstream.println("Bases Processed:    "+bpstring+" \t"+String.format(Locale.ROOT, "%.2fm bases/sec", bpnano*1000));
+			outstream.println("Reads Processed:    "+rpstring+" \t"+Tools.format("%.2fk reads/sec", rpnano*1000000));
+			outstream.println("Bases Processed:    "+bpstring+" \t"+Tools.format("%.2fm bases/sec", bpnano*1000));
 			outstream.println();
-			outstream.println("Reads Retained:     "+rgstring+" \t"+String.format(Locale.ROOT, "%.2f%%", (rg*100.0/readsProcessed)));
-			outstream.println("Bases Retained:     "+bgstring+" \t"+String.format(Locale.ROOT, "%.2f%%", (bg*100.0/basesProcessed)));
+			outstream.println("Reads Retained:     "+rgstring+" \t"+Tools.format("%.2f%%", (rg*100.0/readsProcessed)));
+			outstream.println("Bases Retained:     "+bgstring+" \t"+Tools.format("%.2f%%", (bg*100.0/basesProcessed)));
 			outstream.println("Avg. Qual Retained: "+avgQGoodS);
 			outstream.println("Avg. MapQ Retained: "+avgMapQGoodS);
 			outstream.println("Avg. Vars Retained: "+avgVarsGoodS);
 			outstream.println();
-			outstream.println("Reads Discarded:    "+rbstring+" \t"+String.format(Locale.ROOT, "%.2f%%", (rb*100.0/readsProcessed)));
-			outstream.println("Bases Discarded:    "+bbstring+" \t"+String.format(Locale.ROOT, "%.2f%%", (bb*100.0/basesProcessed)));
+			outstream.println("Reads Discarded:    "+rbstring+" \t"+Tools.format("%.2f%%", (rb*100.0/readsProcessed)));
+			outstream.println("Bases Discarded:    "+bbstring+" \t"+Tools.format("%.2f%%", (bb*100.0/basesProcessed)));
 			outstream.println("Avg. Qual Discarded:"+avgQBadS);
 			outstream.println("Avg. MapQ Discarded:"+avgMapQBadS);
 			outstream.println("Avg. Vars Discarded:"+avgVarsBadS);
@@ -814,7 +813,7 @@ public class FilterSam {
 	/** True if an error was encountered */
 	public boolean errorState=false;
 	/** Overwrite existing output files */
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	/** Append to existing output files */
 	private boolean append=false;
 	/** Reads are output in input order */
