@@ -2,7 +2,6 @@ package var2;
 
 import java.io.PrintStream;
 import java.util.ArrayList;
-import java.util.Locale;
 import java.util.concurrent.ArrayBlockingQueue;
 
 import fileIO.ByteFile;
@@ -267,7 +266,7 @@ public class MergeSamples {
 			}
 			properPairRate=properlyPairedReads*1.0/(Tools.max(1, reads));
 			bb.append("##properlyPairedReads="+properlyPairedReads+"\n");
-			bb.append("##properPairRate="+String.format(Locale.ROOT, "%.4f\n", properPairRate));
+			bb.append("##properPairRate="+Tools.format("%.4f\n", properPairRate));
 		}else if(matrix[0][0].equals("##properPairRate")){
 			//do nothing
 		}else if(matrix[0][0].equals("##totalQualityAvg")){
@@ -276,21 +275,21 @@ public class MergeSamples {
 				totalQualityAvg+=Float.parseFloat(split[1]);
 			}
 			totalQualityAvg/=lines.length;
-			bb.append("##totalQualityAvg="+String.format(Locale.ROOT, "%.4f\n", totalQualityAvg));
+			bb.append("##totalQualityAvg="+Tools.format("%.4f\n", totalQualityAvg));
 		}else if(matrix[0][0].equals("##mapqAvg")){
 			mapqAvg=0;
 			for(String[] split : matrix){
 				mapqAvg+=Float.parseFloat(split[1]);
 			}
 			mapqAvg/=lines.length;
-			bb.append("##mapqAvg="+String.format(Locale.ROOT, "%.2f\n", mapqAvg));
+			bb.append("##mapqAvg="+Tools.format("%.2f\n", mapqAvg));
 		}else if(matrix[0][0].equals("##readLengthAvg")){
 			readLengthAvg=0;
 			for(String[] split : matrix){
 				readLengthAvg+=Float.parseFloat(split[1]);
 			}
 			readLengthAvg/=lines.length;
-			bb.append("##readLengthAvg="+String.format(Locale.ROOT, "%.2f\n", readLengthAvg));
+			bb.append("##readLengthAvg="+Tools.format("%.2f\n", readLengthAvg));
 		}else if(matrix[0][0].startsWith("#CHROM\tPOS\t")){
 			bb.append(lines[0]);
 			for(int i=1; i<lines.length; i++){
@@ -487,7 +486,7 @@ public class MergeSamples {
 	private PrintStream outstream=System.err;
 	public static boolean verbose=false;
 	public boolean errorState=false;
-	private boolean overwrite=false;
+	private boolean overwrite=true;
 	private boolean append=false;
 	
 }
