@@ -153,6 +153,10 @@ minvalue=               If set, only accept a numeric value of at least this.
 maxvalue=               If set, only accept a numeric value of at most this.
 value=                  If set, only accept a string value of exactly this.
 
+Illumina-specific parameters:
+top=true                Include reads from the top of the flowcell.
+bottom=true             Include reads from the bottom of the flowcell.
+
 Sam and bam processing options:
 
 mappedonly=f            Toss unmapped reads.
