@@ -3,7 +3,7 @@
 usage(){
 echo "
 Written by Brian Bushnell
-Last modified September 25, 2019
+Last modified July 10, 2023
 
 Description:  Reads the entire file to find extended information about the format and contents.
 
@@ -16,9 +16,13 @@ full=t          Process the full file.
 speed=f         Print processing time.
 
 printjunk=f     Print headers of junk reads to stdout.
-printbarcodes=f Print barcodes to stdout.
 zmw=t           Parse PacBio ZMW IDs.
 
+barcodelist=    Optional list of expected barcodes.  May be a filename
+                with one line per barcode, or a comma-delimited literal. 
+printbarcodes=f Print barcodes and counts to stdout.
+edist=f         Calculate barcode edit distance.
+
 printqhist=f    Print quality histogram to stdout.
 printihist=f    Print insert size histogram to stdout.
 
@@ -30,7 +34,6 @@ sketch=t        (card) Calculate cardinality via BBSketch.
                 If enabled, also sends the sketch to the refseq server.
 trim=t          Calculate trimmability from quality.
 
-
 File output parameters (these can be eliminated by setting to null):
 
 junk=junk.txt          Print headers of junk reads to this file.
